(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    667434,      21103]*)
(*NotebookOutlinePosition[    668229,      21130]*)
(*  CellTagsIndexPosition[    668185,      21126]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Modelica Exam 2003-05", "Title"],

Cell[BoxData[
    \(Needs["\<MathModelica`\>"]\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Chaotic System (Lorentz System)", "Section"],

Cell[TextData[StyleBox["Use \[Sigma] = 10, b = 8/3, R = 28 and other values.\n\
 ",
  FontFamily->"Courier New"]], "Text"],

Cell[TextData[{
  "class Lorentz\n  parameter",
  StyleBox[" Real sigma \t= 10;",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t\t// Parameter sigma from the Lorentz system\n  ",
  StyleBox["parameter Real b \t= 8/3;\t",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t\t// Parameter b from the Lorentz system\n  parameter ",
  StyleBox["Real R \t= 28;\t\t            ",
    FontColor->RGBColor[0, 0, 1]],
  "// Parameter R from the Lorentz system\n  Real x (start=1);\n  Real y \
(start=1);\n  Real z (start=1);\n equation\n  der(x) = - sigma * x + sigma * \
y;\n  der(y) = R * x - y - x * z;\n  der(z) = - b * x + x * y;\nend Lorentz;"
}], "ModelicaInput"],

Cell["\<\
class SimulateLorentz
  Lorentz lorentz1;  // the system with default parameters
  Lorentz lorentz2(sigma=1, b=10, R=1); // the system with diffrent \
parameters
  Lorentz lorentz1SC(x(start=1.1),y(start=1.1),z(start=1.1)); // the system \
with diffrent start conditions
  Lorentz lorentz2SC(sigma=1, b=10, R=1, \
x(start=1.1),y(start=1.1),z(start=1.1)); // the system with diffrent \
parameters and diffrent start conditions
end SimulateLorentz;\
\>", "ModelicaInput"],

Cell["\<\

Now we simulate
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simulate[SimulateLorentz, {t, 0, 200}]\)], "Input"],

Cell[BoxData["\<\"<SimulationData: \\!\\(SimulateLorentz\\) : 2003-5-7 \
21:54:21 : \\!\\({0.`, 200.`}\\) : 502 data points : 36 \
variables>\\n\\!\\({\\*TagBox[\\(lorentz1 . b\\), HoldForm], \
\\*TagBox[\\(lorentz1 . R\\), HoldForm], \\*TagBox[\\(lorentz1SC . b\\), \
HoldForm], \\*TagBox[\\(lorentz1SC . R\\), HoldForm], \\*TagBox[\\(lorentz1SC \
. \[Sigma]\\), HoldForm], \\*TagBox[\\(lorentz1SC . x\\), HoldForm], \
\\*TagBox[\\(lorentz1SC . y\\), HoldForm], \\*TagBox[\\(lorentz1SC . z\\), \
HoldForm], \\*TagBox[\\(lorentz1 . \[Sigma]\\), HoldForm], \
\\*TagBox[\\(lorentz1 . x\\), HoldForm], \\*TagBox[\\(lorentz1 . y\\), \
HoldForm], \\*TagBox[\\(lorentz1 . z\\), HoldForm], \\*TagBox[\\(lorentz2 . b\
\\), HoldForm], \\*TagBox[\\(lorentz2 . R\\), HoldForm], \
\\*TagBox[\\(lorentz2SC . b\\), HoldForm], \\*TagBox[\\(lorentz2SC . R\\), \
HoldForm], \\*TagBox[\\(lorentz2SC . \[Sigma]\\), HoldForm], \
\\*TagBox[\\(lorentz2SC . x\\), HoldForm], \\*TagBox[\\(lorentz2SC . y\\), \
HoldForm], \\*TagBox[\\(lorentz2SC . z\\), HoldForm], \\*TagBox[\\(lorentz2 . \
\[Sigma]\\), HoldForm], \\*TagBox[\\(lorentz2 . x\\), HoldForm], \
\\*TagBox[\\(lorentz2 . y\\), HoldForm], \\*TagBox[\\(lorentz2 . z\\), \
HoldForm], \\*TagBox[SuperscriptBox[\\((lorentz1 . x)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\((lorentz1 . y)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\((lorentz1 . z)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\((lorentz1SC . x)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\((lorentz1SC . y)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\((lorentz1SC . z)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\((lorentz2 . x)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\((lorentz2 . y)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\((lorentz2 . z)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\((lorentz2SC . x)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\((lorentz2SC . y)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\((lorentz2SC . z)\\), \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm]}\\)\"\>"], "Output"]
}, Open  ]],

Cell[TextData[{
  "Why is the behaviour chaotic?\nFrom ",
  ButtonBox["http://mathworld.wolfram.com/Chaos.html",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Chaos.html"], None},
    ButtonStyle->"Hyperlink"],
  "\nA ",
  StyleBox["dynamical system",
    FontColor->RGBColor[0, 0, 0.996109],
    FontVariations->{"Underline"->True}],
  " is chaotic if it \n1. Has a ",
  StyleBox["dense",
    FontColor->RGBColor[0, 0, 0.996109],
    FontVariations->{"Underline"->True}],
  " collection of points with periodic orbits, \n2. Is sensitive to the \
initial condition of the system (so that initially nearby points can evolve \
quickly into very different states), and \n3. Is ",
  StyleBox["topologically transitive",
    FontColor->RGBColor[0, 0, 0.996109],
    FontVariations->{"Underline"->True}],
  ". \n\nA: The plots are showing that the small differences in start \
condition for x, y, z  for the instances lorentz1 and lorentz1SC \
(respectively lorentz2 and lorentz2SC) evolve in big differences quickly (3 \
time steps)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ParametricPlot[
        Evaluate[{{lorentz1 . x[t], \ lorentz1 . y[t]}, {lorentz1SC . x[t], \ 
              lorentz1SC . y[t]}}], \ {t, \ 0, \ 
          3}];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot[
        Evaluate[{{lorentz2 . x[t], \ 
              lorentz2 . y[t]}, \ {lorentz2SC . x[t], \ 
              lorentz2SC . y[t]}}], \ {t, \ 0, \ 3}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0434739 0.666708 0.256665 0.253575 [
[.17682 .24416 -9 -9 ]
[.17682 .24416 9 0 ]
[.31016 .24416 -9 -9 ]
[.31016 .24416 9 0 ]
[.4435 .24416 -9 -9 ]
[.4435 .24416 9 0 ]
[.57684 .24416 -9 -9 ]
[.57684 .24416 9 0 ]
[.71018 .24416 -3 -9 ]
[.71018 .24416 3 0 ]
[.84352 .24416 -9 -9 ]
[.84352 .24416 9 0 ]
[.97687 .24416 -9 -9 ]
[.97687 .24416 9 0 ]
[.03097 .00309 -12 -4.5 ]
[.03097 .00309 0 4.5 ]
[.03097 .12988 -24 -4.5 ]
[.03097 .12988 0 4.5 ]
[.03097 .38345 -18 -4.5 ]
[.03097 .38345 0 4.5 ]
[.03097 .51024 -6 -4.5 ]
[.03097 .51024 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17682 .25666 m
.17682 .26291 L
s
[(0.2)] .17682 .24416 0 1 Mshowa
.31016 .25666 m
.31016 .26291 L
s
[(0.4)] .31016 .24416 0 1 Mshowa
.4435 .25666 m
.4435 .26291 L
s
[(0.6)] .4435 .24416 0 1 Mshowa
.57684 .25666 m
.57684 .26291 L
s
[(0.8)] .57684 .24416 0 1 Mshowa
.71018 .25666 m
.71018 .26291 L
s
[(1)] .71018 .24416 0 1 Mshowa
.84352 .25666 m
.84352 .26291 L
s
[(1.2)] .84352 .24416 0 1 Mshowa
.97687 .25666 m
.97687 .26291 L
s
[(1.4)] .97687 .24416 0 1 Mshowa
.125 Mabswid
.07681 .25666 m
.07681 .26041 L
s
.11014 .25666 m
.11014 .26041 L
s
.14348 .25666 m
.14348 .26041 L
s
.21015 .25666 m
.21015 .26041 L
s
.24349 .25666 m
.24349 .26041 L
s
.27682 .25666 m
.27682 .26041 L
s
.34349 .25666 m
.34349 .26041 L
s
.37683 .25666 m
.37683 .26041 L
s
.41016 .25666 m
.41016 .26041 L
s
.47683 .25666 m
.47683 .26041 L
s
.51017 .25666 m
.51017 .26041 L
s
.54351 .25666 m
.54351 .26041 L
s
.61018 .25666 m
.61018 .26041 L
s
.64351 .25666 m
.64351 .26041 L
s
.67685 .25666 m
.67685 .26041 L
s
.74352 .25666 m
.74352 .26041 L
s
.77685 .25666 m
.77685 .26041 L
s
.81019 .25666 m
.81019 .26041 L
s
.87686 .25666 m
.87686 .26041 L
s
.91019 .25666 m
.91019 .26041 L
s
.94353 .25666 m
.94353 .26041 L
s
.01014 .25666 m
.01014 .26041 L
s
.25 Mabswid
0 .25666 m
1 .25666 L
s
.04347 .00309 m
.04972 .00309 L
s
[(-1)] .03097 .00309 1 0 Mshowa
.04347 .12988 m
.04972 .12988 L
s
[(-0.5)] .03097 .12988 1 0 Mshowa
.04347 .38345 m
.04972 .38345 L
s
[(0.5)] .03097 .38345 1 0 Mshowa
.04347 .51024 m
.04972 .51024 L
s
[(1)] .03097 .51024 1 0 Mshowa
.125 Mabswid
.04347 .02845 m
.04722 .02845 L
s
.04347 .0538 m
.04722 .0538 L
s
.04347 .07916 m
.04722 .07916 L
s
.04347 .10452 m
.04722 .10452 L
s
.04347 .15523 m
.04722 .15523 L
s
.04347 .18059 m
.04722 .18059 L
s
.04347 .20595 m
.04722 .20595 L
s
.04347 .23131 m
.04722 .23131 L
s
.04347 .28202 m
.04722 .28202 L
s
.04347 .30738 m
.04722 .30738 L
s
.04347 .33274 m
.04722 .33274 L
s
.04347 .35809 m
.04722 .35809 L
s
.04347 .40881 m
.04722 .40881 L
s
.04347 .43417 m
.04722 .43417 L
s
.04347 .45952 m
.04722 .45952 L
s
.04347 .48488 m
.04722 .48488 L
s
.04347 .5356 m
.04722 .5356 L
s
.04347 .56095 m
.04722 .56095 L
s
.04347 .58631 m
.04722 .58631 L
s
.04347 .61167 m
.04722 .61167 L
s
.25 Mabswid
.04347 0 m
.04347 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.71019 .51024 m
0 0 rlineto s
.71019 .51024 m
1 .4732 L
s
1 .60095 m
.99172 .60116 L
.96008 .60183 L
.93133 .60234 L
.9057 .60271 L
.87779 .60302 L
.84861 .60323 L
.82232 .60332 L
.79858 .60331 L
.77305 .6032 L
.74663 .60297 L
.72418 .60268 L
.7036 .60233 L
.65824 .60127 L
.63456 .60054 L
.60999 .59965 L
.56747 .59775 L
.51962 .59501 L
.47877 .59209 L
.4049 .58517 L
.34324 .57732 L
.2904 .56856 L
.24761 .55957 L
.2067 .54876 L
.17007 .53635 L
.13962 .52293 L
.11716 .50997 L
.10679 .50253 L
.09711 .49425 L
.09003 .48693 L
.08355 .4787 L
.07878 .47099 L
.0753 .46366 L
.07387 .45985 L
.07263 .45581 L
.07158 .45136 L
.07088 .44726 L
.07047 .44368 L
.07025 .43985 L
.07023 .43621 L
.07037 .4329 L
.07072 .42899 L
.07132 .42474 L
.0721 .42071 L
.07299 .41699 L
.07561 .40855 L
.07936 .39932 L
.08842 .38247 L
.10206 .36304 L
.11708 .34542 L
Mistroke
.12522 .33684 L
.13329 .32883 L
.13747 .32484 L
.13751 .32205 L
.13523 .32133 L
.13286 .32057 L
.1287 .31923 L
.1017 .31027 L
.06127 .29535 L
.03554 .2834 L
.03127 .28079 L
.02819 .27856 L
.02615 .27674 L
.02536 .27586 L
.02468 .27494 L
.02444 .27454 L
.02423 .27413 L
.02408 .27378 L
.02395 .27341 L
.02386 .273 L
.02381 .27262 L
.02381 .27227 L
.02384 .27195 L
.02391 .27163 L
.024 .27134 L
.02411 .27109 L
.02426 .27082 L
.02468 .27025 L
.02518 .26975 L
.02588 .26922 L
.02662 .26877 L
.02753 .26832 L
.02866 .26787 L
.03095 .26715 L
.03344 .26658 L
.03673 .26602 L
.04057 .26555 L
.04242 .26537 L
.04442 .26522 L
.04617 .2651 L
.04718 .26504 L
.04704 .26483 L
.04672 .26459 L
.04642 .26437 L
.04589 .26397 L
.04478 .26311 L
.04284 .26155 L
.04051 .25939 L
.03981 .25857 L
.03959 .25822 L
Mistroke
.03949 .25805 L
.03943 .2579 L
.03941 .25785 L
.03939 .25778 L
.03938 .25773 L
.03937 .25768 L
.03936 .25762 L
.03936 .25757 L
.03936 .25752 L
.03937 .25747 L
.03938 .25743 L
.03939 .25739 L
.03941 .25736 L
.03943 .25733 L
.03945 .25729 L
.03948 .25726 L
.03954 .2572 L
.03962 .25715 L
.03967 .25712 L
.03972 .2571 L
.03978 .25708 L
.03983 .25706 L
.03995 .25704 L
.04002 .25702 L
.04006 .25702 L
.04011 .25701 L
.04015 .25701 L
.04019 .25701 L
.04023 .25701 L
.04027 .257 L
.04036 .257 L
.0404 .257 L
.04045 .257 L
.04053 .257 L
.04058 .257 L
.04062 .25701 L
.04071 .25701 L
.04081 .25702 L
.04099 .25704 L
.04136 .25708 L
.04181 .25716 L
.04225 .25725 L
.04268 .25735 L
.04279 .25738 L
.04292 .25741 L
.04302 .25743 L
.043 .2574 L
.04294 .2572 L
.04291 .2571 L
.04288 .25701 L
Mistroke
.04287 .25693 L
.04286 .25689 L
.04285 .25686 L
.04285 .25683 L
.04285 .25681 L
.04285 .2568 L
.04285 .2568 L
.04285 .25678 L
.04285 .25677 L
.04285 .25676 L
.04285 .25674 L
.04285 .25674 L
.04285 .25673 L
.04285 .25672 L
.04285 .25671 L
.04285 .2567 L
.04286 .25668 L
.04286 .25667 L
.04287 .25666 L
.04287 .25664 L
.04288 .25663 L
.04289 .25661 L
.0429 .2566 L
.04291 .25659 L
.04292 .25659 L
.04293 .25658 L
.04295 .25657 L
.04296 .25657 L
.04297 .25657 L
.04297 .25657 L
.04298 .25657 L
.04299 .25657 L
.04299 .25657 L
.043 .25657 L
.04301 .25657 L
.04302 .25657 L
.04302 .25657 L
.04303 .25657 L
.04305 .25657 L
.04307 .25658 L
.0431 .25659 L
.04314 .2566 L
.04321 .25663 L
.04329 .25667 L
.04331 .25669 L
.04332 .2567 L
.04333 .2567 L
.04334 .25671 L
.04334 .2567 L
.04335 .2567 L
Mistroke
.04336 .25668 L
.04338 .25667 L
.04339 .25665 L
.0434 .25665 L
.0434 .25664 L
.04341 .25664 L
.04341 .25664 L
.04341 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04343 .25664 L
.04343 .25664 L
.04343 .25664 L
.04343 .25664 L
.04343 .25664 L
.04343 .25664 L
.04344 .25664 L
.04344 .25664 L
.04344 .25665 L
.04345 .25665 L
.04345 .25666 L
.04345 .25666 L
.04345 .25666 L
.04345 .25666 L
.04346 .25666 L
.04346 .25666 L
.04346 .25666 L
.04346 .25666 L
.04346 .25666 L
.04346 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
Mistroke
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
Mfstroke
.77686 .5356 m
0 0 rlineto s
.77686 .5356 m
1 .48725 L
s
1 .54216 m
.91241 .55004 L
.80743 .55768 L
.75962 .5605 L
.71036 .56292 L
.66597 .56462 L
.62707 .5657 L
.60768 .56607 L
.58746 .56635 L
.56883 .56648 L
.55228 .5665 L
.53327 .5664 L
.52276 .56629 L
.51322 .56615 L
.49601 .5658 L
.47827 .56531 L
.46175 .56472 L
.44449 .56395 L
.41458 .56224 L
.3811 .55967 L
.35245 .55683 L
.29998 .54972 L
.27343 .54492 L
.25075 .54001 L
.21386 .52989 L
.18091 .51765 L
.15372 .50382 L
.13397 .49 L
.12551 .48237 L
.11766 .47373 L
.11098 .46442 L
.10609 .4555 L
.10427 .45137 L
.10259 .44683 L
.10134 .44279 L
.10026 .43846 L
.09949 .43453 L
.09886 .43018 L
.09849 .42618 L
.09831 .42241 L
.09831 .41792 L
.09838 .41565 L
.09853 .41317 L
.09895 .40874 L
.09951 .40461 L
.10039 .39968 L
.10138 .39519 L
.10425 .38505 L
.11122 .36725 L
.12104 .34834 L
Mistroke
.13127 .33201 L
.13421 .32772 L
.13751 .32306 L
.14072 .31867 L
.14026 .31622 L
.13603 .3151 L
.13164 .31392 L
.12413 .31188 L
.11039 .30805 L
.08367 .3001 L
.04992 .28824 L
.04036 .28397 L
.03619 .28178 L
.03308 .27989 L
.0305 .27799 L
.02882 .27639 L
.02815 .27556 L
.02768 .27481 L
.02749 .27441 L
.02735 .27405 L
.02724 .27366 L
.0272 .27347 L
.02717 .27327 L
.02716 .27308 L
.02715 .27287 L
.02718 .27251 L
.02725 .27216 L
.02735 .27185 L
.02751 .27148 L
.02769 .27116 L
.02824 .27048 L
.02886 .26991 L
.02967 .26933 L
.03148 .26837 L
.04234 .26547 L
.04604 .26491 L
.04714 .26477 L
.04769 .2647 L
.04798 .26461 L
.04762 .26438 L
.04724 .26413 L
.04479 .26245 L
.04168 .2601 L
.04066 .25918 L
.04027 .25877 L
.03997 .2584 L
.03979 .25811 L
.03972 .25796 L
.0397 .25789 L
.03968 .25783 L
Mistroke
.03967 .25778 L
.03966 .25773 L
.03966 .25768 L
.03966 .25764 L
.03966 .2576 L
.03967 .25756 L
.03968 .25754 L
.03968 .25751 L
.0397 .25747 L
.03972 .25744 L
.03975 .25741 L
.03978 .25737 L
.03981 .25734 L
.03988 .25729 L
.03997 .25724 L
.04006 .25721 L
.04017 .25718 L
.04022 .25717 L
.04028 .25716 L
.0404 .25714 L
.04047 .25713 L
.04051 .25713 L
.04055 .25713 L
.04062 .25712 L
.0407 .25712 L
.04077 .25712 L
.04084 .25712 L
.04092 .25712 L
.041 .25712 L
.04109 .25713 L
.0412 .25713 L
.04139 .25715 L
.04178 .25719 L
.04217 .25725 L
.0426 .25732 L
.0428 .25736 L
.04291 .25738 L
.04302 .2574 L
.04311 .25742 L
.04311 .2574 L
.04309 .25738 L
.04308 .25735 L
.04299 .25714 L
.04293 .25698 L
.04291 .25691 L
.0429 .25688 L
.04289 .25684 L
.04289 .25681 L
.04289 .2568 L
.04289 .25678 L
Mistroke
.04288 .25677 L
.04288 .25676 L
.04288 .25675 L
.04288 .25674 L
.04288 .25673 L
.04288 .25672 L
.04288 .25672 L
.04288 .25671 L
.04289 .2567 L
.04289 .25669 L
.04289 .25668 L
.04289 .25667 L
.0429 .25665 L
.0429 .25664 L
.04291 .25663 L
.04292 .25662 L
.04293 .25661 L
.04294 .2566 L
.04295 .2566 L
.04296 .25659 L
.04297 .25659 L
.04298 .25659 L
.04298 .25659 L
.04299 .25659 L
.043 .25658 L
.043 .25658 L
.04301 .25658 L
.04302 .25658 L
.04302 .25658 L
.04303 .25658 L
.04303 .25658 L
.04304 .25659 L
.04305 .25659 L
.04306 .25659 L
.04308 .25659 L
.04311 .2566 L
.04315 .25661 L
.0433 .25668 L
.04332 .25669 L
.04333 .2567 L
.04334 .2567 L
.04335 .25671 L
.04335 .25671 L
.04335 .2567 L
.04336 .2567 L
.04336 .25669 L
.04337 .25668 L
.04339 .25666 L
.0434 .25665 L
.0434 .25665 L
Mistroke
.04341 .25664 L
.04341 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04342 .25664 L
.04343 .25664 L
.04343 .25664 L
.04343 .25664 L
.04343 .25664 L
.04343 .25664 L
.04343 .25664 L
.04344 .25664 L
.04344 .25665 L
.04344 .25665 L
.04345 .25665 L
.04345 .25666 L
.04345 .25666 L
.04345 .25666 L
.04346 .25666 L
.04346 .25666 L
.04346 .25666 L
.04346 .25666 L
.04346 .25666 L
.04346 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
.04347 .25666 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@004`3IfMT500000?l0fMWI2@3IfMT001D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@3o0=WIf@<0fMWI000E0=WIf@030000003IfMT0fMWI00<0fMWI0`00003o0=WIf@<0fMWI
000=0=WIf@@00000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0?l0fMWI0`3I
fMT001D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI000D0=WI
f@8000001@3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI000K0=WIf@030000003IfMT0fMWI0?l0
fMWI0`3IfMT001/0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WIf@006`3IfMT00`000000fMWI0=WI
f@3o0=WIf@<0fMWI000K0=WIf@800000o`3IfMT40=WIf@006`3IfMT00`000000fMWI0=WIf@3o0=WI
f@<0fMWI000K0=WIf@030000003IfMT0fMWI0?l0fMWI0`3IfMT001/0fMWI00<000000=WIf@3IfMT0
o`3IfMT30=WIf@006`3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI000K0=WIf@030000003IfMT0
fMWI0?l0fMWI0`3IfMT001/0fMWI0P00003o0=WIf@@0fMWI000K0=WIf@030000003IfMT0fMWI0?l0
fMWI0`3IfMT001/0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WIf@006`3IfMT00`000000fMWI0=WI
f@3o0=WIf@<0fMWI000K0=WIf@030000003IfMT0fMWI0?l0fMWI0`3IfMT001/0fMWI00<000000=WI
f@3IfMT0o`3IfMT30=WIf@006`3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI000K0=WIf@800000
o`3IfMT40=WIf@006`3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI000K0=WIf@030000003IfMT0
fMWI0?l0fMWI0`3IfMT001/0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WIf@006`3IfMT00`000000
fMWI0=WIf@3o0=WIf@<0fMWI000K0=WIf@030000003IfMT0fMWI0?l0fMWI0`3IfMT001/0fMWI00<0
00000=WIf@3IfMT0o`3IfMT30=WIf@006`3IfMT200000?l0fMWI103IfMT001/0fMWI00<000000=WI
f@3IfMT0o`3IfMT30=WIf@006`3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI000K0=WIf@030000
003IfMT0fMWI0?l0fMWI0`3IfMT001/0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WIf@00203IfMT2
000000@0fMWI0P0000040=WIf@8000001@3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI00070=WI
f@040000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WI
f@3o0=WIf@<0fMWI00070=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00P3I
fMT300000?l0fMWI0`3IfMT000030=WIf@0000000000008000000P3IfMT010000000fMWI0=WIf@00
00090=WIf@8000001@3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI00070=WIf@040000003IfMT0
fMWI000000T0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI0008
0=WIf@8000002P3IfMT3000000@0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WIf@006`3IfMT00`00
0000fMWI0=WIf@3o0=WIf@<0fMWI000K0=WIf@030000003IfMT0fMWI0?l0fMWI0`3IfMT001/0fMWI
00<000000=WIf@3IfMT0o`3IfMT30=WIf@006`3IfMT200000?l0fMWI103IfMT001/0fMWI00<00000
0=WIf@3IfMT0o`3IfMT30=WIf@006`3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI000K0=WIf@03
0000003IfMT0fMWI0?l0fMWI0`3IfMT001/0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WIf@006`3I
fMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI000K0=WIf@800000o`3IfMT40=WIf@006`3IfMT00`00
0000fMWI0=WIf@3o0=WIf@<0fMWI000K0=WIf@030000003IfMT0fMWI0?l0fMWI0`3IfMT001/0fMWI
00<000000=WIf@3IfMT0o`3IfMT30=WIf@006`3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI000K
0=WIf@030000003IfMT0fMWI0?l0fMWI0`3IfMT001/0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WI
f@006`3IfMT200000?l0fMWI103IfMT001/0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WIf@006`3I
fMT00`000000fMWI0=WIf@0J0=WIf@800000103IfMT2000000<0fMWI1000000D0=WIf@800000103I
fMT2000000D0fMWI0`00000D0=WIf@800000103IfMT2000000<0fMWI0`00000F0=WIf@800000103I
fMT2000000@0fMWI0P00000K0=WIf@D000006@3IfMT500000080fMWI0P0000030=WIf@@00000503I
fMT500000080fMWI0P0000050=WIf@<000000@3IfMT001/0fMWI00<000000=WIf@3IfMT06@3IfMT0
10000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI01@0fMWI00@000000=WIf@3IfMT00000
2`3IfMT00`000000fMWI0=WIf@0B0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WIf@3I
fMT00000503IfMT010000000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI000001`0fMWI00<0
00000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01L0fMWI00<0
00000=WIf@3IfMT02P3IfMT100000040fMWI0@3IfMT001/0fMWI00<000000=WIf@3IfMT06@3IfMT0
10000000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI01<0fMWI00@000000=WIf@3IfMT00000
203IfMT5000001<0fMWI00@000000=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@00000D0=WI
f@040000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT00000703IfMT00`000000fMWI0=WI
f@0K0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WI
f@070=WIf@D000000@3IfMT001/0fMWI00<000000=WIf@3IfMT06@3IfMT010000000fMWI0=WIf@00
000:0=WIf@030000003IfMT0fMWI0180fMWI00@000000=WIf@3IfMT00000203IfMT010000000fMWI
0=WIf@00000D0=WIf@040000003IfMT0fMWI000000P0fMWI0`00000E0=WIf@040000003IfMT0fMWI
000000T0fMWI0P00000M0=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT02@3IfMT0
0`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI00L0fMWI00@000000=WIf@3IfMT000000P3I
fMT001/0fMWI00<000000=WIf@3IfMT06@3IfMT010000000fMWI0=WIf@0000080=WIf@040000003I
fMT0fMWI000001<0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0000000D0=WIf@04
0000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT0503IfMT010000000fMWI0=WIf@000008
0=WIf@040000003IfMT0fMWI000001`0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WI
f@070=WIf@040000003IfMT0fMWI000001H0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
000000020=WIf@006`3IfMT2000001/0fMWI0P00000:0=WIf@8000005@3IfMT2000000/0fMWI0P00
000E0=WIf@8000002P3IfMT3000001D0fMWI0P00000:0=WIf@800000703IfMT2000001`0fMWI0P00
000:0=WIf@8000005P3IfMT2000000/0fMWI0P0000020=WIf@006`3IfMT00`000000fMWI0=WIf@3o
0=WIf@<0fMWI000K0=WIf@030000003IfMT0fMWI0?l0fMWI0`3IfMT001/0fMWI00<000000=WIf@3I
fMT0o`3IfMT30=WIf@006`3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI000K0=WIf@030000003I
fMT0fMWI0?l0fMWI0`3IfMT001/0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WIf@003`3IfMWo0000
00l000000`3IfMT00180fMWI00<000000=WIf@3IfMT01@3IfMT2000000P0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01`3IfMT001P0fMWI1@00003o0=WIf@@0fMWI000F0=WIf@@0000000<0fMWI0000003IfMT0o`3I
fMT40=WIf@005P3IfMT2000000<0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WIf@005P3IfMT20000
00<0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WIf@005`3IfMT200000080fMWI00<000000=WIf@3I
fMT0o`3IfMT30=WIf@006@3IfMT400000?l0fMWI103IfMT001/0fMWI1000003o0=WIf@80fMWI000K
0=WIf@030000003IfMT0000000@00000oP3IfMT001/0fMWI00@000000=WIf@3IfMT0fMWI1P00003k
0=WIf@006`3IfMT00`000000fMWI0=WIf@040=WIf@80000000@0fMWI0000000000000000n03IfMT0
01/0fMWI00<000000=WIf@3IfMT01P3IfMT3000000030=WIf@00000000000?H0fMWI000K0=WIf@80
00002P3IfMT2000000030=WIf@00000000000?@0fMWI000K0=WIf@030000003IfMT0fMWI00/0fMWI
1`00003`0=WIf@006`3IfMT00`000000fMWI0=WIf@0>0=WIf@<0000000<0fMWI0000000000000`00
003[0=WIf@006`3IfMT00`000000fMWI0=WIf@0A0=WIf@800000103IfMT00`000000fMWI0=WIf@3X
0=WIf@006`3IfMT00`000000fMWI0=WIf@0C0=WIf@D00000jP3IfMT001/0fMWI00<000000=WIf@3I
fMT05P3IfMT00`000000fMWI0=WIf@3Y0=WIf@006`3IfMT00`000000fMWI0=WIf@0E0=WIf@030000
003IfMT0fMWI0>X0fMWI000K0=WIf@8000005@3IfMT00`000000fMWI0=WIf@3[0=WIf@006`3IfMT0
0`000000fMWI0=WIf@0C0=WIf@800000k@3IfMT001/0fMWI00<000000=WIf@3IfMT04P3IfMT20000
0>h0fMWI000K0=WIf@030000003IfMT0fMWI0180fMWI0P00003^0=WIf@006`3IfMT00`000000fMWI
0=WIf@0A0=WIf@800000k`3IfMT001/0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0000
003_0=WIf@006`3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT000000?00fMWI000K0=WI
f@8000003`3IfMT010000000fMWI0=WIf@00003`0=WIf@006`3IfMT00`000000fMWI0=WIf@0=0=WI
f@040000003IfMT0fMWI00000?40fMWI000K0=WIf@030000003IfMT0fMWI00`0fMWI00D000000=WI
f@3IfMT0fMWI0000003a0=WIf@006`3IfMT00`000000fMWI0=WIf@0<0=WIf@040000003IfMT0fMWI
00000?80fMWI000K0=WIf@030000003IfMT0fMWI00/0fMWI00D000000=WIf@3IfMT0fMWI0000003b
0=WIf@00203IfMT2000000@0fMWI0P0000040=WIf@8000001@3IfMT00`000000fMWI0=WIf@0:0=WI
f@050000003IfMT0fMWI0=WIf@000000l`3IfMT000L0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI00X0fMWI00D000000=WIf@3IfMT0fMWI
0000003c0=WIf@001`3IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI0080fMWI
0`0000090=WIf@050000003IfMT0fMWI0=WIf@000000m03IfMT000L0fMWI00@000000=WIf@3IfMT0
00002@3IfMT2000000D0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0?80fMWI00070=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@080=WIf@050000003IfMT0fMWI0=WIf@000000m@3IfMT000P0
fMWI0P00000:0=WIf@<00000103IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0l`3IfMT001/0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI
0=WIf@030=WIf@030000003IfMT0fMWI0?<0fMWI000K0=WIf@030000003IfMT0fMWI00H0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@3c0=WIf@006`3IfMT00`000000fMWI0=WIf@05
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0l`3IfMT001/0fMWI0P0000060=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0l`3IfMT001/0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?<0fMWI000K0=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@3c0=WIf@006`3I
fMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0l`3I
fMT001/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0
fMWI0?<0fMWI000K0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI0=WIf@3c0=WIf@006`3IfMT2000000D0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@3c0=WIf@006`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00D0fMWI
00<000000=WIf@3IfMT0l`3IfMT001/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI0?<0fMWI000K0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3c0=WIf@006`3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0lP3IfMT001/0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0?80fMWI000K0=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@3a0=WIf@006`3I
fMT2000000H0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@3a0=WIf@006`3IfMT0
0`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0l03IfMT0
01/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
0?00fMWI000K0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000
fMWI0=WIf@3_0=WIf@006`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT0i`3IfMT4000000<0fMWI000K0=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3N0=WIf@P000001`3IfMT001/0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=D0fMWI2000000?
0=WIf@006`3IfMT2000000X0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3<0=WI
f@P000005`3IfMT001/0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI0<<0fMWI2000000I0=WIf@<000000`3IfMT001/0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI0;/0fMWI1`00000M0=WIf@@00000
1P3IfMT001/0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@090=WIf@800000/`3I
fMT8000001l0fMWI1@00000:0=WIf@006`3IfMT00`000000fMWI0=WIf@0<0=WIf@8000002`3IfMT0
0`000000fMWI0=WIf@2X0=WIf@P000008P3IfMT5000000l0fMWI000C0=WIf@D000000`3IfMT00`00
0000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00T0fMWI0P00002P0=WIf@P000009P3IfMT40000
01@0fMWI000E0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT03`3IfMT2000000/0
fMWI0P00002F0=WIf@P00000:@3IfMT5000001P0fMWI000E0=WIf@030000003IfMT0fMWI00<0fMWI
0`00000A0=WIf@8000002`3IfMT200000900fMWI1000000/0=WIf@D000007@3IfMT001D0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0C0=WIf@8000002`3IfMT200000;X0fMWI1000
000R0=WIf@005@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI01D0fMWI0P00000;
0=WIf@800000/`3IfMT5000002H0fMWI000D0=WIf@8000001@3IfMT00`000000fMWI0=WIf@0G0=WI
f@8000002`3IfMT300000:`0fMWI1000000[0=WIf@006`3IfMT00`000000fMWI0=WIf@0I0=WIf@80
0000303IfMT300000:@0fMWI1@00000_0=WIf@006`3IfMT00`000000fMWI0=WIf@0K0=WIf@800000
3@3IfMT3000009`0fMWI1@00000d0=WIf@006`3IfMT00`000000fMWI0=WIf@0M0=WIf@8000003P3I
fMT400000940fMWI00<000000=WIf@3IfMT01000000i0=WIf@006`3IfMT200000200fMWI0P00000@
0=WIf@<00000SP3IfMT3000003d0fMWI000K0=WIf@030000003IfMT0fMWI0240fMWI1000000?0=WI
f@D00000`P3IfMT4000000<0fMWI000K0=WIf@030000003IfMT0fMWI02D0fMWI0`00000A0=WIf@H0
0000]03IfMT8000000L0fMWI000K0=WIf@030000003IfMT0fMWI02P0fMWI0`00000D0=WIf@L00000
Y@3IfMT8000000l0fMWI000K0=WIf@030000003IfMT0fMWI02/0fMWI1000000G0=WIf@L00000T`3I
fMT;000001L0fMWI000K0=WIf@030000003IfMT0fMWI02l0fMWI1000000J0=WIf@P00000O@3IfMT>
00000280fMWI000K0=WIf@030000003IfMT0fMWI03<0fMWI0`00000O0=WIf@P00000FP3IfMTK0000
0300fMWI000K0=WIf@800000=`3IfMT4000002<0fMWI3`00000o0=WIf@`00000B`3IfMT001/0fMWI
00<000000=WIf@3IfMT0>P3IfMT4000002h0fMWI?`00001G0=WIf@006`3IfMT00`000000fMWI0=WI
f@0n0=WIf@D00000_`3IfMT001/0fMWI00<000000=WIf@3IfMT0@`3IfMT700000;P0fMWI000K0=WI
f@030000003IfMT0fMWI04X0fMWI2000002`0=WIf@006`3IfMT00`000000fMWI0=WIf@1B0=WIf@P0
0000Z03IfMT001/0fMWI0P00001K0=WIf@X00000WP3IfMT001/0fMWI00<000000=WIf@3IfMT0I03I
fMT:000009@0fMWI000K0=WIf@030000003IfMT0fMWI06h0fMWI2P00002:0=WIf@006`3IfMT00`00
0000fMWI0=WIf@1h0=WIfAP00000LP3IfMT001/0fMWI00<000000=WIf@3IfMT0T03IfMTI000004L0
fMWI3`0000030=WIf@006`3IfMT00`000000fMWI0=WIf@2Y0=WIfDL000004P3IfMT001/0fMWI00<0
00000=WIf@3IfMT0o`3IfMT30=WIf@006`3IfMT200000?l0fMWI103IfMT001/0fMWI00<000000=WI
f@3IfMT0o`3IfMT30=WIf@006`3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI003o0=WIfB40fMWI
003o0=WIfB40fMWI003o0=WIfB40fMWI0000\
\>"],
  ImageRangeCache->{{{138, 425}, {671.938, 495}} -> {-0.923651, 6.1499, \
0.00558573, 0.0146862}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.102447 0.0147151 0.0331052 [
[.2287 .00222 -3 -9 ]
[.2287 .00222 3 0 ]
[.4336 .00222 -3 -9 ]
[.4336 .00222 3 0 ]
[.63849 .00222 -3 -9 ]
[.63849 .00222 3 0 ]
[.84338 .00222 -3 -9 ]
[.84338 .00222 3 0 ]
[.01131 .09748 -18 -4.5 ]
[.01131 .09748 0 4.5 ]
[.01131 .18024 -6 -4.5 ]
[.01131 .18024 0 4.5 ]
[.01131 .263 -18 -4.5 ]
[.01131 .263 0 4.5 ]
[.01131 .34577 -12 -4.5 ]
[.01131 .34577 0 4.5 ]
[.01131 .42853 -24 -4.5 ]
[.01131 .42853 0 4.5 ]
[.01131 .51129 -12 -4.5 ]
[.01131 .51129 0 4.5 ]
[.01131 .59406 -24 -4.5 ]
[.01131 .59406 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2287 .01472 m
.2287 .02097 L
s
[(2)] .2287 .00222 0 1 Mshowa
.4336 .01472 m
.4336 .02097 L
s
[(4)] .4336 .00222 0 1 Mshowa
.63849 .01472 m
.63849 .02097 L
s
[(6)] .63849 .00222 0 1 Mshowa
.84338 .01472 m
.84338 .02097 L
s
[(8)] .84338 .00222 0 1 Mshowa
.125 Mabswid
.07503 .01472 m
.07503 .01847 L
s
.12626 .01472 m
.12626 .01847 L
s
.17748 .01472 m
.17748 .01847 L
s
.27993 .01472 m
.27993 .01847 L
s
.33115 .01472 m
.33115 .01847 L
s
.38237 .01472 m
.38237 .01847 L
s
.48482 .01472 m
.48482 .01847 L
s
.53604 .01472 m
.53604 .01847 L
s
.58727 .01472 m
.58727 .01847 L
s
.68971 .01472 m
.68971 .01847 L
s
.74094 .01472 m
.74094 .01847 L
s
.79216 .01472 m
.79216 .01847 L
s
.89461 .01472 m
.89461 .01847 L
s
.94583 .01472 m
.94583 .01847 L
s
.99706 .01472 m
.99706 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09748 m
.03006 .09748 L
s
[(2.5)] .01131 .09748 1 0 Mshowa
.02381 .18024 m
.03006 .18024 L
s
[(5)] .01131 .18024 1 0 Mshowa
.02381 .263 m
.03006 .263 L
s
[(7.5)] .01131 .263 1 0 Mshowa
.02381 .34577 m
.03006 .34577 L
s
[(10)] .01131 .34577 1 0 Mshowa
.02381 .42853 m
.03006 .42853 L
s
[(12.5)] .01131 .42853 1 0 Mshowa
.02381 .51129 m
.03006 .51129 L
s
[(15)] .01131 .51129 1 0 Mshowa
.02381 .59406 m
.03006 .59406 L
s
[(17.5)] .01131 .59406 1 0 Mshowa
.125 Mabswid
.02381 .03127 m
.02756 .03127 L
s
.02381 .04782 m
.02756 .04782 L
s
.02381 .06437 m
.02756 .06437 L
s
.02381 .08093 m
.02756 .08093 L
s
.02381 .11403 m
.02756 .11403 L
s
.02381 .13058 m
.02756 .13058 L
s
.02381 .14714 m
.02756 .14714 L
s
.02381 .16369 m
.02756 .16369 L
s
.02381 .19679 m
.02756 .19679 L
s
.02381 .21335 m
.02756 .21335 L
s
.02381 .2299 m
.02756 .2299 L
s
.02381 .24645 m
.02756 .24645 L
s
.02381 .27956 m
.02756 .27956 L
s
.02381 .29611 m
.02756 .29611 L
s
.02381 .31266 m
.02756 .31266 L
s
.02381 .32921 m
.02756 .32921 L
s
.02381 .36232 m
.02756 .36232 L
s
.02381 .37887 m
.02756 .37887 L
s
.02381 .39542 m
.02756 .39542 L
s
.02381 .41198 m
.02756 .41198 L
s
.02381 .44508 m
.02756 .44508 L
s
.02381 .46163 m
.02756 .46163 L
s
.02381 .47819 m
.02756 .47819 L
s
.02381 .49474 m
.02756 .49474 L
s
.02381 .52785 m
.02756 .52785 L
s
.02381 .5444 m
.02756 .5444 L
s
.02381 .56095 m
.02756 .56095 L
s
.02381 .5775 m
.02756 .5775 L
s
.02381 .61061 m
.02756 .61061 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.12626 .04782 m
.12643 .04808 L
.12656 .0483 L
.12668 .04855 L
.12676 .04877 L
.12679 .04887 L
.12682 .04899 L
.12684 .04909 L
.12685 .04919 L
.12685 .04924 L
.12686 .04929 L
.12686 .04935 L
.12686 .04938 L
.12686 .0494 L
.12686 .04946 L
.12686 .04949 L
.12686 .04952 L
.12686 .04957 L
.12686 .0496 L
.12686 .04963 L
.12686 .04969 L
.12685 .04975 L
.12684 .04987 L
.12682 .05011 L
.12678 .05038 L
.12674 .05069 L
.12673 .05085 L
.12671 .05101 L
.1267 .05117 L
.12669 .05133 L
.12668 .05149 L
.12668 .05157 L
.12667 .05166 L
.12667 .05175 L
.12667 .05181 L
.12667 .05186 L
.12667 .05195 L
.12667 .05205 L
.12668 .05215 L
.12668 .05226 L
.12669 .05247 L
.12671 .05268 L
.12673 .05289 L
.12679 .05338 L
.12689 .05396 L
.12713 .05505 L
.12753 .05645 L
.1289 .06006 L
.13139 .0653 L
.14047 .08083 L
Mistroke
.15605 .10392 L
.17669 .13566 L
.20931 .18135 L
.25672 .23847 L
.34219 .3395 L
.45724 .46688 L
.51229 .51786 L
.57224 .56363 L
.60029 .58069 L
.62961 .59488 L
.63777 .59807 L
.64542 .60073 L
.64873 .60178 L
.65222 .60281 L
.65404 .60332 L
.65583 .60257 L
.65865 .59912 L
.68006 .56954 L
.71781 .50259 L
.75395 .42052 L
.81154 .2551 L
.82271 .21921 L
.83344 .1844 L
.83822 .16907 L
.84045 .16196 L
.84245 .15568 L
.84422 .15019 L
.84506 .14789 L
.84563 .14972 L
.84774 .15778 L
.85132 .17704 L
.85297 .18944 L
.85427 .20164 L
.85531 .21366 L
.85627 .22741 L
.85763 .25392 L
.85816 .26887 L
.85856 .28324 L
.8589 .29929 L
.85904 .30841 L
.85915 .31683 L
.85924 .32457 L
.85931 .33286 L
.85936 .34196 L
.8594 .35043 L
.85942 .355 L
.85943 .35994 L
.85944 .36221 L
.85944 .3646 L
.85944 .36889 L
Mistroke
.85945 .37299 L
.85945 .37682 L
.85945 .38101 L
.85945 .38335 L
.85945 .38549 L
.85944 .38962 L
.85944 .3935 L
.85943 .40068 L
.85943 .40898 L
.85942 .41258 L
.85942 .41651 L
.85942 .4199 L
.85942 .42304 L
.85942 .42633 L
.85942 .42983 L
.85942 .43363 L
.85942 .43719 L
.85943 .44036 L
.85944 .44377 L
.85945 .44744 L
.85946 .45085 L
.85948 .45485 L
.8595 .45847 L
.85956 .46569 L
.85964 .47324 L
.85972 .47913 L
.85983 .48536 L
.85998 .49165 L
.86013 .49721 L
.86021 .49992 L
.8604 .50206 L
.86112 .50018 L
.86192 .49803 L
.86477 .48997 L
.87035 .47255 L
.8839 .42453 L
.91245 .31461 L
.92588 .26499 L
.93287 .24095 L
.94016 .21784 L
.9422 .2118 L
.9441 .20638 L
.9458 .20174 L
.94626 .2005 L
.94672 .19965 L
.94744 .20119 L
.9529 .21515 L
.96287 .25116 L
.97015 .28663 L
.97619 .32254 L
Mistroke
Mfstroke
.1365 .05113 m
.13672 .05143 L
.13688 .05169 L
.13703 .05198 L
.13714 .05223 L
.13718 .05235 L
.13721 .05248 L
.13724 .0526 L
.13725 .05271 L
.13726 .05278 L
.13727 .05283 L
.13727 .0529 L
.13727 .05293 L
.13727 .05296 L
.13728 .05303 L
.13728 .05306 L
.13728 .0531 L
.13727 .05316 L
.13727 .0532 L
.13727 .05323 L
.13727 .05329 L
.13726 .05336 L
.13725 .05351 L
.13722 .05378 L
.13712 .05446 L
.13708 .0548 L
.13706 .05501 L
.13704 .05521 L
.13703 .05541 L
.13702 .05553 L
.13702 .05564 L
.13701 .05573 L
.13701 .05584 L
.13701 .05596 L
.13701 .05607 L
.13701 .05618 L
.13702 .0563 L
.13702 .05642 L
.13702 .05653 L
.13704 .05681 L
.13706 .05709 L
.13713 .05768 L
.13724 .05839 L
.13755 .05984 L
.138 .06142 L
.13954 .0656 L
.14243 .07178 L
.15283 .08981 L
.17062 .11643 L
.19858 .16115 L
Mistroke
.23829 .21861 L
.29304 .28332 L
.38816 .37721 L
.51593 .48643 L
.58203 .53337 L
.61599 .55418 L
.65077 .57258 L
.68081 .58558 L
.69616 .59096 L
.71209 .59549 L
.71944 .59717 L
.72627 .59847 L
.72921 .59895 L
.7323 .5994 L
.73502 .59812 L
.73673 .59475 L
.74913 .56641 L
.76014 .53444 L
.77039 .49712 L
.78519 .42444 L
.79132 .38495 L
.79693 .34176 L
.80553 .25813 L
.80898 .2184 L
.81183 .18443 L
.81422 .15752 L
.81487 .15083 L
.81522 .1473 L
.81554 .14409 L
.81583 .14142 L
.81672 .14309 L
.81872 .14756 L
.83497 .19433 L
.84968 .24958 L
.87941 .38519 L
.89171 .44526 L
.8982 .47646 L
.90124 .49063 L
.90393 .50286 L
.90528 .50885 L
.90651 .51422 L
.90712 .51685 L
.90753 .5168 L
.90769 .51595 L
.90784 .51513 L
.90811 .51355 L
.90925 .50593 L
.91019 .49797 L
.91187 .47919 L
.91337 .45559 L
Mistroke
.91448 .43246 L
.9154 .40938 L
.91734 .35398 L
.91932 .30406 L
.92072 .27719 L
.92229 .25387 L
.92327 .24208 L
.9243 .23161 L
.92459 .22891 L
.92491 .22611 L
.92508 .22467 L
.92541 .22389 L
.92592 .22432 L
.9264 .22473 L
.93009 .22828 L
.9452 .24855 L
.96023 .27542 L
.97392 .3042 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00C`3IfMT4000003D0fMWI0`00000a0=WIf@<00000
=@3IfMT2000002X0fMWI001?0=WIf@030000003IfMT0fMWI03L0fMWI00<000000=WIf@3IfMT0<03I
fMT010000000fMWI0=WIf@00000c0=WIf@040000003IfMT0fMWI000002T0fMWI001@0=WIf@030000
003IfMT0fMWI03<0fMWI1@00000a0=WIf@040000003IfMT0fMWI000003<0fMWI00@000000=WIf@3I
fMT00000:@3IfMT00540fMWI00<000000=WIf@3IfMT0<P3IfMT010000000fMWI0=WIf@00000b0=WI
f@<00000=@3IfMT2000002X0fMWI001?0=WIf@040000003IfMT0fMWI000003@0fMWI00<000000=WI
f@000000<`3IfMT00`000000fMWI0=WIf@0c0=WIf@040000003IfMT0fMWI000002T0fMWI001@0=WI
f@800000=P3IfMT2000003<0fMWI0`00000d0=WIf@800000:P3IfMT00?l0fMWI8@3IfMT001/0fMWI
00<000000=WIf@3IfMT0o`3IfMT30=WIf@006`3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI000K
0=WIf@030000003IfMT0fMWI0?l0fMWI0`3IfMT001/0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WI
f@00503IfMWo000000d00000000K0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
2`3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
2`3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
2`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0
2`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0
2`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00/0fMWI0@0000010=WIf@006`3I
fMT00`000000fMWI0=WIf@0c0=WIf@030000003IfMT0fMWI03@0fMWI00<000000=WIf@3IfMT0<`3I
fMT00`000000fMWI0=WIf@0d0=WIf@030000003IfMT0fMWI02P0fMWI000K0=WIf@030000003IfMT0
fMWI0?l0fMWI0`3IfMT001/0fMWI0P00003o0=WIf@@0fMWI000K0=WIf@030000003IfMT0fMWI0?l0
fMWI0`3IfMT001/0fMWI00<000000=WIf@3IfMT0o`3IfMT30=WIf@006`3IfMT00`000000fMWI0=WI
f@3o0=WIf@<0fMWI000K0=WIf@030000003IfMT0fMWI0?l0fMWI0`3IfMT001/0fMWI0P00000I0=WI
f@030000003IfMT0fMWI0>L0fMWI000K0=WIf@030000003IfMT0fMWI01P0fMWI00@000000=WIf@3I
fMT00000iP3IfMT001/0fMWI00<000000=WIf@3IfMT0603IfMT010000000fMWI0=WIf@00003V0=WI
f@006`3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT000000>H0fMWI000K0=WIf@800000
6P3IfMT010000000fMWI0=WIf@00003U0=WIf@006`3IfMT00`000000fMWI0=WIf@0J0=WIf@030000
003IfMT000000>D0fMWI000K0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@000000i@3I
fMT001/0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0000003T0=WIf@006`3IfMT00`00
0000fMWI0=WIf@0K0=WIf@030000003IfMT000000>@0fMWI000K0=WIf@8000007@3IfMT00`000000
fMWI0000003S0=WIf@006`3IfMT00`000000fMWI0=WIf@0M0=WIf@800000h`3IfMT000L0fMWI1000
00030=WIf@800000103IfMT2000000D0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0000
003R0=WIf@001`3IfMT00`000000fMWI0=WIf@090=WIf@040000003IfMT0fMWI000000@0fMWI00<0
00000=WIf@3IfMT07P3IfMT00`000000fMWI0000003Q0=WIf@00203IfMT00`000000fMWI0=WIf@0;
0=WIf@030000003IfMT0fMWI0080fMWI0P00000P0=WIf@800000h@3IfMT000T0fMWI00<000000=WI
f@3IfMT0203IfMT2000000D0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0000003P0=WI
f@001`3IfMT010000000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0803IfMT00`000000fMWI0000003O0=WIf@00203IfMT2000000X0fMWI0`0000040=WIf@03
0000003IfMT0fMWI0240fMWI00<000000=WIf@000000gP3IfMT001/0fMWI0P00000R0=WIf@030000
003IfMT000000=h0fMWI000K0=WIf@030000003IfMT0fMWI0280fMWI00<000000=WIf@000000g@3I
fMT001/0fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0000003L0=WIf@006`3IfMT00`00
0000fMWI0=WIf@0S0=WIf@030000003IfMT000000=`0fMWI000K0=WIf@030000003IfMT0fMWI02@0
fMWI00<000000=WIf@000000f`3IfMT001/0fMWI0P00000U0=WIf@030000003IfMT000000=/0fMWI
000K0=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@000000fP3IfMT001/0fMWI00<00000
0=WIf@3IfMT09P3IfMT00`000000fMWI0000003I0=WIf@006`3IfMT00`000000fMWI0=WIf@0W0=WI
f@800000YP3IfMT200000340fMWI000K0=WIf@800000:03IfMT00`000000fMWI0000002U0=WIf@80
00001P3IfMT00`000000fMWI0=WIf@0X0=WIf@006`3IfMT00`000000fMWI0=WIf@0X0=WIf@800000
Y@3IfMT2000000H0fMWI00<000000=WIf@3IfMT0:03IfMT001/0fMWI00<000000=WIf@3IfMT0:@3I
fMT200000:@0fMWI00<000000=WIf@0000001@3IfMT2000002T0fMWI000K0=WIf@030000003IfMT0
fMWI02X0fMWI00<000000=WIf@3IfMT0XP3IfMT00`000000fMWI000000050=WIf@800000:@3IfMT0
01/0fMWI00<000000=WIf@3IfMT0:P3IfMT200000:<0fMWI00@000000=WIf@3IfMT000000`3IfMT0
0`000000fMWI0000000Y0=WIf@006`3IfMT2000002`0fMWI0P00002R0=WIf@040000003IfMT0fMWI
000000<0fMWI00<000000=WIf@000000:@3IfMT001/0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@2P0=WIf@040000003IfMT0fMWI00000080fMWI00D000000=WIf@3IfMT0fMWI0000
000X0=WIf@00503IfMT2000000D0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000fMWI0=WIf@2N
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@0000000`3IfMT00`000000fMWI0=WIf@0V
0=WIf@004`3IfMT010000000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI02d0fMWI0P00002O
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@0000000`3IfMT00`000000fMWI0=WIf@0V
0=WIf@005P3IfMT00`000000fMWI0=WIf@020=WIf@800000;`3IfMT2000009h0fMWI00<000000=WI
f@3IfMT00P3IfMT2000000@0fMWI00<000000=WIf@3IfMT09P3IfMT001@0fMWI0P0000050=WIf@03
0000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0W03IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT09P3IfMT001@0fMWI00<000000=WIf@3IfMT0
103IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI09/0fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02H0fMWI000D0=WIf@<00000103I
fMT00`000000fMWI0=WIf@0a0=WIf@030000003IfMT0fMWI09X0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI000000030=WIf@030000003IfMT0fMWI02H0fMWI000K0=WIf@800000<P3IfMT2
000009/0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI000000040=WIf@030000003IfMT0
fMWI02D0fMWI000K0=WIf@030000003IfMT0fMWI0380fMWI00<000000=WIf@3IfMT0V@3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0000000@0fMWI00<000000=WIf@3IfMT05@3IfMT00`00
0000fMWI0=WIf@0=0=WIf@006`3IfMT00`000000fMWI0=WIf@0c0=WIf@030000003IfMT0fMWI09P0
fMWI00D000000=WIf@3IfMT0fMWI000000030=WIf@050000003IfMT0fMWI0=WIf@0000005`3IfMT2
000000h0fMWI000K0=WIf@030000003IfMT0fMWI03@0fMWI00<000000=WIf@3IfMT0U`3IfMT01@00
0000fMWI0=WIf@3IfMT0000000<0fMWI00D000000=WIf@3IfMT0fMWI0000000G0=WIf@8000003P3I
fMT001/0fMWI00<000000=WIf@3IfMT0=@3IfMT00`000000fMWI0=WIf@2F0=WIf@050000003IfMT0
fMWI0=WIf@0000000`3IfMT01@000000fMWI0=WIf@3IfMT0000001H0fMWI00@000000=WIf@3IfMT0
00003@3IfMT001/0fMWI0P00000f0=WIf@800000U`3IfMT010000000fMWI0=WIf@0000040=WIf@05
0000003IfMT0fMWI0=WIf@0000005P3IfMT010000000fMWI0=WIf@00000=0=WIf@006`3IfMT00`00
0000fMWI0=WIf@0f0=WIf@800000UP3IfMT010000000fMWI0=WIf@0000050=WIf@040000003IfMT0
fMWI000001H0fMWI00@000000=WIf@3IfMT000003@3IfMT001/0fMWI00<000000=WIf@3IfMT0=`3I
fMT2000009D0fMWI00@000000=WIf@3IfMT000001@3IfMT010000000fMWI0=WIf@00000F0=WIf@05
0000003IfMT0fMWI0=WIf@000000303IfMT001/0fMWI00<000000=WIf@3IfMT0>03IfMT00`000000
fMWI0=WIf@2C0=WIf@030000003IfMT0000000H0fMWI00@000000=WIf@3IfMT000004P3IfMT01000
0000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI00X0fMWI000K0=WIf@800000>@3IfMT20000
09@0fMWI00<000000=WIf@0000001`3IfMT00`000000fMWI0000000A0=WIf@050000003IfMT00000
0=WIf@000000103IfMT00`000000fMWI0=WIf@0:0=WIf@006`3IfMT00`000000fMWI0=WIf@0i0=WI
f@800000T`3IfMT00`000000fMWI000000070=WIf@030000003IfMT000000140fMWI00<000000=WI
f@3IfMT00P0000050=WIf@030000003IfMT0fMWI00T0fMWI000K0=WIf@030000003IfMT0fMWI03X0
fMWI0P00002B0=WIf@030000003IfMT0000000L0fMWI00<000000=WIf@0000004@3IfMT00`000000
fMWI0=WIf@02000000D0fMWI00<000000=WIf@3IfMT02@3IfMT001/0fMWI00<000000=WIf@3IfMT0
>`3IfMT200000900fMWI00<000000=WIf@000000203IfMT00`000000fMWI0000000A0=WIf@030000
003IfMT0fMWI008000001@3IfMT00`000000fMWI0=WIf@090=WIf@006`3IfMT00`000000fMWI0=WI
f@0l0=WIf@800000S`3IfMT00`000000fMWI000000090=WIf@030000003IfMT000000100fMWI00H0
00000=WIf@3IfMT000000=WIf@0000040=WIf@030000003IfMT0fMWI00T0fMWI000K0=WIf@800000
?P3IfMT2000008h0fMWI00<000000=WIf@0000002@3IfMT00`000000fMWI0000000@0=WIf@030000
003IfMT0000000<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@080=WIf@006`3I
fMT00`000000fMWI0=WIf@0m0=WIf@800000SP3IfMT2000000X0fMWI00<000000=WIf@000000403I
fMT00`000000fMWI000000040=WIf@050000003IfMT0fMWI0=WIf@0000002P3IfMT000T0fMWI00<0
00000=WIf@3IfMT00P3IfMT2000000@0fMWI0P0000050=WIf@030000003IfMT0fMWI03h0fMWI0P00
002=0=WIf@8000002P3IfMT00`000000fMWI0000000@0=WIf@030000003IfMT0000000@0fMWI00D0
00000=WIf@3IfMT0fMWI0000000:0=WIf@002@3IfMT00`000000fMWI0=WIf@070=WIf@040000003I
fMT0fMWI000000@0fMWI00<000000=WIf@3IfMT0?`3IfMT2000008`0fMWI0P00000;0=WIf@800000
403IfMT00`000000fMWI000000050=WIf@040000003IfMT0fMWI000000X0fMWI00090=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT00P3IfMT200000440fMWI0P00002;0=WIf@030000
003IfMT0fMWI00X0fMWI0P00000@0=WIf@8000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000T0
fMWI000:0=WIf@030000003IfMT0fMWI00L0fMWI0P0000050=WIf@030000003IfMT0fMWI0440fMWI
0P00002:0=WIf@030000003IfMT0fMWI00X0fMWI0P00000@0=WIf@8000001`3IfMT010000000fMWI
0=WIf@0000090=WIf@001`3IfMT010000000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0@P3IfMT2000008T0fMWI00<000000=WIf@3IfMT02P3IfMT2000000l0
fMWI00<000000=WIf@0000001`3IfMT010000000fMWI0=WIf@0000090=WIf@001`3IfMT4000000T0
fMWI0`0000040=WIf@030000003IfMT0fMWI0480fMWI00<000000=WIf@000000Q`3IfMT00`000000
fMWI0=WIf@0;0=WIf@8000003`3IfMT2000000T0fMWI00<000000=WIf@0000002@3IfMT001/0fMWI
0P0000140=WIf@800000Q`3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00d0fMWI
0P00000:0=WIf@030000003IfMT0000000P0fMWI000K0=WIf@030000003IfMT0fMWI04@0fMWI0P00
00260=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT03@3IfMT2000000X0fMWI00<0
00000=WIf@000000203IfMT001/0fMWI00<000000=WIf@3IfMT0A@3IfMT2000008@0fMWI0P00000>
0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT02P3IfMT2000000P0fMWI000K0=WI
f@030000003IfMT0fMWI04H0fMWI0P0000230=WIf@8000003P3IfMT00`000000fMWI0=WIf@0=0=WI
f@030000003IfMT0fMWI00X0fMWI0P0000080=WIf@006`3IfMT00`000000fMWI0=WIf@170=WIf@80
0000PP3IfMT2000000h0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0;0=WIf@03
0000003IfMT0fMWI00H0fMWI000K0=WIf@800000B@3IfMT200000800fMWI00<000000=WIf@000000
3P3IfMT2000000h0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@060=WIf@006`3I
fMT00`000000fMWI0=WIf@190=WIf@030000003IfMT0fMWI07h0fMWI00<000000=WIf@0000003P3I
fMT2000000d0fMWI0P00000=0=WIf@8000001`3IfMT001/0fMWI00<000000=WIf@3IfMT0BP3IfMT0
0`000000fMWI0=WIf@1m0=WIf@8000003`3IfMT2000000d0fMWI0P00000>0=WIf@030000003IfMT0
fMWI00D0fMWI000K0=WIf@030000003IfMT0fMWI04/0fMWI00<000000=WIf@3IfMT0N`3IfMT00`00
0000fMWI0000000?0=WIf@8000003@3IfMT2000000h0fMWI00<000000=WIf@3IfMT01@3IfMT001/0
fMWI0P00001=0=WIf@030000003IfMT0fMWI07X0fMWI00<000000=WIf@0000003`3IfMT2000000`0
fMWI00<000000=WIf@0000003P3IfMT00`000000fMWI0=WIf@050=WIf@006`3IfMT00`000000fMWI
0=WIf@1=0=WIf@030000003IfMT0fMWI07T0fMWI00<000000=WIf@0000003`3IfMT00`000000fMWI
0000000;0=WIf@030000003IfMT0000000h0fMWI00<000000=WIf@3IfMT01@3IfMT001/0fMWI00<0
00000=WIf@3IfMT0CP3IfMT00`000000fMWI0=WIf@1g0=WIf@040000003IfMT0fMWI000000l0fMWI
00<000000=WIf@0000002`3IfMT00`000000fMWI0000000>0=WIf@030000003IfMT0fMWI00D0fMWI
000K0=WIf@030000003IfMT0fMWI04l0fMWI00<000000=WIf@3IfMT0MP3IfMT010000000fMWI0=WI
f@00000?0=WIf@030000003IfMT0000000/0fMWI00<000000=WIf@0000003P3IfMT00`000000fMWI
0=WIf@050=WIf@006`3IfMT00`000000fMWI0=WIf@1?0=WIf@800000M`3IfMT010000000fMWI0=WI
f@00000?0=WIf@030000003IfMT0000000X0fMWI00@000000=WIf@3IfMT000005P3IfMT001/0fMWI
0P00001A0=WIf@<00000M03IfMT010000000fMWI0=WIf@00000@0=WIf@030000003IfMT0000000X0
fMWI00@000000=WIf@3IfMT000005P3IfMT001/0fMWI00<000000=WIf@3IfMT0D@3IfMT00`000000
fMWI0000001c0=WIf@040000003IfMT0fMWI00000100fMWI00<000000=WIf@0000002P3IfMT01000
0000fMWI0=WIf@00000F0=WIf@003@3IfMT500000080fMWI0P0000050=WIf@030000003IfMT0fMWI
0580fMWI00<000000=WIf@000000LP3IfMT010000000fMWI0=WIf@00000@0=WIf@040000003IfMT0
fMWI000000T0fMWI00@000000=WIf@3IfMT000005P3IfMT000l0fMWI00D000000=WIf@3IfMT0fMWI
000000020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0D`3IfMT00`000000fMWI
0000001`0=WIf@050000003IfMT0fMWI0=WIf@000000403IfMT010000000fMWI0=WIf@0000080=WI
f@050000003IfMT0fMWI0=WIf@0000005P3IfMT000l0fMWI00D000000=WIf@3IfMT0fMWI00000002
0=WIf@030000003IfMT0fMWI0080fMWI0P00001E0=WIf@030000003IfMT0000006l0fMWI00D00000
0=WIf@3IfMT0fMWI0000000@0=WIf@040000003IfMT0fMWI000000P0fMWI00D000000=WIf@3IfMT0
fMWI0000000F0=WIf@003`3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@1E0=WIf@030000003IfMT0000006d0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@040000003IfMT0fMWI000000P0fMWI00D000000=WI
f@3IfMT0fMWI0000000F0=WIf@003`3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@1F0=WIf@030000003IfMT0000006`0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@040000003IfMT0fMWI000000P0fMWI00D0
00000=WIf@3IfMT0fMWI0000000F0=WIf@003P3IfMT2000000@0fMWI0P0000050=WIf@030000003I
fMT0fMWI05H0fMWI00@000000=WIf@3IfMT00000J`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00h0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0503IfMT001/0fMWI0P00001H0=WIf@040000003IfMT0fMWI000006T0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0>0=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI01@0fMWI000K0=WIf@03
0000003IfMT0fMWI05P0fMWI00@000000=WIf@3IfMT00000J03IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00l0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0503IfMT001/0fMWI00<000000=WIf@3IfMT0F@3IfMT01000
0000fMWI0=WIf@00001W0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@0D0=WIf@006`3IfMT00`000000fMWI0=WIf@1J0=WIf@040000003IfMT0fMWI000006D0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0?0=WIf@050000003IfMT0fMWI0=WIf@000000
1@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI01@0fMWI000K0=WIf@030000003I
fMT0fMWI05/0fMWI00@000000=WIf@3IfMT00000I03IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0503IfMT001/0fMWI0P00001M0=WIf@040000003I
fMT0fMWI000006<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0?0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI01@0fMWI000K0=WIf@030000003IfMT0fMWI05d0fMWI00@000000=WIf@3IfMT00000
H@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
5@3IfMT001/0fMWI00<000000=WIf@3IfMT0G@3IfMT010000000fMWI0=WIf@3IfMT2000005l0fMWI
00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI0080fMWI
00D000000=WIf@3IfMT0fMWI000000050=WIf@030000003IfMT0fMWI01D0fMWI000K0=WIf@030000
003IfMT0fMWI05h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@1L0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@030=WIf@040000
003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT05@3IfMT001/0fMWI0P00001P0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0FP3IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT010000000fMWI0=WIf@0000050=WIf@03
0000003IfMT0fMWI01D0fMWI000K0=WIf@030000003IfMT0fMWI0600fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@1I0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
403IfMT00`000000fMWI0=WIf@030=WIf@040000003IfMT0fMWI000000D0fMWI00<000000=WIf@3I
fMT05@3IfMT001/0fMWI00<000000=WIf@3IfMT0H@3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI05P0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0@0=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@0000001P3IfMT00`000000fMWI0=WIf@0E0=WIf@006`3I
fMT00`000000fMWI0=WIf@1R0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0EP3I
fMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT0103I
fMT2000000H0fMWI00<000000=WIf@3IfMT05@3IfMT001/0fMWI00<000000=WIf@3IfMT0H`3IfMT0
0`000000fMWI0=WIf@020=WIf@800000EP3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0
fMWI0100fMWI00<000000=WIf@3IfMT0103IfMT2000000H0fMWI00<000000=WIf@3IfMT05@3IfMT0
01/0fMWI0P00001U0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0D`3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT0103IfMT20000
00H0fMWI00<000000=WIf@3IfMT05@3IfMT001/0fMWI00<000000=WIf@3IfMT0I@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0540fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@0E0=WIf@0000<0fMWI0000000000000`0000000`3IfMT0000000000002000000<0fMWI
0P0000040=WIf@8000001@3IfMT00`000000fMWI0=WIf@1U0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT0D03IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0140fMWI
00<000000=WIf@3IfMT0103IfMT2000000H0fMWI00<000000=WIf@3IfMT05@3IfMT000<0fMWI00D0
00000=WIf@3IfMT0fMWI0000000;0=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@3I
fMT0IP3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI04l0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00@0fMWI0P0000060=WIf@03
0000003IfMT0fMWI01D0fMWI00030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
2`3IfMT00`000000fMWI0=WIf@020=WIf@800000J03IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0fMWI04d0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000
003IfMT0fMWI00@0fMWI0P0000060=WIf@030000003IfMT0fMWI01D0fMWI00030=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT0203IfMT2000000D0fMWI00<000000=WIf@3IfMT0J03I
fMT00`000000fMWI0=WIf@040=WIf@800000C@3IfMT00`000000fMWI0=WIf@060=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI000000060=WIf@030000003I
fMT0fMWI01D0fMWI00030=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0J@3IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI04T0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@0B0=WIf@030000003IfMT0fMWI00<0fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI
0=WIf@0E0=WIf@000P3IfMT2000000@0fMWI0P00000:0=WIf@<00000103IfMT00`000000fMWI0=WI
f@1Z0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0B03IfMT00`000000fMWI0=WI
f@060=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT00`3IfMT010000000fMWI0=WI
f@0000050=WIf@030000003IfMT0fMWI01D0fMWI000K0=WIf@800000K03IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI04H0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@0B0=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI000000050=WIf@030000
003IfMT0fMWI01D0fMWI000K0=WIf@030000003IfMT0fMWI06`0fMWI00<000000=WIf@3IfMT01@3I
fMT00`000000fMWI0=WIf@150=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT04P3I
fMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT00`000000fMWI
0=WIf@0F0=WIf@006`3IfMT00`000000fMWI0=WIf@1/0=WIf@030000003IfMT0fMWI00H0fMWI0P00
00140=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WI
f@020=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT00`000000fMWI0=WIf@0F0=WIf@006`3I
fMT00`000000fMWI0=WIf@1]0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0@@3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT00P3I
fMT01@000000fMWI0=WIf@3IfMT0000000@0fMWI00<000000=WIf@3IfMT05P3IfMT001/0fMWI00<0
00000=WIf@3IfMT0KP3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI03l0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0C0=WIf@050000003IfMT0fMWI0=WIf@000000
103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI01H0fMWI000K0=WIf@800000L03I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI03h0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@0C0=WIf@050000003IfMT0fMWI0=WIf@0000001@3IfMT01@000000fMWI
0=WIf@3IfMT0000001P0fMWI000K0=WIf@030000003IfMT0fMWI0700fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@0m0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
4`3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00D000000=WIf@3IfMT0fMWI0000000H0=WI
f@006`3IfMT00`000000fMWI0=WIf@1a0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT0>`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI01@0fMWI00@000000=WIf@3I
fMT000001P3IfMT01@000000fMWI0=WIf@3IfMT0000001P0fMWI000K0=WIf@030000003IfMT0fMWI
0780fMWI00<000000=WIf@3IfMT01`3IfMT2000003/0fMWI00<000000=WIf@3IfMT0203IfMT00`00
0000fMWI0=WIf@0D0=WIf@040000003IfMT0fMWI000000H0fMWI00D000000=WIf@3IfMT0fMWI0000
000H0=WIf@006`3IfMT2000007@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0g
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0503IfMT010000000fMWI0=WIf@00
00060=WIf@050000003IfMT0fMWI0=WIf@000000603IfMT001/0fMWI00<000000=WIf@3IfMT0M03I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI03H0fMWI00<000000=WIf@3IfMT02@3I
fMT00`000000fMWI0=WIf@0D0=WIf@040000003IfMT0fMWI000000H0fMWI00D000000=WIf@3IfMT0
fMWI0000000H0=WIf@006`3IfMT00`000000fMWI0=WIf@1e0=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT0=03IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI01@0fMWI
00<000000=WIf@000000203IfMT010000000fMWI0=WIf@00000H0=WIf@006`3IfMT00`000000fMWI
0=WIf@1f0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0<`3IfMT00`000000fMWI
0=WIf@090=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@000000203IfMT010000000fMWI
0=WIf@00000H0=WIf@006`3IfMT00`000000fMWI0=WIf@1g0=WIf@8000002@3IfMT200000380fMWI
00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0000000P0fMWI
00@000000=WIf@3IfMT00000603IfMT001/0fMWI0P00001j0=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI01D0fMWI
0P0000090=WIf@040000003IfMT0fMWI000001P0fMWI000K0=WIf@030000003IfMT0fMWI07X0fMWI
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0fMWI00/0fMWI
00<000000=WIf@3IfMT05@3IfMT2000000X0fMWI00<000000=WIf@000000603IfMT000d0fMWI1@00
00020=WIf@8000001@3IfMT00`000000fMWI0=WIf@1k0=WIf@030000003IfMT0fMWI00P0fMWI0P00
000]0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WI
f@090=WIf@8000006@3IfMT000l0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT0O03IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI02T0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0R0=WIf@8000006@3I
fMT000l0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@800000OP3IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT02`3IfMT0
0`000000fMWI0=WIf@0S0=WIf@030000003IfMT0fMWI01L0fMWI000?0=WIf@030000003IfMT0fMWI
0080fMWI0P0000050=WIf@030000003IfMT0fMWI07h0fMWI00<000000=WIf@3IfMT02@3IfMT20000
02L0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0S0=WIf@030000003IfMT0fMWI
01L0fMWI000?0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@1o0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0903IfMT00`000000
fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT05`3IfMT000h0fMWI
0P0000040=WIf@<00000103IfMT00`000000fMWI0=WIf@200=WIf@030000003IfMT0fMWI00X0fMWI
00<000000=WIf@3IfMT08P3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI03d0fMWI
000K0=WIf@800000PP3IfMT2000000/0fMWI0P00000R0=WIf@030000003IfMT0fMWI00`0fMWI00<0
00000=WIf@3IfMT0?P3IfMT001/0fMWI00<000000=WIf@3IfMT0P`3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0n
0=WIf@006`3IfMT00`000000fMWI0=WIf@240=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT07@3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI03h0fMWI000K0=WIf@03
0000003IfMT0fMWI08D0fMWI0P00000;0=WIf@800000703IfMT00`000000fMWI0=WIf@0>0=WIf@03
0000003IfMT0fMWI03h0fMWI000K0=WIf@030000003IfMT0fMWI08L0fMWI00<000000=WIf@3IfMT0
2P3IfMT2000001T0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0o0=WIf@006`3I
fMT2000008T0fMWI00<000000=WIf@3IfMT02`3IfMT2000001L0fMWI00<000000=WIf@3IfMT03P3I
fMT00`000000fMWI0=WIf@0o0=WIf@006`3IfMT00`000000fMWI0=WIf@290=WIf@8000003@3IfMT2
000001@0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@0o0=WIf@006`3IfMT00`00
0000fMWI0=WIf@2;0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT04@3IfMT00`00
0000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI0400fMWI000K0=WIf@030000003IfMT0fMWI08`0
fMWI00<000000=WIf@3IfMT0303IfMT200000100fMWI00<000000=WIf@3IfMT03`3IfMT00`000000
fMWI0=WIf@100=WIf@006`3IfMT2000008h0fMWI0P00000>0=WIf@8000003P3IfMT00`000000fMWI
0=WIf@0?0=WIf@030000003IfMT0fMWI0400fMWI000K0=WIf@030000003IfMT0fMWI08l0fMWI00<0
00000=WIf@3IfMT03@3IfMT2000000/0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WI
f@110=WIf@006`3IfMT00`000000fMWI0=WIf@2@0=WIf@8000003`3IfMT2000000T0fMWI00<00000
0=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@110=WIf@006`3IfMT00`000000fMWI0=WIf@2B0=WI
f@030000003IfMT0fMWI00h0fMWI0P0000060=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT0@P3IfMT001/0fMWI00<000000=WIf@3IfMT0T`3IfMT00`000000fMWI0=WIf@0?0=WIf@80
00000`3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI0480fMWI000K0=WIf@800000
U@3IfMT200000140fMWI0P0000000`3IfMT000000=WIf@0@0=WIf@030000003IfMT0fMWI04<0fMWI
000K0=WIf@030000003IfMT0fMWI09H0fMWI0P00000A0=WIf@8000004@3IfMT00`000000fMWI0=WI
f@130=WIf@0000<0fMWI0000000000000`0000030=WIf@030000003IfMT0fMWI0080fMWI0P000004
0=WIf@8000001@3IfMT00`000000fMWI0=WIf@2H0=WIf@8000003P3IfMT00`000000fMWI0=WIf@03
000000d0fMWI00<000000=WIf@3IfMT0A03IfMT000<0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@070=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@3IfMT0VP3IfMT3
000000X0fMWI00<000000=WIf@3IfMT0103IfMT4000000T0fMWI00<000000=WIf@3IfMT0A03IfMT0
00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI
0080fMWI0P00002N0=WIf@800000203IfMT00`000000fMWI0=WIf@080=WIf@<000001@3IfMT00`00
0000fMWI0=WIf@150=WIf@000`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00L0
fMWI0P0000050=WIf@030000003IfMT0fMWI09l0fMWI0P0000050=WIf@030000003IfMT0fMWI00`0
fMWI1P0000170=WIf@000`3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0:40fMWI1@00001L0=WIf@00
0P3IfMT2000000<0fMWI100000090=WIf@<00000103IfMT00`000000fMWI0=WIf@2T0=WIf@030000
003IfMT0fMWI05/0fMWI000K0=WIf@800000o`3IfMT40=WIf@006`3IfMT00`000000fMWI0=WIf@3o
0=WIf@<0fMWI000K0=WIf@030000003IfMT0fMWI0?l0fMWI0`3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00001\
\>"],
  ImageRangeCache->{{{138, 425}, {241.938, 65}} -> {-6.06668, 5.74733, \
0.0366952, 0.113557}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ParametricPlot3D[
        Evaluate[{{lorentz1 . x[t], \ lorentz1 . y[t], \ 
              lorentz1 . z[t]}, \ {lorentz1SC . x[t], \ lorentz1SC . y[t], \ 
              lorentz1SC . z[t]}}\[IndentingNewLine]], \ {t, \ 0, \ 
          2}];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[
        Evaluate[{{lorentz2 . x[t], \ lorentz2 . y[t], \ 
              lorentz2 . z[t]}\[IndentingNewLine], {lorentz2SC . x[t], \ 
              lorentz2SC . y[t], \ 
              lorentz2SC . z[t]}}\[IndentingNewLine]], \ {t, \ 0, \ 
          3}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97123 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00843848 1.00974 -5.55112e-017 1.00974 [
[.24931 .97927 -3.16983 0 ]
[.24931 .97927 2.83017 9 ]
[.47845 .92007 -3.01253 0 ]
[.47845 .92007 2.98747 9 ]
[.72492 .85637 -5.67685 0 ]
[.72492 .85637 6.32315 9 ]
[.99075 .78761 -5.28937 0 ]
[.99075 .78761 6.71063 9 ]
[.06299 .85853 -6.61271 0 ]
[.06299 .85853 5.38729 9 ]
[.12677 .90592 -6.51678 0 ]
[.12677 .90592 5.48322 9 ]
[.18719 .9508 -3.21392 0 ]
[.18719 .9508 2.78608 9 ]
[.95982 .33745 0 -5.95297 ]
[.95982 .33745 12 3.04703 ]
[.97245 .44145 0 -5.88351 ]
[.97245 .44145 24 3.11649 ]
[.9858 .55141 0 -5.81033 ]
[.9858 .55141 12 3.18967 ]
[.99993 .66786 0 -5.73314 ]
[.99993 .66786 24 3.26686 ]
[ 0 0 0 0 ]
[ 1 .97123 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23242 .97123 m
1 .77229 L
s
.25003 .96666 m
.25038 .96036 L
s
[(0)] .24931 .97927 .05661 -1 Mshowa
.47851 .90745 m
.47853 .90114 L
s
[(5)] .47845 .92007 .00418 -1 Mshowa
.72424 .84376 m
.7239 .83746 L
s
[(10)] .72492 .85637 -0.05386 -1 Mshowa
.98926 .77508 m
.98852 .76881 L
s
[(15)] .99075 .78761 -0.11844 -1 Mshowa
.125 Mabswid
.29443 .95516 m
.29461 .95137 L
s
.33947 .94349 m
.3396 .9397 L
s
.38515 .93165 m
.38525 .92786 L
s
.43149 .91964 m
.43155 .91585 L
s
.52621 .89509 m
.52619 .8913 L
s
.57462 .88254 m
.57455 .87875 L
s
.62375 .86981 m
.62364 .86602 L
s
.67362 .85688 m
.67346 .8531 L
s
.77563 .83044 m
.77538 .82667 L
s
.82781 .81692 m
.82751 .81315 L
s
.8808 .80319 m
.88045 .79942 L
s
.93461 .78924 m
.93421 .78548 L
s
.25 Mabswid
0 .79811 m
.23242 .97123 L
s
.06427 .84598 m
.06491 .8397 L
s
[(-4)] .06299 .85853 .10212 -1 Mshowa
.12786 .89334 m
.1284 .88705 L
s
[(-2)] .12677 .90592 .08613 -1 Mshowa
.18809 .93821 m
.18854 .93191 L
s
[(0)] .18719 .9508 .07131 -1 Mshowa
.125 Mabswid
.01421 .80869 m
.01464 .80493 L
s
.03113 .82129 m
.03155 .81753 L
s
.04782 .83372 m
.04822 .82996 L
s
.0805 .85807 m
.08087 .8543 L
s
.0965 .86999 m
.09685 .86622 L
s
.11229 .88174 m
.11263 .87797 L
s
.14322 .90478 m
.14353 .90101 L
s
.15838 .91607 m
.15867 .9123 L
s
.17333 .92721 m
.17361 .92344 L
s
.20265 .94906 m
.20291 .94528 L
s
.21703 .95976 m
.21727 .95598 L
s
.23122 .97033 m
.23145 .96655 L
s
.25 Mabswid
.93616 .24513 m
1 .77229 L
s
.94781 .34133 m
.9418 .34326 L
s
[(45)] .95982 .33745 -1 .32288 Mshowa
.96038 .44515 m
.95435 .44701 L
s
[(47.5)] .97245 .44145 -1 .30745 Mshowa
.97368 .55493 m
.96762 .5567 L
s
[(50)] .9858 .55141 -1 .29118 Mshowa
.98776 .67119 m
.98167 .67286 L
s
[(52.5)] .99993 .66786 -1 .27403 Mshowa
.125 Mabswid
.93823 .26223 m
.93464 .26343 L
s
.94059 .28169 m
.93699 .28288 L
s
.94297 .30135 m
.93937 .30254 L
s
.94538 .32123 m
.94178 .3224 L
s
.95027 .36164 m
.94666 .36279 L
s
.95276 .38217 m
.94915 .38332 L
s
.95527 .40294 m
.95166 .40407 L
s
.95781 .42393 m
.9542 .42505 L
s
.96298 .46662 m
.95936 .46772 L
s
.96561 .48832 m
.96199 .48942 L
s
.96827 .51028 m
.96464 .51136 L
s
.97096 .53248 m
.96733 .53355 L
s
.97643 .57765 m
.97279 .5787 L
s
.97921 .60063 m
.97557 .60166 L
s
.98203 .62388 m
.97838 .6249 L
s
.98487 .64739 m
.98123 .64841 L
s
.99067 .69527 m
.98702 .69626 L
s
.99362 .71964 m
.98996 .72061 L
s
.99661 .7443 m
.99295 .74526 L
s
.99963 .76925 m
.99597 .77021 L
s
.25 Mabswid
.06216 .27424 m
0 .79811 L
s
0 .79811 m
.23242 .97123 L
s
.23242 .97123 m
.26265 .47226 L
s
.26265 .47226 m
.06216 .27424 L
s
.78225 0 m
.93616 .24513 L
s
.93616 .24513 m
1 .77229 L
s
1 .77229 m
.82878 .55123 L
s
.82878 .55123 m
.78225 0 L
s
.06216 .27424 m
0 .79811 L
s
0 .79811 m
.82878 .55123 L
s
.82878 .55123 m
.78225 0 L
s
.78225 0 m
.06216 .27424 L
s
.26265 .47226 m
.93616 .24513 L
s
.93616 .24513 m
1 .77229 L
s
1 .77229 m
.23242 .97123 L
s
.23242 .97123 m
.26265 .47226 L
s
0 0 m
1 0 L
1 .97123 L
0 .97123 L
closepath
clip
newpath
.5 Mabswid
.26151 .78031 m
.25514 .77927 L
s
.26887 .78074 m
.26151 .78031 L
s
.2773 .78046 m
.26887 .78074 L
s
.26299 .77585 m
.25709 .77513 L
s
.2696 .77581 m
.26299 .77585 L
s
.25514 .77927 m
.24966 .77768 L
s
.25709 .77513 m
.25186 .77372 L
s
.27697 .7749 m
.2696 .77581 L
s
.28687 .77941 m
.2773 .78046 L
s
.25186 .77372 m
.24724 .77173 L
s
.24966 .77768 m
.24502 .77561 L
s
.28517 .77304 m
.27697 .7749 L
s
.29768 .7775 m
.28687 .77941 L
s
.24724 .77173 m
.2432 .76924 L
s
.24502 .77561 m
.24114 .77315 L
s
.29425 .77013 m
.28517 .77304 L
s
.2432 .76924 m
.23968 .76633 L
s
.30982 .77465 m
.29768 .7775 L
s
.24114 .77315 m
.23795 .77036 L
s
.23968 .76633 m
.23665 .7631 L
s
.30427 .76606 m
.29425 .77013 L
s
.23795 .77036 m
.23538 .76732 L
s
.32339 .77077 m
.30982 .77465 L
s
.23665 .7631 m
.23406 .75964 L
s
.23538 .76732 m
.23336 .76411 L
s
.31531 .76072 m
.30427 .76606 L
s
.23406 .75964 m
.23188 .75603 L
s
.34795 .77392 m
.32339 .77077 L
s
.23336 .76411 m
.23182 .7608 L
s
.23188 .75603 m
.22958 .75439 L
s
.33394 .76049 m
.31531 .76072 L
s
.23182 .7608 m
.22967 .75919 L
s
.22958 .75439 m
.22731 .75408 L
s
.22731 .75408 m
.22536 .75378 L
s
.22536 .75378 m
.22371 .75348 L
s
.22371 .75348 m
.22234 .75318 L
s
.22234 .75318 m
.22122 .75289 L
s
.22122 .75289 m
.22034 .7526 L
s
.22034 .7526 m
.21968 .75231 L
s
.21968 .75231 m
.21921 .75203 L
s
.21921 .75203 m
.21892 .75176 L
s
.22967 .75919 m
.2272 .75874 L
s
.21892 .75176 m
.21878 .7515 L
s
.2272 .75874 m
.22509 .75832 L
s
.21878 .7515 m
.21878 .75125 L
s
.22509 .75832 m
.22332 .75792 L
s
.21878 .75125 m
.21889 .75101 L
s
.22332 .75792 m
.22185 .75754 L
s
.21889 .75101 m
.2191 .75078 L
s
.2191 .75078 m
.21938 .75057 L
s
.22185 .75754 m
.22066 .75718 L
s
.21938 .75057 m
.2192 .75043 L
s
.22066 .75718 m
.21974 .75684 L
s
.2192 .75043 m
.21893 .75032 L
s
.21893 .75032 m
.21871 .75022 L
s
.21871 .75022 m
.21853 .75013 L
s
.21974 .75684 m
.21906 .75652 L
s
.21853 .75013 m
.21839 .75006 L
s
.21839 .75006 m
.21828 .75 L
s
.21828 .75 m
.2182 .74995 L
s
.2182 .74995 m
.21815 .74991 L
s
.21815 .74991 m
.21813 .74987 L
s
.21813 .74987 m
.21812 .74985 L
s
.21906 .75652 m
.2186 .75622 L
s
.21812 .74985 m
.21814 .74983 L
s
.21814 .74983 m
.21817 .74982 L
s
.21817 .74982 m
.21822 .74981 L
s
.21822 .74981 m
.21828 .74981 L
s
.21828 .74981 m
.21834 .74981 L
s
.2186 .75622 m
.21833 .75594 L
s
.21833 .75594 m
.21823 .75568 L
s
.21823 .75568 m
.21828 .75543 L
s
.21828 .75543 m
.21845 .75521 L
s
.21845 .75521 m
.21872 .755 L
s
.21872 .755 m
.21908 .75482 L
s
.21908 .75482 m
.2189 .75467 L
s
.2189 .75467 m
.21863 .75454 L
s
.21863 .75454 m
.2184 .75443 L
s
.2184 .75443 m
.21822 .75434 L
s
.21822 .75434 m
.21807 .75426 L
s
.21807 .75426 m
.21796 .75419 L
s
.21796 .75419 m
.21788 .75414 L
s
.21788 .75414 m
.21783 .75409 L
s
.21783 .75409 m
.21781 .75406 L
s
.21781 .75406 m
.21781 .75404 L
s
.21781 .75404 m
.21783 .75402 L
s
.21783 .75402 m
.21787 .75401 L
s
.21787 .75401 m
.21792 .75401 L
s
.21792 .75401 m
.21799 .75401 L
s
.21799 .75401 m
.21806 .75401 L
s
.38098 .78129 m
.34795 .77392 L
s
.35847 .76304 m
.33394 .76049 L
s
.41613 .787 m
.38098 .78129 L
s
.38458 .76358 m
.35847 .76304 L
s
.45313 .79046 m
.41613 .787 L
s
.41207 .76159 m
.38458 .76358 L
s
.49163 .79107 m
.45313 .79046 L
s
.80173 .10166 m
.80604 .11635 L
s
.4407 .75652 m
.41207 .76159 L
s
.80604 .11635 m
.82472 .20207 L
s
.53122 .78818 m
.49163 .79107 L
s
.68528 .04806 m
.69609 .11728 L
s
.47018 .74777 m
.4407 .75652 L
s
.57139 .7811 m
.53122 .78818 L
s
.82472 .20207 m
.83602 .28472 L
s
.50015 .73473 m
.47018 .74777 L
s
.69609 .11728 m
.70353 .19798 L
s
.61153 .76916 m
.57139 .7811 L
s
.53017 .7168 m
.50015 .73473 L
s
.83602 .28472 m
.83981 .36309 L
s
.65095 .75167 m
.61153 .76916 L
s
.70353 .19798 m
.70542 .2757 L
s
.55975 .69341 m
.53017 .7168 L
s
.83981 .36309 m
.83618 .43609 L
s
.68889 .72801 m
.65095 .75167 L
s
.58832 .66402 m
.55975 .69341 L
s
.72448 .69762 m
.68889 .72801 L
s
.70542 .2757 m
.70183 .34928 L
s
.83618 .43609 m
.82546 .50282 L
s
.75683 .66007 m
.72448 .69762 L
s
.61523 .62823 m
.58832 .66402 L
s
.82546 .50282 m
.80817 .56262 L
s
.70183 .34928 m
.69301 .41773 L
s
.78502 .6151 m
.75683 .66007 L
s
.80817 .56262 m
.78502 .6151 L
s
.63984 .58572 m
.61523 .62823 L
s
.69301 .41773 m
.67937 .48028 L
s
.66144 .53638 m
.63984 .58572 L
s
.67937 .48028 m
.66144 .53638 L
s
.25 Mabswid
.78225 0 m
.93616 .24513 L
s
.93616 .24513 m
1 .77229 L
s
1 .77229 m
.82878 .55123 L
s
.82878 .55123 m
.78225 0 L
s
.06216 .27424 m
0 .79811 L
s
0 .79811 m
.82878 .55123 L
s
.82878 .55123 m
.78225 0 L
s
.78225 0 m
.06216 .27424 L
s
0 .79811 m
.23242 .97123 L
s
.06427 .84598 m
.06491 .8397 L
s
[(-4)] .06299 .85853 .10212 -1 Mshowa
.12786 .89334 m
.1284 .88705 L
s
[(-2)] .12677 .90592 .08613 -1 Mshowa
.18809 .93821 m
.18854 .93191 L
s
[(0)] .18719 .9508 .07131 -1 Mshowa
.125 Mabswid
.01421 .80869 m
.01464 .80493 L
s
.03113 .82129 m
.03155 .81753 L
s
.04782 .83372 m
.04822 .82996 L
s
.0805 .85807 m
.08087 .8543 L
s
.0965 .86999 m
.09685 .86622 L
s
.11229 .88174 m
.11263 .87797 L
s
.14322 .90478 m
.14353 .90101 L
s
.15838 .91607 m
.15867 .9123 L
s
.17333 .92721 m
.17361 .92344 L
s
.20265 .94906 m
.20291 .94528 L
s
.21703 .95976 m
.21727 .95598 L
s
.23122 .97033 m
.23145 .96655 L
s
.25 Mabswid
.93616 .24513 m
1 .77229 L
s
.94781 .34133 m
.9418 .34326 L
s
[(45)] .95982 .33745 -1 .32288 Mshowa
.96038 .44515 m
.95435 .44701 L
s
[(47.5)] .97245 .44145 -1 .30745 Mshowa
.97368 .55493 m
.96762 .5567 L
s
[(50)] .9858 .55141 -1 .29118 Mshowa
.98776 .67119 m
.98167 .67286 L
s
[(52.5)] .99993 .66786 -1 .27403 Mshowa
.125 Mabswid
.93823 .26223 m
.93464 .26343 L
s
.94059 .28169 m
.93699 .28288 L
s
.94297 .30135 m
.93937 .30254 L
s
.94538 .32123 m
.94178 .3224 L
s
.95027 .36164 m
.94666 .36279 L
s
.95276 .38217 m
.94915 .38332 L
s
.95527 .40294 m
.95166 .40407 L
s
.95781 .42393 m
.9542 .42505 L
s
.96298 .46662 m
.95936 .46772 L
s
.96561 .48832 m
.96199 .48942 L
s
.96827 .51028 m
.96464 .51136 L
s
.97096 .53248 m
.96733 .53355 L
s
.97643 .57765 m
.97279 .5787 L
s
.97921 .60063 m
.97557 .60166 L
s
.98203 .62388 m
.97838 .6249 L
s
.98487 .64739 m
.98123 .64841 L
s
.99067 .69527 m
.98702 .69626 L
s
.99362 .71964 m
.98996 .72061 L
s
.99661 .7443 m
.99295 .74526 L
s
.99963 .76925 m
.99597 .77021 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 279.688},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00015b000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00c03IfMT200000580fMWI003:0=WIf@80000000<0fMWI000000000000D@3IfMT00<L0fMWI
0`0000030=WIf@800000D@3IfMT00<@0fMWI0`0000060=WIf@030000003IfMT000000500fMWI0032
0=WIf@8000002@3IfMT010000000fMWI0=WIf@00001?0=WIf@00_`3IfMT3000000/0fMWI00@00000
0=WIf@3IfMT00000C`3IfMT00;`0fMWI0`00000>0=WIf@050000003IfMT0fMWI0=WIf@000000CP3I
fMT00;X0fMWI0P00000B0=WIf@040000003IfMT0fMWI000004h0fMWI002g0=WIf@<00000503IfMT0
1@000000fMWI0=WIf@3IfMT0000004d0fMWI002e0=WIf@8000005`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI04X0fMWI002b0=WIf@<000006@3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI04X0fMWI002_0=WIf@<00000703IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI04T0fMWI002]0=WIf@8000007`3IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0fMWI04P0fMWI002Z0=WIf@<000001`3IfMT00`000000fMWI0=WIf@0G0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0B03IfMT00:L0fMWI0`00000:0=WIf@030000003IfMT0
fMWI01L0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@170=WIf@00Y@3IfMT20000
00d0fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
04H0fMWI002R0=WIf@<00000403IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00H0
fMWI00<000000=WIf@3IfMT0AP3IfMT00:00fMWI0P00000C0=WIf@030000003IfMT0fMWI01H0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@150=WIf@00W@3IfMT3000001D0fMWI00<0
00000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI04@0fMWI002J
0=WIf@<00000603IfMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI00L0fMWI00<00000
0=WIf@3IfMT0A03IfMT009P0fMWI0P00000K0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@130=WIf@00U@3IfMT3000001d0fMWI00<000000=WIf@3I
fMT05`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI04<0fMWI002B0=WIf@<00000
8@3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
@P3IfMT00900fMWI0P00000T0=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI0=WIf@110=WIf@00S@3IfMT3000002H0fMWI00<000000=WIf@3IfMT05P3IfMT0
0`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0440fMWI002;0=WIf@800000:@3IfMT00`00
0000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0@03IfMT008P0
fMWI0`00000[0=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT0303IfMT00`000000
fMWI0=WIf@0o0=WIf@00Q@3IfMT3000002h0fMWI00<000000=WIf@3IfMT05P3IfMT010000000fMWI
0=WIf@00000;0=WIf@030000003IfMT0fMWI03l0fMWI00230=WIf@800000<P3IfMT00`000000fMWI
0=WIf@0E0=WIf@050000003IfMT0fMWI0=WIf@0000002`3IfMT00`000000fMWI0=WIf@0n0=WIf@00
P03IfMT3000003@0fMWI00<000000=WIf@3IfMT05@3IfMT01@000000fMWI0=WIf@3IfMT0000000`0
fMWI00<000000=WIf@3IfMT0?@3IfMT007d0fMWI0`00000g0=WIf@030000003IfMT0fMWI01D0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI03d0fMWI
001k0=WIf@800000>P3IfMT00`000000fMWI0=WIf@0F0=WIf@050000003IfMT0fMWI0=WIf@000000
303IfMT00`000000fMWI0=WIf@0l0=WIf@00N03IfMT3000003`0fMWI00<000000=WIf@3IfMT05P3I
fMT01@000000fMWI0=WIf@3IfMT0000000d0fMWI00<000000=WIf@3IfMT0>`3IfMT007H0fMWI0P00
000o0=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI03/0fMWI001c0=WIf@<00000@@3IfMT00`000000fMWI0=WIf@0F
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0j
0=WIf@00L03IfMT3000004@0fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0>P3IfMT006h0fMWI0P0000170=WIf@03
0000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI03T0fMWI001[0=WIf@<00000BP3IfMT00`000000fMWI0=WIf@0E0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0h0=WIf@00J03I
fMT3000004d0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00d0fMWI00<000000=WIf@3IfMT0>03IfMT006H0fMWI0P00001@0=WIf@030000003IfMT0
fMWI01D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0
fMWI03L0fMWI001S0=WIf@<00000DP3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0f0=WIf@00H@3IfMT2000005D0
fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00h0
fMWI00<000000=WIf@3IfMT0=P3IfMT005h0fMWI0`00001G0=WIf@030000003IfMT0fMWI01D0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI03D0fMWI
001K0=WIf@<00000FP3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0d0=WIf@00F@3IfMT2000005d0fMWI00<00000
0=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<00000
0=WIf@3IfMT0=03IfMT005H0fMWI0`00001O0=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI03<0fMWI001C0=WIf@<0
0000HP3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT0403IfMT00`000000fMWI0=WIf@0c0=WIf@00D@3IfMT2000006H0fMWI00<000000=WIf@3IfMT0
5@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0
<P3IfMT004h0fMWI0`00001X0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI0340fMWI001<0=WIf@800000J`3IfMT0
0`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT04P3IfMT0
0`000000fMWI0=WIf@0a0=WIf@00B@3IfMT3000006d0fMWI00<000000=WIf@3IfMT05@3IfMT00`00
0000fMWI0=WIf@030=WIf@030000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT0<03IfMT004H0
fMWI0`00001`0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI02l0fMWI00140=WIf@800000L`3IfMT00`000000fMWI
0=WIf@0E0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT04`3IfMT00`000000fMWI
0=WIf@0_0=WIf@00@@3IfMT3000007D0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0;P3IfMT003h0fMWI0`00001h
0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0E
0=WIf@030000003IfMT0fMWI02d0fMWI000l0=WIf@800000N`3IfMT00`000000fMWI0=WIf@0F0=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@0]0=WI
f@00>@3IfMT3000007d0fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT0;03IfMT003L0fMWI0P0000200=WIf@030000
003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0F0=WIf@030000
003IfMT0fMWI02/0fMWI000d0=WIf@<00000PP3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@0[0=WIf@00<@3IfMT3
000008D0fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI01L0fMWI00<000000=WIf@3IfMT0:P3IfMT002l0fMWI0P0000280=WIf@030000003IfMT0fMWI
01H0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI
02X0fMWI000/0=WIf@<00000RP3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@0Y0=WIf@00:@3IfMT3000008d0fMWI
00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI01T0fMWI
00<000000=WIf@3IfMT0:03IfMT002L0fMWI0P00002@0=WIf@030000003IfMT0fMWI01H0fMWI00<0
00000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI02P0fMWI000T
0=WIf@<00000TP3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0603IfMT2000002T0fMWI000R0=WIf@800000U@3IfMT00`000000fMWI0=WIf@0F0=WI
f@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT05@3IfMT3000000030=WIf@000000fMWI
02P0fMWI000O0=WIf@<00000U`3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00D0
fMWI00<000000=WIf@3IfMT04P3IfMT3000000@0fMWI00<000000=WIf@3IfMT09`3IfMT001`0fMWI
0`00002J0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@0?0=WIf@<000001`3IfMT00`000000fMWI0=WIf@0W0=WIf@006P3IfMT2000009d0fMWI00<0
00000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00`0fMWI0`00
000:0=WIf@030000003IfMT0fMWI02L0fMWI000G0=WIf@<00000W`3IfMT00`000000fMWI0=WIf@0G
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT3000000`0fMWI0`00000X
0=WIf@00503IfMT300000:80fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00H0fMWI0`00000A0=WIf@030000003IfMT0fMWI02H0fMWI000B0=WIf@80
0000Y@3IfMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00`3IfMT3000001@0fMWI00<000000=WIf@3IfMT09P3IfMT00100fMWI0P00002W0=WIf@030000
003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI00000002000001L0fMWI
00<000000=WIf@3IfMT09P3IfMT00100fMWI0P00002W0=WIf@030000003IfMT0fMWI01L0fMWI00<0
00000=WIf@3IfMT0103IfMT3000001X0fMWI00<000000=WIf@3IfMT09P3IfMT00100fMWI00<00000
0=WIf@000000YP3IfMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI0080fMWI0P000000
0`3IfMT000000=WIf@0I0=WIf@800000:03IfMT00100fMWI00@000000=WIf@3IfMT00000Y@3IfMT0
0`000000fMWI0=WIf@0G0=WIf@030000003IfMT00000008000000`3IfMT00`000000fMWI0=WIf@0I
0=WIf@030000003IfMT0fMWI02H0fMWI000@0=WIf@050000003IfMT0fMWI0=WIf@000000Y03IfMT0
0`000000fMWI0=WIf@0F0=WIf@<000001P3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0
fMWI02H0fMWI000?0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0X@3IfMT00`00
0000fMWI0=WIf@0C0=WIf@<0000000<0fMWI0000003IfMT01P3IfMT00`000000fMWI0=WIf@0J0=WI
f@030000003IfMT0fMWI02D0fMWI000?0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0X03IfMT00`000000fMWI0=WIf@0@0=WIf@<00000103IfMT00`000000fMWI0=WIf@050=WIf@03
0000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT09@3IfMT000l0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@2O0=WIf@030000003IfMT0fMWI00d0fMWI0`0000080=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT06@3IfMT2000002L0fMWI000?0=WIf@030000003I
fMT0fMWI00H0fMWI00<000000=WIf@3IfMT0WP3IfMT00`000000fMWI0=WIf@0:0=WIf@<000002`3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT09@3I
fMT000l0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@2M0=WIf@030000003IfMT0
fMWI00L0fMWI0`00000>0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT06P3IfMT0
0`000000fMWI0=WIf@0U0=WIf@003`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI
09/0fMWI00<000000=WIf@3IfMT01@3IfMT300000140fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI02D0fMWI000?0=WIf@030000003IfMT0fMWI00T0
fMWI00<000000=WIf@3IfMT0VP3IfMT00`000000fMWI0=WIf@020=WIf@<00000503IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT09@3IfMT000l0fMWI
00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@2I0=WIf@030000003IfMT0000000800000
5`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0
9@3IfMT000h0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@2G0=WIf@<000006P3I
fMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WIf@0000001@3I
fMT300000080fMWI0P00000J0=WIf@003P3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0
fMWI09<0fMWI0`0000000`3IfMT000000=WIf@0J0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI00000080fMWI00<0
00000=WIf@3IfMT05`3IfMT000h0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@2?
0=WIf@<00000103IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT06P3IfMT010000000fMWI0=WIf@3IfMT5000000@0fMWI00<000000=WIf@3IfMT05`3I
fMT000h0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@2;0=WIf@<000001`3IfMT0
0`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT06P3IfMT0
1@000000fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT0fMWI0P00000J0=WIf@003P3I
fMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI08L0fMWI0`00000:0=WIf@030000003I
fMT0fMWI01T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@0000000`3IfMT00`000000fMWI0=WIf@0I0=WIf@003P3IfMT0
0`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI08<0fMWI0`00000=0=WIf@030000003IfMT0
fMWI01T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0H0=WIf@<000001@3IfMT2
000000<0fMWI0`00000I0=WIf@003P3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI
07l0fMWI0`00000@0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI02@0fMWI000>0=WIf@030000003IfMT0fMWI01<0
fMWI00<000000=WIf@3IfMT0N`3IfMT3000001<0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0903IfMT000h0fMWI
00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@1g0=WIf@<000005P3IfMT00`000000fMWI
0=WIf@0J0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI
0=WIf@0S0=WIf@003@3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI07@0fMWI0P00
000I0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@0K0=WIf@030000003IfMT0fMWI02<0fMWI000=0=WIf@030000003IfMT0fMWI01L0fMWI00<00000
0=WIf@3IfMT0L03IfMT3000001/0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI01T0fMWI0`00000U0=WIf@003@3IfMT00`000000fMWI0=WIf@0H0=WI
f@030000003IfMT0fMWI06`0fMWI0`00000N0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI02<0fMWI000=0=WIf@03
0000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0J03IfMT300000200fMWI00<000000=WIf@3I
fMT06`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3I
fMT08`3IfMT000d0fMWI00<000000=WIf@3IfMT06P3IfMT2000006D0fMWI0`00000S0=WIf@030000
003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0K0=WIf@030000
003IfMT0fMWI02<0fMWI000=0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT0G`3I
fMT3000002H0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI01/0fMWI00<000000=WIf@3IfMT08`3IfMT000d0fMWI00<000000=WIf@3IfMT07@3IfMT0
0`000000fMWI0=WIf@1K0=WIf@<00000:@3IfMT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@0S0=WIf@003@3IfMT00`00
0000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI05L0fMWI0`00000/0=WIf@030000003IfMT0fMWI
01/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT00000
02@0fMWI000=0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT0D`3IfMT3000002l0
fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI01`0
fMWI00<000000=WIf@3IfMT08P3IfMT000`0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI
0=WIf@1?0=WIf@<00000<P3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@0R0=WIf@00303IfMT00`000000fMWI0=WI
f@0R0=WIf@030000003IfMT0fMWI04/0fMWI0`00000e0=WIf@030000003IfMT0fMWI01`0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI0280fMWI000<
0=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT0A`3IfMT3000003P0fMWI00<00000
0=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI01d0fMWI00<00000
0=WIf@3IfMT08P3IfMT000`0fMWI00<000000=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@130=WI
f@<00000>P3IfMT00`000000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0703IfMT2000002@0fMWI000<0=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@3I
fMT0?`3IfMT3000003d0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT08P3IfMT000`0fMWI00<000000=WIf@3IfMT0
9P3IfMT00`000000fMWI0=WIf@0k0=WIf@<00000@03IfMT00`000000fMWI0=WIf@0M0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0R0=WIf@00303I
fMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI03L0fMWI0`0000130=WIf@030000003I
fMT0fMWI01d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003I
fMT0fMWI0240fMWI000<0=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT0<`3IfMT3
000004H0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI01h0fMWI00<000000=WIf@3IfMT08@3IfMT000/0fMWI00<000000=WIf@3IfMT0:P3IfMT00`00
0000fMWI0=WIf@0_0=WIf@<00000B@3IfMT00`000000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT07@3IfMT2000002<0fMWI000;0=WIf@030000003IfMT0fMWI02/0
fMWI00<000000=WIf@3IfMT0:`3IfMT3000004/0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@0000001@3IfMT3000000<0
fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI0P00000;0=WIf@002`3IfMT00`000000fMWI
0=WIf@0/0=WIf@030000003IfMT0fMWI02L0fMWI0`00001>0=WIf@030000003IfMT0fMWI01h0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@070=WIf@040000003IfMT0fMWI000000X0
fMWI000;0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0903IfMT200000540fMWI
00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI01h0fMWI
00@000000=WIf@3IfMT0fMWI1@0000030=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0203IfMT000/0fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@0P0=WIf@<00000
D`3IfMT00`000000fMWI0=WIf@0O0=WIf@050000003IfMT0fMWI0=WIf@000000803IfMT01@000000
fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@070=WI
f@8000002`3IfMT000/0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0L0=WIf@<0
0000E@3IfMT00`000000fMWI0=WIf@0P0=WIf@050000003IfMT0fMWI0=WIf@000000803IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT000000080fMWI00@000000=WIf@3IfMT000002@3IfMT0
0`000000fMWI0=WIf@0:0=WIf@002`3IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI
01P0fMWI0`00001H0=WIf@030000003IfMT0fMWI0200fMWI00D000000=WIf@3IfMT0fMWI0000000O
0=WIf@8000001@3IfMT200000080fMWI100000090=WIf@<000002P3IfMT000/0fMWI00<000000=WI
f@3IfMT0<@3IfMT00`000000fMWI0=WIf@0D0=WIf@<00000F`3IfMT00`000000fMWI0=WIf@0P0=WI
f@050000003IfMT0fMWI0=WIf@0000008@3IfMT00`000000fMWI0=WIf@0P0=WIf@002`3IfMT00`00
0000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI0100fMWI0`00001N0=WIf@030000003IfMT0fMWI
0200fMWI00D000000=WIf@3IfMT0fMWI0000000Q0=WIf@030000003IfMT0fMWI0200fMWI000:0=WI
f@030000003IfMT0fMWI03@0fMWI00<000000=WIf@3IfMT0303IfMT300000600fMWI00<000000=WI
f@3IfMT08@3IfMT010000000fMWI0=WIf@00000R0=WIf@030000003IfMT0fMWI0200fMWI000:0=WI
f@030000003IfMT0fMWI03D0fMWI00<000000=WIf@3IfMT0203IfMT3000006<0fMWI00<000000=WI
f@3IfMT08@3IfMT010000000fMWI0=WIf@00000R0=WIf@030000003IfMT0fMWI0200fMWI000:0=WI
f@030000003IfMT0fMWI03H0fMWI00<000000=WIf@3IfMT0103IfMT3000006H0fMWI00<000000=WI
f@3IfMT08@3IfMT010000000fMWI0=WIf@00000R0=WIf@030000003IfMT0fMWI0200fMWI000:0=WI
f@030000003IfMT0fMWI03L0fMWI00<000000=WIf@3IfMT00`00001Y0=WIf@030000003IfMT0fMWI
0240fMWI00@000000=WIf@3IfMT000008@3IfMT200000280fMWI000:0=WIf@030000003IfMT0fMWI
03P0fMWI0P00001[0=WIf@030000003IfMT0fMWI0280fMWI00@000000=WIf@3IfMT000008P3IfMT0
0`000000fMWI0=WIf@0P0=WIf@002P3IfMT00`000000fMWI0=WIf@0h0=WIf@030000003IfMT0fMWI
06X0fMWI00<000000=WIf@3IfMT08P3IfMT010000000fMWI0=WIf@00000R0=WIf@030000003IfMT0
fMWI0200fMWI000:0=WIf@030000003IfMT0fMWI03P0fMWI00<000000=WIf@3IfMT0JP3IfMT00`00
0000fMWI0=WIf@0R0=WIf@040000003IfMT0fMWI000002<0fMWI00<000000=WIf@3IfMT07`3IfMT0
00X0fMWI00<000000=WIf@3IfMT0>03IfMT00`000000fMWI0=WIf@1Z0=WIf@030000003IfMT0fMWI
02<0fMWI00<000000=WIf@0000008`3IfMT00`000000fMWI0=WIf@0O0=WIf@002P3IfMT00`000000
fMWI0=WIf@0h0=WIf@030000003IfMT0fMWI06T0fMWI00<000000=WIf@3IfMT0903IfMT2000002<0
fMWI0P00000Q0=WIf@002@3IfMT00`000000fMWI0=WIf@0i0=WIf@030000003IfMT0fMWI06T0fMWI
00<000000=WIf@3IfMT0903IfMT2000002<0fMWI0P00000Q0=WIf@002@3IfMT00`000000fMWI0=WI
f@0i0=WIf@030000003IfMT0fMWI06T0fMWI00<000000=WIf@3IfMT0903IfMT2000002@0fMWI00<0
00000=WIf@3IfMT07`3IfMT000T0fMWI00<000000=WIf@3IfMT0>@3IfMT00`000000fMWI0=WIf@1X
0=WIf@030000003IfMT0fMWI02D0fMWI0P00000T0=WIf@030000003IfMT0fMWI01l0fMWI00090=WI
f@030000003IfMT0fMWI03T0fMWI00<000000=WIf@3IfMT0J03IfMT00`000000fMWI0=WIf@0U0=WI
f@800000903IfMT00`000000fMWI0=WIf@0O0=WIf@002@3IfMT00`000000fMWI0=WIf@0h0=WIf@03
0000003IfMT0fMWI06T0fMWI00<000000=WIf@3IfMT09@3IfMT2000002@0fMWI00<000000=WIf@3I
fMT07`3IfMT000T0fMWI00<000000=WIf@3IfMT0>03IfMT00`000000fMWI0=WIf@1X0=WIf@030000
003IfMT0fMWI02H0fMWI00<000000=WIf@3IfMT08P3IfMT300000200fMWI00090=WIf@030000003I
fMT0fMWI03P0fMWI00<000000=WIf@3IfMT0J03IfMT00`000000fMWI0=WIf@0V0=WIf@030000003I
fMT0fMWI02@0fMWI00<000000=WIf@3IfMT07P3IfMT000T0fMWI00<000000=WIf@3IfMT0>03IfMT0
0`000000fMWI0=WIf@1X0=WIf@030000003IfMT0fMWI02H0fMWI00<000000=WIf@3IfMT0903IfMT0
0`000000fMWI0=WIf@0N0=WIf@00203IfMT00`000000fMWI0=WIf@0i0=WIf@030000003IfMT0fMWI
06L0fMWI00<000000=WIf@3IfMT09P3IfMT2000002H0fMWI00<000000=WIf@3IfMT07P3IfMT000P0
fMWI00<000000=WIf@3IfMT0>@3IfMT00`000000fMWI0=WIf@1W0=WIf@030000003IfMT0fMWI02H0
fMWI0P00000V0=WIf@030000003IfMT0fMWI01h0fMWI00080=WIf@030000003IfMT0fMWI03T0fMWI
00<000000=WIf@3IfMT0I`3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0000002D0fMWI
00<000000=WIf@3IfMT07P3IfMT000P0fMWI00<000000=WIf@3IfMT0>@3IfMT00`000000fMWI0=WI
f@1V0=WIf@030000003IfMT0fMWI02H0fMWI00@000000=WIf@3IfMT00000903IfMT200000200fMWI
00080=WIf@030000003IfMT0fMWI03T0fMWI00<000000=WIf@3IfMT0IP3IfMT00`000000fMWI0=WI
f@0V0=WIf@040000003IfMT0fMWI000002D0fMWI00<000000=WIf@3IfMT00`3IfMT2000000@0fMWI
0P00000C0=WIf@00203IfMT00`000000fMWI0=WIf@0i0=WIf@030000003IfMT0fMWI06H0fMWI00<0
00000=WIf@3IfMT09P3IfMT010000000fMWI0=WIf@00000V0=WIf@050000003IfMT0fMWI0=WIf@00
00000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI0100fMWI00080=WIf@03
0000003IfMT0fMWI03T0fMWI00<000000=WIf@3IfMT0I@3IfMT00`000000fMWI0=WIf@0W0=WIf@04
0000003IfMT0fMWI000002H0fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@000002
0=WIf@030000003IfMT0fMWI0100fMWI00080=WIf@030000003IfMT0fMWI03T0fMWI00<000000=WI
f@3IfMT0I@3IfMT00`000000fMWI0=WIf@0V0=WIf@050000003IfMT0fMWI0=WIf@0000009P3IfMT0
0`000000fMWI0=WIf@020=WIf@8000000`3IfMT010000000fMWI0=WIf@00000B0=WIf@00203IfMT0
0`000000fMWI0=WIf@0i0=WIf@030000003IfMT0fMWI06@0fMWI00<000000=WIf@3IfMT09`3IfMT0
0`000000fMWI0=WIf@02000002H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@02
0=WIf@040000003IfMT0fMWI00000180fMWI00070=WIf@030000003IfMT0fMWI03X0fMWI00<00000
0=WIf@3IfMT0I03IfMT00`000000fMWI0=WIf@0V0=WIf@@000000P3IfMT00`000000fMWI0=WIf@0Q
0=WIf@<00000103IfMT3000000<0fMWI0P00000C0=WIf@001`3IfMT00`000000fMWI0=WIf@0j0=WI
f@030000003IfMT0fMWI06@0fMWI00<000000=WIf@3IfMT08`3IfMT4000000H0fMWI00<000000=WI
f@3IfMT08P3IfMT00`000000fMWI0=WIf@0M0=WIf@001`3IfMT00`000000fMWI0=WIf@0j0=WIf@03
0000003IfMT0fMWI06<0fMWI00<000000=WIf@3IfMT08@3IfMT3000000<0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0fMWI01d0fMWI00070=WIf@030000
003IfMT0fMWI03T0fMWI00<000000=WIf@3IfMT0I03IfMT00`000000fMWI0=WIf@0M0=WIf@@00000
1P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT0
7@3IfMT000L0fMWI00<000000=WIf@3IfMT0>@3IfMT00`000000fMWI0=WIf@1T0=WIf@030000003I
fMT0fMWI01X0fMWI0`0000090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT08@3I
fMT00`000000fMWI0=WIf@0L0=WIf@001`3IfMT00`000000fMWI0=WIf@0i0=WIf@030000003IfMT0
fMWI06<0fMWI00<000000=WIf@3IfMT0603IfMT3000000`0fMWI00<000000=WIf@3IfMT0203IfMT0
0`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI01`0fMWI00070=WIf@030000003IfMT0fMWI
03T0fMWI00<000000=WIf@3IfMT0H`3IfMT00`000000fMWI0=WIf@0D0=WIf@@000003P3IfMT00`00
0000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI01d0fMWI0`00000N0=WIf@001`3IfMT00`000000
fMWI0=WIf@0i0=WIf@030000003IfMT0fMWI0680fMWI00<000000=WIf@3IfMT04P3IfMT300000180
fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0
fMWI00060=WIf@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0HP3IfMT00`000000fMWI
0=WIf@0?0=WIf@<00000503IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI01h0fMWI
00<000000=WIf@3IfMT0703IfMT000H0fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000fMWI0=WI
f@1Q0=WIf@030000003IfMT0fMWI00`0fMWI1000000G0=WIf@030000003IfMT0fMWI00d0fMWI00<0
00000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0L0=WIf@001P3IfMT00`000000fMWI0=WIf@0j
0=WIf@030000003IfMT0fMWI0640fMWI00<000000=WIf@3IfMT02@3IfMT3000001/0fMWI00<00000
0=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI01`0fMWI00060=WI
f@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0H03IfMT00`000000fMWI0=WIf@070=WI
f@<000007@3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WI
f@3IfMT0703IfMT000H0fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000fMWI0=WIf@1O0=WIf@03
0000003IfMT0fMWI00@0fMWI1000000P0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3I
fMT06P3IfMT2000001h0fMWI00060=WIf@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0
G`3IfMT010000000fMWI0=WIf@3IfMT3000002<0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000
fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI01/0fMWI00060=WIf@030000003IfMT0fMWI03X0fMWI
00<000000=WIf@3IfMT0GP3IfMT00`000000fMWI00000002000002H0fMWI00<000000=WIf@3IfMT0
4`3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI01/0fMWI00060=WIf@030000003I
fMT0fMWI03X0fMWI00<000000=WIf@3IfMT0G03IfMT4000002P0fMWI00<000000=WIf@3IfMT05@3I
fMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01/0fMWI00060=WIf@030000003IfMT0
fMWI03X0fMWI00<000000=WIf@3IfMT0F@3IfMT3000000030=WIf@000000fMWI02T0fMWI00<00000
0=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01/0fMWI00050=WI
f@030000003IfMT0fMWI03/0fMWI00<000000=WIf@3IfMT0EP3IfMT3000000<0fMWI00<000000=WI
f@3IfMT0:03IfMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WI
f@3IfMT06`3IfMT000D0fMWI00<000000=WIf@3IfMT0>`3IfMT00`000000fMWI0=WIf@1B0=WIf@@0
00001P3IfMT00`000000fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WIf@3I
fMT05P3IfMT2000001d0fMWI00050=WIf@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0
D03IfMT3000000T0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@0J0=WIf@030000
003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT06`3IfMT000D0fMWI00<000000=WIf@3IfMT0>P3I
fMT00`000000fMWI0=WIf@1=0=WIf@<000002`3IfMT00`000000fMWI0=WIf@0X0=WIf@030000003I
fMT0fMWI01`0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@0K0=WIf@001@3IfMT0
0`000000fMWI0=WIf@0j0=WIf@030000003IfMT0fMWI04T0fMWI1000000>0=WIf@030000003IfMT0
fMWI02P0fMWI00<000000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0
fMWI01X0fMWI00050=WIf@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0AP3IfMT30000
0140fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI
01D0fMWI00<000000=WIf@3IfMT06P3IfMT000D0fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000
fMWI0=WIf@130=WIf@<000004`3IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003IfMT0fMWI01l0
fMWI00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@0J0=WIf@001@3IfMT00`000000fMWI
0=WIf@0j0=WIf@030000003IfMT0fMWI03l0fMWI1000000E0=WIf@030000003IfMT0fMWI02T0fMWI
00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0B0=WIf@800000703IfMT000D0fMWI00<0
00000=WIf@3IfMT0>P3IfMT00`000000fMWI0=WIf@0l0=WIf@<000006@3IfMT00`000000fMWI0=WI
f@0X0=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WI
f@0J0=WIf@00103IfMT00`000000fMWI0=WIf@0k0=WIf@030000003IfMT0fMWI03T0fMWI0`00000K
0=WIf@030000003IfMT0fMWI02T0fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@0B
0=WIf@030000003IfMT0fMWI00<0fMWI0P0000030=WIf@@000000`3IfMT2000000@0fMWI0P000003
0=WIf@00103IfMT00`000000fMWI0=WIf@0k0=WIf@030000003IfMT0fMWI03D0fMWI1000000M0=WI
f@030000003IfMT0fMWI02T0fMWI00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WIf@0A0=WI
f@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@09
0=WIf@040000003IfMT0fMWI00000080fMWI00040=WIf@030000003IfMT0fMWI03/0fMWI00<00000
0=WIf@3IfMT0<P3IfMT300000240fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@0W
0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT01@3IfMT01@000000fMWI0=WIf@3I
fMT0000000d0fMWI0@0000010=WIf@40fMWI00040=WIf@030000003IfMT0fMWI03/0fMWI00<00000
0=WIf@3IfMT0;`3IfMT3000002<0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@0Y
0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00P3IfMT2000000D0fMWI00<00000
0=WIf@3IfMT0203IfMT2000000<0fMWI00040=WIf@030000003IfMT0fMWI03/0fMWI00<000000=WI
f@3IfMT0:`3IfMT4000002D0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@0[0=WI
f@030000003IfMT0fMWI00h0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI00@000000=WI
f@3IfMT000002@3IfMT00`000000fMWI0=WIf@020=WIf@00103IfMT00`000000fMWI0=WIf@0k0=WI
f@030000003IfMT0fMWI02P0fMWI0`00000X0=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WI
f@3IfMT0;03IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0000000@0fMWI0`0000030=WI
f@8000002P3IfMT300000080fMWI00040=WIf@030000003IfMT0fMWI03/0fMWI00<000000=WIf@3I
fMT09@3IfMT3000002X0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@0^0=WIf@03
0000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT06@3IfMT000@0fMWI00<000000=WIf@3IfMT0
>`3IfMT00`000000fMWI0=WIf@0Q0=WIf@@00000;03IfMT00`000000fMWI0=WIf@0Y0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0I0=WIf@000`3I
fMT00`000000fMWI0=WIf@0l0=WIf@030000003IfMT0fMWI01h0fMWI0`00000_0=WIf@030000003I
fMT0fMWI02T0fMWI00<000000=WIf@3IfMT0<@3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003I
fMT0fMWI01T0fMWI00030=WIf@030000003IfMT0fMWI03`0fMWI00<000000=WIf@3IfMT06`3IfMT3
00000340fMWI00<000000=WIf@3IfMT0:@3IfMT00`000000fMWI0=WIf@0c0=WIf@030000003IfMT0
fMWI00/0fMWI00<000000=WIf@3IfMT06@3IfMT000<0fMWI00<000000=WIf@3IfMT0>`3IfMT00`00
0000fMWI0=WIf@0H0=WIf@@00000<`3IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003IfMT0fMWI
03@0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0I0=WIf@000`3IfMT00`000000
fMWI0=WIf@0k0=WIf@030000003IfMT0fMWI01D0fMWI0`00000f0=WIf@030000003IfMT0fMWI02T0
fMWI00<000000=WIf@3IfMT0=P3IfMT00`000000fMWI0=WIf@090=WIf@<000006P3IfMT000<0fMWI
00<000000=WIf@3IfMT0>`3IfMT00`000000fMWI0=WIf@0B0=WIf@<00000=`3IfMT2000002/0fMWI
00<000000=WIf@3IfMT0>03IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI01P0fMWI
00030=WIf@030000003IfMT0fMWI03/0fMWI00<000000=WIf@3IfMT03P3IfMT4000003T0fMWI00<0
00000=WIf@3IfMT0:P3IfMT00`000000fMWI0=WIf@0j0=WIf@030000003IfMT0fMWI00T0fMWI00<0
00000=WIf@3IfMT0603IfMT000<0fMWI00<000000=WIf@3IfMT0>`3IfMT00`000000fMWI0=WIf@0;
0=WIf@<00000?03IfMT00`000000fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI03`0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0H0=WIf@000`3IfMT00`000000fMWI0=WIf@0k0=WI
f@030000003IfMT0fMWI00P0fMWI0`00000m0=WIf@800000:`3IfMT2000003l0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@0H0=WIf@000`3IfMT00`000000fMWI0=WIf@0k0=WIf@03
0000003IfMT0fMWI00@0fMWI1000000o0=WIf@030000003IfMT0fMWI02X0fMWI00<000000=WIf@3I
fMT0@03IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01P0fMWI00020=WIf@030000
003IfMT0fMWI03`0fMWI00@000000=WIf@3IfMT0fMWI0`0000110=WIf@800000;03IfMT00`000000
fMWI0=WIf@120=WIf@030000003IfMT0fMWI00D0fMWI0P00000J0=WIf@000P3IfMT00`000000fMWI
0=WIf@0l0=WIf@@00000@`3IfMT00`000000fMWI0=WIf@0[0=WIf@030000003IfMT0fMWI04@0fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0H0=WIf@000P3IfMT00`000000fMWI0=WI
f@0i0=WIf@@00000A03IfMT2000002d0fMWI00<000000=WIf@3IfMT0A@3IfMT00`000000fMWI0=WI
f@060=WIf@030000003IfMT0fMWI01L0fMWI00020=WIf@030000003IfMT0fMWI03H0fMWI0`000003
0=WIf@030000003IfMT0fMWI0400fMWI0P00000]0=WIf@800000B@3IfMT00`000000fMWI0=WIf@05
0=WIf@030000003IfMT0fMWI01L0fMWI00020=WIf@030000003IfMT0fMWI03<0fMWI0`0000060=WI
f@030000003IfMT0fMWI03l0fMWI00<000000=WIf@3IfMT0;03IfMT00`000000fMWI0=WIf@1:0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT05`3IfMT00080fMWI00<000000=WIf@3I
fMT0;`3IfMT4000000T0fMWI00<000000=WIf@3IfMT0?@3IfMT2000002h0fMWI00<000000=WIf@3I
fMT0C03IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI01L0fMWI00020=WIf@030000
003IfMT0fMWI02`0fMWI0`00000=0=WIf@030000003IfMT0fMWI03/0fMWI0P00000^0=WIf@800000
D03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI01L0fMWI00020=WIf@030000003I
fMT0fMWI02T0fMWI0`00000@0=WIf@030000003IfMT0fMWI03T0fMWI0P00000_0=WIf@030000003I
fMT0fMWI0500fMWI00@000000=WIf@3IfMT0fMWI0P00000I0=WIf@000P3IfMT00`000000fMWI0=WI
f@0U0=WIf@@000002`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI03H0fMWI0`00
000_0=WIf@800000E03IfMT01@000000fMWI0=WIf@3IfMT0000001T0fMWI00000`3IfMT000000=WI
f@0T0=WIf@<000003`3IfMT4000000<0fMWI00<000000=WIf@3IfMT0<`3IfMT400000300fMWI0P00
001G0=WIf@040000003IfMT0fMWI000001T0fMWI00000`3IfMT000000=WIf@0Q0=WIf@<000004P3I
fMT4000000<0fMWI00<000000=WIf@3IfMT0;@3IfMT600000340fMWI0`00001J0=WIf@040000003I
fMT0fMWI000001P0fMWI00000`3IfMT000000=WIf@0M0=WIf@@00000603IfMT200000080fMWI00<0
00000=WIf@3IfMT03`3IfMT9000000h0fMWI1`00000e0=WIf@800000GP3IfMT00`000000fMWI0000
000H0=WIf@0000<0fMWI0000003IfMT06P3IfMT3000001d0fMWI1000000>0=WIf@<000002@3IfMT>
000003T0fMWI0`00001P0=WIf@030000003IfMT0000001P0fMWI00000`3IfMT000000=WIf@0G0=WI
f@<00000803IfMT4000000`0fMWI0P00001@0=WIf@<00000H@3IfMT00`000000fMWI000000020000
01P0fMWI00000`3IfMT000000=WIf@0C0=WIf@@000009@3IfMT4000000L0fMWI0`0000070=WIf@X0
0000?P3IfMT3000006@0fMWI00<000000=WIf@3IfMT00P00000H0=WIf@0000<0fMWI0000003IfMT0
403IfMT3000002X0fMWI2P0000030=WIf@L000002P3IfMT4000003H0fMWI1000001V0=WIf@@00000
6P3IfMT000030=WIf@000000fMWI00d0fMWI0`00000]0=WIf@030000003IfMT0fMWI00X000005@3I
fMT5000002d0fMWI1000001V0=WIf@@000007P3IfMT000030000003IfMT0fMWI00T0fMWI1000000`
0=WIf@030000003IfMT0fMWI02@0fMWI1000000S0=WIf@H00000H@3IfMT00`000000fMWI0=WIf@02
0=WIf@@000008P3IfMT000030000003IfMT0fMWI00H0fMWI0`00000d0=WIf@030000003IfMT0fMWI
02P0fMWI2000000D0=WIf@L00000I`3IfMT5000002H0fMWI00000`000000fMWI0=WIf@030=WIf@<0
0000=`3IfMT00`000000fMWI0=WIf@0`0=WIfA@00000J`3IfMT4000002X0fMWI00000`000000fMWI
00000003000003X0fMWI00<000000=WIf@3IfMT0Z`3IfMT4000002h0fMWI0002000003h0fMWI00<0
00000=WIf@3IfMT0Y03IfMT00`000000fMWI0=WIf@0400000380fMWI00000`3IfMT000000000000m
0=WIf@030000003IfMT0fMWI0:<0fMWI1000000F0=WIf@D000000P3IfMT2000001L0fMWI00030=WI
f@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0X03IfMT3000001`0fMWI00D000000=WI
f@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI01@0fMWI00030=WIf@800000>`3IfMT00`00
0000fMWI0=WIf@2L0=WIf@@000007`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
01@0fMWI00050=WIf@800000>@3IfMT00`000000fMWI0=WIf@2F0=WIf@030000003IfMT0000000<0
00008`3IfMT00`000000fMWI0=WIf@020=WIf@8000005`3IfMT000L0fMWI0P00000f0=WIf@030000
003IfMT0fMWI09D0fMWI1000000W0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
5P3IfMT000P0fMWI00<000000=WIf@3IfMT0=03IfMT00`000000fMWI0=WIf@2A0=WIf@@00000:P3I
fMT2000000@0fMWI0`00000F0=WIf@002@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0R@3IfMT0
10000000fMWI0=WIf@3IfMT4000004d0fMWI000;0=WIf@800000<P3IfMT00`000000fMWI0=WIf@29
0=WIf@@00000D@3IfMT000`0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@250=WI
f@@00000E@3IfMT000d0fMWI0P00000`0=WIf@030000003IfMT0fMWI07`0fMWI00<000000=WIf@3I
fMT00`3IfMT3000005T0fMWI000?0=WIf@030000003IfMT0000002d0fMWI00<000000=WIf@3IfMT0
O03IfMT00`000000fMWI00000003000005`0fMWI000@0=WIf@030000003IfMT0fMWI02`0fMWI00<0
00000=WIf@3IfMT0NP3IfMT400000600fMWI000A0=WIf@800000;03IfMT00`000000fMWI0=WIf@1f
0=WIf@@00000I03IfMT001<0fMWI00<000000=WIf@3IfMT0:@3IfMT00`000000fMWI0=WIf@1_0=WI
f@030000003IfMT0fMWI00@00000J03IfMT001@0fMWI0P00000Y0=WIf@030000003IfMT0fMWI06h0
fMWI1000001/0=WIf@005@3IfMT2000002P0fMWI00<000000=WIf@3IfMT0JP3IfMT400000700fMWI
000G0=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT0IP3IfMT4000007@0fMWI000H
0=WIf@8000009@3IfMT00`000000fMWI0=WIf@1R0=WIf@@00000N03IfMT001T0fMWI0P00000T0=WI
f@030000003IfMT0fMWI05l0fMWI1000000D0=WIf@D000000P3IfMT2000005h0fMWI000B0=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI05/0fMWI1000000J0=WIf@05
0000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WIf@1K0=WIf@004`3IfMT00`000000
fMWI0=WIf@060=WIf@800000803IfMT00`000000fMWI0=WIf@1F0=WIf@030000003IfMT0000000<0
00007P3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT0F`3IfMT00100
fMWI1@0000080=WIf@8000007`3IfMT00`000000fMWI0=WIf@1D0=WIf@@000008P3IfMT01@000000
fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT0F`3IfMT000X0fMWI100000020=WIf@04
0000003IfMT0fMWI000000/0fMWI00<000000=WIf@000000703IfMT00`000000fMWI0=WIf@1@0=WI
f@@000009P3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT0F`3IfMT0
0140fMWI00<000000=WIf@000000303IfMT2000001`0fMWI00<000000=WIf@3IfMT0B@3IfMT00`00
0000fMWI0=WIf@04000002T0fMWI0P0000040=WIf@800000GP3IfMT00180fMWI0P00000=0=WIf@80
00006`3IfMT00`000000fMWI0=WIf@180=WIf@@00000T`3IfMT002<0fMWI00<000000=WIf@3IfMT0
603IfMT00`000000fMWI0=WIf@140=WIf@@00000U`3IfMT002@0fMWI0P00000H0=WIf@030000003I
fMT0fMWI03`0fMWI00@000000=WIf@3IfMT0fMWI1000002K0=WIf@009@3IfMT2000001L0fMWI00<0
00000=WIf@3IfMT0?03IfMT4000009l0fMWI000W0=WIf@030000003IfMT0fMWI01@0fMWI00<00000
0=WIf@3IfMT0>@3IfMT400000:80fMWI000X0=WIf@800000503IfMT00`000000fMWI0=WIf@0e0=WI
f@@00000YP3IfMT002T0fMWI0P00000C0=WIf@030000003IfMT0fMWI0300fMWI1@00002Z0=WIf@00
8@3IfMT4000000H0fMWI0P00000A0=WIf@030000003IfMT0fMWI02d0fMWI1000002^0=WIf@008@3I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0:@3I
fMT400000;80fMWI000R0=WIf@030000003IfMT0fMWI00P0fMWI0P00000?0=WIf@030000003IfMT0
fMWI02@0fMWI1@00002f0=WIf@006`3IfMT4000000@0fMWI00<000000=WIf@3IfMT02@3IfMT30000
00`0fMWI00<000000=WIf@3IfMT08@3IfMT400000;X0fMWI000Q0=WIf@040000003IfMT0fMWI0000
00`0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0N0=WIf@<000006P3IfMT20000
0:80fMWI000R0=WIf@8000003@3IfMT2000000X0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000
fMWI00000003000001`0fMWI00@000000=WIf@3IfMT00000X@3IfMT003<0fMWI0`0000070=WIf@03
0000003IfMT0fMWI01L0fMWI1000000S0=WIf@030000003IfMT0fMWI09l0fMWI000e0=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT04`3IfMT4000002D0fMWI0P00002R0=WIf@00=P3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@0000000`00
000Y0=WIf@030000003IfMT0fMWI0:40fMWI000g0=WIf@<000000`3IfMT00`000000fMWI0=WIf@0;
0=WIf@@00000;@3IfMT300000:40fMWI000i0=WIf@050000003IfMT0fMWI0=WIf@0000000`3IfMT0
0`000000fMWI0=WIf@030=WIf@@00000e@3IfMT003X0fMWI00@000000=WIf@3IfMT000000`3IfMT0
0`000000fMWI0000000300000=T0fMWI000_0=WIf@8000002P3IfMT3000000030=WIf@0000000000
00800000g@3IfMT002h0fMWI00@000000=WIf@3IfMT000002P3IfMT300000>40fMWI000^0=WIf@04
0000003IfMT0fMWI00000>h0fMWI000^0=WIf@040000003IfMT0fMWI00000>h0fMWI000^0=WIf@04
0000003IfMT0fMWI00000>h0fMWI000_0=WIf@800000k`3IfMT00?l0fMWI8@3IfMT00400fMWI0P00
003N0=WIf@00?`3IfMT010000000fMWI0=WIf@00003M0=WIf@00?`3IfMT010000000fMWI0=WIf@00
003M0=WIf@00?`3IfMT010000000fMWI0=WIf@00003M0=WIf@00?`3IfMT010000000fMWI0=WIf@00
003M0=WIf@00@03IfMT200000=h0fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI
003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI0000\
\>"],
  ImageRangeCache->{{{138, 425}, {673.875, 395.188}} -> {-0.51127, 1.4652, \
0.00376538, 0.00376538}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.23896 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.124453 1.32875 2.22045e-016 1.32875 [
[.06725 .17287 -5.77195 -9 ]
[.06725 .17287 .22805 0 ]
[.15843 .13561 -5.64577 -9 ]
[.15843 .13561 .35423 0 ]
[.25196 .0974 -5.51959 -9 ]
[.25196 .0974 .48041 0 ]
[.34791 .05821 -5.39341 -9 ]
[.34791 .05821 .60659 0 ]
[.44639 .018 -5.26723 -9 ]
[.44639 .018 .73277 0 ]
[.00026 .80008 -6 -3.03593 ]
[.00026 .80008 0 5.96407 ]
[.17017 .94221 -6 -3.15751 ]
[.17017 .94221 0 5.84249 ]
[.32047 1.06795 -12 -3.26043 ]
[.32047 1.06795 0 5.73957 ]
[.45439 1.17998 -12 -3.3487 ]
[.45439 1.17998 0 5.6513 ]
[.05169 .20446 -18 -2.67357 ]
[.05169 .20446 0 6.32643 ]
[.02776 .41087 -12 -2.79711 ]
[.02776 .41087 0 6.20289 ]
[.00131 .63914 -6 -2.9347 ]
[.00131 .63914 0 6.0653 ]
[ 0 0 0 0 ]
[ 1 1.23896 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0681 .18931 m
.53317 0 L
s
.07852 .18507 m
.08415 .19117 L
s
[(0)] .06725 .17287 .92398 1 Mshowa
.16942 .14807 m
.17491 .15429 L
s
[(2)] .15843 .13561 .88192 1 Mshowa
.26264 .11012 m
.26798 .11648 L
s
[(4)] .25196 .0974 .83986 1 Mshowa
.35827 .07119 m
.36345 .07768 L
s
[(6)] .34791 .05821 .7978 1 Mshowa
.45641 .03125 m
.46142 .03787 L
s
[(8)] .44639 .018 .75574 1 Mshowa
.125 Mabswid
.10103 .1759 m
.10439 .17958 L
s
.12368 .16668 m
.12702 .17038 L
s
.14648 .1574 m
.1498 .16112 L
s
.1925 .13867 m
.19578 .14243 L
s
.21574 .12921 m
.21899 .13299 L
s
.23911 .1197 m
.24234 .12349 L
s
.28632 .10048 m
.2895 .10432 L
s
.31015 .09078 m
.31331 .09464 L
s
.33413 .08102 m
.33727 .08489 L
s
.38257 .0613 m
.38565 .06522 L
s
.40702 .05135 m
.41008 .05528 L
s
.43163 .04133 m
.43467 .04529 L
s
.48135 .0211 m
.48432 .02509 L
s
.50645 .01088 m
.5094 .01489 L
s
.53171 .00059 m
.53464 .00463 L
s
.25 Mabswid
0 .78148 m
.54576 1.23896 L
s
.01606 .79494 m
.02396 .79237 L
s
[(0)] .00026 .80008 1 -0.32535 Mshowa
.18608 .93747 m
.19404 .93509 L
s
[(5)] .17017 .94221 1 -0.29833 Mshowa
.33649 1.06354 m
.34449 1.06134 L
s
[(10)] .32047 1.06795 1 -0.27546 Mshowa
.47048 1.17586 m
.47852 1.1738 L
s
[(15)] .45439 1.17998 1 -0.25584 Mshowa
.125 Mabswid
.05182 .82491 m
.05656 .8234 L
s
.08666 .85412 m
.09142 .85263 L
s
.12064 .8826 m
.1254 .88113 L
s
.15377 .91037 m
.15853 .90893 L
s
.21762 .9639 m
.2224 .9625 L
s
.2484 .9897 m
.25319 .98832 L
s
.27846 1.0149 m
.28325 1.01354 L
s
.30781 1.0395 m
.31261 1.03816 L
s
.36451 1.08703 m
.36932 1.08573 L
s
.3919 1.10999 m
.39671 1.1087 L
s
.41868 1.13244 m
.42349 1.13117 L
s
.44486 1.15439 m
.44969 1.15314 L
s
.49554 1.19687 m
.50037 1.19565 L
s
.52007 1.21743 m
.5249 1.21623 L
s
.54408 1.23756 m
.54892 1.23637 L
s
.25 Mabswid
.0681 .18931 m
0 .78148 L
s
.06708 .19821 m
.07477 .19509 L
s
[(-10)] .05169 .20446 1 -0.40587 Mshowa
.0433 .405 m
.05106 .40206 L
s
[(-5)] .02776 .41087 1 -0.37842 Mshowa
.017 .63368 m
.02484 .63095 L
s
[(0)] .00131 .63914 1 -0.34785 Mshowa
.125 Mabswid
.06251 .23797 m
.06713 .23611 L
s
.05784 .2785 m
.06248 .27667 L
s
.05309 .31983 m
.05773 .31803 L
s
.04824 .36199 m
.05289 .3602 L
s
.03825 .44887 m
.04292 .44713 L
s
.0331 .49365 m
.03778 .49194 L
s
.02784 .53936 m
.03253 .53767 L
s
.02248 .58603 m
.02717 .58436 L
s
.0114 .68236 m
.01611 .68075 L
s
.00568 .73209 m
.01041 .73051 L
s
.25 Mabswid
.0681 .18931 m
0 .78148 L
s
0 .78148 m
.54576 1.23896 L
s
.54576 1.23896 m
.54515 .70289 L
s
.54515 .70289 m
.0681 .18931 L
s
.53317 0 m
.94961 .57551 L
s
.94961 .57551 m
1 1.12762 L
s
1 1.12762 m
.53212 .60696 L
s
.53212 .60696 m
.53317 0 L
s
.0681 .18931 m
0 .78148 L
s
0 .78148 m
.53212 .60696 L
s
.53212 .60696 m
.53317 0 L
s
.53317 0 m
.0681 .18931 L
s
.54515 .70289 m
.94961 .57551 L
s
.94961 .57551 m
1 1.12762 L
s
1 1.12762 m
.54576 1.23896 L
s
.54576 1.23896 m
.54515 .70289 L
s
0 0 m
1 0 L
1 1.23896 L
0 1.23896 L
closepath
clip
newpath
.5 Mabswid
.74361 .77736 m
.77588 .82085 L
s
.70753 .73092 m
.74361 .77736 L
s
.66826 .68236 m
.70753 .73092 L
s
.77588 .82085 m
.80369 .86058 L
s
.62645 .63251 m
.66826 .68236 L
s
.80369 .86058 m
.81063 .88098 L
s
.58273 .58227 m
.62645 .63251 L
s
.53778 .53255 m
.58273 .58227 L
s
.63379 .65869 m
.67633 .72249 L
s
.59013 .59528 m
.63379 .65869 L
s
.54604 .53361 m
.59013 .59528 L
s
.4923 .48435 m
.53778 .53255 L
s
.67633 .72249 m
.71704 .78533 L
s
.81063 .88098 m
.79824 .88357 L
s
.50224 .47505 m
.54604 .53361 L
s
.71704 .78533 m
.75522 .84586 L
s
.46776 .44042 m
.50224 .47505 L
s
.75522 .84586 m
.79011 .90269 L
s
.44708 .43874 m
.4923 .48435 L
s
.44006 .42372 m
.46776 .44042 L
s
.79011 .90269 m
.82094 .95439 L
s
.41351 .4116 m
.44006 .42372 L
s
.41284 .41246 m
.44708 .43874 L
s
.82094 .95439 m
.8469 .99948 L
s
.38807 .40372 m
.41351 .4116 L
s
.79824 .88357 m
.78078 .88159 L
s
.3869 .40103 m
.41284 .41246 L
s
.8469 .99948 m
.84907 1.00847 L
s
.36372 .39971 m
.38807 .40372 L
s
.36264 .3938 m
.3869 .40103 L
s
.84907 1.00847 m
.82915 .98385 L
s
.33997 .39042 m
.36264 .3938 L
s
.34046 .39924 m
.36372 .39971 L
s
.84038 .78925 m
.83621 .78097 L
s
.82092 .78816 m
.84038 .78925 L
s
.83621 .78097 m
.82371 .76966 L
s
.31883 .39057 m
.33997 .39042 L
s
.78078 .88159 m
.7589 .87538 L
s
.31829 .40196 m
.34046 .39924 L
s
.82915 .98385 m
.80366 .95095 L
s
.29916 .3939 m
.31883 .39057 L
s
.82371 .76966 m
.80837 .7577 L
s
.79789 .78624 m
.82092 .78816 L
s
.29725 .40753 m
.31829 .40196 L
s
.28088 .40006 m
.29916 .3939 L
s
.87985 .92007 m
.87564 .90538 L
s
.8541 .89549 m
.87985 .92007 L
s
.87564 .90538 m
.86086 .87706 L
s
.27738 .41557 m
.29725 .40753 L
s
.80837 .7577 m
.79075 .74546 L
s
.80366 .95095 m
.77359 .91101 L
s
.86086 .87706 m
.8425 .84454 L
s
.26396 .40868 m
.28088 .40006 L
s
.7589 .87538 m
.73337 .86532 L
s
.77181 .78371 m
.79789 .78624 L
s
.82402 .86573 m
.8541 .89549 L
s
.25874 .42571 m
.27738 .41557 L
s
.8425 .84454 m
.82133 .8089 L
s
.24833 .41938 m
.26396 .40868 L
s
.79075 .74546 m
.77147 .73332 L
s
.82133 .8089 m
.79811 .77128 L
s
.24291 .4331 m
.25874 .42571 L
s
.79044 .83186 m
.82402 .86573 L
s
.77359 .91101 m
.74002 .86541 L
s
.23397 .43177 m
.24833 .41938 L
s
.74331 .78075 m
.77181 .78371 L
s
.22901 .44027 m
.24291 .4331 L
s
.79811 .77128 m
.77367 .73293 L
s
.22081 .44074 m
.23397 .43177 L
s
.73337 .86532 m
.70508 .85182 L
s
.77147 .73332 m
.75121 .72172 L
s
.75428 .79502 m
.79044 .83186 L
s
.21646 .44875 m
.22901 .44027 L
s
.20885 .44902 m
.22081 .44074 L
s
.74002 .86541 m
.70418 .81574 L
s
.77367 .73293 m
.7489 .69516 L
s
.20519 .45846 m
.21646 .44875 L
s
.19805 .45823 m
.20885 .44902 L
s
.71313 .77761 m
.74331 .78075 L
s
.19513 .46934 m
.20519 .45846 L
s
.18834 .46835 m
.19805 .45823 L
s
.71661 .75652 m
.75428 .79502 L
s
.7489 .69516 m
.72476 .65941 L
s
.75121 .72172 m
.73076 .71117 L
s
.18621 .48131 m
.19513 .46934 L
s
.17967 .47931 m
.18834 .46835 L
s
.70418 .81574 m
.66744 .76377 L
s
.70508 .85182 m
.67513 .83542 L
s
.17834 .49427 m
.18621 .48131 L
s
.17197 .49105 m
.17967 .47931 L
s
.72476 .65941 m
.70227 .62723 L
s
.67861 .7178 m
.71661 .75652 L
s
.16517 .50354 m
.17197 .49105 L
s
.17146 .50815 m
.17834 .49427 L
s
.73076 .71117 m
.71101 .70224 L
s
.68218 .77456 m
.71313 .77761 L
s
.1592 .5167 m
.16517 .50354 L
s
.16547 .52286 m
.17146 .50815 L
s
.70227 .62723 m
.68253 .60026 L
s
.66744 .76377 m
.63138 .71155 L
s
.15399 .53049 m
.1592 .5167 L
s
.16028 .5383 m
.16547 .52286 L
s
.64163 .68047 m
.67861 .7178 L
s
.14946 .54484 m
.15399 .53049 L
s
.76271 .79645 m
.78794 .82379 L
s
.68253 .60026 m
.69309 .62497 L
s
.74942 .7396 m
.77194 .78288 L
s
.1558 .5544 m
.16028 .5383 L
s
.72826 .69781 m
.74942 .7396 L
s
.67513 .83542 m
.64483 .81676 L
s
.69309 .62497 m
.70922 .65908 L
s
.70922 .65908 m
.72826 .69781 L
s
.14554 .5597 m
.14946 .54484 L
s
.71101 .70224 m
.69295 .69557 L
s
.15194 .57105 m
.1558 .5544 L
s
.14213 .57501 m
.14554 .5597 L
s
.63138 .71155 m
.59771 .66132 L
s
.73793 .76837 m
.76271 .79645 L
s
.65155 .77189 m
.68218 .77456 L
s
.1486 .58816 m
.15194 .57105 L
s
.60717 .64633 m
.64163 .68047 L
s
.13915 .5907 m
.14213 .57501 L
s
.14568 .60563 m
.1486 .58816 L
s
.13653 .60672 m
.13915 .5907 L
s
.71451 .74058 m
.73793 .76837 L
s
.14307 .62337 m
.14568 .60563 L
s
.13416 .623 m
.13653 .60672 L
s
.69295 .69557 m
.67767 .69183 L
s
.57685 .6173 m
.60717 .64633 L
s
.59771 .66132 m
.56831 .61557 L
s
.14068 .64128 m
.14307 .62337 L
s
.13197 .6395 m
.13416 .623 L
s
.64483 .81676 m
.61571 .79664 L
s
.69344 .71414 m
.71451 .74058 L
s
.13839 .65927 m
.14068 .64128 L
s
.12986 .65614 m
.13197 .6395 L
s
.62253 .76994 m
.65155 .77189 L
s
.13609 .67722 m
.13839 .65927 L
s
.56831 .61557 m
.57685 .6173 L
s
.12773 .67287 m
.12986 .65614 L
s
.67767 .69183 m
.69344 .71414 L
s
.13367 .69506 m
.13609 .67722 L
s
.1255 .68963 m
.12773 .67287 L
s
.12306 .70635 m
.1255 .68963 L
s
.13102 .71266 m
.13367 .69506 L
s
.61571 .79664 m
.58955 .77602 L
s
.5966 .76905 m
.62253 .76994 L
s
.58955 .77602 m
.5966 .76905 L
s
.25 Mabswid
.53317 0 m
.94961 .57551 L
s
.94961 .57551 m
1 1.12762 L
s
1 1.12762 m
.53212 .60696 L
s
.53212 .60696 m
.53317 0 L
s
.0681 .18931 m
0 .78148 L
s
0 .78148 m
.53212 .60696 L
s
.53212 .60696 m
.53317 0 L
s
.53317 0 m
.0681 .18931 L
s
.0681 .18931 m
.53317 0 L
s
.07852 .18507 m
.08415 .19117 L
s
[(0)] .06725 .17287 .92398 1 Mshowa
.16942 .14807 m
.17491 .15429 L
s
[(2)] .15843 .13561 .88192 1 Mshowa
.26264 .11012 m
.26798 .11648 L
s
[(4)] .25196 .0974 .83986 1 Mshowa
.35827 .07119 m
.36345 .07768 L
s
[(6)] .34791 .05821 .7978 1 Mshowa
.45641 .03125 m
.46142 .03787 L
s
[(8)] .44639 .018 .75574 1 Mshowa
.125 Mabswid
.10103 .1759 m
.10439 .17958 L
s
.12368 .16668 m
.12702 .17038 L
s
.14648 .1574 m
.1498 .16112 L
s
.1925 .13867 m
.19578 .14243 L
s
.21574 .12921 m
.21899 .13299 L
s
.23911 .1197 m
.24234 .12349 L
s
.28632 .10048 m
.2895 .10432 L
s
.31015 .09078 m
.31331 .09464 L
s
.33413 .08102 m
.33727 .08489 L
s
.38257 .0613 m
.38565 .06522 L
s
.40702 .05135 m
.41008 .05528 L
s
.43163 .04133 m
.43467 .04529 L
s
.48135 .0211 m
.48432 .02509 L
s
.50645 .01088 m
.5094 .01489 L
s
.53171 .00059 m
.53464 .00463 L
s
.25 Mabswid
0 .78148 m
.54576 1.23896 L
s
.01606 .79494 m
.02396 .79237 L
s
[(0)] .00026 .80008 1 -0.32535 Mshowa
.18608 .93747 m
.19404 .93509 L
s
[(5)] .17017 .94221 1 -0.29833 Mshowa
.33649 1.06354 m
.34449 1.06134 L
s
[(10)] .32047 1.06795 1 -0.27546 Mshowa
.47048 1.17586 m
.47852 1.1738 L
s
[(15)] .45439 1.17998 1 -0.25584 Mshowa
.125 Mabswid
.05182 .82491 m
.05656 .8234 L
s
.08666 .85412 m
.09142 .85263 L
s
.12064 .8826 m
.1254 .88113 L
s
.15377 .91037 m
.15853 .90893 L
s
.21762 .9639 m
.2224 .9625 L
s
.2484 .9897 m
.25319 .98832 L
s
.27846 1.0149 m
.28325 1.01354 L
s
.30781 1.0395 m
.31261 1.03816 L
s
.36451 1.08703 m
.36932 1.08573 L
s
.3919 1.10999 m
.39671 1.1087 L
s
.41868 1.13244 m
.42349 1.13117 L
s
.44486 1.15439 m
.44969 1.15314 L
s
.49554 1.19687 m
.50037 1.19565 L
s
.52007 1.21743 m
.5249 1.21623 L
s
.54408 1.23756 m
.54892 1.23637 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 356.813},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001I2000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00P03IfMT2000009h0fMWI001o0=WIf@040000003I
fMT0fMWI000009d0fMWI001o0=WIf@040000003IfMT0fMWI000001L0fMWI0P0000240=WIf@00P03I
fMT2000001H0fMWI0P0000000`3IfMT00000000000230=WIf@00O`3IfMT010000000fMWI0=WIf@00
000B0=WIf@<000000`3IfMT2000008<0fMWI00200=WIf@8000004@3IfMT2000000H0fMWI00<00000
0=WIf@000000PP3IfMT00940fMWI0P0000000`3IfMT000000=WIf@050=WIf@040000003IfMT0fMWI
00000840fMWI002>0=WIf@<00000103IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI
0=WIf@000000P03IfMT008`0fMWI0P00000=0=WIf@050000003IfMT0fMWI0=WIf@000000P03IfMT0
08T0fMWI0`0000020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@1m0=WIf@00Q`3IfMT200000180fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@1l0=WIf@00H`3IfMT3000001l0fMWI0P00000D0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT0N`3IfMT006<0fMWI00@000000=WIf@3IfMT000006`3IfMT300000080fMWI
00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI07/0fMWI
001S0=WIf@040000003IfMT0fMWI000001T0fMWI0P0000050=WIf@030000003IfMT0fMWI0140fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@1j0=WIf@00H`3IfMT3000001L0fMWI0`00
000K0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0N@3IfMT006@0fMWI00<00000
0=WIf@3IfMT0503IfMT2000000<0fMWI00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI07T0fMWI001T0=WIf@<000004P3IfMT200000200fMWI00<000000=WI
f@3IfMT01`3IfMT00`000000fMWI0=WIf@1h0=WIf@00MP3IfMT300000280fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@1g0=WIf@00M03IfMT2000000<0fMWI00<000000=WIf@3IfMT0
7`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI07H0fMWI001a0=WIf@<000009`3I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI07H0fMWI001_0=WIf@<00000:@3IfMT0
0`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI07D0fMWI001]0=WIf@8000000`3IfMT00`00
0000fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0M03IfMT004X0
fMWI0`00000M0=WIf@<00000;P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI07@0
fMWI001;0=WIf@030000003IfMT0fMWI01X0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@030000
003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0L`3IfMT004P0fMWI1@00000H0=WIf@<00000103I
fMT00`000000fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0LP3I
fMT004P0fMWI00@000000=WIf@3IfMT000005`3IfMT2000003H0fMWI00<000000=WIf@3IfMT03P3I
fMT00`000000fMWI0=WIf@1a0=WIf@00B@3IfMT00`000000fMWI0000000E0=WIf@80000000<0fMWI
0000003IfMT0=@3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI0740fMWI001:0=WI
f@8000004P3IfMT3000003X0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@1`0=WI
f@00G03IfMT2000003d0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@1_0=WIf@00
F@3IfMT3000000030=WIf@000000fMWI03`0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI
0=WIf@1^0=WIf@00E`3IfMT200000480fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WI
f@1^0=WIf@00E03IfMT3000004@0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@1]
0=WIf@00DP3IfMT2000000<0fMWI00<000000=WIf@3IfMT0@@3IfMT00`000000fMWI0=WIf@0C0=WI
f@030000003IfMT0fMWI06`0fMWI000]0=WIf@@000007P3IfMT3000004T0fMWI00<000000=WIf@3I
fMT04`3IfMT00`000000fMWI0=WIf@1/0=WIf@00;@3IfMT00`000000fMWI0=WIf@0M0=WIf@@00000
BP3IfMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI06/0fMWI000^0=WIf@030000003I
fMT0fMWI01X0fMWI0P0000040=WIf@030000003IfMT0fMWI04L0fMWI00<000000=WIf@3IfMT05@3I
fMT00`000000fMWI0=WIf@1Z0=WIf@00;`3IfMT00`000000fMWI0=WIf@0F0=WIf@<00000D03IfMT0
0`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI06T0fMWI000]0=WIf@040000003IfMT0fMWI
000001D0fMWI0P0000020=WIf@030000003IfMT0fMWI04h0fMWI00<000000=WIf@3IfMT05P3IfMT0
0`000000fMWI0=WIf@1Y0=WIf@00;P3IfMT2000001@0fMWI0P00001E0=WIf@030000003IfMT0fMWI
01L0fMWI00<000000=WIf@3IfMT0J03IfMT00440fMWI0`00001G0=WIf@030000003IfMT0fMWI01P0
fMWI00<000000=WIf@3IfMT0I`3IfMT003l0fMWI0P0000020=WIf@030000003IfMT0fMWI05D0fMWI
00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@1W0=WIf@00?03IfMT3000005`0fMWI00<0
00000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@1V0=WIf@00>P3IfMT3000005h0fMWI00<00000
0=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@1U0=WIf@005@3IfMT200000240fMWI0P00001Q0=WI
f@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0I03IfMT001@0fMWI00@000000=WIf@3I
fMT000007@3IfMT3000006<0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@1T0=WI
f@00503IfMT010000000fMWI0=WIf@00000K0=WIf@80000000<0fMWI0000003IfMT0H`3IfMT00`00
0000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI06<0fMWI000D0=WIf@040000003IfMT0fMWI0000
01P0fMWI0`0000040=WIf@030000003IfMT0fMWI0640fMWI00<000000=WIf@3IfMT07@3IfMT00`00
0000fMWI0=WIf@1R0=WIf@00503IfMT010000000fMWI0=WIf@00000F0=WIf@800000J`3IfMT00`00
0000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0640fMWI000E0=WIf@8000005@3IfMT200000080
fMWI00<000000=WIf@3IfMT0J03IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0640
fMWI000X0=WIf@@00000K`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI0600fMWI
000W0=WIf@<00000L@3IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI05l0fMWI000T
0=WIf@<00000M03IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI05l0fMWI000R0=WI
f@800000M`3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI05h0fMWI000P0=WIf@80
000000<0fMWI0000003IfMT0MP3IfMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0fMWI05d0
fMWI000K0=WIf@030000003IfMT0000000800000N`3IfMT00`000000fMWI0=WIf@0S0=WIf@030000
003IfMT0fMWI05`0fMWI000K0=WIf@800000OP3IfMT00`000000fMWI0=WIf@0S0=WIf@030000003I
fMT0fMWI05`0fMWI000I0=WIf@8000000P3IfMT00`000000fMWI0=WIf@1k0=WIf@030000003IfMT0
fMWI02@0fMWI00<000000=WIf@3IfMT0F`3IfMT001T0fMWI0P0000200=WIf@030000003IfMT0fMWI
02D0fMWI00<000000=WIf@3IfMT0FP3IfMT001P0fMWI0P0000000`3IfMT000000=WIf@1n0=WIf@03
0000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT0FP3IfMT001T0fMWI00@000000=WIf@3IfMT0
0000OP3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI05T0fMWI00090=WIf@D00000
0P3IfMT2000000L0fMWI00D000000=WIf@3IfMT0fMWI0000001m0=WIf@030000003IfMT0fMWI02L0
fMWI00<000000=WIf@3IfMT0F03IfMT000/0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@1j0=WIf@03
0000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT0E`3IfMT000/0fMWI00D000000=WIf@3IfMT0
fMWI000000020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@1i0=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT0E`3IfMT000<0fMWI
100000040=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0N03IfMT00`000000fMWI0=WIf@0Y0=WIf@03
0000003IfMT0fMWI05H0fMWI000;0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0N03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI05D0fMWI000:0=WIf@800000103IfMT2000000H0fMWI
00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@1g0=WIf@030000003IfMT0fMWI02/0fMWI
00<000000=WIf@3IfMT0E03IfMT001P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@1f0=WIf@030000003IfMT0fMWI02/0fMWI00<000000=WIf@3IfMT0E03IfMT001P0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@1e0=WIf@030000003IfMT0fMWI02`0fMWI00<00000
0=WIf@3IfMT0D`3IfMT001P0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@1d0=WI
f@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0DP3IfMT001L0fMWI0P00000<0=WIf@03
0000003IfMT0fMWI07<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000fMWI0=WIf@1B0=WIf@00
5`3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI0780fMWI00<000000=WIf@3IfMT0
;P3IfMT00`000000fMWI0=WIf@1A0=WIf@005`3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003I
fMT0fMWI0740fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@1@0=WIf@005`3IfMT0
0`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI0700fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@1?0=WIf@005`3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI
06l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@1?0=WIf@005`3IfMT00`000000
fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI06h0fMWI00<000000=WIf@3IfMT0<@3IfMT00`000000
fMWI0=WIf@1>0=WIf@005`3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI06d0fMWI
00<000000=WIf@3IfMT0<P3IfMT00`000000fMWI0=WIf@1=0=WIf@005`3IfMT00`000000fMWI0=WI
f@0B0=WIf@030000003IfMT0fMWI06`0fMWI00<000000=WIf@3IfMT0<P3IfMT00`000000fMWI0=WI
f@1=0=WIf@005P3IfMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI06/0fMWI00<00000
0=WIf@3IfMT0<`3IfMT00`000000fMWI0=WIf@1<0=WIf@005P3IfMT00`000000fMWI0=WIf@0D0=WI
f@030000003IfMT0fMWI06/0fMWI00<000000=WIf@3IfMT0=03IfMT00`000000fMWI0=WIf@1;0=WI
f@005P3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI06X0fMWI00<000000=WIf@3I
fMT0=@3IfMT00`000000fMWI0=WIf@1:0=WIf@005P3IfMT2000001L0fMWI00<000000=WIf@3IfMT0
J@3IfMT00`000000fMWI0=WIf@0e0=WIf@030000003IfMT0fMWI04X0fMWI000F0=WIf@030000003I
fMT0fMWI01L0fMWI00<000000=WIf@3IfMT0J03IfMT00`000000fMWI0=WIf@0f0=WIf@030000003I
fMT0fMWI04T0fMWI000F0=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0I`3IfMT0
0`000000fMWI0=WIf@0g0=WIf@030000003IfMT0fMWI04P0fMWI000F0=WIf@030000003IfMT0fMWI
01T0fMWI00<000000=WIf@3IfMT0IP3IfMT00`000000fMWI0=WIf@0h0=WIf@030000003IfMT0fMWI
04L0fMWI000F0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0I@3IfMT00`000000
fMWI0=WIf@0h0=WIf@030000003IfMT0fMWI04L0fMWI000F0=WIf@030000003IfMT0fMWI01/0fMWI
00<000000=WIf@3IfMT0I03IfMT00`000000fMWI0=WIf@0i0=WIf@030000003IfMT0fMWI04H0fMWI
000E0=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0H`3IfMT00`000000fMWI0=WI
f@0j0=WIf@030000003IfMT0fMWI04D0fMWI000E0=WIf@030000003IfMT0fMWI01h0fMWI00<00000
0=WIf@3IfMT0HP3IfMT00`000000fMWI0=WIf@0j0=WIf@030000003IfMT0fMWI04D0fMWI000E0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT0H@3IfMT00`000000fMWI0=WIf@0k0=WI
f@030000003IfMT0fMWI04@0fMWI000E0=WIf@030000003IfMT0fMWI0200fMWI00<000000=WIf@3I
fMT0H03IfMT00`000000fMWI0=WIf@0l0=WIf@030000003IfMT0fMWI04<0fMWI000E0=WIf@030000
003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT0G`3IfMT00`000000fMWI0=WIf@0m0=WIf@030000
003IfMT0fMWI0480fMWI000E0=WIf@030000003IfMT0fMWI0280fMWI00<000000=WIf@3IfMT0GP3I
fMT00`000000fMWI0=WIf@0m0=WIf@030000003IfMT0fMWI0480fMWI000D0=WIf@<000008`3IfMT0
0`000000fMWI0=WIf@1N0=WIf@030000003IfMT0fMWI03h0fMWI00<000000=WIf@3IfMT0@@3IfMT0
01D0fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@1M0=WIf@030000003IfMT0fMWI
03l0fMWI00<000000=WIf@3IfMT0@03IfMT001@0fMWI00<000000=WIf@3IfMT09@3IfMT00`000000
fMWI0=WIf@1L0=WIf@030000003IfMT0fMWI03l0fMWI00<000000=WIf@3IfMT0@03IfMT001@0fMWI
00<000000=WIf@3IfMT09P3IfMT00`000000fMWI0=WIf@1K0=WIf@030000003IfMT0fMWI0400fMWI
00<000000=WIf@3IfMT0?`3IfMT001@0fMWI00<000000=WIf@3IfMT09`3IfMT00`000000fMWI0=WI
f@1J0=WIf@030000003IfMT0fMWI0440fMWI00<000000=WIf@3IfMT0?P3IfMT001@0fMWI00<00000
0=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@1I0=WIf@030000003IfMT0fMWI0480fMWI00<00000
0=WIf@3IfMT0?@3IfMT001@0fMWI00<000000=WIf@3IfMT0:@3IfMT00`000000fMWI0=WIf@1H0=WI
f@030000003IfMT0fMWI0480fMWI00<000000=WIf@3IfMT0?@3IfMT001@0fMWI00<000000=WIf@3I
fMT0:P3IfMT00`000000fMWI0=WIf@1G0=WIf@030000003IfMT0fMWI04<0fMWI00<000000=WIf@3I
fMT0?03IfMT001@0fMWI00<000000=WIf@3IfMT0:`3IfMT00`000000fMWI0=WIf@1F0=WIf@030000
003IfMT0fMWI04@0fMWI00<000000=WIf@3IfMT0>`3IfMT001@0fMWI00<000000=WIf@3IfMT0;03I
fMT00`000000fMWI0=WIf@1E0=WIf@030000003IfMT0fMWI04D0fMWI00<000000=WIf@3IfMT0>P3I
fMT001<0fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@1D0=WIf@030000003IfMT0
fMWI04D0fMWI00<000000=WIf@3IfMT0>P3IfMT001<0fMWI00<000000=WIf@3IfMT0;`3IfMT00`00
0000fMWI0=WIf@1C0=WIf@030000003IfMT0fMWI04H0fMWI00<000000=WIf@3IfMT0>@3IfMT001<0
fMWI0P00000a0=WIf@030000003IfMT0fMWI0580fMWI00<000000=WIf@3IfMT0A`3IfMT00`000000
fMWI0=WIf@0h0=WIf@004`3IfMT00`000000fMWI0=WIf@0a0=WIf@030000003IfMT0fMWI0540fMWI
00<000000=WIf@3IfMT0A`3IfMT00`000000fMWI0=WIf@0h0=WIf@004`3IfMT00`000000fMWI0=WI
f@0b0=WIf@030000003IfMT0fMWI0500fMWI00<000000=WIf@3IfMT0B03IfMT00`000000fMWI0=WI
f@0g0=WIf@004`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI0500fMWI00<00000
0=WIf@3IfMT0B@3IfMT00`000000fMWI0=WIf@0f0=WIf@004`3IfMT00`000000fMWI0=WIf@0c0=WI
f@030000003IfMT0fMWI04l0fMWI00<000000=WIf@3IfMT0BP3IfMT00`000000fMWI0=WIf@0e0=WI
f@004`3IfMT00`000000fMWI0=WIf@0d0=WIf@030000003IfMT0fMWI04h0fMWI00<000000=WIf@3I
fMT0BP3IfMT00`000000fMWI0=WIf@0e0=WIf@004P3IfMT00`000000fMWI0=WIf@0f0=WIf@030000
003IfMT0fMWI04d0fMWI00<000000=WIf@3IfMT0B`3IfMT00`000000fMWI0=WIf@0d0=WIf@004P3I
fMT00`000000fMWI0=WIf@0g0=WIf@030000003IfMT0fMWI04`0fMWI00<000000=WIf@3IfMT0C03I
fMT00`000000fMWI0=WIf@0c0=WIf@004P3IfMT00`000000fMWI0=WIf@0h0=WIf@030000003IfMT0
fMWI00d0fMWI2`00000c0=WIf@030000003IfMT0fMWI04`0fMWI00<000000=WIf@3IfMT0<`3IfMT0
0180fMWI00<000000=WIf@3IfMT0>@3IfMT00`000000fMWI0=WIf@080=WIf@@000002`3IfMT50000
02h0fMWI00<000000=WIf@3IfMT0C@3IfMT00`000000fMWI0=WIf@0b0=WIf@004P3IfMT00`000000
fMWI0=WIf@0j0=WIf@030000003IfMT0fMWI00@0fMWI0`00000D0=WIf@@00000:P3IfMT00`000000
fMWI0=WIf@1>0=WIf@030000003IfMT0fMWI0340fMWI000B0=WIf@<00000>`3IfMT00`000000fMWI
0=WIf@03000000P0fMWI4P000000103IfMT0000000000000000W0=WIf@030000003IfMT0fMWI04l0
fMWI00<000000=WIf@3IfMT0<03IfMT00180fMWI00<000000=WIf@3IfMT0?03IfMT2000000P0fMWI
0`00000B0=WIf@H000009@3IfMT00`000000fMWI0=WIf@1?0=WIf@030000003IfMT0fMWI0300fMWI
000B0=WIf@030000003IfMT0fMWI03/0fMWI00<000000=WIf@0000001@3IfMT3000001X0fMWI1000
000R0=WIf@030000003IfMT0fMWI0500fMWI00<000000=WIf@3IfMT0;`3IfMT000T0fMWI0P000007
0=WIf@030000003IfMT0fMWI03T0fMWI0P0000030=WIf@030000003IfMT0000000800000803IfMT3
00000200fMWI00<000000=WIf@3IfMT0D@3IfMT00`000000fMWI0=WIf@0^0=WIf@00203IfMT01000
0000fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI03P0fMWI0P0000050=WIf@8000009@3IfMT3
000001h0fMWI00<000000=WIf@3IfMT0DP3IfMT00`000000fMWI0=WIf@0]0=WIf@002`3IfMT00`00
0000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03L0fMWI00<000000=WIf@3IfMT00`3IfMT20000
0080fMWI00<000000=WIf@3IfMT08`3IfMT4000001`0fMWI00<000000=WIf@3IfMT0DP3IfMT00`00
0000fMWI0=WIf@0]0=WIf@000P3IfMT4000000<0fMWI0P0000060=WIf@030000003IfMT0fMWI03H0
fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI00<000000=WIf@3IfMT09@3IfMT010000000
fMWI00000000000J0=WIf@030000003IfMT0fMWI05<0fMWI00<000000=WIf@3IfMT0;03IfMT000T0
fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0e0=WIf@040000003IfMT0fMWI0=WI
f@8000001`3IfMT00`000000fMWI0=WIf@0U0=WIf@040000003IfMT0fMWI000001T0fMWI00<00000
0=WIf@3IfMT0E03IfMT00`000000fMWI0=WIf@0[0=WIf@002@3IfMT3000000D0fMWI00<000000=WI
f@3IfMT0=03IfMT00`000000fMWI0=WIf@02000000X0fMWI00<000000=WIf@3IfMT09@3IfMT00`00
0000fMWI0=WIf@02000001L0fMWI00<000000=WIf@3IfMT0E03IfMT00`000000fMWI0=WIf@0[0=WI
f@004@3IfMT00`000000fMWI0=WIf@0b0=WIf@80000000<0fMWI0000000000003@3IfMT00`000000
fMWI0=WIf@0U0=WIf@8000000P3IfMT2000001D0fMWI00<000000=WIf@3IfMT0E@3IfMT00`000000
fMWI0=WIf@0Z0=WIf@004@3IfMT00`000000fMWI0=WIf@0`0=WIf@80000000<0fMWI000000000000
403IfMT00`000000fMWI0=WIf@0V0=WIf@040000003IfMT0fMWI0=WIf@8000004`3IfMT00`000000
fMWI0=WIf@1F0=WIf@030000003IfMT0fMWI02T0fMWI000A0=WIf@030000003IfMT0fMWI02l0fMWI
00@000000=WIf@3IfMT000004`3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI0080
fMWI0P00000A0=WIf@030000003IfMT0fMWI05L0fMWI00<000000=WIf@3IfMT0:03IfMT00100fMWI
00<000000=WIf@3IfMT0;`3IfMT010000000fMWI00000000000E0=WIf@030000003IfMT0fMWI02H0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI05L0
fMWI00<000000=WIf@3IfMT0:03IfMT00100fMWI0P00000_0=WIf@030000003IfMT0000001P0fMWI
00<000000=WIf@3IfMT09P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00d0fMWI
00<000000=WIf@3IfMT0F03IfMT00`000000fMWI0=WIf@0W0=WIf@00403IfMT00`000000fMWI0=WI
f@0]0=WIf@030000003IfMT0000001X0fMWI00<000000=WIf@3IfMT09P3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0F@3IfMT00`000000fMWI0=WI
f@0V0=WIf@00403IfMT00`000000fMWI0=WIf@0[0=WIf@@00000703IfMT00`000000fMWI0=WIf@0V
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@1I
0=WIf@030000003IfMT0fMWI02H0fMWI000@0=WIf@030000003IfMT0fMWI02X0fMWI00<000000=WI
f@0000007`3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@1J0=WIf@030000003IfMT0fMWI02D0fMWI000@0=WIf@03
0000003IfMT0fMWI02T0fMWI00<000000=WIf@0000008@3IfMT00`000000fMWI0=WIf@0V0=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@1K0=WIf@03
0000003IfMT0fMWI02@0fMWI000@0=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WIf@000000
8`3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@1L0=WIf@030000003IfMT0fMWI02<0fMWI000@0=WIf@030000003I
fMT0fMWI02L0fMWI00<000000=WIf@0000009@3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@1L0=WIf@030000003I
fMT0fMWI02<0fMWI000?0=WIf@030000003IfMT0fMWI02L0fMWI00@000000=WIf@3IfMT000009P3I
fMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@1M0=WIf@030000003IfMT0fMWI0280fMWI000?0=WIf@030000003IfMT0
fMWI02L0fMWI00<000000=WIf@0000009`3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@1N0=WIf@030000003IfMT0
fMWI0240fMWI000?0=WIf@030000003IfMT0fMWI02H0fMWI00@000000=WIf@3IfMT00000:03IfMT0
0`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@1O0=WIf@030000003IfMT0fMWI0200fMWI000?0=WIf@030000003IfMT0fMWI
02D0fMWI00@000000=WIf@3IfMT00000:P3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@1O0=WIf@030000003IfMT0
fMWI0200fMWI000?0=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@000000;03IfMT00`00
0000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@1P0=WIf@030000003IfMT0fMWI01l0fMWI000?0=WIf@030000003IfMT0fMWI02@0
fMWI00@000000=WIf@3IfMT00000;@3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@1Q0=WIf@030000003IfMT0fMWI
01h0fMWI000?0=WIf@8000009@3IfMT00`000000fMWI0000000_0=WIf@030000003IfMT0fMWI02L0
fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT0000006<0fMWI00<000000=WI
f@3IfMT07P3IfMT000l0fMWI00<000000=WIf@3IfMT08`3IfMT010000000fMWI0=WIf@00000`0=WI
f@030000003IfMT0fMWI02L0fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WIf@00001T
0=WIf@030000003IfMT0fMWI01d0fMWI000?0=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WI
f@000000<P3IfMT00`000000fMWI0=WIf@0W0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT0
0`000000fMWI0=WIf@1S0=WIf@030000003IfMT0fMWI01`0fMWI000>0=WIf@030000003IfMT0fMWI
02<0fMWI00@000000=WIf@3IfMT00000<`3IfMT00`000000fMWI0=WIf@0W0=WIf@070000003IfMT0
fMWI0=WIf@000000fMWI0000001V0=WIf@030000003IfMT0fMWI01/0fMWI000>0=WIf@030000003I
fMT0fMWI02<0fMWI00<000000=WIf@000000=@3IfMT00`000000fMWI0=WIf@0W0=WIf@040000003I
fMT0fMWI0=WIf@800000IP3IfMT00`000000fMWI0=WIf@0K0=WIf@003P3IfMT00`000000fMWI0=WI
f@0R0=WIf@040000003IfMT0fMWI000003H0fMWI00<000000=WIf@3IfMT09`3IfMT01@000000fMWI
0=WIf@3IfMT0000006L0fMWI00<000000=WIf@3IfMT06P3IfMT000h0fMWI00<000000=WIf@3IfMT0
8P3IfMT00`000000fMWI0000000h0=WIf@030000003IfMT0fMWI02L0fMWI00@000000=WIf@3IfMT0
0000J03IfMT00`000000fMWI0=WIf@0I0=WIf@003P3IfMT00`000000fMWI0=WIf@0Q0=WIf@040000
003IfMT0fMWI000003T0fMWI00<000000=WIf@3IfMT09`3IfMT010000000fMWI00000000001W0=WI
f@030000003IfMT0fMWI01T0fMWI000>0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@00
0000>`3IfMT00`000000fMWI0=WIf@0W0=WIf@80000000<0fMWI0000003IfMT0IP3IfMT00`000000
fMWI0=WIf@0H0=WIf@003P3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0000003/0fMWI
00<000000=WIf@3IfMT0:03IfMT010000000fMWI0=WIf@00001W0=WIf@030000003IfMT0fMWI01L0
fMWI000>0=WIf@030000003IfMT0fMWI0200fMWI00<000000=WIf@000000?@3IfMT00`000000fMWI
0=WIf@0W0=WIf@80000000<0fMWI0000003IfMT0I`3IfMT00`000000fMWI0=WIf@0F0=WIf@003@3I
fMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0000003h0fMWI00<000000=WIf@3IfMT09P3I
fMT01@000000fMWI0000003IfMT0000006L0fMWI00<000000=WIf@3IfMT05P3IfMT000d0fMWI00<0
00000=WIf@3IfMT08@3IfMT200000400fMWI00<000000=WIf@3IfMT09@3IfMT01P000000fMWI0=WI
f@000000fMWI000006L0fMWI00<000000=WIf@3IfMT05@3IfMT000d0fMWI0`00000P0=WIf@030000
003IfMT000000440fMWI00<000000=WIf@3IfMT0903IfMT010000000fMWI0=WIf@3IfMT2000006P0
fMWI00<000000=WIf@3IfMT0503IfMT000d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI
000000120=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT00P3IfMT2000006P0fMWI
00<000000=WIf@3IfMT04`3IfMT000d0fMWI00<000000=WIf@3IfMT07`3IfMT010000000fMWI0=WI
f@0000130=WIf@030000003IfMT0fMWI0280fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0000001W0=WIf@030000003IfMT0fMWI01<0fMWI000=0=WIf@030000003IfMT0fMWI01l0fMWI00<0
00000=WIf@000000A@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0fMWI0P00
001X0=WIf@030000003IfMT0fMWI0180fMWI000=0=WIf@030000003IfMT0fMWI01l0fMWI00<00000
0=WIf@000000AP3IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI00@0fMWI0P00001X
0=WIf@030000003IfMT0fMWI0140fMWI000=0=WIf@030000003IfMT0fMWI01h0fMWI00@000000=WI
f@3IfMT00000A`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI0P00001W
0=WIf@030000003IfMT0fMWI0140fMWI000<0=WIf@030000003IfMT0fMWI01l0fMWI00@000000=WI
f@3IfMT00000B03IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT0IP3IfMT00`000000fMWI0=WIf@0@0=WIf@00303IfMT00`000000fMWI0=WIf@0O0=WI
f@030000003IfMT0000004X0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI06H0fMWI00<000000=WIf@3IfMT03`3IfMT000`0fMWI00<000000=WIf@3I
fMT07`3IfMT00`000000fMWI0000001;0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@1V0=WIf@030000003IfMT0fMWI00h0fMWI000<0=WIf@030000
003IfMT0fMWI01h0fMWI00@000000=WIf@3IfMT00000C03IfMT00`000000fMWI0=WIf@0K0=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0IP3IfMT00`000000fMWI0=WIf@0>0=WIf@00
303IfMT00`000000fMWI0=WIf@0N0=WIf@040000003IfMT0fMWI000004`0fMWI00<000000=WIf@3I
fMT06`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI06D0fMWI0P00000?0=WIf@00
303IfMT00`000000fMWI0=WIf@0N0=WIf@040000003IfMT0fMWI000004d0fMWI00<000000=WIf@3I
fMT06P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0640fMWI0`0000000`3IfMT0
00000=WIf@0>0=WIf@00303IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0000004l0fMWI
00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0:0=WIf@800000G`3IfMT3000000@0fMWI
00<000000=WIf@3IfMT03@3IfMT000`0fMWI0P00000O0=WIf@030000003IfMT000000500fMWI00<0
00000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@0;0=WIf@800000F`3IfMT3000000L0fMWI00<0
00000=WIf@3IfMT03@3IfMT000`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0000001A
0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT0303IfMT2000005H0fMWI1000000:
0=WIf@030000003IfMT0fMWI00d0fMWI000;0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WI
f@000000DP3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WI
f@000000DP3IfMT3000000h0fMWI00<000000=WIf@3IfMT03@3IfMT000/0fMWI00<000000=WIf@3I
fMT07`3IfMT00`000000fMWI0000001C0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3I
fMT03@3IfMT00`000000fMWI0000001>0=WIf@<000004P3IfMT00`000000fMWI0=WIf@0<0=WIf@00
2`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0000005D0fMWI00<000000=WIf@3IfMT0
503IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0000001H0fMWI00<000000=WIf@3IfMT0
<@3IfMT3000001D0fMWI00<000000=WIf@3IfMT0303IfMT000/0fMWI00<000000=WIf@3IfMT07P3I
fMT00`000000fMWI0000001F0=WIf@030000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT03P3I
fMT010000000fMWI0=WIf@00000E0=WIf@800000;`3IfMT3000001P0fMWI00<000000=WIf@3IfMT0
303IfMT000/0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0000001G0=WIf@030000003I
fMT0fMWI0140fMWI0P00000A0=WIf@040000003IfMT0fMWI000001D0fMWI00<000000=WIf@3IfMT0
:P3IfMT3000001/0fMWI00<000000=WIf@3IfMT0303IfMT000/0fMWI00<000000=WIf@3IfMT07P3I
fMT00`000000fMWI0000001H0=WIf@030000003IfMT0fMWI00d0fMWI0`0000020=WIf@030000003I
fMT0fMWI00l0fMWI00<000000=WIf@0000005@3IfMT2000002P0fMWI0`00000N0=WIf@030000003I
fMT0fMWI00`0fMWI000;0=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@000000F@3IfMT0
0`000000fMWI0=WIf@090=WIf@<000001P3IfMT00`000000fMWI0=WIf@050=WIf@800000203IfMT0
0`000000fMWI0000000E0=WIf@8000008`3IfMT400000240fMWI00<000000=WIf@3IfMT0303IfMT0
00/0fMWI00<000000=WIf@3IfMT07@3IfMT010000000fMWI0=WIf@00001J0=WIf@030000003IfMT0
fMWI00D0fMWI0`00000:0=WIf@030000003IfMT0fMWI00D0fMWI0`0000060=WIf@040000003IfMT0
fMWI000001@0fMWI00<000000=WIf@0000007`3IfMT3000002D0fMWI00<000000=WIf@3IfMT0303I
fMT000X0fMWI00<000000=WIf@3IfMT07P3IfMT010000000fMWI0=WIf@00001K0=WIf@040000003I
fMT0fMWI0=WIf@<000003P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000H0
fMWI00@000000=WIf@3IfMT00000503IfMT2000001`0fMWI0`00000X0=WIf@030000003IfMT0fMWI
00`0fMWI000:0=WIf@030000003IfMT0fMWI01h0fMWI00@000000=WIf@3IfMT00000G03IfMT30000
0180fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000060=WIf@040000003IfMT0
fMWI000001<0fMWI00<000000=WIf@000000603IfMT3000002/0fMWI00<000000=WIf@3IfMT0303I
fMT000X0fMWI00<000000=WIf@3IfMT07P3IfMT010000000fMWI0=WIf@00001I0=WIf@@00000503I
fMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI
0=WIf@00000C0=WIf@030000003IfMT0000001@0fMWI0`00000^0=WIf@030000003IfMT0fMWI00`0
fMWI000:0=WIf@<000007P3IfMT010000000fMWI0=WIf@00001F0=WIf@<00000103IfMT00`000000
fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000050=WI
f@050000003IfMT0fMWI0=WIf@0000004P3IfMT010000000fMWI0=WIf@00000@0=WIf@<00000<P3I
fMT00`000000fMWI0=WIf@0;0=WIf@002P3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0
000005<0fMWI100000080=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT0103IfMT0
1@000000fMWI0=WIf@3IfMT0000000D0fMWI00D000000=WIf@3IfMT0fMWI0000000B0=WIf@030000
003IfMT0000000d0fMWI0`00000e0=WIf@030000003IfMT0fMWI00/0fMWI00020=WIf@8000001P3I
fMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT000000500fMWI0`00000=0=WIf@030000003I
fMT0fMWI0180fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI0000000A0=WIf@040000003IfMT0fMWI000000P0
fMWI1000000h0=WIf@030000003IfMT0fMWI00/0fMWI00001@3IfMT000000=WIf@3IfMT0000000D0
fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0000001=0=WIf@<000004@3IfMT00`000000
fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WIf@0000004P3IfMT010000000fMWI0=WIf@000004
0=WIf@<00000?03IfMT00`000000fMWI0=WIf@0;0=WIf@0000D0fMWI0000003IfMT0fMWI00000005
0=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@000000BP3IfMT3000001D0fMWI00<00000
0=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT000000140fMWI00D000000=WIf@3IfMT00000
0=WIf@03000003l0fMWI00<000000=WIf@3IfMT02`3IfMT000050=WIf@000000fMWI0=WIf@000000
103IfMT00`000000fMWI0=WIf@0N0=WIf@040000003IfMT0fMWI000004L0fMWI0`00000I0=WIf@03
0000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI0000000A0=WIf@@00000@P3IfMT00`00
0000fMWI0=WIf@0;0=WIf@0000D0fMWI0000003IfMT0fMWI000000040=WIf@030000003IfMT0fMWI
01h0fMWI00<000000=WIf@000000A@3IfMT3000001d0fMWI00<000000=WIf@3IfMT04P3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT01@00
0000fMWI0=WIf@3IfMT0000000h0fMWI0`0000030=WIf@030000003IfMT0fMWI03l0fMWI00<00000
0=WIf@3IfMT02`3IfMT00080fMWI0P0000050=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WI
f@000000@P3IfMT300000240fMWI00<000000=WIf@3IfMT04P3IfMT01@000000fMWI0=WIf@3IfMT0
000000H0fMWI00D000000=WIf@3IfMT0fMWI000000040=WIf@030000003IfMT0fMWI00P0fMWI0`00
00030=WIf@040000003IfMT0fMWI00000440fMWI00<000000=WIf@3IfMT02`3IfMT000T0fMWI00<0
00000=WIf@3IfMT07P3IfMT00`000000fMWI0000000o0=WIf@<000009@3IfMT00`000000fMWI0=WI
f@0B0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000<0
fMWI00<000000=WIf@3IfMT01@3IfMT3000000H0fMWI00D000000=WIf@3IfMT0fMWI000000100=WI
f@030000003IfMT0fMWI00/0fMWI00090=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@00
0000?03IfMT3000002T0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000030=WIf@030000003IfMT0fMWI
00@000002@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03d0fMWI00<000000=WI
f@3IfMT02`3IfMT000T0fMWI00<000000=WIf@3IfMT07@3IfMT010000000fMWI0=WIf@00000i0=WI
f@<00000;@3IfMT00`000000fMWI0=WIf@0A0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT0
10000000fMWI0=WIf@0000030=WIf@<000003P3IfMT01@000000fMWI0=WIf@3IfMT000000400fMWI
00<000000=WIf@3IfMT02P3IfMT000T0fMWI00<000000=WIf@3IfMT07@3IfMT010000000fMWI0=WI
f@00000f0=WIf@<00000<@3IfMT00`000000fMWI0=WIf@0A0=WIf@050000003IfMT0fMWI0=WIf@00
00001`3IfMT00`000000fMWI0=WIf@0300000080fMWI00<000000=WIf@3IfMT0303IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI03d0fMWI00<000000=WIf@3IfMT02P3IfMT000T0fMWI
00<000000=WIf@3IfMT07@3IfMT010000000fMWI0=WIf@00000c0=WIf@<00000=@3IfMT00`000000
fMWI0=WIf@0A0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT3000000030=WIf@000000fMWI
0080fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
03`0fMWI00<000000=WIf@3IfMT02P3IfMT000P0fMWI00<000000=WIf@3IfMT07P3IfMT010000000
fMWI0=WIf@00000`0=WIf@<00000>03IfMT00`000000fMWI0=WIf@0B0=WIf@050000003IfMT0fMWI
0=WIf@0000000P3IfMT300000080fMWI00<000000=WIf@000000103IfMT00`000000fMWI0=WIf@0<
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0?03IfMT00`000000fMWI0=WIf@0:
0=WIf@00203IfMT3000001h0fMWI00@000000=WIf@3IfMT00000;@3IfMT3000003`0fMWI00<00000
0=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@03000000H0fMWI00<000000=WIf@000000103IfMT0
0`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0>`3IfMT0
0`000000fMWI0=WIf@0:0=WIf@00203IfMT00`000000fMWI0=WIf@0N0=WIf@040000003IfMT0fMWI
000002X0fMWI0`0000100=WIf@030000003IfMT0fMWI0140fMWI0`0000000`3IfMT000000=WIf@07
0=WIf@030000003IfMT0000000@0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT02P3IfMT000P0fMWI00<000000=WI
f@3IfMT07P3IfMT00`000000fMWI0000000X0=WIf@<00000A03IfMT00`000000fMWI0=WIf@0<0=WI
f@@000000P3IfMT010000000fMWI0=WIf@0000080=WIf@8000001@3IfMT00`000000fMWI0=WIf@0;
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0>@3IfMT00`000000fMWI0=WIf@0:
0=WIf@00203IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0000002@0fMWI100000180=WI
f@030000003IfMT0fMWI00P0fMWI0`0000070=WIf@030000003IfMT0000000T0fMWI0P0000040=WI
f@@000002P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03T0fMWI00<000000=WI
f@3IfMT02P3IfMT000P0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0000000Q0=WIf@<0
0000C@3IfMT00`000000fMWI0=WIf@040=WIf@<000002`3IfMT00`000000fMWI000000090=WIf@80
0000103IfMT2000000040=WIf@0000000000000000P0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@0h0=WIf@030000003IfMT0fMWI00X0fMWI00080=WIf@030000003IfMT0fMWI01d0
fMWI00@000000=WIf@3IfMT000007P3IfMT300000540fMWI00<000000=WIf@3IfMT00`00000?0=WI
f@030000003IfMT0000000T0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WI
f@8000001P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI03L0fMWI00<000000=WI
f@3IfMT02P3IfMT000P0fMWI00<000000=WIf@3IfMT07@3IfMT010000000fMWI0=WIf@00000K0=WI
f@<00000E@3IfMT200000180fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00<0fMWI0`0000040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0=`3IfMT00`000000fMWI0=WIf@0:0=WIf@00203IfMT00`000000fMWI0=WIf@0M0=WI
f@030000003IfMT0000001T0fMWI0`00001H0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WI
f@0000002P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI0`0000000`3I
fMT000000=WIf@050=WIf@030000003IfMT0fMWI03L0fMWI00<000000=WIf@3IfMT02@3IfMT000L0
fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0D0=WIf@<00000F`3IfMT00`000000
fMWI0=WIf@0C0=WIf@030000003IfMT0000000T0fMWI0P0000040=WIf@030000003IfMT0fMWI00P0
fMWI0`0000060=WIf@030000003IfMT0fMWI03H0fMWI00<000000=WIf@3IfMT02@3IfMT000L0fMWI
00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0A0=WIf@<00000GP3IfMT00`000000fMWI
0=WIf@0D0=WIf@030000003IfMT0000000T0fMWI0P0000040=WIf@030000003IfMT0fMWI00T0fMWI
0`0000040=WIf@030000003IfMT0fMWI03H0fMWI00<000000=WIf@3IfMT02@3IfMT000L0fMWI00<0
00000=WIf@3IfMT0<@3IfMT300000640fMWI00<000000=WIf@3IfMT05@3IfMT2000000X0fMWI0P00
00040=WIf@030000003IfMT0fMWI00T0fMWI00@000000=WIf@00000000000`3IfMT00`000000fMWI
0=WIf@0e0=WIf@030000003IfMT0fMWI00T0fMWI00070=WIf@030000003IfMT0fMWI02h0fMWI0`00
001T0=WIf@030000003IfMT0fMWI01H0fMWI0P0000090=WIf@030000003IfMT0000000@0fMWI00<0
00000=WIf@3IfMT0203IfMT01@000000fMWI0=WIf@3IfMT0000000<0fMWI00<000000=WIf@3IfMT0
=03IfMT00`000000fMWI0=WIf@090=WIf@001`3IfMT00`000000fMWI0=WIf@0[0=WIf@<00000I`3I
fMT00`000000fMWI0=WIf@0G0=WIf@8000002@3IfMT00`000000fMWI000000030=WIf@030000003I
fMT0fMWI00T0fMWI00D000000=WIf@3IfMT0fMWI000000030=WIf@030000003IfMT0fMWI03<0fMWI
00<000000=WIf@3IfMT02@3IfMT000L0fMWI00<000000=WIf@3IfMT0:03IfMT3000006X0fMWI00<0
00000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0000000<0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@020=WIf@80000000<0fMWI0000003IfMT0=03I
fMT00`000000fMWI0=WIf@090=WIf@001`3IfMT2000002H0fMWI0`00001]0=WIf@030000003IfMT0
fMWI01T0fMWI00<000000=WIf@3IfMT01`3IfMT010000000fMWI0=WIf@0000030=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0000000d0=WIf@030000003I
fMT0fMWI00T0fMWI00070=WIf@030000003IfMT0fMWI0280fMWI0`00001`0=WIf@030000003IfMT0
fMWI01X0fMWI00<000000=WIf@3IfMT01`3IfMT010000000fMWI0=WIf@0000030=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0103IfMT3000003<0fMWI00<000000=WIf@3IfMT02@3I
fMT000H0fMWI00<000000=WIf@3IfMT0803IfMT3000007<0fMWI00<000000=WIf@3IfMT06P3IfMT0
0`000000fMWI0=WIf@080=WIf@040000003IfMT0fMWI00000080fMWI0P0000090=WIf@030000003I
fMT0fMWI00D0fMWI0P00000b0=WIf@030000003IfMT0fMWI00T0fMWI00060=WIf@030000003IfMT0
fMWI01d0fMWI0`00001f0=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT01`3IfMT0
1@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WI
f@050=WIf@<00000<@3IfMT00`000000fMWI0=WIf@080=WIf@001P3IfMT00`000000fMWI0=WIf@0J
0=WIf@<00000N@3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI00L0fMWI00D00000
0=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0000000`0=WIf@030000003IfMT0fMWI00P0fMWI00060=WIf@030000003IfMT0
fMWI01L0fMWI0`00001l0=WIf@030000003IfMT0fMWI01`0fMWI0P0000090=WIf@050000003IfMT0
fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT00P00000^0=WIf@030000003IfMT0fMWI00P0fMWI00060=WIf@030000003IfMT0
fMWI01<0fMWI1000001o0=WIf@030000003IfMT0fMWI01d0fMWI0P0000080=WIf@030000003IfMT0
fMWI0080fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@040000003I
fMT0fMWI0=WIf@800000;03IfMT00`000000fMWI0=WIf@080=WIf@001P3IfMT00`000000fMWI0=WI
f@0@0=WIf@<00000P`3IfMT00`000000fMWI0=WIf@0N0=WIf@800000203IfMT00`000000fMWI0=WI
f@020=WIf@040000003IfMT00000000000P0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI
0=WIf@030=WIf@030000003IfMT0fMWI02T0fMWI00<000000=WIf@3IfMT0203IfMT000H0fMWI00<0
00000=WIf@3IfMT03@3IfMT3000008H0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0000
00070=WIf@030000003IfMT0fMWI00<0fMWI00@000000=WIf@00000000001`3IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI
0=WIf@080=WIf@001P3IfMT00`000000fMWI0=WIf@0:0=WIf@<00000R@3IfMT00`000000fMWI0=WI
f@0O0=WIf@030000003IfMT0000000L0fMWI00<000000=WIf@3IfMT00`3IfMT010000000fMWI0000
000000070=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@0W0=WIf@030000003IfMT0fMWI00P0fMWI00050=WIf@030000003IfMT0fMWI00P0fMWI0`00
002<0=WIf@030000003IfMT0fMWI0200fMWI00<000000=WIf@0000001`3IfMT00`000000fMWI0=WI
f@030=WIf@040000003IfMT00000000000H0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI02H0fMWI00<000000=WIf@3IfMT0203IfMT000D0fMWI00<0
00000=WIf@3IfMT01@3IfMT3000008l0fMWI00<000000=WIf@3IfMT02`3IfMTD000000050=WIf@00
0000fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@040=WIf@80000000<0fMWI0000003IfMT0
1@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
9@3IfMT00`000000fMWI0=WIf@080=WIf@001@3IfMT00`000000fMWI0=WIf@020=WIf@<00000TP3I
fMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0180fMWI2@0000030=WIf@030000003I
fMT0fMWI00@0fMWI0P0000000`3IfMT000000=WIf@040=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0T0=WIf@030000003IfMT0fMWI00P0fMWI0005
0=WIf@030000003IfMT0000000800000U@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI01H0fMWI00<000000=WIf@0000000`3IfMT800000080fMWI00D000000=WIf@000000fMWI0000
00050=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WI
f@0T0=WIf@030000003IfMT0fMWI00L0fMWI00050=WIf@800000V03IfMT00`000000fMWI0=WIf@0:
0=WIf@8000005P3IfMT010000000fMWI0=WIf@0000060=WIf@040000003IfMT0fMWI0=WIf@P00000
103IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
8`3IfMT00`000000fMWI0=WIf@070=WIf@001P3IfMT00`000000fMWI0=WIf@2F0=WIf@030000003I
fMT0fMWI00`0fMWI00<000000=WIf@3IfMT0503IfMT010000000fMWI0=WIf@0000060=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@000000400000080=WIf@030000003IfMT0fMWI0280fMWI
00<000000=WIf@3IfMT01`3IfMT000L0fMWI00<000000=WIf@3IfMT0U@3IfMT00`000000fMWI0=WI
f@0=0=WIf@030000003IfMT0fMWI01@0fMWI00@000000=WIf@3IfMT000001P3IfMT00`000000fMWI
0=WIf@040=WIf@040000003IfMT00000000000h0fMWI2P00000S0=WIf@030000003IfMT0fMWI00L0
fMWI00080=WIf@80000000<0fMWI000000000000TP3IfMT00`000000fMWI0=WIf@0>0=WIf@800000
503IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00<000000=WIf@3IfMT01@3IfMT200000003
0=WIf@000000fMWI00`0fMWI00<000000=WIf@3IfMT0:P3IfMT00`000000fMWI0=WIf@070=WIf@00
2P3IfMT00`000000fMWI0=WIf@2B0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT0
4P3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00<000000=WIf@3IfMT01@3IfMT200000003
0=WIf@000000fMWI00`0fMWI00<000000=WIf@3IfMT0:@3IfMT00`000000fMWI0=WIf@070=WIf@00
0P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0T@3IfMT00`000000fMWI0=WIf@0A0=WIf@800000
4`3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00<000000=WIf@3IfMT01@3IfMT200000003
0=WIf@000000fMWI00/0fMWI00<000000=WIf@3IfMT0:@3IfMT00`000000fMWI0=WIf@070=WIf@00
00D0fMWI0000003IfMT0fMWI000000070=WIf@030000003IfMT0fMWI0900fMWI00<000000=WIf@3I
fMT04`3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@060=WIf@80000000<0fMWI0000003IfMT02`3IfMT00`000000
fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI00L0fMWI00001@3IfMT000000=WIf@3IfMT0000000P0
fMWI00<000000=WIf@3IfMT0S`3IfMT00`000000fMWI0=WIf@0D0=WIf@8000004@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT200000003
0=WIf@000000fMWI00X0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@070=WIf@00
00D0fMWI0000003IfMT0fMWI000000090=WIf@800000S`3IfMT00`000000fMWI0=WIf@0F0=WIf@03
0000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00H0fMWI0P0000000`3IfMT000000=WIf@0:0=WIf@030000003IfMT0fMWI02L0
fMWI00<000000=WIf@3IfMT01`3IfMT000050=WIf@000000fMWI0=WIf@0000002`3IfMT00`000000
fMWI0=WIf@2<0=WIf@030000003IfMT0fMWI01L0fMWI0P00000?0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@070=WIf@<00000303IfMT00`000000
fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI00L0fMWI00020=WIf@8000003@3IfMT00`000000fMWI
0=WIf@2;0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01`3IfMT3000000/0fMWI
00<000000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@060=WIf@004P3IfMT00`000000fMWI0=WI
f@2:0=WIf@030000003IfMT0fMWI01X0fMWI0P00000>0=WIf@030000003IfMT0fMWI0080fMWI00D0
00000=WIf@3IfMT0fMWI0000000:0=WIf@<000002`3IfMT00`000000fMWI0=WIf@0V0=WIf@030000
003IfMT0fMWI00H0fMWI000C0=WIf@<00000R@3IfMT00`000000fMWI0=WIf@0L0=WIf@800000303I
fMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000002P3IfMT3000000X0fMWI
00<000000=WIf@3IfMT09P3IfMT00`000000fMWI0=WIf@060=WIf@00503IfMT2000008T0fMWI00<0
00000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00<0fMWI00D0
00000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0000000/0fMWI00<000000=WIf@3IfMT0
9@3IfMT00`000000fMWI0=WIf@060=WIf@005P3IfMT00`000000fMWI0=WIf@260=WIf@030000003I
fMT0fMWI01l0fMWI0P00000;0=WIf@030000003IfMT0fMWI00<0fMWI00@000000=WIf@3IfMT00000
2P3IfMT00`000000fMWI0000000;0=WIf@030000003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT0
1P3IfMT001L0fMWI00<000000=WIf@3IfMT0Q@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT00`3IfMT010000000fMWI0=WIf@00000:0=WIf@030000
003IfMT0000000X0fMWI00<000000=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@060=WIf@00603I
fMT00`000000fMWI0=WIf@240=WIf@030000003IfMT0fMWI0280fMWI0P0000090=WIf@030000003I
fMT0fMWI00@0fMWI00@000000=WIf@3IfMT000002@3IfMT010000000fMWI0=WIf@00000:0=WIf@03
0000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT01P3IfMT001T0fMWI00<000000=WIf@3IfMT0
P`3IfMT00`000000fMWI0=WIf@0T0=WIf@800000203IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0000000X0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@0S0=WIf@03
0000003IfMT0fMWI00H0fMWI000J0=WIf@800000P`3IfMT00`000000fMWI0=WIf@0V0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0000000T0fMWI00D000000=WIf@3IfMT0
fMWI000000090=WIf@030000003IfMT0fMWI0280fMWI00<000000=WIf@3IfMT01P3IfMT001`0fMWI
00<000000=WIf@3IfMT0P03IfMT00`000000fMWI0=WIf@0X0=WIf@8000001@3IfMT00`000000fMWI
0=WIf@040=WIf@040000003IfMT0fMWI000000T0fMWI00D000000=WIf@3IfMT0fMWI000000090=WI
f@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT01P3IfMT001d0fMWI00<000000=WIf@00
0000O`3IfMT00`000000fMWI0=WIf@0Z0=WIf@800000103IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0000000X0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@0R0=WI
f@030000003IfMT0fMWI00D0fMWI000N0=WIf@030000003IfMT0fMWI07h0fMWI00<000000=WIf@3I
fMT0;03IfMT2000000<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI000000090=WIf@05
0000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI
00D0fMWI000O0=WIf@030000003IfMT0fMWI07d0fMWI00<000000=WIf@3IfMT0;P3IfMT200000080
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI000000090=WIf@050000003IfMT0fMWI0=WI
f@000000203IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00D0fMWI000P0=WIf@80
0000O@3IfMT00`000000fMWI0=WIf@0`0=WIf@<000001`3IfMT2000000T0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0200fMWI00<000000=WIf@3I
fMT01@3IfMT00280fMWI00<000000=WIf@3IfMT0NP3IfMT00`000000fMWI0=WIf@0b0=WIf@800000
1`3IfMT2000000T0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@050=WIf@030000
003IfMT0fMWI0200fMWI00<000000=WIf@3IfMT01@3IfMT002<0fMWI00<000000=WIf@3IfMT0N@3I
fMT00`000000fMWI0=WIf@0d0=WIf@@00000103IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003I
fMT0fMWI00D0fMWI000T0=WIf@030000003IfMT0fMWI07P0fMWI00<000000=WIf@3IfMT0=@3IfMT0
0`000000fMWI0=WIf@0300000080fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@05
0=WIf@009@3IfMT00`000000fMWI0=WIf@1g0=WIf@030000003IfMT0fMWI03D0fMWI00<000000=WI
f@3IfMT00`3IfMT4000000P0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT01@3IfMT002H0fMWI1000001e0=WIf@03
0000003IfMT0fMWI03H0fMWI00<000000=WIf@3IfMT01@3IfMT4000000@0fMWI0P0000070=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@050=WIf@00
9`3IfMT2000007H0fMWI00<000000=WIf@3IfMT0=`3IfMT00`000000fMWI0=WIf@050=WIf@800000
00<0fMWI0000000000000P00000:0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
7@3IfMT00`000000fMWI0=WIf@050=WIf@00:@3IfMT00`000000fMWI0=WIf@1c0=WIf@030000003I
fMT0fMWI03P0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@040=WIf@00:P3IfMT0
0`000000fMWI0=WIf@1b0=WIf@030000003IfMT0fMWI03P0fMWI00<000000=WIf@3IfMT01@3IfMT2
00000100fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0M0=WIf@030000003IfMT0
fMWI00@0fMWI000[0=WIf@030000003IfMT0fMWI0740fMWI00<000000=WIf@3IfMT0>@3IfMT00`00
0000fMWI0=WIf@050=WIf@800000403IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
01`0fMWI00<000000=WIf@3IfMT0103IfMT002`0fMWI00<000000=WIf@3IfMT0L03IfMT00`000000
fMWI0=WIf@0j0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@000000403IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0103IfMT002d0fMWI
0P00001`0=WIf@030000003IfMT0fMWI03/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0000000@0=WIf@050000003IfMT0fMWI0=WIf@0000007@3IfMT00`000000fMWI0=WIf@040=WIf@00
;`3IfMT00`000000fMWI0=WIf@1]0=WIf@030000003IfMT0fMWI03/0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0000000@0=WIf@050000003IfMT0fMWI0=WIf@000000703IfMT00`000000
fMWI0=WIf@040=WIf@00<03IfMT3000006`0fMWI00<000000=WIf@3IfMT0?03IfMT00`000000fMWI
0=WIf@040=WIf@040000003IfMT0fMWI00000100fMWI0P0000000`3IfMT000000=WIf@0K0=WIf@03
0000003IfMT0fMWI00@0fMWI000a0=WIf@030000003IfMT0fMWI06/0fMWI00<000000=WIf@3IfMT0
?@3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI00000140fMWI0P00000L0=WIf@03
0000003IfMT0fMWI00@0fMWI000b0=WIf@030000003IfMT0fMWI06X0fMWI00<000000=WIf@3IfMT0
?P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000004@3IfMT2000001/0
fMWI00<000000=WIf@3IfMT0103IfMT003<0fMWI0P00001Z0=WIf@030000003IfMT0fMWI03h0fMWI
00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT000000140fMWI00<000000=WIf@3I
fMT06@3IfMT00`000000fMWI0=WIf@040=WIf@00=@3IfMT00`000000fMWI0=WIf@1W0=WIf@030000
003IfMT0fMWI03l0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000002d0
fMWI00<000000=WIf@3IfMT0103IfMT003H0fMWI00<000000=WIf@3IfMT0IP3IfMT00`000000fMWI
0=WIf@100=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI0000000]0=WIf@03
0000003IfMT0fMWI00<0fMWI000g0=WIf@030000003IfMT0fMWI06D0fMWI00<000000=WIf@3IfMT0
@@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
:P3IfMT00`000000fMWI0=WIf@030=WIf@00>03IfMT00`000000fMWI0=WIf@0200000680fMWI00<0
00000=WIf@3IfMT0@@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0:@3IfMT00`000000fMWI0=WIf@030=WIf@00>@3IfMT2000006@0fMWI00<00000
0=WIf@3IfMT0@P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@030=WIf@00<@3IfMT2000000P0fMWI00<000000=WI
f@3IfMT0H@3IfMT00`000000fMWI0=WIf@130=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI00<0fMWI000`0=WIf@04
0000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0H03IfMT00`000000fMWI0=WIf@140=WI
f@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0
fMWI00<0fMWI000c0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0G`3IfMT00`00
0000fMWI0=WIf@140=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@0U0=WIf@030000003IfMT0fMWI00<0fMWI000a0=WIf@8000002`3IfMT00`000000
fMWI0=WIf@1N0=WIf@030000003IfMT0fMWI04D0fMWI00D000000=WIf@3IfMT0fMWI000000070=WI
f@030000003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT00`3IfMT00340fMWI00<000000=WIf@3I
fMT02`3IfMT2000005h0fMWI00<000000=WIf@3IfMT0AP3IfMT01@000000fMWI0=WIf@3IfMT00000
00L0fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@030=WIf@00<@3IfMT3000000d0
fMWI00<000000=WIf@3IfMT0F`3IfMT00`000000fMWI0=WIf@170=WIf@050000003IfMT0fMWI0=WI
f@0000001`3IfMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0fMWI00<0fMWI00120=WIf@<0
0000FP3IfMT00`000000fMWI0=WIf@170=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`00
0000fMWI0=WIf@0S0=WIf@030000003IfMT0fMWI0080fMWI00130=WIf@030000003IfMT0fMWI05T0
fMWI00<000000=WIf@3IfMT0B03IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WI
f@3IfMT08P3IfMT00`000000fMWI0=WIf@020=WIf@00A03IfMT00`000000fMWI0=WIf@1H0=WIf@03
0000003IfMT0fMWI04T0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@0Q0=WI
f@030000003IfMT0fMWI0080fMWI00150=WIf@800000F03IfMT00`000000fMWI0=WIf@1:0=WIf@04
0000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@020=WI
f@00A`3IfMT00`000000fMWI0=WIf@1E0=WIf@030000003IfMT0fMWI04X0fMWI00D000000=WIf@3I
fMT0fMWI000000080=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT00P3IfMT004P0
fMWI00<000000=WIf@3IfMT0E03IfMT00`000000fMWI0=WIf@1;0=WIf@040000003IfMT0fMWI0000
00T0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@020=WIf@00B@3IfMT00`000000
fMWI0=WIf@1C0=WIf@030000003IfMT0fMWI04`0fMWI00@000000=WIf@3IfMT000002@3IfMT00`00
0000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI0080fMWI001:0=WIf@040000003IfMT000000000
0540fMWI00<000000=WIf@3IfMT0C@3IfMT00`000000fMWI0000000:0=WIf@030000003IfMT0fMWI
01`0fMWI00<000000=WIf@3IfMT00P3IfMT004/0fMWI0P00001B0=WIf@030000003IfMT0fMWI04h0
fMWI00<000000=WIf@0000002P3IfMT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI0080
fMWI001=0=WIf@030000003IfMT0fMWI04l0fMWI00<000000=WIf@3IfMT0C`3IfMT2000000/0fMWI
00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@020=WIf@00CP3IfMT00`000000fMWI0=WI
f@1>0=WIf@030000003IfMT0fMWI04l0fMWI00<000000=WIf@0000002P3IfMT00`000000fMWI0=WI
f@0K0=WIf@030000003IfMT0fMWI0040fMWI001?0=WIf@030000003IfMT0fMWI04d0fMWI00<00000
0=WIf@3IfMT0D03IfMT2000000/0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@01
0=WIf@00D03IfMT00`000000fMWI0=WIf@1<0=WIf@030000003IfMT0fMWI0540fMWI0P00000;0=WI
f@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT00@3IfMT00540fMWI00<000000=WIf@3I
fMT0B`3IfMT00`000000fMWI0=WIf@1B0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0603IfMT00`000000fMWI0=WIf@010=WIf@00DP3IfMT2000000030=WIf@000000fMWI04P0fMWI
00<000000=WIf@3IfMT0H03IfMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI0040fMWI
001D0=WIf@030000003IfMT0fMWI04P0fMWI00<000000=WIf@3IfMT0H@3IfMT00`000000fMWI0=WI
f@0F0=WIf@030000003IfMT0fMWI0040fMWI001E0=WIf@030000003IfMT0fMWI04L0fMWI00<00000
0=WIf@3IfMT0HP3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI0040fMWI001F0=WI
f@030000003IfMT0fMWI04H0fMWI00<000000=WIf@3IfMT0H`3IfMT00`000000fMWI0=WIf@0D0=WI
f@030000003IfMT0fMWI0040fMWI001G0=WIf@030000003IfMT0fMWI04D0fMWI00<000000=WIf@3I
fMT0I03IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI0040fMWI001H0=WIf@800000
A@3IfMT00`000000fMWI0=WIf@1U0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT0
0@3IfMT005X0fMWI00<000000=WIf@3IfMT0@P3IfMT00`000000fMWI0=WIf@1U0=WIf@030000003I
fMT0fMWI0180fMWI00<000000=WIf@3IfMT00@3IfMT005/0fMWI00<000000=WIf@000000@@3IfMT0
0`000000fMWI0=WIf@1V0=WIf@030000003IfMT0fMWI0180fMWI0@0000010=WIf@40fMWI001L0=WI
f@030000003IfMT0fMWI0400fMWI00<000000=WIf@3IfMT0I`3IfMT00`000000fMWI0=WIf@0A0=WI
f@4000000@3IfMT10=WIf@00G@3IfMT00`000000fMWI0=WIf@0o0=WIf@030000003IfMT0fMWI06P0
fMWI00<000000=WIf@3IfMT0403IfMT100000040fMWI0@3IfMT005h0fMWI0P00000o0=WIf@030000
003IfMT0fMWI06T0fMWI00<000000=WIf@3IfMT03`3IfMT100000040fMWI0@3IfMT00600fMWI00<0
00000=WIf@3IfMT0?03IfMT00`000000fMWI0=WIf@1Z0=WIf@030000003IfMT0fMWI00h0fMWI0@00
00010=WIf@40fMWI001Q0=WIf@030000003IfMT0fMWI03/0fMWI00<000000=WIf@3IfMT0J`3IfMT0
0`000000fMWI0=WIf@0=0=WIf@4000000@3IfMT10=WIf@00HP3IfMT00`000000fMWI0=WIf@0j0=WI
f@030000003IfMT0fMWI06`0fMWI00<000000=WIf@3IfMT0303IfMT100000040fMWI0@3IfMT006<0
fMWI1000000h0=WIf@030000003IfMT0fMWI06d0fMWI00<000000=WIf@3IfMT02`3IfMT100000040
fMWI0@3IfMT005D0fMWI1@0000020=WIf@8000001P3IfMT2000003T0fMWI00<000000=WIf@3IfMT0
KP3IfMT00`000000fMWI0=WIf@0:0=WIf@4000000@3IfMT10=WIf@00E`3IfMT01@000000fMWI0=WI
f@3IfMT000000080fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0f0=WIf@030000
003IfMT0fMWI06l0fMWI00<000000=WIf@3IfMT02@3IfMT100000040fMWI0@3IfMT005L0fMWI00D0
00000=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0
=@3IfMT00`000000fMWI0=WIf@1_0=WIf@030000003IfMT0fMWI00X0fMWI0@0000010=WIf@00E`3I
fMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@0d0=WIf@030000003IfMT0fMWI0700fMWI00<000000=WIf@3IfMT02@3IfMT100000040fMWI
001G0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WIf@080=WIf@030000
003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0L@3IfMT00`000000fMWI0=WIf@080=WIf@400000
0@3IfMT005H0fMWI0P0000040=WIf@800000303IfMT2000003<0fMWI00<000000=WIf@3IfMT0LP3I
fMT00`000000fMWI0=WIf@070=WIf@4000000@3IfMT006`0fMWI0P00000a0=WIf@030000003IfMT0
fMWI07<0fMWI00<000000=WIf@3IfMT01P3IfMT100000040fMWI001]0=WIf@030000003IfMT0fMWI
02l0fMWI00<000000=WIf@3IfMT0M03IfMT00`000000fMWI0=WIf@050=WIf@4000000@3IfMT006h0
fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@1e0=WIf@030000003IfMT0fMWI00@0
fMWI0@0000010=WIf@00K`3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0fMWI07H0fMWI
00<000000=WIf@3IfMT00`3IfMT100000040fMWI001`0=WIf@800000;@3IfMT00`000000fMWI0=WI
f@1g0=WIf@030000003IfMT0fMWI0080fMWI0@0000010=WIf@00LP3IfMT00`000000fMWI0=WIf@0Z
0=WIf@030000003IfMT0fMWI07P0fMWI00D000000=WIf@3IfMT0fMWI000000010=WIf@00L`3IfMT3
000002T0fMWI00<000000=WIf@3IfMT0N03IfMT00`000000fMWI0=WIf@020=WIf@400000001d0=WI
f@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT0N@3IfMT010000000fMWI0=WIf@3IfMT1
00000000M@3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI07X0fMWI00<000000=WI
f@3IfMT00@00000007H0fMWI0P00000W0=WIf@030000003IfMT0fMWI07/0fMWI0@0000010=WIf@40
0000001h0=WIf@030000003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT0O03IfMT200000000N@3I
fMT00`000000fMWI0=WIf@0S0=WIf@030000003IfMT0fMWI07`0fMWI0P00000007X0fMWI00<00000
0=WIf@0000008P3IfMT00`000000fMWI0=WIf@1h0=WIf@@000000P3IfMT007/0fMWI00<000000=WI
f@3IfMT08@3IfMT00`000000fMWI0=WIf@1d0=WIf@@000001P3IfMT007`0fMWI00<000000=WIf@3I
fMT0803IfMT00`000000fMWI0=WIf@1`0=WIf@@000002P3IfMT007d0fMWI0P00000P0=WIf@030000
003IfMT0fMWI06`0fMWI1000000>0=WIf@00O`3IfMT00`000000fMWI0=WIf@0M0=WIf@030000003I
fMT0fMWI06P0fMWI1000000B0=WIf@00P03IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0
fMWI06@0fMWI1000000F0=WIf@00P@3IfMT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI
0600fMWI1000000J0=WIf@00PP3IfMT3000001X0fMWI00<000000=WIf@3IfMT0G03IfMT4000001h0
fMWI00230=WIf@8000006P3IfMT00`000000fMWI0=WIf@1H0=WIf@@000008P3IfMT008D0fMWI00<0
00000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@1D0=WIf@@000009P3IfMT008H0fMWI00<00000
0=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@1@0=WIf@@00000:P3IfMT008L0fMWI00<000000=WI
f@3IfMT05@3IfMT00`000000fMWI0=WIf@1<0=WIf@@00000;P3IfMT008P0fMWI00<000000=WIf@3I
fMT00P00000B0=WIf@030000003IfMT0fMWI04P0fMWI1000000b0=WIf@00R@3IfMT2000001@0fMWI
00<000000=WIf@3IfMT0A03IfMT4000003H0fMWI001j0=WIf@D000000P3IfMT2000000P0fMWI00<0
00000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@100=WIf@@00000>P3IfMT007`0fMWI00D00000
0=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0403I
fMT00`000000fMWI0=WIf@0l0=WIf@@00000?P3IfMT007`0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0>03IfMT4
00000480fMWI001l0=WIf@030000003IfMT0fMWI0080fMWI0P00000;0=WIf@030000003IfMT0fMWI
00h0fMWI00<000000=WIf@3IfMT0=03IfMT4000004H0fMWI001l0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT02`3IfMT2000000h0fMWI00<000000=WIf@3IfMT0<03IfMT4000004X0
fMWI001k0=WIf@800000103IfMT3000000d0fMWI0P00000<0=WIf@030000003IfMT0fMWI02`0fMWI
1000001>0=WIf@00TP3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI02P0fMWI1000
001B0=WIf@00T`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI02@0fMWI1000001F
0=WIf@00U03IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0200fMWI1000001J0=WI
f@00U@3IfMT2000000P0fMWI00<000000=WIf@3IfMT0703IfMT4000005h0fMWI002G0=WIf@030000
003IfMT0000000D0fMWI00<000000=WIf@3IfMT0603IfMT400000680fMWI002H0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0503IfMT4000006H0fMWI002I0=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT0403IfMT4000006X0fMWI002J0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0303IfMT4000006h0fMWI002K0=WIf@8000000P3IfMT00`000000
fMWI0=WIf@080=WIf@@00000LP3IfMT009d0fMWI00<000000=WIf@0000001P3IfMT4000007H0fMWI
002N0=WIf@<0000000<0fMWI0000000000000P00001j0=WIf@00W`3IfMT3000007h0fMWI003o0=WI
fB40fMWI0000\
\>"],
  ImageRangeCache->{{{138, 425}, {420.813, 65}} -> {-0.291717, 0.158622, \
0.00267758, 0.00267758}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Duble pendulum", "Section"],

Cell["\<\
(a) Make a modelica model and simulate it with sinusoidal u. Choose the \
parameters to get an interesting response\
\>", "Text"],

Cell["\<\
partial model Exercise2 \"Modelica Exam Exercise 2\" 
  parameter Real length1=2 \"Length of the first arm\";
  parameter Real length2=3 \"Length of the second arm\";
  parameter Real mass1=1 \"Mass of the first arm\";
  parameter Real mass2=1 \"Mass of the second arm\";
  Modelica.Electrical.Analog.Basic.Ground ground;
  Modelica.Electrical.Analog.Basic.Resistor resistor;
  Modelica.Electrical.Analog.Basic.EMF emf;
  Modelica.Mechanics.Rotational.Inertia inertia;
  ModelicaAdditions.MultiBody.Parts.InertialSystem inertialsystem;
  ModelicaAdditions.MultiBody.Parts.Body arm2(rCM={length2/2,0,0}, m=mass2);
  ModelicaAdditions.MultiBody.Parts.Body2 arm1(r={length1,0,0}, 
    rCM={length1/2,0,0}, m=mass1);
  ModelicaAdditions.MultiBody.Joints.Revolute joint1(n={0,0,1});
  ModelicaAdditions.MultiBody.Joints.Revolute joint2(n={0,0,1});
  Modelica.Electrical.Analog.Sources.SineVoltage sinevoltage ;
equation 
  connect(emf.p, resistor.n) ;
  connect(ground.p, emf.n) ;
  connect(emf.flange_b, inertia.flange_a) ;
  connect(inertialsystem.frame_b, joint1.frame_a);
  connect(joint1.frame_b, arm1.frame_a);
  connect(arm1.frame_b, joint2.frame_a);
  connect(arm2.frame_a, joint2.frame_b);
  connect(sinevoltage.n, resistor.p);
  connect(sinevoltage.p, ground.p);
end Exercise2;
\
\>", "ModelicaInput"],

Cell["\<\
class Exercise2withSpring \"Modelica Exam Exercise 2 with spring\"
   extends Exercise2;
  replaceable Modelica.Mechanics.Rotational.Spring spring(c=300);
 equation 
  connect(inertia.flange_b, spring.flange_a);
  connect(spring.flange_b, joint1.axis);
end Exercise2withSpring;\
\>", "ModelicaInput"],

Cell["", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result1\  = \ Simulate[Exercise2withSpring, {t, 0, 200}]\)], "Input"],

Cell[BoxData["\<\"<SimulationData: \\!\\(Exercise2withSpring\\) : 2003-5-7 \
21:54:40 : \\!\\({0.`, 200.`}\\) : 502 data points : 912 \
variables>\\nVariables of range 100 and depth Infinity listed: \
\\!\\({\\*TagBox[\\(\\(\\(arm1 . aa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . aa\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . aa\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . ab\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . ab\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . ab\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . aa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
aa\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . aa\\)\\) \[LeftDoubleBracket] \\(\
\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . fa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . fa\\)\\) \[LeftDoubleBracket] \\(\
\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . fa\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(3, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(3, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(3, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . t\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . t\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . t\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . v\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . v\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . v\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . w\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . w\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . w\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . z\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . z\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . z\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . \[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\
\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . \[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(1, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(1, 3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(2, 1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(2, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(2, 3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(3, 1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(3, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(3, 3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(arm1 . body . m\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . r0a\\)\\) \[LeftDoubleBracket] \
\\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . r0a\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . r0a\\)\\) \[LeftDoubleBracket] \
\\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . rCM\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . rCM\\)\\) \[LeftDoubleBracket] \
\\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . rCM\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . Sa\\)\\) \[LeftDoubleBracket] \\(\
\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . Sa\\)\\) \[LeftDoubleBracket] \\(\\(1, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
Sa\\)\\) \[LeftDoubleBracket] \\(\\(1, 3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . Sa\\)\\) \[LeftDoubleBracket] \\(\
\\(2, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . Sa\\)\\) \[LeftDoubleBracket] \\(\\(2, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
Sa\\)\\) \[LeftDoubleBracket] \\(\\(2, 3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . Sa\\)\\) \[LeftDoubleBracket] \\(\
\\(3, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . Sa\\)\\) \[LeftDoubleBracket] \\(\\(3, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
Sa\\)\\) \[LeftDoubleBracket] \\(\\(3, 3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . ta\\)\\) \[LeftDoubleBracket] \\(\
\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . ta\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . ta\\)\\) \[LeftDoubleBracket] \\(\
\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . va\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . va\\)\\) \[LeftDoubleBracket] \\(\
\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . va\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . wa\\)\\) \[LeftDoubleBracket] \\(\
\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . wa\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . wa\\)\\) \[LeftDoubleBracket] \\(\
\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . za\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . za\\)\\) \[LeftDoubleBracket] \\(\
\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . za\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . fa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\
\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . fa\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . fa\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . fb\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . fb\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . fb\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 3\\)\\) \[RightDoubleBracket]\\), HoldForm]}\\)\
\"\>"], "Output"]
}, Open  ]],

Cell["\<\
class Exercise2withDumping \"Modelica Exam Exercise 2 with dumping\"
   = Exercise2withSpring(redeclare Modelica.Mechanics.Rotational.SpringDamper \
spring(c=300, phi_rel0 = 1, d = 100));
\
\>", "ModelicaInput"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result2\  = \ Simulate[Exercise2withDumping, {t, 0, 200}]\)], "Input"],

Cell[BoxData["\<\"<SimulationData: \\!\\(Exercise2withDumping\\) : 2003-5-7 \
21:54:58 : \\!\\({0.`, 200.`}\\) : 502 data points : 915 \
variables>\\nVariables of range 100 and depth Infinity listed: \
\\!\\({\\*TagBox[\\(\\(\\(arm1 . aa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . aa\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . aa\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . ab\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . ab\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . ab\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . aa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
aa\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . aa\\)\\) \[LeftDoubleBracket] \\(\
\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . fa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . fa\\)\\) \[LeftDoubleBracket] \\(\
\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . fa\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(3, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(3, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(3, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . t\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . t\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . t\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . v\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . v\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . v\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . w\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . w\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . w\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . z\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . z\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . z\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . \[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\
\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . \[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(1, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(1, 3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(2, 1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(2, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(2, 3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(3, 1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(3, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(3, 3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(arm1 . body . m\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . r0a\\)\\) \[LeftDoubleBracket] \
\\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . r0a\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . r0a\\)\\) \[LeftDoubleBracket] \
\\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . rCM\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . rCM\\)\\) \[LeftDoubleBracket] \
\\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . rCM\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . Sa\\)\\) \[LeftDoubleBracket] \\(\
\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . Sa\\)\\) \[LeftDoubleBracket] \\(\\(1, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
Sa\\)\\) \[LeftDoubleBracket] \\(\\(1, 3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . Sa\\)\\) \[LeftDoubleBracket] \\(\
\\(2, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . Sa\\)\\) \[LeftDoubleBracket] \\(\\(2, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
Sa\\)\\) \[LeftDoubleBracket] \\(\\(2, 3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . Sa\\)\\) \[LeftDoubleBracket] \\(\
\\(3, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . Sa\\)\\) \[LeftDoubleBracket] \\(\\(3, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
Sa\\)\\) \[LeftDoubleBracket] \\(\\(3, 3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . ta\\)\\) \[LeftDoubleBracket] \\(\
\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . ta\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . ta\\)\\) \[LeftDoubleBracket] \\(\
\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . va\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . va\\)\\) \[LeftDoubleBracket] \\(\
\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . va\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . wa\\)\\) \[LeftDoubleBracket] \\(\
\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . wa\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . wa\\)\\) \[LeftDoubleBracket] \\(\
\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . za\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . za\\)\\) \[LeftDoubleBracket] \\(\
\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . za\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . fa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\
\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . fa\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . fa\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . fb\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . fb\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . fb\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 3\\)\\) \[RightDoubleBracket]\\), HoldForm]}\\)\
\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(PlotSimulation[{spring . tau[t], joint1 . q[t], \ joint2 . q[t], \ 
          arm1 . \(aa[\([1]\)]\)[t], \ arm2 . \(aa[\([1]\)]\)[t]}, \ {t, 0, 
          3}, \ SimulationResult \[Rule] {result1}];\)\), \
"\[IndentingNewLine]", 
    \(PlotSimulation[{spring . tau[t], joint1 . q[t], \ joint2 . q[t], \ 
        arm1 . \(aa[\([1]\)]\)[t], \ arm2 . \(aa[\([1]\)]\)[t]}, \ {t, 0, 
        3}, \ SimulationResult \[Rule] {result2}]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74402 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.312017 0.47619 [
[ 0 0 0 0 ]
[ 1 .74402 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0177147 0.97619 0.606318 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.297619 0.370327 0.0133471 [
[.17262 .35783 -9 -9 ]
[.17262 .35783 9 0 ]
[.32143 .35783 -3 -9 ]
[.32143 .35783 3 0 ]
[.47024 .35783 -9 -9 ]
[.47024 .35783 9 0 ]
[.61905 .35783 -3 -9 ]
[.61905 .35783 3 0 ]
[.76786 .35783 -9 -9 ]
[.76786 .35783 9 0 ]
[.91667 .35783 -3 -9 ]
[.91667 .35783 3 0 ]
[1.025 .37033 0 -6.28125 ]
[1.025 .37033 10 6.28125 ]
[.01131 .10338 -18 -4.5 ]
[.01131 .10338 0 4.5 ]
[.01131 .23686 -18 -4.5 ]
[.01131 .23686 0 4.5 ]
[.01131 .5038 -12 -4.5 ]
[.01131 .5038 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17262 .37033 m
.17262 .37658 L
s
[(0.5)] .17262 .35783 0 1 Mshowa
.32143 .37033 m
.32143 .37658 L
s
[(1)] .32143 .35783 0 1 Mshowa
.47024 .37033 m
.47024 .37658 L
s
[(1.5)] .47024 .35783 0 1 Mshowa
.61905 .37033 m
.61905 .37658 L
s
[(2)] .61905 .35783 0 1 Mshowa
.76786 .37033 m
.76786 .37658 L
s
[(2.5)] .76786 .35783 0 1 Mshowa
.91667 .37033 m
.91667 .37658 L
s
[(3)] .91667 .35783 0 1 Mshowa
.125 Mabswid
.05357 .37033 m
.05357 .37408 L
s
.08333 .37033 m
.08333 .37408 L
s
.1131 .37033 m
.1131 .37408 L
s
.14286 .37033 m
.14286 .37408 L
s
.20238 .37033 m
.20238 .37408 L
s
.23214 .37033 m
.23214 .37408 L
s
.2619 .37033 m
.2619 .37408 L
s
.29167 .37033 m
.29167 .37408 L
s
.35119 .37033 m
.35119 .37408 L
s
.38095 .37033 m
.38095 .37408 L
s
.41071 .37033 m
.41071 .37408 L
s
.44048 .37033 m
.44048 .37408 L
s
.5 .37033 m
.5 .37408 L
s
.52976 .37033 m
.52976 .37408 L
s
.55952 .37033 m
.55952 .37408 L
s
.58929 .37033 m
.58929 .37408 L
s
.64881 .37033 m
.64881 .37408 L
s
.67857 .37033 m
.67857 .37408 L
s
.70833 .37033 m
.70833 .37408 L
s
.7381 .37033 m
.7381 .37408 L
s
.79762 .37033 m
.79762 .37408 L
s
.82738 .37033 m
.82738 .37408 L
s
.85714 .37033 m
.85714 .37408 L
s
.8869 .37033 m
.8869 .37408 L
s
.94643 .37033 m
.94643 .37408 L
s
.97619 .37033 m
.97619 .37408 L
s
.25 Mabswid
0 .37033 m
1 .37033 L
s
gsave
1.025 .37033 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10338 m
.03006 .10338 L
s
[(-20)] .01131 .10338 1 0 Mshowa
.02381 .23686 m
.03006 .23686 L
s
[(-10)] .01131 .23686 1 0 Mshowa
.02381 .5038 m
.03006 .5038 L
s
[(10)] .01131 .5038 1 0 Mshowa
.125 Mabswid
.02381 .13008 m
.02756 .13008 L
s
.02381 .15677 m
.02756 .15677 L
s
.02381 .18347 m
.02756 .18347 L
s
.02381 .21016 m
.02756 .21016 L
s
.02381 .26355 m
.02756 .26355 L
s
.02381 .29024 m
.02756 .29024 L
s
.02381 .31694 m
.02756 .31694 L
s
.02381 .34363 m
.02756 .34363 L
s
.02381 .39702 m
.02756 .39702 L
s
.02381 .42372 m
.02756 .42372 L
s
.02381 .45041 m
.02756 .45041 L
s
.02381 .4771 m
.02756 .4771 L
s
.02381 .07669 m
.02756 .07669 L
s
.02381 .05 m
.02756 .05 L
s
.02381 .0233 m
.02756 .0233 L
s
.02381 .53049 m
.02756 .53049 L
s
.02381 .55719 m
.02756 .55719 L
s
.02381 .58388 m
.02756 .58388 L
s
.02381 .61058 m
.02756 .61058 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 1 r
.001 w
.02381 .37033 m
.14286 .27825 L
.2619 .40812 L
.38095 .26878 L
.5 .48812 L
.61905 .31623 L
.7381 .43458 L
.85714 .2913 L
.97619 .10504 L
s
0 .5 0 r
.02381 .37033 m
.14286 .36525 L
.2619 .35759 L
.38095 .34498 L
.5 .33511 L
.61905 .33413 L
.7381 .33846 L
.85714 .34528 L
.97619 .34645 L
s
1 0 0 r
.02381 .37033 m
.14286 .37502 L
.2619 .37018 L
.38095 .37035 L
.5 .36948 L
.61905 .35919 L
.7381 .35236 L
.85714 .35829 L
.97619 .38325 L
s
0 .75 .75 r
.02381 .37033 m
.14286 .32173 L
.2619 .26349 L
.38095 .2464 L
.5 .30721 L
.61905 .31577 L
.7381 .28067 L
.85714 .24547 L
.97619 .2425 L
s
.75 0 .75 r
.02381 .37033 m
.14286 .31335 L
.2619 .22254 L
.38095 .01472 L
.5 .29662 L
.61905 .33041 L
.7381 .37653 L
.85714 .60332 L
.97619 .58777 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0714286 0.583445 0.547619 0.726302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00611247 0.0611247 0.005 0.05 [
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0110024 0.009 0.0721271 0.059 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.75 0 .75 r
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .034 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arm2) show
87.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(aa) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(P) show
111.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(T) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.067 0.0721271 0.117 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .75 .75 r
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .092 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arm1) show
87.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(aa) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(P) show
111.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(T) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.125 0.0721271 0.175 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .15 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(joint2) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.183 0.0721271 0.233 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .5 0 r
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .208 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(joint1) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.241 0.0721271 0.291 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .266 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spring) show
105.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .74402 L
0 .74402 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 214.25},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eR000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00703IfMT0
0`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0
fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI
000L0=WIf@030000003IfMT0fMWI05<0fMWI00<0_`2o0=WIf@3IfMT0Z`3IfMT001`0fMWI00<00000
0=WIf@3IfMT0DP3IfMT20;l0_jd0fMWI000L0=WIf@030000003IfMT0fMWI0580fMWI00<0_`2o0=WI
f@2o0;l0[03IfMT001`0fMWI00<000000=WIf@3IfMT0D@3IfMT0102o0;l0fMWI0=WIf@2o0;n/0=WI
f@00703IfMT00`000000fMWI0=WIf@1A0=WIf@050;l0_`3IfMT0fMWI0=WIf@2o0;l0Z`3IfMT001`0
fMWI00<000000=WIf@3IfMT0D03IfMT00`2o0;l0fMWI0=WIf@020=WIf@030;l0_`3IfMT0fMWI0:T0
fMWI000L0=WIf@030000003IfMT0fMWI0500fMWI00<0_`2o0=WIf@3IfMT00`3IfMT00`2o0;l0fMWI
0=WIf@2X0=WIf@00703IfMT00`000000fMWI0=WIf@1?0=WIf@030;l0_`3IfMT0fMWI00@0fMWI00<0
_`2o0=WIf@3IfMT0Z03IfMT001`0fMWI00<000000=WIf@3IfMT0CP3IfMT00`2o0;l0fMWI0=WIf@05
0=WIf@030;l0_`3IfMT0fMWI0:P0fMWI000L0=WIf@030000003IfMT0fMWI04h0fMWI00<0_`2o0=WI
f@3IfMT01P3IfMT00`2o0;l0fMWI0=WIf@2W0=WIf@00703IfMT00`000000fMWI0=WIf@1=0=WIf@03
0;l0_`3IfMT0fMWI00L0fMWI00<0_`2o0=WIf@3IfMT0Y`3IfMT001`0fMWI00<000000=WIf@3IfMT0
C@3IfMT00`2o0;l0fMWI0=WIf@080=WIf@030;l0_`3IfMT0fMWI0:H0fMWI000L0=WIf@030000003I
fMT0fMWI04`0fMWI00<0_`2o0=WIf@3IfMT02@3IfMT00`2o0;l0fMWI0=WIf@2V0=WIf@00703IfMT0
0`000000fMWI0=WIf@1;0=WIf@030;l0_`3IfMT0fMWI00/0fMWI00<0_`2o0=WIf@3IfMT0Y@3IfMT0
01`0fMWI00<000000=WIf@3IfMT0B`3IfMT00`2o0;l0fMWI0=WIf@0;0=WIf@030;l0_`3IfMT0fMWI
0:D0fMWI000L0=WIf@030000003IfMT0fMWI04X0fMWI00<0_`2o0=WIf@3IfMT0303IfMT00`2o0;l0
fMWI0=WIf@2U0=WIf@00703IfMT00`000000fMWI0=WIf@1:0=WIf@030;l0_`3IfMT0fMWI00d0fMWI
00<0_`2o0=WIf@3IfMT0Y03IfMT001`0fMWI00<000000=WIf@3IfMT0B@3IfMT00`2o0;l0fMWI0=WI
f@0>0=WIf@030;l0_`3IfMT0fMWI0:@0fMWI000L0=WIf@030000003IfMT0fMWI04T0fMWI00<0_`2o
0=WIf@3IfMT03`3IfMT00`2o0;l0fMWI0=WIf@2S0=WIf@003P3IfMT4000000<0fMWI0P0000050=WI
f@030000003IfMT0fMWI04P0fMWI00<0_`2o0=WIf@3IfMT0403IfMT00`2o0;l0fMWI0=WIf@2S0=WI
f@003P3IfMT00`000000fMWI0=WIf@030=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WI
f@3IfMT0A`3IfMT00`2o0;l0fMWI0=WIf@0B0=WIf@030;l0_`3IfMT0fMWI0:80fMWI000?0=WIf@03
0000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT00000103IfMT2000004P0fMWI00<0_`2o0=WI
f@3IfMT04P3IfMT00`2o0;l0fMWI0=WIf@240=WIf@030000o`3IfMT0fMWI01/0fMWI00080=WIf@@0
0000103IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@160=WIf@030;l0_`3IfMT0fMWI01<0fMWI00<0_`2o0=WIf@3IfMT0P`3IfMT00`00
0?l0fMWI0=WIf@0L0=WIf@003P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI
000000@0fMWI00<000000=WIf@3IfMT0AP3IfMT00`2o0;l0fMWI0=WIf@0D0=WIf@030;l0_`3IfMT0
fMWI0880fMWI00<0003o0=WIf@3IfMT0703IfMT000l0fMWI0P0000040=WIf@8000001@3IfMT00`00
0000fMWI0=WIf@150=WIf@030;l0_`3IfMT0fMWI01D0fMWI00<0_`2o0=WIf@3IfMT0P@3IfMT00`00
0?l0fMWI0=WIf@0M0=WIf@00703IfMT00`000000fMWI0=WIf@150=WIf@030;l0_`3IfMT0fMWI01H0
fMWI00<0_`2o0=WIf@3IfMT0O`3IfMT00`000?l0fMWI0=WIf@0N0=WIf@00703IfMT00`000000fMWI
0=WIf@140=WIf@030;l0_`3IfMT0fMWI01L0fMWI00<0_`2o0=WIf@3IfMT0O`3IfMT00`000?l0fMWI
0=WIf@0N0=WIf@00703IfMT00`000000fMWI0=WIf@130=WIf@030;l0_`3IfMT0fMWI01T0fMWI00<0
_`2o0=WIf@3IfMT0O@3IfMT00`000?l0fMWI0=WIf@0O0=WIf@00703IfMT00`000000fMWI0=WIf@13
0=WIf@030;l0_`3IfMT0fMWI01T0fMWI00<0_`2o0=WIf@3IfMT0O03IfMT00`000?l0fMWI0=WIf@0P
0=WIf@00703IfMT00`000000fMWI0=WIf@120=WIf@030;l0_`3IfMT0fMWI01X0fMWI00<0_`2o0=WI
f@3IfMT0O03IfMT00`000?l0fMWI0=WIf@0P0=WIf@00703IfMT00`000000fMWI0=WIf@120=WIf@03
0;l0_`3IfMT0fMWI01/0fMWI00<0_`2o0=WIf@3IfMT0NP3IfMT00`000?l0fMWI0=WIf@0Q0=WIf@00
703IfMT00`000000fMWI0=WIf@110=WIf@030;l0_`3IfMT0fMWI01`0fMWI00<0_`2o0=WIf@3IfMT0
NP3IfMT00`000?l0fMWI0=WIf@0Q0=WIf@00703IfMT00`000000fMWI0=WIf@100=WIf@030;l0_`3I
fMT0fMWI01h0fMWI00<0_`2o0=WIf@3IfMT0N03IfMT00`000?l0fMWI0=WIf@0R0=WIf@00703IfMT0
0`000000fMWI0=WIf@100=WIf@030;l0_`3IfMT0fMWI01h0fMWI00<0_`2o0=WIf@3IfMT0M`3IfMT0
0`000?l0fMWI0=WIf@0S0=WIf@00703IfMT00`000000fMWI0=WIf@0o0=WIf@030;l0_`3IfMT0fMWI
0200fMWI00<0_`2o0=WIf@3IfMT0MP3IfMT00`000?l0fMWI0=WIf@0S0=WIf@00703IfMT00`000000
fMWI0=WIf@0o0=WIf@030;l0_`3IfMT0fMWI0200fMWI00<0_`2o0=WIf@3IfMT0M@3IfMT00`000?l0
fMWI0=WIf@0T0=WIf@00703IfMT00`000000fMWI0=WIf@0n0=WIf@030;l0_`3IfMT0fMWI0240fMWI
00<0_`2o0=WIf@3IfMT0M03IfMT00`000?l0fMWI0=WIf@0U0=WIf@00703IfMT00`000000fMWI0=WI
f@0n0=WIf@030;l0_`3IfMT0fMWI0280fMWI00<0_`2o0=WIf@3IfMT0L`3IfMT00`000?l0fMWI0=WI
f@0U0=WIf@00703IfMT00`000000fMWI0=WIf@0m0=WIf@030;l0_`3IfMT0fMWI02<0fMWI00<0_`2o
0=WIf@3IfMT0LP3IfMT00`000?l0fMWI0=WIf@0V0=WIf@00703IfMT00`000000fMWI0=WIf@0l0=WI
f@030;l0_`3IfMT0fMWI02D0fMWI00<0_`2o0=WIf@3IfMT0L03IfMT00`000?l0fMWI0=WIf@0W0=WI
f@00703IfMT00`000000fMWI0=WIf@0l0=WIf@030;l0_`3IfMT0fMWI02D0fMWI00<0_`2o0=WIf@3I
fMT0L03IfMT00`000?l0fMWI0=WIf@0W0=WIf@00703IfMT00`000000fMWI0=WIf@0k0=WIf@030;l0
_`3IfMT0fMWI02H0fMWI00<0_`2o0=WIf@3IfMT0K`3IfMT00`000?l0fMWI0=WIf@0X0=WIf@00703I
fMT00`000000fMWI0=WIf@0k0=WIf@030;l0_`3IfMT0fMWI02L0fMWI00<0_`2o0=WIf@3IfMT0K@3I
fMT00`000?l0fMWI0=WIf@0Y0=WIf@00703IfMT00`000000fMWI0=WIf@0j0=WIf@030;l0_`3IfMT0
fMWI02P0fMWI00<0_`2o0=WIf@3IfMT0K@3IfMT00`000?l0fMWI0=WIf@0Y0=WIf@00703IfMT00`00
0000fMWI0=WIf@0i0=WIf@030;l0_`3IfMT0fMWI02X0fMWI00<0_`2o0=WIf@3IfMT0J`3IfMT00`00
0?l0fMWI0=WIf@0Z0=WIf@00703IfMT00`000000fMWI0=WIf@0i0=WIf@030;l0_`3IfMT0fMWI02X0
fMWI00<0_`2o0=WIf@3IfMT0J`3IfMT00`000?l0fMWI0=WIf@0Z0=WIf@00703IfMT00`000000fMWI
0=WIf@0h0=WIf@030;l0_`3IfMT0fMWI02`0fMWI00<0_`2o0=WIf@3IfMT0J@3IfMT00`000?l0fMWI
0=WIf@0[0=WIf@00703IfMT00`000000fMWI0=WIf@0h0=WIf@030;l0_`3IfMT0fMWI02`0fMWI00<0
_`2o0=WIf@3IfMT0J03IfMT00`000?l0fMWI0=WIf@0/0=WIf@00703IfMT00`000000fMWI0=WIf@0g
0=WIf@030;l0_`3IfMT0fMWI02d0fMWI00<0_`2o0=WIf@3IfMT0J03IfMT00`000?l0fMWI0=WIf@0/
0=WIf@00703IfMT00`000000fMWI0=WIf@0g0=WIf@030;l0_`3IfMT0fMWI02h0fMWI00<0_`2o0=WI
f@3IfMT0IP3IfMT00`000?l0fMWI0=WIf@0]0=WIf@00703IfMT00`000000fMWI0=WIf@0f0=WIf@03
0;l0_`3IfMT0fMWI02l0fMWI00<0_`2o0=WIf@3IfMT0I@3IfMT00`000?l0fMWI0=WIf@0^0=WIf@00
3P3IfMT500000080fMWI0P0000050=WIf@030000003IfMT0fMWI03D0fMWI00<0_`2o0=WIf@3IfMT0
<@3IfMT00`2o0;l0fMWI0=WIf@1T0=WIf@030000o`3IfMT0fMWI02h0fMWI000@0=WIf@050000003I
fMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03<0fMWI
0P2o0;ld0=WIf@030;l0_`3IfMT0fMWI06<0fMWI00<0003o0=WIf@3IfMT0;`3IfMT00100fMWI00D0
00000=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI0080fMWI0P00000c0=WIf@030;l0
_`3IfMT0fMWI03D0fMWI00<0_`2o0=WIf@3IfMT0H@3IfMT00`000?l0fMWI0=WIf@0`0=WIf@00203I
fMT4000000@0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0<@3IfMT00`2o0;l0fMWI0=WIf@0f0=WIf@030;l0_`3IfMT0fMWI0640fMWI
00<0003o0=WIf@3IfMT0<03IfMT00100fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0;`3IfMT20;l0_cT0fMWI00<0_`2o0=WIf@3IfMT0
F03IfMTO002o_ad0fMWI000?0=WIf@800000103IfMT2000000D0fMWI00<000000=WIf@3IfMT0;P3I
fMT00`2o0;l0fMWI0=WIf@0O0=WIf@D00;no5P3IfMT00`2o0;l0fMWI0=WIf@1D0=WIf@<00;no1`3I
fMT00`000?l0fMWI0=WIf@0b0=WIf@00703IfMT00`000000fMWI0=WIf@0]0=WIf@030;l0_`3IfMT0
fMWI01T0fMWI1`00_kl50=WIf@800;no503IfMT00`2o0;l0fMWI0=WIf@1@0=WIf@@00;no2P3IfMT0
0`000?l0fMWI0=WIf@0b0=WIf@00703IfMT00`000000fMWI0=WIf@0[0=WIf@80_`2o503IfMT8002o
_`h0fMWI0P00_klC0=WIf@030;l0_`3IfMT0fMWI04`0fMWI0`00_kl=0=WIf@030000o`3IfMT0fMWI
03<0fMWI000L0=WIf@030000003IfMT0fMWI02X0fMWI00<0_`2o0=WIf@3IfMT03@3IfMT7002o_aP0
fMWI0P00_klA0=WIf@030;l0_`3IfMT0fMWI04T0fMWI0`00_kl@0=WIf@030000o`3IfMT0fMWI03<0
fMWI000L0=WIf@030000003IfMT0fMWI02T0fMWI00<0_`2o0=WIf@3IfMT02@3IfMT5002o_b40fMWI
0P00_kl@0=WIf@030;l0_`3IfMT0fMWI04D0fMWI0`00_klB0=WIf@030000o`3IfMT0fMWI03@0fMWI
000L0=WIf@030000003IfMT0fMWI02L0fMWI0P2o0;l:0=WIf@800;no7P3IfMT00`000?l0fMWI0=WI
f@070=WIf@800;no3P3IfMT00`2o0;l0fMWI0=WIf@120=WIf@<00;no503IfMT00`000?l0fMWI0=WI
f@0e0=WIf@00703IfMT00`000000fMWI0=WIf@0V0=WIf@030;l0_`3IfMT0fMWI00P0fMWI0P00_klO
0=WIf@030000o`3IfMT0003o00X0fMWI0P00_kl<0=WIf@030;l0_`3IfMT0fMWI03h0fMWI1000_klG
0=WIf@030000o`3IfMT0fMWI03D0fMWI000L0=WIf@030000003IfMT0fMWI01T0fMWI00<0003o0=WI
f@3IfMT02@3IfMT00`2o0;l0fMWI0=WIf@070=WIf@800;no803IfMT010000?l0fMWI0=WIf@000?l<
0=WIf@800;no2`3IfMT00`2o0;l0fMWI0=WIf@0j0=WIf@<00;no6P3IfMT00`000?l0fMWI0=WIf@0f
0=WIf@00703IfMT00`000000fMWI0=WIf@0H0=WIf@030000o`3IfMT0003o00P0fMWI0P2o0;l80=WI
f@800;no8@3IfMT00`000?l0fMWI0=WIf@020=WIf@030000o`3IfMT0fMWI00/0fMWI0P00_kl90=WI
f@030;l0_`3IfMT0fMWI03L0fMWI0`00_klL0=WIf@030000o`3IfMT0fMWI03L0fMWI000L0=WIf@03
0000003IfMT0fMWI01H0fMWI0P000?l30=WIf@030000o`3IfMT0fMWI00@0fMWI00<0_`2o0=WIf@3I
fMT01P3IfMT2002o_b<0fMWI00<0003o0=WIf@3IfMT00P3IfMT00`000?l0fMWI0=WIf@0=0=WIf@80
0;no203IfMT00`2o0;l0fMWI0=WIf@0b0=WIf@@00;no7`3IfMT00`000?l0fMWI0=WIf@0g0=WIf@00
703IfMT00`000000fMWI0=WIf@0E0=WIf@030000o`3IfMT0fMWI00@0fMWI00<0003o0=WIf@3IfMT0
0P3IfMT00`2o0;l0fMWI0=WIf@050=WIf@800;no903IfMT00`000?l0fMWI0=WIf@040=WIf@030000
o`3IfMT0fMWI00h0fMWI0P00_kl60=WIf@030;l0_`3IfMT0fMWI02h0fMWI1000_klR0=WIf@030000
o`3IfMT0fMWI03P0fMWI000L0=WIf@030000003IfMT0fMWI01@0fMWI00<0003o0=WIf@3IfMT01P3I
fMT010000?l0fMWI0;l0_`2o0;l60=WIf@800;no9@3IfMT00`000?l0fMWI0=WIf@050=WIf@030000
o`3IfMT0fMWI0100fMWI0P00_kl50=WIf@030;l0_`3IfMT0fMWI02X0fMWI0`00_klU0=WIf@030000
o`3IfMT0fMWI03T0fMWI000L0=WIf@030000003IfMT0fMWI01<0fMWI00<0003o0=WIf@3IfMT0203I
fMT00`2o0;l0fMWI0=WIf@040=WIf@800;no9P3IfMT00`000?l0fMWI0=WIf@070=WIf@030000o`3I
fMT0fMWI0140fMWI0P00_kl30=WIf@80_`2o9`3IfMT4002o_bL0fMWI00<0003o0=WIf@3IfMT0>P3I
fMT001`0fMWI00<000000=WIf@3IfMT04P3IfMT00`000?l0fMWI0=WIf@080=WIf@030;l0_`000?l0
fMWI00<0fMWI0P00_klW0=WIf@030000o`3IfMT0fMWI00P0fMWI00<0003o0=WIf@3IfMT04`3IfMT2
002o_`<0fMWI102o0;lP0=WIf@<00;no:`3IfMT00`000?l0fMWI0=WIf@0j0=WIf@00703IfMT00`00
0000fMWI0=WIf@0@0=WIf@80003o2@3IfMT20;l0_`80fMWI00@0003o0=WIf@00_kl00;no:03IfMT0
0`000?l0fMWI0=WIf@0:0=WIf@030000o`3IfMT0fMWI01@0fMWI1`00_kl30;l0_aT0fMWI1000_kl]
0=WIf@030000o`3IfMT0fMWI03/0fMWI000L0=WIf@030000003IfMT0fMWI00l0fMWI00<0003o0=WI
f@3IfMT0203IfMT00`2o0;l0fMWI0=WIf@020=WIf@800;no:@3IfMT00`000?l0fMWI0=WIf@0;0=WI
f@030000o`3IfMT0fMWI01`0fMWI0P00_kl40;l0_`P00;no2@3IfMT4002o_c00fMWI00<0003o0=WI
f@3IfMT0?03IfMT001`0fMWI00<000000=WIf@3IfMT03P3IfMT00`000?l0fMWI0=WIf@070=WIf@80
_`2o0`3IfMT2002o_`80fMWI00<0003o0=WIf@3IfMT09P3IfMT00`000?l0fMWI0=WIf@0<0=WIf@03
0000o`3IfMT0fMWI0240fMWI0`2o0;l50=WIf@T00;no<`3IfMT00`000?l0fMWI0=WIf@0m0=WIf@00
703IfMT00`000000fMWI0=WIf@0=0=WIf@030000o`3IfMT0fMWI00H0fMWI0P2o0;l30=WIf@800;no
1@3IfMT00`000?l0fMWI0=WIf@0T0=WIf@030000o`3IfMT0fMWI00h0fMWI00<0003o0=WIf@3IfMT0
8`3IfMT40;l0_`L0fMWI00<0003o0=WIf@000?l0<P3IfMT00`000?l0fMWI0=WIf@0n0=WIf@00703I
fMT00`000000fMWI0=WIf@0;0=WIf@80003o1`3IfMT20;l0_`80fMWI0`00_kl80=WIf@030000o`3I
fMT0fMWI0280fMWI00<0003o0=WIf@3IfMT03`3IfMT00`000?l0fMWI0=WIf@0W0=WIf@<0_`2o103I
fMT010000?l0fMWI0=WIf@000?l`0=WIf@030000o`3IfMT0fMWI03l0fMWI000L0=WIf@030000003I
fMT0fMWI00X0fMWI00<0003o0=WIf@3IfMT01@3IfMT20;l0_`80fMWI0P00_kl00`3IfMT000000000
00040=WIf@8000000`3IfMT00`000?l000000000000K0=WIf@D0000000<0003o0=WIf@3IfMT04@3I
fMT00`000?l0fMWI0=WIf@020=WIf@D000000P3IfMT2000000@0fMWI0P00000H0=WIf@@0_`2o0`00
00000`3IfMT0003o0=WIf@0G0=WIf@@000000`3IfMT2000000@0fMWI0P0000080=WIf@030000o`3I
fMT0fMWI0140fMWI0P00000/0=WIf@00703IfMT00`000000fMWI0=WIf@090=WIf@030000o`3IfMT0
fMWI00@0fMWI0P2o0;l20=WIf@800;no0P3IfMT010000000fMWI0=WIf@0000080=WIf@0400000000
0?l0fMWI000001`0fMWI00<000000=WIf@000?l0503IfMT00`000?l0fMWI0=WIf@040=WIf@030000
003IfMT0fMWI00L0fMWI00@000000=WIf@3IfMT000006@3IfMT00`000?l000000;l0_`020;l0_`80
fMWI00<0003o0=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@090=WIf@040000003IfMT0fMWI0000
00H0fMWI00<0003o0=WIf@3IfMT04@3IfMT010000000fMWI0=WIf@00000[0=WIf@00703IfMT00`00
0000fMWI0=WIf@080=WIf@030000o`3IfMT0fMWI00<0fMWI0P2o0;l0103IfMT00;no002o_`00_kl4
0=WIf@040000003IfMT0fMWI000000X0fMWI00<0003o0000003IfMT06`3IfMT00`000000003o0=WI
f@0E0=WIf@030000o`3IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMTU001o0080_`2o2`00
O`0>0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000?l0fMWI0=WI
f@0D0=WIf@030000003IfMT0fMWI02X0fMWI000L0=WIf@030000003IfMT0fMWI00L0fMWI00<0003o
0=WIf@3IfMT00P3IfMT20;l0_`030=WIf@00_kl00;no00L0fMWI00@000000=WIf@3IfMT000002@3I
fMT2000000030000o`3IfMT0fMWI01X0fMWI00<000000000o`3IfMT0503IfMT>001o00@0fMWI0P00
000I0=WIf@050000o`3IfMT0fMWI0=WIf@0000000`3IfMT30;l0_`P0fMWI7@00O`040=WIf@030000
o`3IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT0:@3IfMT001`0fMWI00<000000=WIf@3IfMT01@3I
fMT20000o`<0fMWI0P2o0;l00`3IfMT00;no002o_`090=WIf@040000003IfMT0fMWI000000T0fMWI
00@000000=WIf@3IfMT0003o6`3IfMT00`000?l0fMWI0=WIf@080=WIf@`007l00P3IfMT00`000?l0
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT05`3IfMT010000?l0
fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00<0fMWI0`2o0;lB0=WIf@040000003IfMT0fMWI
000000T0fMWI00<000000=WIf@3IfMT07@00O`000`000000fMWI0=WIf@0Y0=WIf@00703IfMT00`00
0000fMWI0=WIf@040=WIf@040000o`3IfMT0fMWI0=WIf@80_`2o0`00_kl<0=WIf@8000002P3IfMT3
000000030000o`3IfMT0fMWI01P0fMWI00<0003o00000000O`002@00O`0>0=WIf@040000o`3IfMT0
fMWI0=WIf@8000002P3IfMT3000001L0fMWI00@0003o0=WIf@3IfMT0fMWI0P0000070=WIf@040000
o`3IfMT0_`2o0;l0_a40fMWI0P00000:0=WIf@<000000P3IfMT00`000?l0fMWI0=WIf@0F0=WIf@80
00003`00O`0M0=WIf@00703IfMT00`000000fMWI0=WIf@030=WIf@030000o`3IfMT0fMWI0080_`2o
0P00_klO0=WIf@030000o`3IfMT0fMWI00l0fMWI2P00O`0I0=WIf@030000o`3IfMT0fMWI02D0fMWI
00<0003o0=WIf@3IfMT0303IfMT00`000?l0fMWI0=WIf@030;l0_`L0fMWI3`3o00090=WIf@030000
o`3IfMT0fMWI04@0fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00@0003o0=WIf@2o0;l0_`2o
0P00_klR0=WIf@030000o`3IfMT0fMWI0080fMWI3000O`060=WIf@030000o`3IfMT0fMWI01X0fMWI
00<0003o0=WIf@3IfMT0903IfMT00`000?l0fMWI0=WIf@0<0=WIf@L0o`000`2o0;l40?l000l0fMWI
3P3o00120=WIf@00703IfMT01@000000fMWI0=WIf@3IfMT0003o0080_`2o0P00_klK0=WIf@h007l0
4@3IfMT00`000?l0fMWI0=WIf@0L0=WIf@030000o`3IfMT0fMWI02<0fMWI3`3o00030=WIf@030000
o`3IfMT0fMWI00@0fMWI0P2o0;lH0=WIf@030000o`3IfMT0fMWI00@0fMWI2P3o000h0=WIf@00703I
fMT00`000000fMWI0000o`020;l0_`03002o_`3IfMT0fMWI00d0fMWI3`00O`0;0=WIf@030000o`3I
fMT0fMWI0100fMWI00<0003o0=WIf@3IfMT07P3IfMT00`000?l0fMWI0=WIf@0D0=WIf@h0o`004`3I
fMT00`000?l0fMWI0=WIf@050=WIf@<0_`2o503IfMT00`000?l0fMWI0=WIf@0?0=WIf@D0o`00903I
fMT2000000d0fMWI000L0=WIf@040000002o0;l0_`2o002o_`<0fMWI3P00O`0K0=WIf@030000o`3I
fMT0o`0001D0o`006`3IfMT00`000?l0fMWI0?l0000D0?l000`0fMWI00<0003o0=WIf@3IfMT04`3I
fMT00`000?l0fMWI0=WIf@070=WIf@<0_`2o403IfMT00`000?l0fMWI0=WIf@0E0=WIf@D0o`007P3I
fMT010000000fMWI0=WIf@00000<0=WIf@005P3IfMT6000000030;l0_`00_kl0o`0000/0o`005P00
000>0?l000l0000000<0003o0000000000001000000M0?l00240000000<0003o0000000000005000
00000`000?l000000000000900000080_`2o3@0000000`000?l000000000000K000000@0o`004P00
00080=WIf@030000003IfMT0fMWI00d0fMWI000L0=WIf@030000003IfMT0fMWI00/0fMWI5P3o000>
0=WIf@030000o`3IfMT0fMWI00/0fMWI00<0003o0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0J
0=WIf@030000o`3IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT05`3IfMT00`000?l0fMWI0=WIf@07
0=WIf@030000003IfMT0fMWI00`0fMWI00<0003o0=WIf@3IfMT02P3IfMT20;l0_`H0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000?l0fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI00D0o`00503IfMT5
000000`0fMWI000L0=WIf@030000003IfMT0fMWI0300fMWI00<0003o0=WIf@3IfMT02@3IfMT00`00
0?l0fMWI0=WIf@0S0=WIf@030000o`3IfMT0fMWI01`0fMWI00<0003o0=WIf@3IfMT0603IfMT00`00
0?l0fMWI0=WIf@0;0=WIf@030;l0_`3IfMT0fMWI00L0fMWI00<0003o0=WIf@3IfMT09@3IfMT50?l0
0100fMWI00<000000=WIf@3IfMT03@3IfMT001`0fMWI00<000000=WIf@3IfMT0<@3IfMT00`000?l0
fMWI0=WIf@070=WIf@030000o`3IfMT0fMWI02@0fMWI00<0003o0=WIf@3IfMT0703IfMT00`000?l0
fMWI0=WIf@0I0=WIf@030000o`3IfMT0fMWI00X0fMWI00<0_`2o0=WIf@3IfMT01P3IfMT00`000?l0
fMWI0=WIf@0[0=WIf@<0o`007@3IfMT001`0fMWI00<000000=WIf@3IfMT0<@3IfMT00`000?l0fMWI
0=WIf@060=WIf@030000o`3IfMT0fMWI02H0fMWI00<0003o0=WIf@3IfMT06P3IfMT00`000?l0fMWI
0=WIf@0K0=WIf@030000o`3IfMT0fMWI00X0fMWI00<0_`2o0=WIf@3IfMT0103IfMT00`000?l0fMWI
0=WIf@1<0=WIf@00703IfMT00`000000fMWI0=WIf@0b0=WIf@030000o`3IfMT0fMWI00@0fMWI00<0
003o0=WIf@3IfMT09`3IfMT00`000?l0fMWI0=WIf@0I0=WIf@030000o`3IfMT0fMWI01d0fMWI00<0
003o0=WIf@3IfMT02@3IfMT00`2o0;l0fMWI0=WIf@030=WIf@030000o`3IfMT0fMWI04d0fMWI000L
0=WIf@030000003IfMT0fMWI03<0fMWI00<0003o0=WIf@3IfMT00`3IfMT00`000?l0fMWI0=WIf@0X
0=WIf@030000o`3IfMT0fMWI01P0fMWI00<0003o0=WIf@3IfMT07P3IfMT00`000?l0fMWI0=WIf@09
0=WIf@050;l0_`3IfMT0fMWI0=WIf@000?l0D03IfMT001`0fMWI00<000000=WIf@3IfMT0=03IfMT0
1@000?l0fMWI0=WIf@3IfMT0003o02`0fMWI00<0003o0=WIf@3IfMT05P3IfMT00`000?l0fMWI0=WI
f@0P0=WIf@030000o`3IfMT0fMWI00P0fMWI00D0_`2o0=WIf@3IfMT0fMWI0000o`1@0=WIf@00703I
fMT00`000000fMWI0=WIf@0e0=WIf@030000o`3IfMT0003o02d0fMWI00<0003o0=WIf@3IfMT05@3I
fMT00`000?l0fMWI0=WIf@0R0=WIf@030000o`3IfMT0fMWI00P0fMWI00<0_`2o0=WIf@000?l0D@3I
fMT001`0fMWI00<000000=WIf@3IfMT0=P3IfMT00`000?l0fMWI0=WIf@0]0=WIf@030000o`3IfMT0
fMWI01@0fMWI00<0003o0=WIf@3IfMT08`3IfMT00`000?l0fMWI0=WIf@070=WIf@030;l0_`000?l0
fMWI0540fMWI000L0=WIf@030000003IfMT0fMWI06H0fMWI00<0003o0=WIf@3IfMT04`3IfMT00`00
0?l0fMWI0=WIf@0U0=WIf@030000o`3IfMT0fMWI00H0fMWI00<0003o0;l0_`3IfMT0D@3IfMT001`0
fMWI00<000000=WIf@3IfMT0I`3IfMT00`000?l0fMWI0=WIf@0A0=WIf@030000o`3IfMT0fMWI02L0
fMWI00<0003o0=WIf@3IfMT0103IfMT00`000?l0fMWI0;l0_`1B0=WIf@00703IfMT00`000000fMWI
0=WIf@1W0=WIf@030000o`3IfMT0fMWI0140fMWI00<0003o0=WIf@3IfMT0:03IfMT00`000?l0fMWI
0=WIf@020=WIf@050000o`3IfMT0fMWI0=WIf@2o0;l0D@3IfMT001`0fMWI00<000000=WIf@3IfMT0
J03IfMT00`000?l0fMWI0=WIf@0?0=WIf@030000o`3IfMT0fMWI02X0fMWI00D0003o0=WIf@3IfMT0
fMWI0000o`030=WIf@030;l0_`3IfMT0fMWI04l0fMWI000L0=WIf@030000003IfMT0fMWI06P0fMWI
00<0003o0=WIf@3IfMT03P3IfMT00`000?l0fMWI0=WIf@0/0=WIf@030000o`3IfMT0003o00D0fMWI
00<0_`2o0=WIf@3IfMT0CP3IfMT001`0fMWI00<000000=WIf@3IfMT0J@3IfMT00`000?l0fMWI0=WI
f@0=0=WIf@030000o`3IfMT0fMWI02d0fMWI00<0003o0=WIf@3IfMT0103IfMT00`2o0;l0fMWI0=WI
f@1>0=WIf@00703IfMT00`000000fMWI0=WIf@1Y0=WIf@030000o`3IfMT0fMWI00`0fMWI00<0003o
0=WIf@3IfMT0=P3IfMT00`2o0;l0fMWI0=WIf@1=0=WIf@00703IfMT00`000000fMWI0=WIf@1Z0=WI
f@030000o`3IfMT0fMWI00X0fMWI00<0003o0=WIf@3IfMT0=`3IfMT00`2o0;l0fMWI0=WIf@1=0=WI
f@00703IfMT00`000000fMWI0=WIf@1[0=WIf@030000o`3IfMT0fMWI00T0fMWI00<0003o0=WIf@3I
fMT0>03IfMT00`2o0;l0fMWI0=WIf@1<0=WIf@00703IfMT00`000000fMWI0=WIf@1[0=WIf@030000
o`3IfMT0fMWI00P0fMWI00<0003o0=WIf@3IfMT0>@3IfMT00`2o0;l0fMWI0=WIf@1<0=WIf@00703I
fMT00`000000fMWI0=WIf@1/0=WIf@030000o`3IfMT0fMWI00H0fMWI00<0003o0=WIf@3IfMT0>`3I
fMT00`2o0;l0fMWI0=WIf@1;0=WIf@00703IfMT00`000000fMWI0=WIf@1/0=WIf@030000o`3IfMT0
fMWI00H0fMWI00<0003o0=WIf@3IfMT0?03IfMT00`2o0;l0fMWI0=WIf@1:0=WIf@00703IfMT00`00
0000fMWI0=WIf@1]0=WIf@030000o`3IfMT0fMWI00@0fMWI00<0003o0=WIf@3IfMT0?@3IfMT00`2o
0;l0fMWI0=WIf@1:0=WIf@00703IfMT00`000000fMWI0=WIf@1]0=WIf@030000o`3IfMT0fMWI00<0
fMWI00<0003o0=WIf@3IfMT0?`3IfMT00`2o0;l0fMWI0=WIf@190=WIf@00703IfMT00`000000fMWI
0=WIf@1^0=WIf@030000o`3IfMT0fMWI0080fMWI00<0003o0=WIf@3IfMT0?`3IfMT00`2o0;l0fMWI
0=WIf@190=WIf@00703IfMT00`000000fMWI0=WIf@1^0=WIf@050000o`3IfMT0fMWI0=WIf@000?l0
@`3IfMT00`2o0;l0fMWI0=WIf@180=WIf@00703IfMT00`000000fMWI0=WIf@1_0=WIf@030000o`3I
fMT0003o04@0fMWI00<0_`2o0=WIf@3IfMT0B03IfMT001`0fMWI00<000000=WIf@3IfMT0K`3IfMT0
0`000?l0fMWI0000o`150=WIf@030;l0_`3IfMT0fMWI04L0fMWI000L0=WIf@030000003IfMT0fMWI
0700fMWI00<0003o0=WIf@3IfMT0A03IfMT00`2o0;l0fMWI0=WIf@170=WIf@00703IfMT00`000000
fMWI0=WIf@2h0=WIf@030;l0_`3IfMT0fMWI04H0fMWI000>0=WIf@D000000P3IfMT2000000D0fMWI
00<000000=WIf@3IfMT0^03IfMT00`2o0;l0fMWI0=WIf@160=WIf@00403IfMT01@000000fMWI0=WI
f@3IfMT000000080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@2i0=WIf@030;l0
_`3IfMT0fMWI04D0fMWI000@0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI
0=WIf@020=WIf@800000^P3IfMT00`2o0;l0fMWI0=WIf@150=WIf@00403IfMT01@000000fMWI0=WI
f@3IfMT000000080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@2j0=WIf@030;l0
_`3IfMT0fMWI04@0fMWI000@0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI0;X0fMWI00<0_`2o0=WIf@3IfMT0A03IfMT000l0fMWI0P00
00040=WIf@8000001@3IfMT00`000000fMWI0=WIf@2k0=WIf@030;l0_`3IfMT0fMWI04<0fMWI000L
0=WIf@030000003IfMT0fMWI0;/0fMWI00<0_`2o0=WIf@3IfMT0@`3IfMT001`0fMWI00<000000=WI
f@3IfMT0_03IfMT00`2o0;l0fMWI0=WIf@120=WIf@00703IfMT00`000000fMWI0=WIf@2m0=WIf@03
0;l0_`3IfMT0fMWI0440fMWI000L0=WIf@030000003IfMT0fMWI0;d0fMWI00<0_`2o0=WIf@3IfMT0
@@3IfMT001`0fMWI00<000000=WIf@3IfMT0_P3IfMT00`2o0;l0fMWI0=WIf@100=WIf@00703IfMT0
0`000000fMWI0=WIf@2n0=WIf@030;l0_`3IfMT0fMWI0400fMWI000L0=WIf@030000003IfMT0fMWI
0;l0fMWI00<0_`2o0=WIf@3IfMT0?`3IfMT001`0fMWI00<000000=WIf@3IfMT0_`3IfMT00`2o0;l0
fMWI0=WIf@0o0=WIf@00703IfMT00`000000fMWI0=WIf@300=WIf@030;l0_`3IfMT0fMWI03h0fMWI
000L0=WIf@030000003IfMT0fMWI0<00fMWI00<0_`2o0=WIf@3IfMT0?P3IfMT001`0fMWI00<00000
0=WIf@3IfMT0`@3IfMT00`2o0;l0fMWI0=WIf@0m0=WIf@00703IfMT00`000000fMWI0=WIf@310=WI
f@030;l0_`3IfMT0fMWI03d0fMWI000L0=WIf@030000003IfMT0fMWI0<80fMWI00<0_`2o0=WIf@3I
fMT0?03IfMT001`0fMWI00<000000=WIf@3IfMT0`P3IfMT00`2o0;l0fMWI0=WIf@0l0=WIf@00703I
fMT00`000000fMWI0=WIf@330=WIf@030;l0_`3IfMT0fMWI03/0fMWI000L0=WIf@030000003IfMT0
fMWI0<<0fMWI00<0_`2o0=WIf@3IfMT0>`3IfMT001`0fMWI00<000000=WIf@3IfMT0a03IfMT00`2o
0;l0fMWI0=WIf@0I0=WIf@@0_`2o7@3IfMT001`0fMWI00<000000=WIf@3IfMT0a03IfMT00`2o0;l0
fMWI0=WIf@0B0=WIf@L0_`2o8@3IfMT001`0fMWI00<000000=WIf@3IfMT0a@3IfMT00`2o0;l0fMWI
0=WIf@090=WIf@P0_`2o:03IfMT001`0fMWI00<000000=WIf@3IfMT0a@3IfMT00`2o0;l0fMWI0=WI
f@020=WIf@L0_`2o<03IfMT001`0fMWI00<000000=WIf@3IfMT0aP3IfMT40;l0_cL0fMWI000L0=WI
f@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00
703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WI
fB40fMWI003o0=WIfB40fMWI001=0=WIf@@000001P3IfMT4000000D0fMWI0P0000080=WIf@800000
]03IfMT004d0fMWI00<000000=WIf@000000203IfMT00`000000fMWI000000050=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT0/P3IfMT00280fMWI1@0000000`3IfMT0000000000002
000000080=WIf@00000000000=WIf@000000fMWI0000003IfMT4000000<0fMWI0P0000030=WIf@D0
000000<0fMWI0000000000000`0000020=WIf@030000003IfMT000000080fMWI1@000000103IfMT0
00000=WIf@0000050=WIf@030000003IfMT0fMWI0080fMWI0P0000040=WIf@030000003IfMT0fMWI
0;80fMWI000F0=WIf@P0_`2o103IfMT4000000<0fMWI00<000000=WIf@3IfMT00P3IfMT01`000000
fMWI0000003IfMT000000=WIf@0000002`3IfMT400000080fMWI100000030=WIf@030000003IfMT0
000000@0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000D0fMWI00D000000=WIf@3IfMT0
fMWI000000020=WIf@050000003IfMT0fMWI0=WIf@000000]03IfMT002D0fMWI00D000000=WIf@3I
fMT0fMWI000000040=WIf@050000003IfMT000000=WIf@0000000P3IfMT00`000000fMWI0=WIf@0;
0=WIf@030000003IfMT0fMWI00<0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000@0fMWI
00L000000=WIf@3IfMT0fMWI0000003IfMT0000000D0fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@030000003IfMT0fMWI0;80fMWI000S0=WIf@<000000P3IfMT4000000060=WIf@0000000000
0000003IfMT00000103IfMT00`000000fMWI0=WIf@080=WIf@<000000`3IfMT3000000<0fMWI00<0
00000=WIf@000000103IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT00`000000
fMWI0=WIf@05000000<0fMWI00<000000=WIf@3IfMT0/P3IfMT003@0fMWI00@000000=WIf@3IfMT0
00005@3IfMT00`000000fMWI000000040=WIf@070000003IfMT0fMWI0=WIf@000000fMWI00000005
0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@2b0=WIf@00=@3IfMT2
000001H0fMWI100000020=WIf@8000000P3IfMT4000000D0fMWI0P0000080=WIf@800000]03IfMT0
04d0fMWI100000060=WIf@@000001@3IfMT2000000P0fMWI0P00002d0=WIf@00C@3IfMT00`000000
fMWI000000080=WIf@030000003IfMT0000000D0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@2b0=WIf@008P3IfMT5000000030=WIf@00000000000080000000P0fMWI000000000000
fMWI0000003IfMT000000=WIf@D000000P3IfMT2000000<0fMWI1@0000000`3IfMT0000000000003
00000080fMWI00<000000=WIf@0000000P3IfMT5000000040=WIf@000000fMWI000000D0fMWI00<0
00000=WIf@3IfMT00P3IfMT2000000@0fMWI00<000000=WIf@3IfMT0/P3IfMT001H0fMWI2000_kl4
0=WIf@@000000`3IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT000000=WIf@0000000`3I
fMT00`000000fMWI0=WIf@070=WIf@@000000P3IfMT4000000<0fMWI00<000000=WIf@000000103I
fMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT01@000000fMWI0=WIf@3IfMT00000
0080fMWI00D000000=WIf@3IfMT0fMWI0000002d0=WIf@009@3IfMT01@000000fMWI0=WIf@3IfMT0
000000@0fMWI00D000000=WIf@000000fMWI000000030=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT00`3IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@000000103IfMT01`000000
fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<0
00000=WIf@3IfMT0/P3IfMT002<0fMWI0`0000020=WIf@@0000000H0fMWI00000000000000000=WI
f@0000040=WIf@030000003IfMT0fMWI00P0fMWI0`0000030=WIf@<000000`3IfMT00`000000fMWI
000000040=WIf@070000003IfMT0fMWI0=WIf@000000fMWI000000050=WIf@030000003IfMT0fMWI
00D000000`3IfMT00`000000fMWI0=WIf@2b0=WIf@00=P3IfMT00`000000fMWI0=WIf@0D0=WIf@03
0000003IfMT0000000@0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000D0fMWI00D00000
0=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0;80fMWI000U0=WIf@030000003IfMT0
fMWI00@000002@3IfMT2000001H0fMWI100000020=WIf@P000001@3IfMT2000000P0fMWI0P00002d
0=WIf@00903IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI02L0fMWI00D000000=WI
f@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0/P3IfMT0
02<0fMWI00<000000=WIf@3IfMT01@3IfMT010000000fMWI0=WIf@3IfMT2000000@0fMWI0`000000
0`3IfMT00000000000020=WIf@8000000P3IfMT2000000<0fMWI100000030=WIf@800000103IfMT3
000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@800000103IfMT0
0`000000fMWI0=WIf@2b0=WIf@008`3IfMT00`000000fMWI0=WIf@050=WIf@040000003IfMT0fMWI
00000080fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00@0
00000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI0000
00@0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00D00000
0=WIf@3IfMT0fMWI0000002d0=WIf@005P3IfMT80?l000D0fMWI00<000000=WIf@3IfMT01@3IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI
000000020=WIf@040000003IfMT0fMWI000000H0fMWI00<000000=WIf@3IfMT0203IfMT010000000
fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@030000003IfMT0fMWI0;80fMWI000S0=WIf@030000003IfMT0fMWI0080fMWI100000030=WI
f@800000103IfMT200000080fMWI100000020=WIf@D00000103IfMT00`000000fMWI0=WIf@080=WI
f@@000000`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D000000`3IfMT00`00
0000fMWI0=WIf@2b0=WIf@00903IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI00<0
fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI
0=WIf@0000001P3IfMT00`000000fMWI0=WIf@2b0=WIf@009@3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT03P3IfMT2000000l0fMWI00<000000=WI
f@3IfMT01@3IfMT2000000P0fMWI0P00002d0=WIf@009@3IfMT00`000000fMWI0=WIf@04000002P0
fMWI0`0000000`3IfMT000000=WIf@060=WIf@800000203IfMT200000;@0fMWI000T0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT09`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@2b0=WIf@008`3IfMT00`000000fMWI
0=WIf@050=WIf@040000003IfMT0fMWI0=WIf@800000103IfMT3000000030=WIf@00000000000080
fMWI0P0000020=WIf@8000000`3IfMT500000080fMWI0P0000040=WIf@<00000103IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0P0000040=WIf@030000003IfMT0fMWI0;80
fMWI000S0=WIf@030000003IfMT0fMWI00D0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000
fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@000002
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01`3IfMT010000000fMWI0=WIf@00
00040=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@050000
003IfMT0fMWI0=WIf@000000]03IfMT001H0fMWI2000O`050=WIf@030000003IfMT0fMWI00D0fMWI
00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WI
f@0000000P3IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT0fMWI00L0fMWI00@00000
0=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@000000
1P3IfMT00`000000fMWI0=WIf@2b0=WIf@008`3IfMT00`000000fMWI0=WIf@020=WIf@@000000`3I
fMT2000000@0fMWI0P0000020=WIf@@000000P3IfMT5000000@0fMWI00<000000=WIf@3IfMT0203I
fMT4000000<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@05000000<0fMWI00<0
00000=WIf@3IfMT0/P3IfMT002@0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@05
0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3I
fMT0000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT002D0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00h0fMWI0P00000?0=WIf@030000003IfMT0
fMWI00D0fMWI0P0000080=WIf@800000]03IfMT002D0fMWI00<000000=WIf@3IfMT01@3IfMT30000
01H0fMWI0`00000?0=WIf@030000003IfMT0fMWI00D0fMWI0P0000080=WIf@800000]03IfMT002@0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI00d0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0;80
fMWI000S0=WIf@030000003IfMT0fMWI0080fMWI0`0000030=WIf@<000000`3IfMT4000000<0fMWI
0`0000000`3IfMT00000000000020=WIf@8000000P3IfMT3000000<0fMWI0P0000040=WIf@<00000
103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0P0000040=WIf@030000
003IfMT0fMWI0;80fMWI000S0=WIf@030000003IfMT0fMWI00D0fMWI00@000000=WIf@3IfMT00000
0P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000020=WI
f@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@050000003I
fMT0fMWI0=WIf@000000]03IfMT001H0fMWI20000?l50=WIf@030000003IfMT0fMWI0080fMWI0`00
00030=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI
0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0
000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT002<0fMWI00<000000=WIf@3IfMT00P3IfMT40000
00030=WIf@0000000000008000000`3IfMT4000000<0fMWI0P0000020=WIf@@00000103IfMT40000
00T0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00D000000`3IfMT00`000000fMWI0=WIf@2b0=WIf@00903IfMT00`000000fMWI0=WIf@0[0=WIf@@0
00000`3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`00
0000fMWI0=WIf@2b0=WIf@009@3IfMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI01T0
fMWI00<000000=WIf@3IfMT01@3IfMT2000000P0fMWI0P00002d0=WIf@00o`3IfMTQ0=WIf@00o`3I
fMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00\
\>"],
  ImageRangeCache->{{{138, 425}, {387, 173.75}} -> {-2.06252, 0.617803, \
0.00732689, 0.00732689}, {{145, 417.938}, {381.875, 213.188}} -> {-2.30865, \
21.5399, 0.0139057, 0.310075}, {{158.625, 295.125}, {219.75, 178.813}} -> \
{-19.1203, 0.852651, 0.119891, 0.146566}, {{160.125, 168.438}, {218.5, \
211.688}} -> {-48.2298, 0.54129, 0.293581, 0.293581}, {{160.125, 168.438}, \
{210.563, 203.75}} -> {-48.2298, -1.78901, 0.293581, 0.293581}, {{160.125, \
168.438}, {202.688, 195.813}} -> {-47.7914, -4.07277, 0.290912, 0.290912}, \
{{160.125, 168.438}, {194.75, 187.938}} -> {-48.2298, -6.43126, 0.293581, \
0.293581}, {{160.125, 168.438}, {186.813, 180}} -> {-48.2298, -8.76156, \
0.293581, 0.293581}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74402 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.312017 0.47619 [
[ 0 0 0 0 ]
[ 1 .74402 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0177147 0.97619 0.606318 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.297619 0.58197 0.00189085 [
[.17262 .56947 -9 -9 ]
[.17262 .56947 9 0 ]
[.32143 .56947 -3 -9 ]
[.32143 .56947 3 0 ]
[.47024 .56947 -9 -9 ]
[.47024 .56947 9 0 ]
[.61905 .56947 -3 -9 ]
[.61905 .56947 3 0 ]
[.76786 .56947 -9 -9 ]
[.76786 .56947 9 0 ]
[.91667 .56947 -3 -9 ]
[.91667 .56947 3 0 ]
[1.025 .58197 0 -6.28125 ]
[1.025 .58197 10 6.28125 ]
[.01131 .01472 -24 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .10926 -24 -4.5 ]
[.01131 .10926 0 4.5 ]
[.01131 .2038 -24 -4.5 ]
[.01131 .2038 0 4.5 ]
[.01131 .29834 -24 -4.5 ]
[.01131 .29834 0 4.5 ]
[.01131 .39288 -24 -4.5 ]
[.01131 .39288 0 4.5 ]
[.01131 .48743 -18 -4.5 ]
[.01131 .48743 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17262 .58197 m
.17262 .58822 L
s
[(0.5)] .17262 .56947 0 1 Mshowa
.32143 .58197 m
.32143 .58822 L
s
[(1)] .32143 .56947 0 1 Mshowa
.47024 .58197 m
.47024 .58822 L
s
[(1.5)] .47024 .56947 0 1 Mshowa
.61905 .58197 m
.61905 .58822 L
s
[(2)] .61905 .56947 0 1 Mshowa
.76786 .58197 m
.76786 .58822 L
s
[(2.5)] .76786 .56947 0 1 Mshowa
.91667 .58197 m
.91667 .58822 L
s
[(3)] .91667 .56947 0 1 Mshowa
.125 Mabswid
.05357 .58197 m
.05357 .58572 L
s
.08333 .58197 m
.08333 .58572 L
s
.1131 .58197 m
.1131 .58572 L
s
.14286 .58197 m
.14286 .58572 L
s
.20238 .58197 m
.20238 .58572 L
s
.23214 .58197 m
.23214 .58572 L
s
.2619 .58197 m
.2619 .58572 L
s
.29167 .58197 m
.29167 .58572 L
s
.35119 .58197 m
.35119 .58572 L
s
.38095 .58197 m
.38095 .58572 L
s
.41071 .58197 m
.41071 .58572 L
s
.44048 .58197 m
.44048 .58572 L
s
.5 .58197 m
.5 .58572 L
s
.52976 .58197 m
.52976 .58572 L
s
.55952 .58197 m
.55952 .58572 L
s
.58929 .58197 m
.58929 .58572 L
s
.64881 .58197 m
.64881 .58572 L
s
.67857 .58197 m
.67857 .58572 L
s
.70833 .58197 m
.70833 .58572 L
s
.7381 .58197 m
.7381 .58572 L
s
.79762 .58197 m
.79762 .58572 L
s
.82738 .58197 m
.82738 .58572 L
s
.85714 .58197 m
.85714 .58572 L
s
.8869 .58197 m
.8869 .58572 L
s
.94643 .58197 m
.94643 .58572 L
s
.97619 .58197 m
.97619 .58572 L
s
.25 Mabswid
0 .58197 m
1 .58197 L
s
gsave
1.025 .58197 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03006 .01472 L
s
[(-300)] .01131 .01472 1 0 Mshowa
.02381 .10926 m
.03006 .10926 L
s
[(-250)] .01131 .10926 1 0 Mshowa
.02381 .2038 m
.03006 .2038 L
s
[(-200)] .01131 .2038 1 0 Mshowa
.02381 .29834 m
.03006 .29834 L
s
[(-150)] .01131 .29834 1 0 Mshowa
.02381 .39288 m
.03006 .39288 L
s
[(-100)] .01131 .39288 1 0 Mshowa
.02381 .48743 m
.03006 .48743 L
s
[(-50)] .01131 .48743 1 0 Mshowa
.125 Mabswid
.02381 .03362 m
.02756 .03362 L
s
.02381 .05253 m
.02756 .05253 L
s
.02381 .07144 m
.02756 .07144 L
s
.02381 .09035 m
.02756 .09035 L
s
.02381 .12817 m
.02756 .12817 L
s
.02381 .14707 m
.02756 .14707 L
s
.02381 .16598 m
.02756 .16598 L
s
.02381 .18489 m
.02756 .18489 L
s
.02381 .22271 m
.02756 .22271 L
s
.02381 .24162 m
.02756 .24162 L
s
.02381 .26053 m
.02756 .26053 L
s
.02381 .27943 m
.02756 .27943 L
s
.02381 .31725 m
.02756 .31725 L
s
.02381 .33616 m
.02756 .33616 L
s
.02381 .35507 m
.02756 .35507 L
s
.02381 .37398 m
.02756 .37398 L
s
.02381 .41179 m
.02756 .41179 L
s
.02381 .4307 m
.02756 .4307 L
s
.02381 .44961 m
.02756 .44961 L
s
.02381 .46852 m
.02756 .46852 L
s
.02381 .50634 m
.02756 .50634 L
s
.02381 .52524 m
.02756 .52524 L
s
.02381 .54415 m
.02756 .54415 L
s
.02381 .56306 m
.02756 .56306 L
s
.02381 .60088 m
.02756 .60088 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 1 r
.001 w
.02381 .01472 m
.14286 .57129 L
.2619 .5865 L
.38095 .56508 L
.5 .59308 L
.61905 .58724 L
.7381 .58961 L
.85714 .56366 L
.97619 .60292 L
s
0 .5 0 r
.02381 .58197 m
.14286 .58192 L
.2619 .58004 L
.38095 .57879 L
.5 .57682 L
.61905 .57654 L
.7381 .57725 L
.85714 .5783 L
.97619 .57863 L
s
1 0 0 r
.02381 .58197 m
.14286 .58107 L
.2619 .5827 L
.38095 .58126 L
.5 .58242 L
.61905 .58126 L
.7381 .57988 L
.85714 .58035 L
.97619 .58372 L
s
0 .75 .75 r
.02381 .58197 m
.14286 .58148 L
.2619 .56617 L
.38095 .56354 L
.5 .57444 L
.61905 .57702 L
.7381 .57081 L
.85714 .56469 L
.97619 .56378 L
s
.75 0 .75 r
.02381 .58197 m
.14286 .57809 L
.2619 .55676 L
.38095 .55849 L
.5 .56734 L
.61905 .57988 L
.7381 .58022 L
.85714 .60332 L
.97619 .57737 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0714286 0.583445 0.547619 0.726302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00611247 0.0611247 0.005 0.05 [
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0110024 0.009 0.0721271 0.059 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.75 0 .75 r
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .034 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arm2) show
87.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(aa) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(P) show
111.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(T) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.067 0.0721271 0.117 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .75 .75 r
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .092 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arm1) show
87.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(aa) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(P) show
111.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(T) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.125 0.0721271 0.175 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .15 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(joint2) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.183 0.0721271 0.233 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .5 0 r
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .208 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(joint1) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.241 0.0721271 0.291 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .266 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spring) show
105.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .74402 L
0 .74402 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 214.25},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eR000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@008@3IfMT00`000000fMWI0=WIf@3l0=WIf@008@3IfMT00`000000fMWI
0=WIf@3l0=WIf@003`3IfMT2000000@0fMWI0P0000040=WIf@800000103IfMT00`000000fMWI0=WI
f@3l0=WIf@003P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI00000080fMWI
00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@3l0=WIf@00403IfMT01@000000fMWI
0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT01@000000fMWI0=WIf@3IfMT0
003o00800000o03IfMT000P0fMWI100000050=WIf@040000003IfMT0fMWI00000080fMWI00@00000
0=WIf@3IfMT000000P3IfMT01@000000fMWI0=WIf@3IfMT0003o0?h0fMWI000>0=WIf@040000003I
fMT0fMWI00000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000030=WI
f@030000o`3IfMT0fMWI0?`0fMWI000?0=WIf@800000103IfMT2000000@0fMWI0P0000040=WIf@03
000000000?l0fMWI0?`0fMWI000Q0=WIf@03000000000?l0fMWI0?`0fMWI000Q0=WIf@0300000000
0?l0fMWI0?`0fMWI000Q0=WIf@03000000000?l0fMWI0?`0fMWI000Q0=WIf@030000003IfMT0003o
0?`0fMWI000Q0=WIf@030000003IfMT0003o0?`0fMWI000Q0=WIf@80000000<0003o0=WIf@3IfMT0
nP3IfMT00240fMWI00<000000=WIf@000?l0o03IfMT00240fMWI00<000000=WIf@000?l0o03IfMT0
0240fMWI00@000000=WIf@3IfMT0003on`3IfMT00240fMWI0P0000000`3IfMT0003o0=WIf@3j0=WI
f@008@3IfMT010000000fMWI0=WIf@000?ok0=WIf@008@3IfMT010000000fMWI0=WIf@000?ok0=WI
f@008@3IfMT01@000000fMWI0=WIf@3IfMT0003o0?X0fMWI000Q0=WIf@050000003IfMT0fMWI0=WI
f@000?l0nP3IfMT00240fMWI0P0000020=WIf@030000o`3IfMT0fMWI0?P0fMWI000Q0=WIf@050000
003IfMT0fMWI0=WIf@000?l0nP3IfMT000h0fMWI100000030=WIf@800000103IfMT2000000@0fMWI
00D000000=WIf@3IfMT0fMWI0000o`3j0=WIf@003P3IfMT00`000000fMWI0=WIf@030=WIf@040000
003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@020=WI
f@030000o`3IfMT0fMWI0?L0fMWI000?0=WIf@030000003IfMT0fMWI00D0fMWI00@000000=WIf@3I
fMT000000P3IfMT010000000fMWI0=WIf@3IfMT300000080fMWI00<0003o0=WIf@3IfMT0m`3IfMT0
00P0fMWI100000040=WIf@030000003IfMT0fMWI0080fMWI0P0000030=WIf@040000003IfMT0fMWI
000000<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000?l0fMWI0=WIf@3g0=WIf@003P3IfMT01000
0000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000000`3I
fMT00`000000fMWI0=WIf@020=WIf@030000o`3IfMT0fMWI0?L0fMWI000?0=WIf@800000103IfMT3
000000<0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI00<0003o0=WIf@3IfMT0mP3IfMT0
0240fMWI00<000000=WIf@3IfMT00`3IfMT00`000?l0fMWI0=WIf@3f0=WIf@008@3IfMT2000000@0
fMWI00<0003o0=WIf@3IfMT0mP3IfMT00240fMWI00<000000=WIf@3IfMT00`3IfMT00`000?l0fMWI
0=WIf@3f0=WIf@008@3IfMT00`000000fMWI0=WIf@030=WIf@030000o`3IfMT0fMWI0?H0fMWI000Q
0=WIf@030000003IfMT0fMWI00@0fMWI00<0003o0=WIf@3IfMT0m@3IfMT00240fMWI0P0000050=WI
f@030000o`3IfMT0fMWI0?D0fMWI000Q0=WIf@030000003IfMT0fMWI00@0fMWI00<0003o0=WIf@3I
fMT0m@3IfMT00240fMWI00<000000=WIf@3IfMT0103IfMT00`000?l0fMWI0=WIf@3e0=WIf@008@3I
fMT00`000000fMWI0=WIf@050=WIf@030000o`3IfMT0fMWI0?@0fMWI000Q0=WIf@030000003IfMT0
fMWI00D0fMWI00<0003o0=WIf@3IfMT0m03IfMT00240fMWI0P0000060=WIf@030000o`3IfMT0fMWI
0?@0fMWI000Q0=WIf@030000003IfMT0fMWI00D0fMWI00<0003o0=WIf@3IfMT0m03IfMT00240fMWI
00<000000=WIf@3IfMT01@3IfMT00`000?l0fMWI0=WIf@3d0=WIf@008@3IfMT00`000000fMWI0=WI
f@060=WIf@030000o`3IfMT0fMWI0?<0fMWI000Q0=WIf@8000001`3IfMT00`000?l0fMWI0=WIf@3c
0=WIf@008@3IfMT00`000000fMWI0=WIf@060=WIf@030000o`3IfMT0fMWI0?<0fMWI000>0=WIf@@0
00000`3IfMT2000000@0fMWI0P0000040=WIf@030000003IfMT0fMWI00H0fMWI00<0003o0=WIf@3I
fMT0l`3IfMT000h0fMWI00<000000=WIf@3IfMT00`3IfMT010000000fMWI0=WIf@0000020=WIf@04
0000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT01`3IfMT00`000?l0fMWI0=WIf@3b0=WI
f@003`3IfMT00`000000fMWI0=WIf@020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WI
f@3IfMT000000`3IfMT3000000L0fMWI00<0003o0=WIf@3IfMT0lP3IfMT000P0fMWI100000040=WI
f@050000003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@050000003I
fMT0fMWI0=WIf@0000002@3IfMT00`000?l0fMWI0=WIf@3b0=WIf@003P3IfMT010000000fMWI0=WI
f@0000020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000000`3IfMT00`00
0000fMWI0=WIf@070=WIf@030000o`3IfMT0fMWI0?80fMWI000?0=WIf@800000103IfMT2000000@0
fMWI0P0000040=WIf@030000003IfMT0fMWI00L0fMWI00<0003o0=WIf@3IfMT0lP3IfMT00240fMWI
00<000000=WIf@3IfMT0203IfMT00`000?l0fMWI0=WIf@3a0=WIf@008@3IfMT2000000T0fMWI00<0
003o0=WIf@3IfMT0l@3IfMT00240fMWI00<000000=WIf@3IfMT0203IfMT00`000?l0fMWI0=WIf@3a
0=WIf@008@3IfMT00`000000fMWI0=WIf@080=WIf@030000o`3IfMT0fMWI0?40fMWI000Q0=WIf@03
0000003IfMT0fMWI00T0fMWI00<0003o0=WIf@3IfMT0l03IfMT00240fMWI0P00000:0=WIf@030000
o`3IfMT0fMWI0?00fMWI000Q0=WIf@030000003IfMT0fMWI00T0fMWI00<0003o0=WIf@3IfMT0l03I
fMT00240fMWI00<000000=WIf@3IfMT02@3IfMT00`000?l0fMWI0=WIf@3`0=WIf@008@3IfMT00`00
0000fMWI0=WIf@090=WIf@030000o`3IfMT0fMWI0?00fMWI000Q0=WIf@030000003IfMT0fMWI00X0
fMWI00<0003o0=WIf@3IfMT0k`3IfMT00240fMWI0P00000;0=WIf@030000o`3IfMT0fMWI0>l0fMWI
000Q0=WIf@030000003IfMT0fMWI00X0fMWI00<0003o0=WIf@3IfMT0k`3IfMT00240fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000?l0fMWI0=WIf@3_0=WIf@008@3IfMT00`000000fMWI0=WIf@0;0=WI
f@030000o`3IfMT0fMWI0>h0fMWI000Q0=WIf@800000303IfMT00`000?l0fMWI0=WIf@3^0=WIf@00
8@3IfMT00`000000fMWI0=WIf@0;0=WIf@030000o`3IfMT0fMWI0>h0fMWI000Q0=WIf@030000003I
fMT0fMWI00/0fMWI00<0003o0=WIf@3IfMT0kP3IfMT000h0fMWI1@0000020=WIf@800000103IfMT2
000000@0fMWI00<000000=WIf@3IfMT02`3IfMT00`000?l0fMWI0=WIf@3^0=WIf@00403IfMT01@00
0000fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT01@000000fMWI0=WI
f@3IfMT0000000h0fMWI00<0003o0=WIf@3IfMT0k@3IfMT00100fMWI00<000000=WIf@3IfMT0103I
fMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI0=WIf@<00000303IfMT00`000?l0
fMWI0=WIf@3]0=WIf@00203IfMT4000000@0fMWI00<000000=WIf@3IfMT00P3IfMT2000000<0fMWI
00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0<0=WIf@030000o`3IfMT0fMWI0>d0
fMWI000@0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI
0=WIf@0000030=WIf@030000003IfMT0fMWI00`0fMWI00<0003o0=WIf@3IfMT0k@3IfMT000l0fMWI
0P0000040=WIf@<000000`3IfMT2000000@0fMWI00<000000=WIf@3IfMT0303IfMT00`000?l0fMWI
0=WIf@3]0=WIf@008@3IfMT2000000h0fMWI00<0003o0=WIf@3IfMT0k03IfMT00240fMWI00<00000
0=WIf@3IfMT03@3IfMT00`000?l0fMWI0=WIf@3/0=WIf@008@3IfMT00`000000fMWI0=WIf@0=0=WI
f@030000o`3IfMT0fMWI0>`0fMWI000Q0=WIf@030000003IfMT0fMWI00d0fMWI00<0003o0=WIf@3I
fMT0k03IfMT00240fMWI00<000000=WIf@3IfMT03P3IfMT00`000?l0fMWI0=WIf@3[0=WIf@008@3I
fMT2000000l0fMWI00<0003o0=WIf@3IfMT0j`3IfMT00240fMWI00<000000=WIf@3IfMT03P3IfMT0
0`000?l0fMWI0=WIf@3[0=WIf@008@3IfMT00`000000fMWI0=WIf@0>0=WIf@030000o`3IfMT0fMWI
0>/0fMWI000Q0=WIf@030000003IfMT0fMWI00h0fMWI00<0003o0=WIf@3IfMT0j`3IfMT00240fMWI
0P00000@0=WIf@030000o`3IfMT0fMWI0>X0fMWI000Q0=WIf@030000003IfMT0fMWI00l0fMWI00<0
003o0=WIf@3IfMT0jP3IfMT00240fMWI00<000000=WIf@3IfMT03`3IfMT00`000?l0fMWI0=WIf@3Z
0=WIf@008@3IfMT00`000000fMWI0=WIf@0?0=WIf@030000o`3IfMT0fMWI0>X0fMWI000Q0=WIf@03
0000003IfMT0fMWI0100fMWI00<0003o0=WIf@3IfMT0j@3IfMT00240fMWI0P00000A0=WIf@030000
o`3IfMT0fMWI0>T0fMWI000Q0=WIf@030000003IfMT0fMWI0100fMWI00<0003o0=WIf@3IfMT0j@3I
fMT000h0fMWI1@0000020=WIf@800000103IfMT2000000@0fMWI00<000000=WIf@3IfMT0403IfMT0
0`000?l0fMWI0=WIf@3Y0=WIf@00403IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00@00000
0=WIf@3IfMT000000P3IfMT01@000000fMWI0=WIf@3IfMT000000180fMWI00<0003o0=WIf@3IfMT0
j@3IfMT00100fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI00000080
fMWI00@000000=WIf@3IfMT0fMWI0`00000A0=WIf@030000o`3IfMT0fMWI0>P0fMWI00080=WIf@@0
0000103IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT0
1@000000fMWI0=WIf@3IfMT0000001<0fMWI00<0003o0=WIf@3IfMT0j03IfMT00100fMWI00D00000
0=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI00D000000=WIf@3IfMT0
fMWI0000000C0=WIf@030000o`3IfMT0fMWI0>P0fMWI000?0=WIf@800000103IfMT2000000@0fMWI
0P0000040=WIf@030000003IfMT0fMWI0140fMWI00<0003o0=WIf@3IfMT0j03IfMT00240fMWI0P00
000C0=WIf@030000o`3IfMT0fMWI0>L0fMWI000Q0=WIf@030000003IfMT0fMWI0180fMWI00<0003o
0=WIf@3IfMT0i`3IfMT00240fMWI00<000000=WIf@3IfMT04P3IfMT00`000?l0fMWI0=WIf@3W0=WI
f@008@3IfMT00`000000fMWI0=WIf@0B0=WIf@030000o`3IfMT0fMWI0>L0fMWI000Q0=WIf@030000
003IfMT0fMWI0180fMWI00<0003o0=WIf@3IfMT0i`3IfMT00240fMWI0P00000D0=WIf@030000o`3I
fMT0fMWI0>H0fMWI000Q0=WIf@030000003IfMT0fMWI01<0fMWI00<0003o0=WIf@3IfMT0iP3IfMT0
0240fMWI00<000000=WIf@3IfMT04`3IfMT00`000?l0fMWI0=WIf@3V0=WIf@008@3IfMT00`000000
fMWI0=WIf@0C0=WIf@030000o`3IfMT0fMWI0>H0fMWI000Q0=WIf@8000005@3IfMT00`000?l0fMWI
0=WIf@3U0=WIf@008@3IfMT00`000000fMWI0=WIf@0D0=WIf@030000o`3IfMT0fMWI0>D0fMWI000Q
0=WIf@030000003IfMT0fMWI01@0fMWI00<0003o0=WIf@3IfMT0i@3IfMT00240fMWI00<000000=WI
f@3IfMT0503IfMT00`000?l0fMWI0=WIf@3U0=WIf@008@3IfMT00`000000fMWI0=WIf@0D0=WIf@03
0000o`3IfMT0fMWI0>D0fMWI000Q0=WIf@8000005P3IfMT00`000?l0fMWI0=WIf@3T0=WIf@008@3I
fMT00`000000fMWI0=WIf@0E0=WIf@030000o`3IfMT0fMWI0>@0fMWI000E0=WIf@800000103IfMT2
000000@0fMWI00<000000=WIf@3IfMT05@3IfMT00`000?l0fMWI0=WIf@3T0=WIf@00503IfMT01000
0000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT05@3I
fMT00`000?l0fMWI0=WIf@3T0=WIf@005`3IfMT010000000fMWI0=WIf@0000020=WIf@040000003I
fMT0fMWI0=WIf@<000005P3IfMT00`000?l0fMWI0=WIf@3S0=WIf@003P3IfMT4000000<0fMWI0P00
00030=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT05P3IfMT00`000?l0fMWI
0=WIf@3S0=WIf@005@3IfMT00`000000fMWI0=WIf@020=WIf@040000003IfMT0fMWI000000<0fMWI
00<000000=WIf@3IfMT05P3IfMT00`000?l0fMWI0=WIf@3S0=WIf@005@3IfMT3000000<0fMWI0P00
00040=WIf@030000003IfMT0fMWI01H0fMWI00<0003o0=WIf@3IfMT0h`3IfMT00240fMWI00<00000
0=WIf@3IfMT05P3IfMT00`000?l0fMWI0=WIf@3S0=WIf@008@3IfMT2000001P0fMWI00<0003o0=WI
f@3IfMT0hP3IfMT00240fMWI00<000000=WIf@3IfMT05`3IfMT00`000?l0fMWI0=WIf@3R0=WIf@00
8@3IfMT00`000000fMWI0=WIf@0G0=WIf@030000o`3IfMT0fMWI0>80fMWI000Q0=WIf@030000003I
fMT0fMWI01L0fMWI00<0003o0=WIf@3IfMT0hP3IfMT00240fMWI0P00000I0=WIf@030000o`3IfMT0
fMWI0>40fMWI000Q0=WIf@030000003IfMT0fMWI01P0fMWI00<0003o0=WIf@3IfMT0h@3IfMT00240
fMWI00<000000=WIf@3IfMT0603IfMT00`000?l0fMWI0=WIf@3Q0=WIf@008@3IfMT00`000000fMWI
0=WIf@0H0=WIf@040000o`3IfMT00000000000@0fMWI0P0000040=WIf@8000006P3IfMT5000001P0
fMWI1@0000020=WIf@800000103IfMT2000001X0fMWI1000000I0=WIf@@000000`3IfMT2000000@0
fMWI0P00000K0=WIf@800000:`3IfMT00240fMWI00<000000=WIf@3IfMT0603IfMT01@000?l00000
0=WIf@3IfMT0000000P0fMWI00@000000=WIf@3IfMT000006`3IfMT00`000000fMWI0=WIf@0J0=WI
f@030000003IfMT0fMWI00L0fMWI00@000000=WIf@3IfMT000006@3IfMT00`000000fMWI0=WIf@0J
0=WIf@030000003IfMT0fMWI00T0fMWI00@000000=WIf@3IfMT000006@3IfMT010000000fMWI0=WI
f@00000Z0=WIf@008@3IfMT2000001X0fMWI00@0003o0=WIf@3IfMT000002`3IfMT00`000000fMWI
0=WIf@0I0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI
0=WIf@0H0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI
0=WIf@0I0=WIf@030000003IfMT0fMWI02T0fMWI000Q0=WIf@030000003IfMT0fMWI01T0fMWI00@0
003o0=WIf@3IfMT000002@3IfMT2000001`0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI
0=WIf@080=WIf@800000703IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI00P0fMWI
0P00000M0=WIf@030000003IfMT0fMWI02P0fMWI000Q0=WIf@030000003IfMT0fMWI01T0fMWI00@0
003o0=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI01X0fMWI
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0I0=WIf@040000003IfMT0fMWI000001T0
fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@0I0=WIf@040000003IfMT0fMWI
000002X0fMWI000Q0=WIf@030000003IfMT0fMWI01T0fMWI00<0003o0000000000002P3IfMT30000
00/0fMWI9@2o0;l70=WIf@8000002P3IfMT3000001X0fMWI0P00000K0=WIf@8000002P3IfMT30000
01X0fMWI0P00000[0=WIf@008@3IfMT2000001/0fMWI00<0003o0=WIf@3IfMT04@3IfMT60;l0_a00
fMWI4`00_kl20=WIf@h0_`2oE03IfMTT002o_ad0fMWI000Q0=WIf@030000003IfMT0fMWI01X0fMWI
00<0003o0=WIf@3IfMT02`3IfMT60;l0_`@0fMWI4P00_kl<0=WIf@D0003o0P3IfMT9002o_`L0fMWI
302o0;lj0=WIf@h00;no1@000?l40=WIf@<0003o=@3IfMT00240fMWI00<000000=WIf@3IfMT06P3I
fMT40000o`D0fMWI1@2o0;l:002o_aP0fMWI1P000?l50=WIf@@0003o1`3IfMT:002o_`T0fMWI2@2o
0;lL0=WIfAD00;no2P3IfMT40000o``0fMWI0P000?lc0=WIf@008@3IfMT00`000000fMWI0=WIf@0M
0=WIf@H0_`2o1@00_klL0=WIf@H0003o3`3IfMT50000o`80fMWI2P00O`0B002o_`X0_`2o4P00_klL
001o00<0003o4P3IfMT30000oa00fMWI0`2o0;l>0=WIf@8000003@3IfMT00240fMWI00<000000=WI
f@3IfMT0303IfMTA0;l0_`800;no2@3o000L001o01`0o`000`000?lI0=WIf@X0o`008`2o0;lW0?l0
00P007l0102o0;l3001o00d0fMWI00@000000=WIf@3IfMT00000303IfMT001`0fMWI1@00000?0;l0
_a`007l0703o000L000001`0o`00;@0000040;l0_b80000000<0003o0?l0003o00000P3o00040;l0
_`L0o`001P0000070=WIf@030000003IfMT0fMWI00d0fMWI000Q0=WIf@030000003IfMT0fMWI0240
fMWI00<000000=WIf@3IfMT03`3IfMT60000o`/0fMWI00<000000=WIf@3IfMT0803IfMT50000oa00
fMWI;@000?l40=WIf@D0_`2o7P3IfMT40;l0_`030000o`3IfMT0fMWI01@0fMWI1@00000<0=WIf@00
8@3IfMT00`000000fMWI0=WIf@1/0=WIfA00003o=P3IfMT50;l0_aD0fMWI102o0;l50=WIf@80003o
5@3IfMT00`000000fMWI0=WIf@0=0=WIf@008@3IfMT00`000000fMWI0=WIf@2g0=WIf@@0_`2o3@3I
fMT40;l0_`/0fMWI0`000?lR0=WIf@008@3IfMT200000;`0fMWI1@2o0;l40=WIf@@0_`2o4P3IfMT3
0000oal0fMWI000Q0=WIf@030000003IfMT0fMWI0<00fMWI102o0;lI0=WIf@80003o7@3IfMT00240
fMWI00<000000=WIf@3IfMT0o03IfMT00240fMWI00<000000=WIf@3IfMT0o03IfMT00240fMWI00<0
00000=WIf@3IfMT0o03IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00?l0fMWI8@3IfMT004d0fMWI100000060=WIf@@000001@3IfMT2000000P0fMWI0P00002d
0=WIf@00C@3IfMT00`000000fMWI000000080=WIf@030000003IfMT0000000D0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@2b0=WIf@008P3IfMT5000000030=WIf@00000000000080
000000P0fMWI000000000000fMWI0000003IfMT000000=WIf@@000000`3IfMT2000000<0fMWI1@00
00000`3IfMT000000000000300000080fMWI00<000000=WIf@0000000P3IfMT5000000040=WIf@00
0000fMWI000000D0fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI00<000000=WIf@3IfMT0
/P3IfMT001H0fMWI202o0;l40=WIf@@000000`3IfMT00`000000fMWI0=WIf@020=WIf@070000003I
fMT000000=WIf@000000fMWI0000000;0=WIf@@000000P3IfMT4000000<0fMWI00<000000=WIf@00
0000103IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT01@000000fMWI0=WIf@3I
fMT000000080fMWI00D000000=WIf@3IfMT0fMWI0000002d0=WIf@009@3IfMT01@000000fMWI0=WI
f@3IfMT0000000@0fMWI00D000000=WIf@000000fMWI000000020=WIf@030000003IfMT0fMWI00/0
fMWI00<000000=WIf@3IfMT00`3IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@000000103IfMT0
1`000000fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT01@000000fMWI0=WIf@3IfMT0000000H0
fMWI00<000000=WIf@3IfMT0/P3IfMT002<0fMWI0`0000020=WIf@@0000000H0fMWI000000000000
00000=WIf@0000040=WIf@030000003IfMT0fMWI00P0fMWI0`0000030=WIf@<000000`3IfMT00`00
0000fMWI000000040=WIf@070000003IfMT0fMWI0=WIf@000000fMWI000000050=WIf@030000003I
fMT0fMWI00D000000`3IfMT00`000000fMWI0=WIf@2b0=WIf@00=03IfMT010000000fMWI0=WIf@00
000E0=WIf@030000003IfMT0000000@0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000D0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0;80fMWI000e0=WIf@80
00005P3IfMT400000080fMWI0P0000020=WIf@@000001@3IfMT2000000P0fMWI0P00002d0=WIf@00
C@3IfMT4000000H0fMWI100000050=WIf@800000203IfMT200000;@0fMWI001=0=WIf@030000003I
fMT0000000P0fMWI00<000000=WIf@0000001@3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI0;80fMWI000R0=WIf@D0000000<0fMWI0000000000000P000000203IfMT000000000003I
fMT000000=WIf@000000fMWI1@0000020=WIf@8000000`3IfMT5000000030=WIf@000000000000<0
00000P3IfMT00`000000fMWI000000020=WIf@D0000000@0fMWI0000003IfMT000001@3IfMT00`00
0000fMWI0=WIf@020=WIf@800000103IfMT00`000000fMWI0=WIf@2b0=WIf@005P3IfMT8002o_`@0
fMWI100000030=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@000000fMWI000000030=WI
f@030000003IfMT0fMWI00L0fMWI100000020=WIf@@000000`3IfMT00`000000fMWI000000040=WI
f@070000003IfMT0fMWI0=WIf@000000fMWI000000050=WIf@050000003IfMT0fMWI0=WIf@000000
0P3IfMT01@000000fMWI0=WIf@3IfMT000000;@0fMWI000U0=WIf@050000003IfMT0fMWI0=WIf@00
0000103IfMT01@000000fMWI0000003IfMT0000000<0fMWI00<000000=WIf@3IfMT02P3IfMT00`00
0000fMWI0=WIf@030=WIf@070000003IfMT0fMWI0=WIf@000000fMWI000000040=WIf@070000003I
fMT0fMWI0=WIf@000000fMWI000000050=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`00
0000fMWI0=WIf@2b0=WIf@008`3IfMT300000080fMWI100000001P3IfMT00000000000000000fMWI
000000@0fMWI00<000000=WIf@3IfMT0203IfMT3000000<0fMWI0`0000030=WIf@030000003IfMT0
000000@0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000D0fMWI00<000000=WIf@3IfMT0
1@0000030=WIf@030000003IfMT0fMWI0;80fMWI000f0=WIf@030000003IfMT0fMWI01@0fMWI00<0
00000=WIf@000000103IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT002D0fMWI00<000000=WIf@3I
fMT0100000090=WIf@8000005P3IfMT400000080fMWI200000050=WIf@800000203IfMT200000;@0
fMWI000T0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT09`3IfMT01@000000fMWI
0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@2b0=WIf@00
8`3IfMT00`000000fMWI0=WIf@050=WIf@040000003IfMT0fMWI0=WIf@800000103IfMT300000003
0=WIf@00000000000080fMWI0P0000020=WIf@8000000`3IfMT4000000<0fMWI0P0000040=WIf@<0
0000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0P0000040=WIf@03
0000003IfMT0fMWI0;80fMWI000S0=WIf@030000003IfMT0fMWI00D0fMWI00@000000=WIf@3IfMT0
00000P3IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT01000
0000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000000/0fMWI00@000000=WIf@3IfMT00000
103IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT01@000000
fMWI0=WIf@3IfMT000000;@0fMWI000F0=WIf@P0o`001@3IfMT00`000000fMWI0=WIf@050=WIf@04
0000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT0
00000080fMWI00@000000=WIf@3IfMT000001P3IfMT00`000000fMWI0=WIf@080=WIf@040000003I
fMT0fMWI000000@0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0
fMWI00<000000=WIf@3IfMT0/P3IfMT002<0fMWI00<000000=WIf@3IfMT00P3IfMT4000000<0fMWI
0P0000040=WIf@8000000P3IfMT400000080fMWI1@0000040=WIf@030000003IfMT0fMWI00P0fMWI
100000030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01@0000030=WIf@030000
003IfMT0fMWI0;80fMWI000T0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT00`3I
fMT010000000fMWI0=WIf@00000?0=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0
fMWI000000060=WIf@030000003IfMT0fMWI0;80fMWI000U0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0>0=WIf@8000003`3IfMT00`000000fMWI
0=WIf@050=WIf@800000203IfMT200000;@0fMWI000U0=WIf@030000003IfMT0fMWI00@00000:03I
fMT3000000030=WIf@000000fMWI00H0fMWI0P0000080=WIf@800000]03IfMT002@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0W0=WIf@050000003IfMT0fMWI0=WIf@0000001P3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0;80fMWI000S0=WIf@030000003IfMT0
fMWI00D0fMWI00@000000=WIf@3IfMT0fMWI0P0000040=WIf@<0000000<0fMWI0000000000000P3I
fMT200000080fMWI0P0000030=WIf@D000000P3IfMT2000000@0fMWI0`0000040=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI00<000000=WIf@3IfMT0/P3I
fMT002<0fMWI00<000000=WIf@3IfMT01@3IfMT010000000fMWI0=WIf@0000020=WIf@030000003I
fMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI00000080
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@070=WIf@040000003IfMT0fMWI0000
00@0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00D00000
0=WIf@3IfMT0fMWI0000002d0=WIf@005P3IfMT8001o00D0fMWI00<000000=WIf@3IfMT01@3IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI
000000020=WIf@040000003IfMT0fMWI000000L0fMWI00<000000=WIf@3IfMT01`3IfMT010000000
fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@030000003IfMT0fMWI0;80fMWI000S0=WIf@030000003IfMT0fMWI0080fMWI100000030=WI
f@800000103IfMT200000080fMWI100000020=WIf@D00000103IfMT00`000000fMWI0=WIf@080=WI
f@@000000`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D000000`3IfMT00`00
0000fMWI0=WIf@2b0=WIf@00903IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI00D0
fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT00`000000fMWI0=WIf@2b0=WIf@009@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT03P3IfMT2000000l0fMWI00<000000=WIf@3I
fMT01@3IfMT2000000P0fMWI0P00002d0=WIf@009@3IfMT00`000000fMWI0=WIf@050=WIf@<00000
5P3IfMT3000000l0fMWI00<000000=WIf@3IfMT01@3IfMT2000000P0fMWI0P00002d0=WIf@00903I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT03@3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0/P3I
fMT002<0fMWI00<000000=WIf@3IfMT00P3IfMT3000000<0fMWI0`0000030=WIf@@000000`3IfMT3
000000030=WIf@00000000000080fMWI0P0000020=WIf@<000000`3IfMT2000000@0fMWI0`000004
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI00<00000
0=WIf@3IfMT0/P3IfMT002<0fMWI00<000000=WIf@3IfMT01@3IfMT010000000fMWI0=WIf@000002
0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI
00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00D000000=WI
f@3IfMT0fMWI0000002d0=WIf@005P3IfMT80000o`D0fMWI00<000000=WIf@3IfMT00P3IfMT30000
00<0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0
fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@00
00001P3IfMT00`000000fMWI0=WIf@2b0=WIf@008`3IfMT00`000000fMWI0=WIf@020=WIf@@00000
00<0fMWI0000000000000P0000030=WIf@@000000`3IfMT200000080fMWI100000040=WIf@@00000
2@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
1@0000030=WIf@030000003IfMT0fMWI0;80fMWI000T0=WIf@030000003IfMT0fMWI02/0fMWI1000
00030=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000
003IfMT0fMWI0;80fMWI000U0=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT06@3I
fMT00`000000fMWI0=WIf@050=WIf@800000203IfMT200000;@0fMWI003o0=WIfB40fMWI003o0=WI
fB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI0000\
\>"],
  ImageRangeCache->{{{138, 425}, {617.25, 404}} -> {-2.06252, 2.30482, \
0.00732689, 0.00732689}, {{145, 417.938}, {612.125, 443.438}} -> {-2.4511, \
560.208, 0.0142549, 2.24372}, {{158.625, 295.125}, {450, 409.063}} -> \
{-19.1203, 34.5996, 0.119891, 0.146566}, {{160.125, 168.438}, {448.75, \
441.938}} -> {-48.2298, 68.1383, 0.293581, 0.293581}, {{160.125, 168.438}, \
{440.813, 434}} -> {-48.2298, 65.808, 0.293581, 0.293581}, {{160.125, \
168.438}, {432.938, 426.063}} -> {-47.7914, 62.9097, 0.290912, 0.290912}, \
{{160.125, 168.438}, {425, 418.188}} -> {-48.2298, 61.1657, 0.293581, \
0.293581}, {{160.125, 168.438}, {417.063, 410.25}} -> {-48.2298, 58.8354, \
0.293581, 0.293581}}]
}, Open  ]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Q: How many initial conditions have to be set? 
A: No initial conditions, only parameters of the pendulum arms and joints.

Q: What happens if damping is added to the sprin?
A: The movements of the spring and pendulum arms are attenuated depending on \
the SpringDamper.d parameter.

(b) replace the spring with and ideal gear\
\>", "Text"],

Cell["\<\
class Exercise2withGear \"Modelica Exam Exercise 2 with ideal gear\"
   extends Exercise2;
  replaceable Modelica.Mechanics.Rotational.IdealGear spring(ratio=3);
 equation 
  connect(inertia.flange_b, spring.flange_a);
  connect(spring.flange_b, joint1.axis);
end Exercise2withSpring;
\
\>", "ModelicaInput"],

Cell["\<\
The next class doesn't work since Spring and IdealGear doesn't have a commune \
supertype (which i would say they should).\
\>", "Text"],

Cell["\<\
class Exercise2withGear2 \"Modelica Exam Exercise 2 with ideal gear\"
   = Exercise2withSpring(redeclare Modelica.Mechanics.Rotational.IdealGear \
spring(ratio=100));
\
\>", "ModelicaInput"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result3\  = \ Simulate[Exercise2withGear, {t, 0, 200}]\)], "Input"],

Cell[BoxData["\<\"<SimulationData: \\!\\(Exercise2withGear\\) : 2003-5-7 \
21:55:26 : \\!\\({0.`, 200.`}\\) : 502 data points : 911 \
variables>\\nVariables of range 100 and depth Infinity listed: \
\\!\\({\\*TagBox[\\(\\(\\(arm1 . aa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . aa\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . aa\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . ab\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . ab\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . ab\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . aa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
aa\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . aa\\)\\) \[LeftDoubleBracket] \\(\
\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . fa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . fa\\)\\) \[LeftDoubleBracket] \\(\
\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . fa\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(3, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(3, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(3, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . t\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . t\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . t\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . v\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . v\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . v\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . w\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . w\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . w\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . z\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . z\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . frame\[UnderBracket]a . z\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . body . \[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\
\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . \[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(1, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(1, 3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(2, 1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(2, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(2, 3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(3, 1\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(3, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
\[ImaginaryI]\\)\\) \[LeftDoubleBracket] \\(\\(3, 3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(arm1 . body . m\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . r0a\\)\\) \[LeftDoubleBracket] \
\\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . r0a\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . r0a\\)\\) \[LeftDoubleBracket] \
\\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . rCM\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . rCM\\)\\) \[LeftDoubleBracket] \
\\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . rCM\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . Sa\\)\\) \[LeftDoubleBracket] \\(\
\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . Sa\\)\\) \[LeftDoubleBracket] \\(\\(1, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
Sa\\)\\) \[LeftDoubleBracket] \\(\\(1, 3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . Sa\\)\\) \[LeftDoubleBracket] \\(\
\\(2, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . Sa\\)\\) \[LeftDoubleBracket] \\(\\(2, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
Sa\\)\\) \[LeftDoubleBracket] \\(\\(2, 3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . Sa\\)\\) \[LeftDoubleBracket] \\(\
\\(3, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . Sa\\)\\) \[LeftDoubleBracket] \\(\\(3, 2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . \
Sa\\)\\) \[LeftDoubleBracket] \\(\\(3, 3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . ta\\)\\) \[LeftDoubleBracket] \\(\
\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . ta\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . ta\\)\\) \[LeftDoubleBracket] \\(\
\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . va\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . va\\)\\) \[LeftDoubleBracket] \\(\
\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . va\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . wa\\)\\) \[LeftDoubleBracket] \\(\
\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . wa\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . wa\\)\\) \[LeftDoubleBracket] \\(\
\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . za\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . body . za\\)\\) \[LeftDoubleBracket] \\(\
\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . \
body . za\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), \
HoldForm], \\*TagBox[\\(\\(\\(arm1 . fa\\)\\) \[LeftDoubleBracket] \\(\\(1\\)\
\\) \[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . fa\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . fa\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . fb\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . fb\\)\\) \[LeftDoubleBracket] \\(\\(2\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(arm1 . fb\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . a\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . f\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . r0\\)\\) \
\[LeftDoubleBracket] \\(\\(3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(1, 3\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(arm1 . frame\[UnderBracket]a . S\\)\\) \
\[LeftDoubleBracket] \\(\\(2, 3\\)\\) \[RightDoubleBracket]\\), HoldForm]}\\)\
\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(PlotSimulation[{joint1 . q[t], \ joint2 . q[t], \ 
          arm1 . \(aa[\([1]\)]\)[t], \ arm2 . \(aa[\([1]\)]\)[t]}, \ {t, 0, 
          8}, \ SimulationResult \[Rule] {result1}];\)\), \
"\[IndentingNewLine]", 
    \(\(PlotSimulation[{joint1 . q[t], \ joint2 . q[t], \ 
          arm1 . \(aa[\([1]\)]\)[t], \ arm2 . \(aa[\([1]\)]\)[t]}, \ {t, 0, 
          8}, \ SimulationResult \[Rule] {result2}];\)\), \
"\[IndentingNewLine]", 
    \(\(PlotSimulation[{joint1 . q[t], \ joint2 . q[t], \ 
          arm1 . \(aa[\([1]\)]\)[t], \ arm2 . \(aa[\([1]\)]\)[t]}, \ {t, 0, 
          8}, \ SimulationResult \[Rule] {result3}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74402 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.312017 0.47619 [
[ 0 0 0 0 ]
[ 1 .74402 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0177147 0.97619 0.606318 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.370327 0.0133471 [
[.2619 .35783 -3 -9 ]
[.2619 .35783 3 0 ]
[.5 .35783 -3 -9 ]
[.5 .35783 3 0 ]
[.7381 .35783 -3 -9 ]
[.7381 .35783 3 0 ]
[.97619 .35783 -3 -9 ]
[.97619 .35783 3 0 ]
[1.025 .37033 0 -6.28125 ]
[1.025 .37033 10 6.28125 ]
[.01131 .10338 -18 -4.5 ]
[.01131 .10338 0 4.5 ]
[.01131 .23686 -18 -4.5 ]
[.01131 .23686 0 4.5 ]
[.01131 .5038 -12 -4.5 ]
[.01131 .5038 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .37033 m
.2619 .37658 L
s
[(2)] .2619 .35783 0 1 Mshowa
.5 .37033 m
.5 .37658 L
s
[(4)] .5 .35783 0 1 Mshowa
.7381 .37033 m
.7381 .37658 L
s
[(6)] .7381 .35783 0 1 Mshowa
.97619 .37033 m
.97619 .37658 L
s
[(8)] .97619 .35783 0 1 Mshowa
.125 Mabswid
.08333 .37033 m
.08333 .37408 L
s
.14286 .37033 m
.14286 .37408 L
s
.20238 .37033 m
.20238 .37408 L
s
.32143 .37033 m
.32143 .37408 L
s
.38095 .37033 m
.38095 .37408 L
s
.44048 .37033 m
.44048 .37408 L
s
.55952 .37033 m
.55952 .37408 L
s
.61905 .37033 m
.61905 .37408 L
s
.67857 .37033 m
.67857 .37408 L
s
.79762 .37033 m
.79762 .37408 L
s
.85714 .37033 m
.85714 .37408 L
s
.91667 .37033 m
.91667 .37408 L
s
.25 Mabswid
0 .37033 m
1 .37033 L
s
gsave
1.025 .37033 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10338 m
.03006 .10338 L
s
[(-20)] .01131 .10338 1 0 Mshowa
.02381 .23686 m
.03006 .23686 L
s
[(-10)] .01131 .23686 1 0 Mshowa
.02381 .5038 m
.03006 .5038 L
s
[(10)] .01131 .5038 1 0 Mshowa
.125 Mabswid
.02381 .13008 m
.02756 .13008 L
s
.02381 .15677 m
.02756 .15677 L
s
.02381 .18347 m
.02756 .18347 L
s
.02381 .21016 m
.02756 .21016 L
s
.02381 .26355 m
.02756 .26355 L
s
.02381 .29024 m
.02756 .29024 L
s
.02381 .31694 m
.02756 .31694 L
s
.02381 .34363 m
.02756 .34363 L
s
.02381 .39702 m
.02756 .39702 L
s
.02381 .42372 m
.02756 .42372 L
s
.02381 .45041 m
.02756 .45041 L
s
.02381 .4771 m
.02756 .4771 L
s
.02381 .07669 m
.02756 .07669 L
s
.02381 .05 m
.02756 .05 L
s
.02381 .0233 m
.02756 .0233 L
s
.02381 .53049 m
.02756 .53049 L
s
.02381 .55719 m
.02756 .55719 L
s
.02381 .58388 m
.02756 .58388 L
s
.02381 .61058 m
.02756 .61058 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 1 r
.001 w
.02381 .37033 m
.07143 .36525 L
.11905 .35759 L
.16667 .34498 L
.21429 .33511 L
.2619 .33413 L
.30952 .33846 L
.35714 .34528 L
.40476 .34645 L
.45238 .36235 L
.5 .37015 L
.54762 .36575 L
.59524 .35189 L
.64286 .34835 L
.69048 .3402 L
.7381 .33309 L
.78571 .3376 L
.83333 .34749 L
.88095 .35255 L
.92857 .36123 L
.97619 .36272 L
s
0 .5 0 r
.02381 .37033 m
.07143 .37502 L
.11905 .37018 L
.16667 .37035 L
.21429 .36948 L
.2619 .35919 L
.30952 .35236 L
.35714 .35829 L
.40476 .38325 L
.45238 .36521 L
.5 .35526 L
.54762 .36189 L
.59524 .38076 L
.64286 .36448 L
.69048 .36404 L
.7381 .37625 L
.78571 .3722 L
.83333 .36557 L
.88095 .37612 L
.92857 .36979 L
.97619 .36901 L
s
1 0 0 r
.02381 .37033 m
.07143 .32173 L
.11905 .26349 L
.16667 .2464 L
.21429 .30721 L
.2619 .31577 L
.30952 .28067 L
.35714 .24547 L
.40476 .2425 L
.45238 .29664 L
.5 .3686 L
.54762 .32632 L
.59524 .24173 L
.64286 .23977 L
.69048 .26906 L
.7381 .32526 L
.78571 .28706 L
.83333 .24068 L
.88095 .24312 L
.92857 .28787 L
.97619 .2997 L
s
0 .75 .75 r
.02381 .37033 m
.07143 .31335 L
.11905 .22254 L
.16667 .01472 L
.21429 .29662 L
.2619 .33041 L
.30952 .37653 L
.35714 .60332 L
.40476 .58777 L
.45238 .13869 L
.5 .44941 L
.54762 .29761 L
.59524 .39398 L
.64286 .32571 L
.69048 .18482 L
.7381 .31613 L
.78571 .20479 L
.83333 .30702 L
.88095 .28457 L
.92857 .25958 L
.97619 .28525 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0714286 0.583445 0.547619 0.726302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00611247 0.0611247 0.00619835 0.0619835 [
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0110024 0.011157 0.0721271 0.0731405 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .75 .75 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .04215 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arm2) show
87.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(aa) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(P) show
111.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(T) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.0830579 0.0721271 0.145041 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .11405 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arm1) show
87.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(aa) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(P) show
111.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(T) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.154959 0.0721271 0.216942 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .5 0 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .18595 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(joint2) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.22686 0.0721271 0.288843 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .25785 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(joint1) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .74402 L
0 .74402 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 214.25},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eR000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00703IfMT0
0`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0
fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI
000L0=WIf@030000003IfMT0fMWI01l0fMWI00<00;no0=WIf@3IfMT0g`3IfMT001`0fMWI00<00000
0=WIf@3IfMT07`3IfMT00`00_kl0fMWI0=WIf@3O0=WIf@00703IfMT00`000000fMWI0=WIf@0O0=WI
f@03002o_`3IfMT0fMWI0=l0fMWI000L0=WIf@030000003IfMT0fMWI01h0fMWI00<00;no0=WIf@00
_kl0h03IfMT001`0fMWI00<000000=WIf@3IfMT07P3IfMT00`00_kl0fMWI002o_`3P0=WIf@00703I
fMT00`000000fMWI0=WIf@0N0=WIf@03002o_`3IfMT00;no0>00fMWI000L0=WIf@030000003IfMT0
fMWI01h0fMWI00<00;no0=WIf@00_kl0h03IfMT001`0fMWI00<000000=WIf@3IfMT07@3IfMT01000
_kl0fMWI0=WIf@00_koP0=WIf@00703IfMT00`000000fMWI0=WIf@0M0=WIf@04002o_`3IfMT0fMWI
002o_n00fMWI000L0=WIf@030000003IfMT0fMWI01d0fMWI00D00;no0=WIf@3IfMT0fMWI002o_`3O
0=WIf@00703IfMT00`000000fMWI0=WIf@0M0=WIf@05002o_`3IfMT0fMWI0=WIf@00_kl0g`3IfMT0
01`0fMWI00<000000=WIf@3IfMT07@3IfMT01@00_kl0fMWI0=WIf@3IfMT00;no0=l0fMWI000L0=WI
f@030000003IfMT0fMWI01`0fMWI00<00;no0=WIf@3IfMT00P3IfMT00`00_kl0fMWI0=WIf@3M0=WI
f@00703IfMT00`000000fMWI0=WIf@0L0=WIf@03002o_`3IfMT0fMWI0080fMWI00<00;no0=WIf@3I
fMT0g@3IfMT001`0fMWI00<000000=WIf@3IfMT0703IfMT00`00_kl0fMWI0=WIf@020=WIf@03002o
_`3IfMT0fMWI0=d0fMWI000L0=WIf@030000003IfMT0fMWI01`0fMWI00<00;no0=WIf@3IfMT00`3I
fMT00`00_kl0fMWI0=WIf@3L0=WIf@00703IfMT00`000000fMWI0=WIf@0K0=WIf@03002o_`3IfMT0
fMWI00@0fMWI00<00;no0=WIf@3IfMT0g03IfMT001`0fMWI00<000000=WIf@3IfMT06`3IfMT00`00
_kl0fMWI0=WIf@040=WIf@03002o_`3IfMT0fMWI0=`0fMWI000L0=WIf@030000003IfMT0fMWI01/0
fMWI00<00;no0=WIf@3IfMT0103IfMT00`00_kl0fMWI0=WIf@3L0=WIf@003P3IfMT4000000<0fMWI
0P0000050=WIf@030000003IfMT0fMWI01/0fMWI00<00;no0=WIf@3IfMT0103IfMT00`00_kl0fMWI
0=WIf@3L0=WIf@003P3IfMT00`000000fMWI0=WIf@030=WIf@040000003IfMT0fMWI000000@0fMWI
00<000000=WIf@3IfMT06`3IfMT00`00_kl0fMWI0=WIf@050=WIf@03002o_`3IfMT0fMWI0=/0fMWI
000?0=WIf@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT00000103IfMT2000001/0fMWI
00<00;no0=WIf@3IfMT01P3IfMT00`00_kl0fMWI0=WIf@3K0=WIf@00203IfMT4000000@0fMWI00D0
00000=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
6P3IfMT00`00_kl0fMWI0=WIf@060=WIf@03002o_`3IfMT0fMWI0=/0fMWI000>0=WIf@040000003I
fMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@0J0=WIf@03
002o_`3IfMT0fMWI00H0fMWI00<00;no0=WIf@3IfMT0f`3IfMT000l0fMWI0P0000040=WIf@800000
1@3IfMT00`000000fMWI0=WIf@0J0=WIf@03002o_`3IfMT0fMWI00H0fMWI00<00;no0=WIf@3IfMT0
f`3IfMT001`0fMWI00<000000=WIf@3IfMT06P3IfMT00`00_kl0fMWI0=WIf@060=WIf@03002o_`3I
fMT0fMWI0=/0fMWI000L0=WIf@030000003IfMT0fMWI01T0fMWI00<00;no0=WIf@3IfMT0203IfMT0
0`00_kl0fMWI0=WIf@3J0=WIf@00703IfMT00`000000fMWI0=WIf@0I0=WIf@03002o_`3IfMT0fMWI
00P0fMWI00<00;no0=WIf@3IfMT0fP3IfMT001`0fMWI00<000000=WIf@3IfMT06@3IfMT00`00_kl0
fMWI0=WIf@080=WIf@03002o_`3IfMT0fMWI0=X0fMWI000L0=WIf@030000003IfMT0fMWI01T0fMWI
00<00;no0=WIf@3IfMT0203IfMT00`00_kl0fMWI0=WIf@3J0=WIf@00703IfMT00`000000fMWI0=WI
f@0H0=WIf@03002o_`3IfMT0fMWI00T0fMWI00<00;no0=WIf@3IfMT0?@3IfMT00`00_kl0fMWI0=WI
f@2J0=WIf@00703IfMT00`000000fMWI0=WIf@0H0=WIf@03002o_`3IfMT0fMWI00T0fMWI00<00;no
0=WIf@3IfMT0?@3IfMT00`00_kl0fMWI0=WIf@2J0=WIf@00703IfMT00`000000fMWI0=WIf@0H0=WI
f@03002o_`3IfMT0fMWI00X0fMWI00<00;no0=WIf@3IfMT0?03IfMT00`00_kl0fMWI0=WIf@2J0=WI
f@00703IfMT00`000000fMWI0=WIf@0H0=WIf@03002o_`3IfMT0fMWI00X0fMWI00<00;no0=WIf@3I
fMT0?03IfMT00`00_kl0fMWI0=WIf@2J0=WIf@00703IfMT00`000000fMWI0=WIf@0H0=WIf@03002o
_`3IfMT0fMWI00X0fMWI00<00;no0=WIf@3IfMT0?03IfMT2002o_i/0fMWI000L0=WIf@030000003I
fMT0fMWI01L0fMWI00<00;no0=WIf@3IfMT02`3IfMT00`00_kl0fMWI0=WIf@0k0=WIf@03002o_`3I
fMT00;no09/0fMWI000L0=WIf@030000003IfMT0fMWI01L0fMWI00<00;no0=WIf@3IfMT02`3IfMT0
0`00_kl0fMWI0=WIf@0k0=WIf@03002o_`3IfMT00;no09/0fMWI000L0=WIf@030000003IfMT0fMWI
01L0fMWI00<00;no0=WIf@3IfMT0303IfMT00`00_kl0fMWI0=WIf@0j0=WIf@03002o_`3IfMT00;no
09/0fMWI000L0=WIf@030000003IfMT0fMWI01L0fMWI00<00;no0=WIf@3IfMT0303IfMT00`00_kl0
fMWI0=WIf@0j0=WIf@03002o_`3IfMT00;no09/0fMWI000L0=WIf@030000003IfMT0fMWI01H0fMWI
00<00;no0=WIf@3IfMT03@3IfMT00`00_kl0fMWI0=WIf@0j0=WIf@03002o_`3IfMT00;no09/0fMWI
000L0=WIf@030000003IfMT0fMWI01H0fMWI00<00;no0=WIf@3IfMT03@3IfMT00`00_kl0fMWI0=WI
f@0j0=WIf@04002o_`3IfMT0fMWI002o_iX0fMWI000L0=WIf@030000003IfMT0fMWI01H0fMWI00<0
0;no0=WIf@3IfMT03@3IfMT00`00_kl0fMWI0=WIf@0j0=WIf@04002o_`3IfMT0fMWI002o_cL0fMWI
00<00;no0=WIf@3IfMT0H03IfMT001`0fMWI00<000000=WIf@3IfMT05P3IfMT00`00_kl0fMWI0=WI
f@0=0=WIf@03002o_`3IfMT0fMWI03X0fMWI00@00;no0=WIf@3IfMT00;no=`3IfMT00`00_kl0fMWI
0=WIf@1P0=WIf@00703IfMT00`000000fMWI0=WIf@0F0=WIf@03002o_`3IfMT0fMWI00h0fMWI00<0
0;no0=WIf@3IfMT0>@3IfMT01000_kl0fMWI0=WIf@00_klf0=WIf@03002o_`3IfMT00;no0640fMWI
000L0=WIf@030000003IfMT0fMWI01D0fMWI00<00;no0=WIf@3IfMT03`3IfMT00`00_kl0fMWI0=WI
f@0i0=WIf@04002o_`3IfMT0fMWI002o_cH0fMWI00<00;no0=WIf@00_kl0H@3IfMT001`0fMWI00<0
00000=WIf@3IfMT05@3IfMT00`00_kl0fMWI0=WIf@0?0=WIf@03002o_`3IfMT0fMWI03P0fMWI00D0
0;no0=WIf@3IfMT0fMWI002o_`0f0=WIf@03002o_`3IfMT00;no0640fMWI000L0=WIf@030000003I
fMT0fMWI01D0fMWI00<00;no0=WIf@3IfMT03`3IfMT00`00_kl0fMWI0=WIf@0h0=WIf@03002o_`3I
fMT0fMWI0080fMWI00<00;no0=WIf@3IfMT0<P3IfMT01@00_kl0fMWI0=WIf@3IfMT00;no01@0fMWI
00<00;no0=WIf@3IfMT0B@3IfMT001`0fMWI00<000000=WIf@3IfMT05@3IfMT00`00_kl0fMWI0=WI
f@0?0=WIf@03002o_`3IfMT0fMWI03P0fMWI00<00;no0=WIf@3IfMT00P3IfMT00`00_kl0fMWI0=WI
f@0b0=WIf@05002o_`3IfMT0fMWI0=WIf@00_kl0503IfMT00`00_kl0fMWI0=WIf@190=WIf@00703I
fMT00`000000fMWI0=WIf@0D0=WIf@03002o_`3IfMT0fMWI0100fMWI00<00;no0=WIf@3IfMT0>03I
fMT00`00_kl0fMWI0=WIf@020=WIf@03002o_`3IfMT0fMWI0380fMWI00D00;no0=WIf@3IfMT0fMWI
002o_`0C0=WIf@03002o_`3IfMT00;no04X0fMWI000L0=WIf@030000003IfMT0fMWI01@0fMWI00<0
0;no0=WIf@3IfMT04@3IfMT00`00_kl0fMWI0=WIf@0g0=WIf@03002o_`3IfMT0fMWI0080fMWI00<0
0;no0=WIf@3IfMT0<@3IfMT00`00_kl0fMWI0=WIf@030=WIf@03002o_`3IfMT0fMWI0100fMWI00<0
0;no0=WIf@00_kl0BP3IfMT001`0fMWI00<000000=WIf@3IfMT0503IfMT00`00_kl0fMWI0=WIf@0A
0=WIf@03002o_`3IfMT0fMWI03L0fMWI00<00;no0=WIf@3IfMT00P3IfMT00`00_kl0fMWI0=WIf@0a
0=WIf@03002o_`3IfMT0fMWI00<0fMWI00<00;no0=WIf@3IfMT03`3IfMT01@00_kl0fMWI0=WIf@3I
fMT00;no04T0fMWI000>0=WIf@D000000P3IfMT2000000D0fMWI00<000000=WIf@3IfMT04`3IfMT0
0`00_kl0fMWI0=WIf@0B0=WIf@03002o_`3IfMT0fMWI03L0fMWI00<00;no0=WIf@3IfMT00P3IfMT0
0`00_kl0fMWI0=WIf@0`0=WIf@03002o_`3IfMT0fMWI00D0fMWI00<00;no0=WIf@3IfMT03P3IfMT0
1@00_kl0fMWI0=WIf@3IfMT00;no04T0fMWI000@0=WIf@050000003IfMT0fMWI0=WIf@0000000P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI01<0fMWI00<00;no0=WIf@3IfMT04P3I
fMT00`00_kl0fMWI0=WIf@0g0=WIf@03002o_`3IfMT0fMWI00<0fMWI00<00;no0=WIf@3IfMT0;`3I
fMT00`00_kl0fMWI0=WIf@050=WIf@03002o_`3IfMT0fMWI00d0fMWI00<00;no0=WIf@3IfMT00`3I
fMT00`00_kl0fMWI0=WIf@160=WIf@00403IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<0
00000=WIf@3IfMT00P3IfMT2000001<0fMWI00<00;no0=WIf@3IfMT04`3IfMT00`00_kl0fMWI0=WI
f@0g0=WIf@03002o_`3IfMT0fMWI00<0fMWI00<00;no0=WIf@3IfMT0;`3IfMT00`00_kl0fMWI0=WI
f@050=WIf@03002o_`3IfMT0fMWI00d0fMWI00<00;no0=WIf@3IfMT00`3IfMT00`00_kl0fMWI0=WI
f@160=WIf@00203IfMT4000000@0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT04P3IfMT00`00_kl0fMWI0=WIf@0D0=WIf@03002o_`3I
fMT0fMWI03H0fMWI00<00;no0=WIf@3IfMT00`3IfMT00`00_kl0fMWI0=WIf@0L0=WIf@`0o`001P3I
fMT00`00_kl0fMWI0=WIf@070=WIf@03002o_`3IfMT0fMWI00/0fMWI00<00;no0=WIf@3IfMT01@3I
fMT00`00_kl0fMWI0=WIf@040=WIf@H0o`00>`3IfMT00100fMWI00D000000=WIf@3IfMT0fMWI0000
00020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`00_kl0fMWI0=WI
f@0E0=WIf@03002o_`3IfMT0fMWI0240fMWI3@3o00070=WIf@03002o_`3IfMT0fMWI00@0fMWI00<0
0;no0=WIf@3IfMT06`3IfMT00`3o0000fMWI0=WIf@0:0=WIf@80o`00103IfMT00`00_kl0fMWI0=WI
f@070=WIf@03002o_`3IfMT0fMWI00/0fMWI00<00;no0=WIf@3IfMT01@3IfMT00`00_kl0fMWI0=WI
f@030=WIf@030?l0003IfMT0fMWI00@0fMWI1`3o000d0=WIf@003`3IfMT2000000@0fMWI0P000005
0=WIf@030000003IfMT0fMWI0140fMWI00<00;no0=WIf@3IfMT02P3IfMT20?l000T0fMWI00<00;no
0=WIf@3IfMT0803IfMT00`3o0000fMWI0=WIf@0;0=WIf@030?l0003IfMT0fMWI00@0fMWI00<00;no
0=WIf@3IfMT0103IfMT00`00_kl0fMWI0=WIf@0K0=WIf@030?l0003IfMT0fMWI00`0fMWI0P3o0002
0=WIf@03002o_`3IfMT0fMWI00L0fMWI00<00;no0=WIf@3IfMT02P3IfMT00`00_kl0fMWI0=WIf@07
0=WIf@05002o_`3IfMT0fMWI0=WIf@3o00003P3IfMT00`3o0000fMWI0=WIf@0a0=WIf@00703IfMT0
0`000000fMWI0=WIf@0@0=WIf@03002o_`3IfMT0fMWI00P0fMWI0`3o00020=WIf@030?l0003IfMT0
fMWI00H0fMWI00<00;no0=WIf@3IfMT07P3IfMT20?l000l0fMWI00<0o`000=WIf@3IfMT00`3IfMT0
0`00_kl0fMWI0=WIf@040=WIf@03002o_`3IfMT0fMWI01X0fMWI00<0o`000=WIf@3IfMT03`3IfMT0
0`3o00000;no0=WIf@0:0=WIf@03002o_`3IfMT0fMWI00T0fMWI00<00;no0=WIf@3IfMT01`3IfMT0
1000_kl0fMWI0=WIf@3o000@0=WIf@030?l0003IfMT0fMWI0300fMWI000L0=WIf@030000003IfMT0
fMWI0100fMWI00<00;no0=WIf@3IfMT01P3IfMT20?l000H0fMWI00<0o`000=WIf@3IfMT01@3IfMT0
0`00_kl0fMWI0=WIf@0M0=WIf@030?l0003IfMT0fMWI0100fMWI00<0o`000=WIf@3IfMT00P3IfMT0
0`00_kl0fMWI0=WIf@040=WIf@03002o_`3IfMT0fMWI01X0fMWI00<0o`000=WIf@3IfMT0403IfMT0
0`00_kl0o`000=WIf@090=WIf@03002o_`3IfMT0fMWI00P0fMWI00<00;no0=WIf@3IfMT02@3IfMT0
0`00_kl0o`000=WIf@0A0=WIf@030?l0003IfMT0fMWI02l0fMWI000L0=WIf@030000003IfMT0fMWI
00l0fMWI00<00;no0=WIf@3IfMT0103IfMT30?l000T0fMWI00<0o`000=WIf@3IfMT0103IfMT00`00
_kl0fMWI0=WIf@0L0=WIf@030?l0003IfMT0fMWI0140fMWI00<0o`000=WIf@3IfMT00P3IfMT00`00
_kl0fMWI0=WIf@050=WIf@03002o_`3IfMT0fMWI01P0fMWI00<0o`000=WIf@3IfMT04@3IfMT01000
_kl0fMWI0?l0003o00080=WIf@03002o_`3IfMT0fMWI00P0fMWI00<00;no0=WIf@3IfMT02@3IfMT0
0`00_kl0fMWI0=WIf@0B0=WIf@030?l0003IfMT0fMWI00@0fMWI00<00;no0=WIf@3IfMT09`3IfMT0
01`0fMWI00<000000=WIf@3IfMT03`3IfMT00`00_kl0fMWI0=WIf@020=WIf@80o`00303IfMT00`3o
0000fMWI0=WIf@050=WIf@03002o_`3IfMT0fMWI01X0fMWI00<0o`000=WIf@3IfMT04`3IfMT01@3o
0000fMWI0=WIf@3IfMT00;no00L0fMWI00<00;no0=WIf@3IfMT0603IfMT00`3o0000fMWI0=WIf@0@
0=WIf@03002o_`3IfMT0fMWI0080fMWI0P3o00070=WIf@03002o_`3IfMT0fMWI00L0fMWI00<00;no
0=WIf@3IfMT0203IfMT00`3o00000;no0=WIf@0D0=WIf@040?l0003IfMT0fMWI0=WIf@800;no00<0
fMWI002o_`00_kl09`3IfMT001`0fMWI00<000000=WIf@3IfMT03P3IfMT00`00_kl0fMWI0=WIf@02
0=WIf@030?l0003IfMT0fMWI00d0fMWI00<0o`000=WIf@3IfMT0103IfMT00`00_kl0fMWI0=WIf@0I
0=WIf@030?l0003IfMT0fMWI01D0fMWI00@0o`000=WIf@3IfMT00;no1`3IfMT00`00_kl0fMWI0=WI
f@0G0=WIf@030?l0003IfMT0fMWI0140fMWI00<00;no0=WIf@3IfMT0103IfMT00`3o0000fMWI0=WI
f@040=WIf@03002o_`3IfMT0fMWI00H0fMWI00<00;no0=WIf@3IfMT0203IfMT0103o0000fMWI0=WI
f@00_klE0=WIf@030?l00000_kl00;no00D0fMWI0P00_klU0=WIf@00703IfMT00`000000fMWI0=WI
f@0=0=WIf@03002o_`3IfMT0fMWI0080fMWI00<0o`000=WIf@3IfMT03`3IfMT00`3o0000fMWI0=WI
f@030=WIf@03002o_`3IfMT0fMWI01L0fMWI0P3o000I0=WIf@030?l0003IfMT00;no00L0fMWI00<0
0;no0=WIf@3IfMT05P3IfMT00`3o0000fMWI0=WIf@0B0=WIf@03002o_`3IfMT0fMWI00D0fMWI00<0
o`000=WIf@3IfMT00`3IfMT00`00_kl0fMWI0=WIf@060=WIf@03002o_`3IfMT0fMWI00L0fMWI00D0
o`000=WIf@3IfMT0fMWI002o_`0D0=WIf@800;no00<0o`000=WIf@3IfMT01P3IfMT2002o_b<0fMWI
000L0=WIf@030000003IfMT0fMWI00d0fMWI00D00;no0=WIf@3IfMT0fMWI0?l0000C0=WIf@030?l0
003IfMT0fMWI0080fMWI00<00;no0=WIf@3IfMT05P3IfMT00`3o0000fMWI0=WIf@0J0=WIf@030?l0
0000_kl0fMWI00H0fMWI00<00;no0=WIf@3IfMT05P3IfMT00`3o0000fMWI0=WIf@0A0=WIf@03002o
_`3IfMT0fMWI00L0fMWI00<0o`000=WIf@3IfMT00`3IfMT00`00_kl0fMWI0=WIf@040=WIf@03002o
_`3IfMT0fMWI00L0fMWI00<0o`000=WIf@3IfMT00`3IfMT00`00_kl0fMWI0=WIf@0?0=WIf@800;no
0`3IfMT00`3o0000fMWI0=WIf@070=WIf@800;no8@3IfMT001`0fMWI00<000000=WIf@3IfMT0303I
fMT00`00_kl0fMWI0=WIf@020=WIf@030?l0003IfMT0fMWI0180fMWI00D0o`000=WIf@3IfMT0fMWI
002o_`0G0=WIf@030?l0003IfMT0fMWI01`0fMWI00<00;no0=WIf@3IfMT01@3IfMT00`00_kl0fMWI
0=WIf@0E0=WIf@030?l0003IfMT0fMWI0180fMWI00<00;no0=WIf@3IfMT01`3IfMT00`3o0000fMWI
0=WIf@030=WIf@03002o_`3IfMT0fMWI00@0fMWI00<00;no0=WIf@3IfMT01P3IfMT00`3o0000fMWI
0=WIf@040=WIf@03002o_`3IfMT0fMWI00d0fMWI0P00_kl60=WIf@030?l0003IfMT0fMWI00P0fMWI
0P00_klO0=WIf@00703IfMT00`000000fMWI0=WIf@0<0=WIf@05002o_`3IfMT0fMWI0=WIf@3o0000
5P3IfMT0103o0000fMWI0=WIf@00_klE0=WIf@80o`007P3IfMT00`00_kl0o`000=WIf@070=WIf@03
002o_`3IfMT0fMWI01@0fMWI00<0o`000=WIf@3IfMT04P3IfMT00`00_kl0fMWI0=WIf@080=WIf@03
0?l0003IfMT0fMWI00<0fMWI00<00;no0=WIf@3IfMT00P3IfMT00`00_kl0fMWI0=WIf@060=WIf@03
0?l0003IfMT0fMWI00H0fMWI00<00;no0=WIf@3IfMT02P3IfMT2002o_`T0fMWI00<0o`000=WIf@3I
fMT02@3IfMT2002o_ad0fMWI000L0=WIf@030000003IfMT0fMWI00/0fMWI00D00;no0=WIf@3IfMT0
fMWI0?l0000H0=WIf@040?l0003IfMT0fMWI002o_a<0fMWI00<0o`000=WIf@3IfMT07P3IfMT00`00
_kl0fMWI0?l000070=WIf@03002o_`3IfMT0fMWI01<0fMWI00<0o`000=WIf@3IfMT04P3IfMT00`00
_kl0fMWI0=WIf@0:0=WIf@030?l0003IfMT0fMWI0080fMWI00<00;no0=WIf@3IfMT00P3IfMT00`00
_kl0fMWI0=WIf@050=WIf@030?l0003IfMT0fMWI00L0fMWI00<00;no0=WIf@3IfMT0203IfMT2002o
_``0fMWI0`3o000W0=WIf@00703IfMT00`000000fMWI0=WIf@0;0=WIf@04002o_`3IfMT0fMWI0?l0
01T0fMWI00@0o`000=WIf@3IfMT00;no4@3IfMT20?l00240fMWI00@00;no0=WIf@3IfMT0o`001P3I
fMT00`00_kl0fMWI0=WIf@0C0=WIf@030?l0003IfMT0fMWI0180fMWI00<00;no0=WIf@3IfMT02`3I
fMT01@3o0000fMWI0=WIf@3IfMT00;no00<0fMWI00<00;no0=WIf@3IfMT0103IfMT20?l000/0fMWI
00<00;no0=WIf@3IfMT0103IfMT3002o_a40fMWI1P3o000Q0=WIf@00703IfMT00`000000fMWI0=WI
f@0:0=WIf@04002o_`3IfMT0fMWI0?l001/0fMWI00<0o`000=WIf@00_kl0403IfMT00`3o0000fMWI
0=WIf@0Q0=WIf@05002o_`3IfMT0fMWI0=WIf@3o00001@3IfMT00`00_kl0fMWI0=WIf@0>0=WIf@05
002o_`3IfMT0fMWI0=WIf@3o0000503IfMT00`00_kl0fMWI0=WIf@0=0=WIf@050?l0003IfMT0fMWI
0=WIf@00_kl00P3IfMT00`00_kl0fMWI0=WIf@030=WIf@030?l0003IfMT0fMWI00/0fMWI00<00;no
0=WIf@3IfMT00P3IfMT2002o_aX0fMWI103o000M0=WIf@00703IfMT00`000000fMWI0=WIf@0:0=WI
f@03002o_`3IfMT0o`0001d0fMWI00@0o`000=WIf@00_kl00;no303IfMT20?l002@0fMWI00<00;no
0=WIf@3IfMT00P3IfMT00`3o0000fMWI0=WIf@020=WIf@03002o_`3IfMT0fMWI00h0fMWI0P00_kl0
0`3IfMT0o`000=WIf@0D0=WIf@03002o_`3IfMT0fMWI00d0fMWI00L0o`000=WIf@3IfMT0fMWI002o
_`3IfMT00;no00D0fMWI00<0o`000=WIf@3IfMT03@3IfMT01000_kl0fMWI002o_`00_klm0=WIf@00
703IfMT00`000000fMWI0=WIf@090=WIf@03002o_`3IfMT0o`0001l0fMWI0`3o00000`00_kl0fMWI
0=WIf@080=WIf@030?l0003IfMT0fMWI02@0fMWI00<00;no0=WIf@3IfMT00P3IfMT00`3o0000fMWI
0=WIf@020=WIf@03002o_`3IfMT0fMWI00d0fMWI00D00;no0=WIf@00_kl0fMWI0?l0000E0=WIf@03
002o_`3IfMT0fMWI00h0fMWI00H0o`000=WIf@3IfMT00;no0=WIf@00_kl40=WIf@030?l0003IfMT0
fMWI00h0fMWI0P00_klo0=WIf@00703IfMT00`000000fMWI0=WIf@090=WIf@03002o_`3IfMT0o`00
0280fMWI00<0o`00002o_`3o00000`3o00030=WIf@80o`009`3IfMT00`00_kl0fMWI0=WIf@030=WI
f@030?l0003IfMT0fMWI0080fMWI00<00;no0=WIf@3IfMT0303IfMT01000_kl0fMWI0=WIf@00_klE
0=WIf@03002o_`3IfMT0fMWI0100fMWI00@0o`000=WIf@3IfMT00;no103IfMT00`3o0000fMWI0=WI
f@1@0=WIf@00703IfMT00`000000fMWI0=WIf@080=WIf@03002o_`3IfMT0o`0002D0fMWI0P00_kl2
0=WIf@<0o`00:@3IfMT00`00_kl0fMWI0=WIf@040=WIf@050?l0003IfMT0fMWI0=WIf@00_kl03P3I
fMT01000_kl0fMWI0=WIf@00_klE0=WIf@03002o_`3IfMT0fMWI0140fMWI00<0o`000=WIf@00_kl0
0P3IfMT20?l005<0fMWI000L0=WIf@030000003IfMT0fMWI00L0fMWI00<00;no0=WIf@3o0000:03I
fMT00`00_kl0fMWI0=WIf@0[0=WIf@03002o_`3IfMT0fMWI00D0fMWI00@0o`000=WIf@3IfMT00;no
3P3IfMT01@00_kl0fMWI0?l0003IfMT00;no01@0fMWI00<00;no0=WIf@3IfMT04@3IfMT01@3o0000
fMWI0=WIf@3IfMT0o`0005D0fMWI000L0=WIf@030000003IfMT0fMWI00H0fMWI00<00;no0=WIf@3o
0000:P3IfMT00`00_kl0fMWI0=WIf@0Z0=WIf@03002o_`3IfMT0fMWI00D0fMWI00@0o`000=WIf@3I
fMT00;no3@3IfMT01P00_kl0fMWI0=WIf@3o0000fMWI002o_a<0fMWI00<00;no0=WIf@3IfMT04`3I
fMT00`3o0000fMWI0?l0001F0=WIf@00703IfMT00`000000fMWI0=WIf@060=WIf@03002o_`3o0000
fMWI02/0fMWI0P00_kl2000002L0fMWI00<00;no0=WIf@3IfMT01`3IfMT00`3o0000fMWI002o_`04
0=WIf@<000001P3IfMT00`00_kl0fMWI0?l000030=WIf@03002o_`3IfMT0fMWI0100fMWI00<00;no
0=WIf@3IfMT04P3IfMT2000000030?l0003IfMT0fMWI03H0fMWI0P00000M0=WIf@00703IfMT00`00
0000fMWI0=WIf@050=WIf@03002o_`3o0000fMWI02`0fMWI00<000000=WIf@00_kl0:03IfMT00`00
_kl0fMWI0=WIf@080=WIf@030?l00000_kl0fMWI00@0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
_kl0o`000=WIf@030=WIf@03002o_`3IfMT0fMWI00l0fMWI00<00;no0=WIf@3IfMT04`3IfMT01000
0000fMWI0=WIf@00000f0=WIf@040000003IfMT0fMWI000001`0fMWI000L0=WIf@030000003IfMT0
fMWI00@0fMWI00<00;no0?l0003IfMT08@3IfMT?0000o`03002o_`000?l0003o0080003o8`3IfMT0
0`00_kl0fMWI0=WIf@080=WIf@040?l0003IfMT00;no0=WIf@D000001@3IfMT00`00_kl0o`000=WI
f@050=WIf@03002o_`3IfMT0fMWI00h0fMWI00<00;no0=WIf@3IfMT0403IfMT;0000oc80fMWI00@0
00000=WIf@3IfMT00000703IfMT001`0fMWI00<000000=WIf@3IfMT00`3IfMT00`00_kl0o`000=WI
f@0L0=WIf@H0003o3P3IfMT00`000000fMWI002o_`030=WIf@`0003o5`3IfMT00`00_kl0fMWI0=WI
f@090=WIf@040?l00000_kl0fMWI00000080fMWI00<000000=WIf@3IfMT0103IfMT00`00_kl0fMWI
0=WIf@050=WIf@03002o_`3IfMT0fMWI00d0fMWI00<00;no0=WIf@3IfMT0203IfMT90000o`<0fMWI
0`0000050=WIf@T0003o:P3IfMT2000001d0fMWI000L0=WIf@030000003IfMT0fMWI00<0fMWI00<0
0;no0=WIf@3IfMT0603IfMT40000oa80fMWI00H000000=WIf@3IfMT000000=WIf@00_kl>0=WIf@/0
003o303IfMT00`00_kl0fMWI0=WIf@0:0=WIf@06002o_`3IfMT0fMWI0000003IfMT000001@3IfMT0
0`3o00000;no0=WIf@070=WIf@03002o_`3IfMT0fMWI00/0fMWI00<00;no0=WIf@3IfMT00`3IfMT6
0000o`d0fMWI00<000000=WIf@3IfMT03@3IfMT60000ob<0fMWI00@000000=WIf@3IfMT00000703I
fMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT00`00_kl0o`000=WIf@0E0=WIf@@0003o5`3IfMT2
000000<0fMWI00<00;no0=WIf@3IfMT05P3IfMT80000o`@0fMWI00<00;no0=WIf@3IfMT02P3IfMT0
1000_kl0fMWI0=WIf@3IfMT2000000<0fMWI0P3o00000`00_kl0fMWI0=WIf@070=WIf@03002o_`3I
fMT0fMWI00T0fMWI0P000?l00`00_kl0003o0000o`030000oa<0fMWI0`00000C0=WIf@P0003o703I
fMT2000001d0fMWI000L0=WIf@060000003IfMT0fMWI0=WIf@00_kl0o`004`3IfMT40000ob40fMWI
00@00;no0=WIf@3IfMT0fMWI1P00O`0F0=WIf@<0003o00<0fMWI002o_`3IfMT02`3IfMT00`00_kl0
o`000=WIf@050=WIf@040?l0003IfMT0fMWI002o_`X0fMWI00<00;no0=WIf@3IfMT020000?l00`3I
fMT00;no0=WIf@0f0=WIf@T0003o<P3IfMT001`0fMWI00D000000=WIf@3IfMT00;no0?l0000?0=WI
f@D0003o8`3IfMT3001o00800;no00<007l00=WIf@3IfMT0103IfMT6001o01<0fMWI00<0003o002o
_`3IfMT02`3IfMT00`00_kl007l00?l00004001o00050?l00000O`0007l00=WIf@00_kl02@3IfMT0
10000?l00;no0000o`000?l80=WIf@03002o_`3IfMT0fMWI03l0fMWI1P000?l/0=WIf@00703IfMT0
10000000fMWI002o_`3o000:0=WIf@H0003o8`3IfMT5001o00D0fMWI00<00;no0=WIf@3IfMT02P3I
fMT3001o0140fMWI00@00;no0000o`000?l0003o103IfMT5001o0004002o_`3IfMT0fMWI0?l00080
fMWI00H0o`000=WIf@3IfMT0fMWI001o0000_kl5001o00@0003o0P3IfMT00`00_kl0fMWI0=WIf@07
0=WIf@03002o_`3IfMT0fMWI04D0fMWI20000?lT0=WIf@00703IfMT00`000000fMWI002o_`060=WI
f@D0003o8`3IfMT6001o00/0fMWI00<00;no0=WIf@3IfMT0303IfMT2001o00l0fMWI00@00;no0=WI
f@3IfMT0fMWI1000O`030000o`<0fMWI00D00;no0=WIf@3o0000fMWI0?l000040=WIf@03002o_`00
0?l0003o00@0003o0P00O`040=WIf@03002o_`3IfMT0fMWI00H0fMWI00<00;no0=WIf@3IfMT00P3I
fMT?001o01h0fMWI1000O`0K0=WIf@L0003o3P3IfMT2000000d0fMWI000L0=WIf@0300000000_kl0
fMWI00H0003o2`3IfMT9001o00/0fMWI2@00O`0B0=WIf@03002o_`3IfMT0fMWI00d0fMWI0P00O`0<
0=WIf@03002o_`3IfMT0fMWI008007l01`3IfMT30000o`04002o_`000?l0003o0?l000D0003o00<0
0;no0=WIf@3IfMT01P3IfMT2001o00<0fMWI00<00;no0=WIf@3IfMT0103IfMT00`00_kl0fMWI0=WI
f@03001o00l0fMWI1000O`0D0=WIf@H007l0103IfMT4001o00l0fMWI3`00O`0=0=WIf@040000003I
fMT0fMWI000000`0fMWI000F0=WIf@H0000000<00;no001o0000O`000`00O`08000000H007l02@00
000;001o01`0000000<00;no0000000000003P000002001o00X0000000<00;no001o0000O`003000
00000`00_kl000000000000600000003002o_`000000000000P000000`00O`000`00_kl000000000
000300000004002o_`00000007l0001o01H000001000O`07000000T007l03P000004001o00D00000
1P00O`0D000000P0fMWI00<000000=WIf@3IfMT03@3IfMT001`0fMWI00<000000=WIf@3IfMT00`3I
fMT8001o02/0fMWI00<000000=WIf@3IfMT02@3IfMT00`00_kl0fMWI0=WIf@0?0=WIf@8007l01`3I
fMT00`00O`000;no0=WIf@0=0=WIf@04002o_`3IfMT0fMWI000000@0fMWI00<00;no0=WIf@3IfMT0
303IfMT00`00O`000;no0=WIf@020=WIf@03001o0000_kl007l001`0fMWI1`00O`0K0=WIf@D007l0
503IfMT00`000000fMWI0=WIf@0:0=WIf@D00000303IfMT001`0fMWI00<000000=WIf@3IfMT0@P3I
fMT00`00_kl0fMWI0=WIf@0A0=WIf@8007l00`3IfMT2001o00030=WIf@00_kl0fMWI00d0fMWI00<0
0;no0=WIf@3IfMT01@3IfMT00`00_kl0fMWI0=WIf@0=0=WIf@05002o_`00O`0007l0001o0000_kl0
I`3IfMT00`000000fMWI0=WIf@0=0=WIf@00703IfMT00`000000fMWI0=WIf@120=WIf@03002o_`3I
fMT0fMWI01<0fMWI0`00O`030=WIf@03002o_`3IfMT0fMWI00`0fMWI00<00;no0=WIf@3IfMT01@3I
fMT00`00_kl0fMWI0=WIf@0>0=WIf@03002o_`3IfMT00;no07P0fMWI000L0=WIf@030000003IfMT0
fMWI04<0fMWI00<00;no0=WIf@3IfMT0603IfMT00`00_kl0fMWI0=WIf@0=0=WIf@03002o_`3IfMT0
fMWI00<0fMWI00<00;no0=WIf@3IfMT03`3IfMT00`00_kl0fMWI002o_`1h0=WIf@00703IfMT00`00
0000fMWI0=WIf@130=WIf@03002o_`3IfMT0fMWI01P0fMWI00<00;no0=WIf@3IfMT03@3IfMT00`00
_kl0fMWI0=WIf@030=WIf@03002o_`3IfMT0fMWI0100fMWI00<00;no0=WIf@3IfMT0M`3IfMT001`0
fMWI00<000000=WIf@3IfMT0@`3IfMT00`00_kl0fMWI0=WIf@0H0=WIf@03002o_`3IfMT0fMWI00d0
fMWI00<00;no0=WIf@3IfMT00`3IfMT00`00_kl0fMWI0=WIf@2:0=WIf@00703IfMT00`000000fMWI
0=WIf@130=WIf@03002o_`3IfMT0fMWI01P0fMWI00<00;no0=WIf@3IfMT03@3IfMT00`00_kl0fMWI
0=WIf@030=WIf@03002o_`3IfMT0fMWI08X0fMWI000L0=WIf@030000003IfMT0fMWI04<0fMWI00<0
0;no0=WIf@3IfMT05`3IfMT00`00_kl0fMWI0=WIf@0>0=WIf@03002o_`3IfMT0fMWI0080fMWI00<0
0;no0=WIf@3IfMT0R`3IfMT001`0fMWI00<000000=WIf@3IfMT0A03IfMT00`00_kl0fMWI0=WIf@0F
0=WIf@03002o_`3IfMT0fMWI00h0fMWI00<00;no0=WIf@3IfMT00P3IfMT00`00_kl0fMWI0=WIf@2;
0=WIf@00703IfMT00`000000fMWI0=WIf@140=WIf@03002o_`3IfMT0fMWI01H0fMWI00<00;no0=WI
f@3IfMT03`3IfMT01@00_kl0fMWI0=WIf@3IfMT00;no08d0fMWI000L0=WIf@030000003IfMT0fMWI
04@0fMWI00<00;no0=WIf@3IfMT05P3IfMT00`00_kl0fMWI0=WIf@0?0=WIf@04002o_`3IfMT0fMWI
002o_hh0fMWI000L0=WIf@030000003IfMT0fMWI04@0fMWI00<00;no0=WIf@3IfMT05P3IfMT00`00
_kl0fMWI0=WIf@0?0=WIf@04002o_`3IfMT0fMWI002o_hh0fMWI000L0=WIf@030000003IfMT0fMWI
04@0fMWI00<00;no0=WIf@3IfMT05P3IfMT00`00_kl0fMWI0=WIf@0?0=WIf@04002o_`3IfMT0fMWI
002o_hh0fMWI000L0=WIf@030000003IfMT0fMWI04D0fMWI00<00;no0=WIf@3IfMT05@3IfMT00`00
_kl0fMWI0=WIf@0?0=WIf@03002o_`3IfMT00;no08l0fMWI000L0=WIf@030000003IfMT0fMWI04D0
fMWI00<00;no0=WIf@3IfMT05@3IfMT00`00_kl0fMWI0=WIf@0?0=WIf@03002o_`3IfMT00;no08l0
fMWI000L0=WIf@030000003IfMT0fMWI04D0fMWI00<00;no0=WIf@3IfMT05@3IfMT00`00_kl0fMWI
0=WIf@0@0=WIf@800;noS`3IfMT001`0fMWI00<000000=WIf@3IfMT0A@3IfMT00`00_kl0fMWI0=WI
f@0E0=WIf@03002o_`3IfMT0fMWI0100fMWI0P00_kn?0=WIf@00703IfMT00`000000fMWI0=WIf@15
0=WIf@03002o_`3IfMT0fMWI01@0fMWI00<00;no0=WIf@3IfMT04@3IfMT00`00_kl0fMWI0=WIf@2>
0=WIf@00703IfMT00`000000fMWI0=WIf@160=WIf@03002o_`3IfMT0fMWI01<0fMWI00<00;no0=WI
f@3IfMT04@3IfMT00`00_kl0fMWI0=WIf@2>0=WIf@00703IfMT00`000000fMWI0=WIf@160=WIf@03
002o_`3IfMT0fMWI01<0fMWI00<00;no0=WIf@3IfMT0XP3IfMT001`0fMWI00<000000=WIf@3IfMT0
AP3IfMT00`00_kl0fMWI0=WIf@0C0=WIf@03002o_`3IfMT0fMWI0:80fMWI000L0=WIf@030000003I
fMT0fMWI04H0fMWI00<00;no0=WIf@3IfMT04`3IfMT00`00_kl0fMWI0=WIf@2R0=WIf@00703IfMT0
0`000000fMWI0=WIf@160=WIf@03002o_`3IfMT0fMWI01<0fMWI00<00;no0=WIf@3IfMT0XP3IfMT0
01`0fMWI00<000000=WIf@3IfMT0A`3IfMT00`00_kl0fMWI0=WIf@0B0=WIf@03002o_`3IfMT0fMWI
0:80fMWI000L0=WIf@030000003IfMT0fMWI04L0fMWI00<00;no0=WIf@3IfMT04P3IfMT00`00_kl0
fMWI0=WIf@2R0=WIf@00703IfMT00`000000fMWI0=WIf@170=WIf@03002o_`3IfMT0fMWI0180fMWI
00<00;no0=WIf@3IfMT0XP3IfMT001`0fMWI00<000000=WIf@3IfMT0A`3IfMT00`00_kl0fMWI0=WI
f@0B0=WIf@03002o_`3IfMT0fMWI0:80fMWI000L0=WIf@030000003IfMT0fMWI04L0fMWI00<00;no
0=WIf@3IfMT04@3IfMT00`00_kl0fMWI0=WIf@2S0=WIf@00703IfMT00`000000fMWI0=WIf@180=WI
f@03002o_`3IfMT0fMWI0100fMWI00<00;no0=WIf@3IfMT0X`3IfMT000h0fMWI1@0000020=WIf@80
00001@3IfMT00`000000fMWI0=WIf@180=WIf@03002o_`3IfMT0fMWI0100fMWI00<00;no0=WIf@3I
fMT0X`3IfMT00100fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0B03IfMT00`00_kl0fMWI0=WIf@0@0=WIf@03002o_`3IfMT0fMWI0:<0
fMWI000@0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WIf@020=WIf@80
0000B@3IfMT00`00_kl0fMWI0=WIf@0@0=WIf@03002o_`3IfMT0fMWI0:<0fMWI000@0=WIf@050000
003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI04P0
fMWI00<00;no0=WIf@3IfMT0403IfMT00`00_kl0fMWI0=WIf@2S0=WIf@00403IfMT01@000000fMWI
0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@190=WIf@03
002o_`3IfMT0fMWI00l0fMWI00<00;no0=WIf@3IfMT0X`3IfMT000l0fMWI0P0000040=WIf@800000
1@3IfMT00`000000fMWI0=WIf@190=WIf@03002o_`3IfMT0fMWI00l0fMWI00<00;no0=WIf@3IfMT0
X`3IfMT001`0fMWI00<000000=WIf@3IfMT0B@3IfMT00`00_kl0fMWI0=WIf@0?0=WIf@03002o_`3I
fMT0fMWI0:<0fMWI000L0=WIf@030000003IfMT0fMWI04T0fMWI00<00;no0=WIf@3IfMT03`3IfMT0
0`00_kl0fMWI0=WIf@2S0=WIf@00703IfMT00`000000fMWI0=WIf@190=WIf@03002o_`3IfMT0fMWI
00h0fMWI00<00;no0=WIf@3IfMT0Y03IfMT001`0fMWI00<000000=WIf@3IfMT0BP3IfMT00`00_kl0
fMWI0=WIf@0=0=WIf@03002o_`3IfMT0fMWI0:@0fMWI000L0=WIf@030000003IfMT0fMWI04X0fMWI
00<00;no0=WIf@3IfMT03@3IfMT00`00_kl0fMWI0=WIf@2T0=WIf@00703IfMT00`000000fMWI0=WI
f@1:0=WIf@03002o_`3IfMT0fMWI00d0fMWI00<00;no0=WIf@3IfMT0Y03IfMT001`0fMWI00<00000
0=WIf@3IfMT0BP3IfMT00`00_kl0fMWI0=WIf@0=0=WIf@03002o_`3IfMT0fMWI0:@0fMWI000L0=WI
f@030000003IfMT0fMWI04X0fMWI00<00;no0=WIf@3IfMT03@3IfMT00`00_kl0fMWI0=WIf@2T0=WI
f@00703IfMT00`000000fMWI0=WIf@1;0=WIf@03002o_`3IfMT0fMWI00`0fMWI00<00;no0=WIf@3I
fMT0Y03IfMT001`0fMWI00<000000=WIf@3IfMT0B`3IfMT00`00_kl0fMWI0=WIf@0<0=WIf@03002o
_`3IfMT0fMWI0:@0fMWI000L0=WIf@030000003IfMT0fMWI04/0fMWI00<00;no0=WIf@3IfMT0303I
fMT00`00_kl0fMWI0=WIf@2T0=WIf@00703IfMT00`000000fMWI0=WIf@1;0=WIf@03002o_`3IfMT0
fMWI00`0fMWI00<00;no0=WIf@3IfMT0Y03IfMT001`0fMWI00<000000=WIf@3IfMT0B`3IfMT00`00
_kl0fMWI0=WIf@0;0=WIf@03002o_`3IfMT0fMWI0:D0fMWI000L0=WIf@030000003IfMT0fMWI04`0
fMWI00<00;no0=WIf@3IfMT02P3IfMT00`00_kl0fMWI0=WIf@2U0=WIf@00703IfMT00`000000fMWI
0=WIf@1<0=WIf@03002o_`3IfMT0fMWI00X0fMWI00<00;no0=WIf@3IfMT0Y@3IfMT001`0fMWI00<0
00000=WIf@3IfMT0C03IfMT00`00_kl0fMWI0=WIf@0:0=WIf@03002o_`3IfMT0fMWI0:D0fMWI000L
0=WIf@030000003IfMT0fMWI04`0fMWI00<00;no0=WIf@3IfMT02@3IfMT2002o_jL0fMWI000L0=WI
f@030000003IfMT0fMWI04`0fMWI00<00;no0=WIf@3IfMT01P3IfMT3002o_jT0fMWI000L0=WIf@03
0000003IfMT0fMWI04d0fMWI00<00;no0=WIf@3IfMT00P3IfMT3002o_j`0fMWI000L0=WIf@030000
003IfMT0fMWI04d0fMWI00<00;no0=WIf@00_kl00P00_kn_0=WIf@00703IfMT00`000000fMWI0=WI
f@1=0=WIf@800;no/P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`00
0000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT00?l0fMWI
8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT004d0fMWI
100000060=WIf@@000001@3IfMT2000000P0fMWI0P00002d0=WIf@00C@3IfMT00`000000fMWI0000
00080=WIf@030000003IfMT0000000D0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WI
f@2b0=WIf@008P3IfMT5000000030=WIf@00000000000080000000P0fMWI000000000000fMWI0000
003IfMT000000=WIf@@000000`3IfMT2000000<0fMWI1@0000000`3IfMT000000000000300000080
fMWI00<000000=WIf@0000000P3IfMT5000000040=WIf@000000fMWI000000D0fMWI00<000000=WI
f@3IfMT00P3IfMT2000000@0fMWI00<000000=WIf@3IfMT0/P3IfMT001H0fMWI2@00_kl30=WIf@@0
00000`3IfMT00`000000fMWI0=WIf@020=WIf@070000003IfMT000000=WIf@000000fMWI0000000;
0=WIf@@000000P3IfMT4000000<0fMWI00<000000=WIf@000000103IfMT01`000000fMWI0=WIf@3I
fMT000000=WIf@0000001@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00D000000=WIf@3I
fMT0fMWI0000002d0=WIf@009@3IfMT01@000000fMWI0=WIf@3IfMT0000000@0fMWI00D000000=WI
f@000000fMWI000000020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT0
1`000000fMWI0=WIf@3IfMT000000=WIf@000000103IfMT01`000000fMWI0=WIf@3IfMT000000=WI
f@0000001@3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT0
02<0fMWI0`0000020=WIf@@0000000H0fMWI00000000000000000=WIf@0000040=WIf@030000003I
fMT0fMWI00P0fMWI0`0000030=WIf@<000000`3IfMT00`000000fMWI000000040=WIf@070000003I
fMT0fMWI0=WIf@000000fMWI000000050=WIf@030000003IfMT0fMWI00D000000`3IfMT00`000000
fMWI0=WIf@2b0=WIf@00=03IfMT010000000fMWI0=WIf@00000E0=WIf@030000003IfMT0000000@0
fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000D0fMWI00D000000=WIf@3IfMT0fMWI0000
00060=WIf@030000003IfMT0fMWI0;80fMWI000e0=WIf@8000005P3IfMT400000080fMWI0P000002
0=WIf@@000001@3IfMT2000000P0fMWI0P00002d0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00
C@3IfMT4000000H0fMWI100000050=WIf@800000203IfMT200000;@0fMWI001=0=WIf@030000003I
fMT0000000P0fMWI00<000000=WIf@0000001@3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI0;80fMWI000R0=WIf@D0000000<0fMWI0000000000000P000000203IfMT000000000003I
fMT000000=WIf@000000fMWI1@0000020=WIf@8000000`3IfMT5000000030=WIf@000000000000<0
00000P3IfMT00`000000fMWI000000020=WIf@D0000000@0fMWI0000003IfMT000001@3IfMT00`00
0000fMWI0=WIf@020=WIf@800000103IfMT00`000000fMWI0=WIf@2b0=WIf@005P3IfMT90?l000<0
fMWI100000030=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@000000fMWI000000030=WI
f@030000003IfMT0fMWI00L0fMWI100000020=WIf@@000000`3IfMT00`000000fMWI000000040=WI
f@070000003IfMT0fMWI0=WIf@000000fMWI000000050=WIf@050000003IfMT0fMWI0=WIf@000000
0P3IfMT01@000000fMWI0=WIf@3IfMT000000;@0fMWI000U0=WIf@050000003IfMT0fMWI0=WIf@00
0000103IfMT01@000000fMWI0000003IfMT0000000<0fMWI00<000000=WIf@3IfMT02P3IfMT00`00
0000fMWI0=WIf@030=WIf@070000003IfMT0fMWI0=WIf@000000fMWI000000040=WIf@070000003I
fMT0fMWI0=WIf@000000fMWI000000050=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`00
0000fMWI0=WIf@2b0=WIf@008`3IfMT300000080fMWI100000001P3IfMT00000000000000000fMWI
000000@0fMWI00<000000=WIf@3IfMT0203IfMT3000000<0fMWI0`0000030=WIf@030000003IfMT0
000000@0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000D0fMWI00<000000=WIf@3IfMT0
1@0000030=WIf@030000003IfMT0fMWI0;80fMWI000f0=WIf@030000003IfMT0fMWI01@0fMWI00<0
00000=WIf@000000103IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT003D0fMWI0P00000F0=WIf@@0
00000P3IfMT200000080fMWI100000050=WIf@800000203IfMT200000;@0fMWI003o0=WIfB40fMWI
000U0=WIf@030000003IfMT0fMWI00@00000:03IfMT3000000030=WIf@000000fMWI00H0fMWI0P00
00080=WIf@800000]03IfMT002@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0W
0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI0;80fMWI000S0=WIf@030000003IfMT0fMWI00D0fMWI00@000000=WIf@3IfMT0fMWI0P00
00040=WIf@<0000000<0fMWI0000000000000P3IfMT200000080fMWI0P0000030=WIf@@000000`3I
fMT2000000@0fMWI0`0000040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3I
fMT2000000@0fMWI00<000000=WIf@3IfMT0/P3IfMT002<0fMWI00<000000=WIf@3IfMT01@3IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI
000000020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000002`3IfMT01000
0000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI0000
00020=WIf@050000003IfMT0fMWI0=WIf@000000]03IfMT001H0fMWI2@00O`040=WIf@030000003I
fMT0fMWI00D0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@020=WIf@050000
003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000060=WIf@030000003IfMT0fMWI
00P0fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0
fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@2b0=WIf@008`3IfMT00`000000fMWI0=WIf@02
0=WIf@@000000`3IfMT2000000@0fMWI0P0000020=WIf@@000000P3IfMT5000000@0fMWI00<00000
0=WIf@3IfMT0203IfMT4000000<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@05
000000<0fMWI00<000000=WIf@3IfMT0/P3IfMT002@0fMWI00<000000=WIf@3IfMT06@3IfMT00`00
0000fMWI0=WIf@030=WIf@040000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT0103IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT002D0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00h0fMWI0P00000?
0=WIf@030000003IfMT0fMWI00D0fMWI0P0000080=WIf@800000]03IfMT00?l0fMWI8@3IfMT00?l0
fMWI8@3IfMT002D0fMWI00<000000=WIf@3IfMT01000000X0=WIf@<0000000<0fMWI0000003IfMT0
1P3IfMT2000000P0fMWI0P00002d0=WIf@00903IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI02L0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT0/P3IfMT002<0fMWI00<000000=WIf@3IfMT01@3IfMT010000000fMWI0=WI
f@3IfMT2000000@0fMWI0`0000000`3IfMT00000000000020=WIf@8000000P3IfMT2000000<0fMWI
1@0000020=WIf@800000103IfMT3000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@020=WIf@800000103IfMT00`000000fMWI0=WIf@2b0=WIf@008`3IfMT00`000000fMWI0=WI
f@050=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI
0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00L0fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@03
0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT01@000000fMWI0=WIf@3IfMT000000;@0fMWI
000F0=WIf@T0003o103IfMT00`000000fMWI0=WIf@050=WIf@040000003IfMT0fMWI00000080fMWI
00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3I
fMT000001`3IfMT00`000000fMWI0=WIf@070=WIf@040000003IfMT0fMWI000000@0fMWI00<00000
0=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0/P3I
fMT002<0fMWI00<000000=WIf@3IfMT00P3IfMT4000000<0fMWI0P0000040=WIf@8000000P3IfMT4
00000080fMWI1@0000040=WIf@030000003IfMT0fMWI00P0fMWI100000030=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT01@0000030=WIf@030000003IfMT0fMWI0;80fMWI000T0=WI
f@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0>0=WI
f@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0
fMWI0;80fMWI000U0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02@3IfMT00`00
0000fMWI0=WIf@0>0=WIf@8000003`3IfMT00`000000fMWI0=WIf@050=WIf@800000203IfMT20000
0;@0fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WI
fB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI0000\
\>"],
  ImageRangeCache->{{{138, 425}, {387, 173.75}} -> {-2.06252, 0.617803, \
0.00732689, 0.00732689}, {{145, 417.938}, {381.875, 213.188}} -> {-5.7716, \
21.5399, 0.0347642, 0.310075}, {{158.625, 295.125}, {219.75, 178.813}} -> \
{-19.1203, 0.668472, 0.119891, 0.11823}, {{160.125, 168.438}, {218.188, \
209.75}} -> {-39.5267, 0.172934, 0.240604, 0.240604}, {{160.125, 168.438}, \
{208.375, 199.938}} -> {-39.5267, -2.18799, 0.240604, 0.240604}, {{160.125, \
168.438}, {198.563, 190.125}} -> {-39.5267, -4.54892, 0.240604, 0.240604}, \
{{160.125, 168.438}, {188.75, 180.313}} -> {-39.5267, -6.90984, 0.240604, \
0.240604}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74402 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.312017 0.47619 [
[ 0 0 0 0 ]
[ 1 .74402 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0177147 0.97619 0.606318 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.392676 0.0186562 [
[.2619 .38018 -3 -9 ]
[.2619 .38018 3 0 ]
[.5 .38018 -3 -9 ]
[.5 .38018 3 0 ]
[.7381 .38018 -3 -9 ]
[.7381 .38018 3 0 ]
[.97619 .38018 -3 -9 ]
[.97619 .38018 3 0 ]
[1.025 .39268 0 -6.28125 ]
[1.025 .39268 10 6.28125 ]
[.01131 .01955 -18 -4.5 ]
[.01131 .01955 0 4.5 ]
[.01131 .11283 -18 -4.5 ]
[.01131 .11283 0 4.5 ]
[.01131 .20611 -18 -4.5 ]
[.01131 .20611 0 4.5 ]
[.01131 .29939 -12 -4.5 ]
[.01131 .29939 0 4.5 ]
[.01131 .48596 -6 -4.5 ]
[.01131 .48596 0 4.5 ]
[.01131 .57924 -12 -4.5 ]
[.01131 .57924 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .39268 m
.2619 .39893 L
s
[(2)] .2619 .38018 0 1 Mshowa
.5 .39268 m
.5 .39893 L
s
[(4)] .5 .38018 0 1 Mshowa
.7381 .39268 m
.7381 .39893 L
s
[(6)] .7381 .38018 0 1 Mshowa
.97619 .39268 m
.97619 .39893 L
s
[(8)] .97619 .38018 0 1 Mshowa
.125 Mabswid
.08333 .39268 m
.08333 .39643 L
s
.14286 .39268 m
.14286 .39643 L
s
.20238 .39268 m
.20238 .39643 L
s
.32143 .39268 m
.32143 .39643 L
s
.38095 .39268 m
.38095 .39643 L
s
.44048 .39268 m
.44048 .39643 L
s
.55952 .39268 m
.55952 .39643 L
s
.61905 .39268 m
.61905 .39643 L
s
.67857 .39268 m
.67857 .39643 L
s
.79762 .39268 m
.79762 .39643 L
s
.85714 .39268 m
.85714 .39643 L
s
.91667 .39268 m
.91667 .39643 L
s
.25 Mabswid
0 .39268 m
1 .39268 L
s
gsave
1.025 .39268 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01955 m
.03006 .01955 L
s
[(-20)] .01131 .01955 1 0 Mshowa
.02381 .11283 m
.03006 .11283 L
s
[(-15)] .01131 .11283 1 0 Mshowa
.02381 .20611 m
.03006 .20611 L
s
[(-10)] .01131 .20611 1 0 Mshowa
.02381 .29939 m
.03006 .29939 L
s
[(-5)] .01131 .29939 1 0 Mshowa
.02381 .48596 m
.03006 .48596 L
s
[(5)] .01131 .48596 1 0 Mshowa
.02381 .57924 m
.03006 .57924 L
s
[(10)] .01131 .57924 1 0 Mshowa
.125 Mabswid
.02381 .03821 m
.02756 .03821 L
s
.02381 .05686 m
.02756 .05686 L
s
.02381 .07552 m
.02756 .07552 L
s
.02381 .09418 m
.02756 .09418 L
s
.02381 .13149 m
.02756 .13149 L
s
.02381 .15014 m
.02756 .15014 L
s
.02381 .1688 m
.02756 .1688 L
s
.02381 .18746 m
.02756 .18746 L
s
.02381 .22477 m
.02756 .22477 L
s
.02381 .24343 m
.02756 .24343 L
s
.02381 .26208 m
.02756 .26208 L
s
.02381 .28074 m
.02756 .28074 L
s
.02381 .31805 m
.02756 .31805 L
s
.02381 .33671 m
.02756 .33671 L
s
.02381 .35536 m
.02756 .35536 L
s
.02381 .37402 m
.02756 .37402 L
s
.02381 .41133 m
.02756 .41133 L
s
.02381 .42999 m
.02756 .42999 L
s
.02381 .44864 m
.02756 .44864 L
s
.02381 .4673 m
.02756 .4673 L
s
.02381 .50461 m
.02756 .50461 L
s
.02381 .52327 m
.02756 .52327 L
s
.02381 .54193 m
.02756 .54193 L
s
.02381 .56058 m
.02756 .56058 L
s
.02381 .00089 m
.02756 .00089 L
s
.02381 .59789 m
.02756 .59789 L
s
.02381 .61655 m
.02756 .61655 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 1 r
.001 w
.02381 .39268 m
.07143 .39218 L
.11905 .37365 L
.16667 .36128 L
.21429 .34187 L
.2619 .33911 L
.30952 .34611 L
.35714 .35642 L
.40476 .35971 L
.45238 .3835 L
.5 .39114 L
.54762 .38109 L
.59524 .36826 L
.64286 .36343 L
.69048 .34384 L
.7381 .34084 L
.78571 .35137 L
.83333 .35737 L
.88095 .36875 L
.92857 .38169 L
.97619 .37873 L
s
0 .5 0 r
.02381 .39268 m
.07143 .38385 L
.11905 .39988 L
.16667 .38564 L
.21429 .39712 L
.2619 .38563 L
.30952 .3721 L
.35714 .37669 L
.40476 .40991 L
.45238 .38168 L
.5 .37822 L
.54762 .39907 L
.59524 .40464 L
.64286 .37942 L
.69048 .40139 L
.7381 .39812 L
.78571 .38041 L
.83333 .39319 L
.88095 .3978 L
.92857 .387 L
.97619 .40058 L
s
1 0 0 r
.02381 .39268 m
.07143 .38781 L
.11905 .23674 L
.16667 .21081 L
.21429 .31836 L
.2619 .34383 L
.30952 .28259 L
.35714 .22221 L
.40476 .21317 L
.45238 .30624 L
.5 .37767 L
.54762 .28617 L
.59524 .2159 L
.64286 .20966 L
.69048 .30112 L
.7381 .32764 L
.78571 .24622 L
.83333 .21905 L
.88095 .21722 L
.92857 .291 L
.97619 .26822 L
s
0 .75 .75 r
.02381 .39268 m
.07143 .35444 L
.11905 .14397 L
.16667 .16102 L
.21429 .24833 L
.2619 .37201 L
.30952 .37539 L
.35714 .60332 L
.40476 .3473 L
.45238 .24888 L
.5 .39976 L
.54762 .19532 L
.59524 .45328 L
.64286 .28357 L
.69048 .27048 L
.7381 .31955 L
.78571 .30943 L
.83333 .22125 L
.88095 .01472 L
.92857 .31125 L
.97619 .30063 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0714286 0.583445 0.547619 0.726302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00611247 0.0611247 0.00619835 0.0619835 [
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0110024 0.011157 0.0721271 0.0731405 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .75 .75 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .04215 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arm2) show
87.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(aa) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(P) show
111.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(T) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.0830579 0.0721271 0.145041 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .11405 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arm1) show
87.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(aa) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(P) show
111.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(T) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.154959 0.0721271 0.216942 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .5 0 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .18595 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(joint2) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.22686 0.0721271 0.288843 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .25785 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(joint1) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .74402 L
0 .74402 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 214.25},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eR000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00703IfMT0
0`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0
fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@003P3IfMT4000000<0fMWI0P0000050=WIf@030000
003IfMT0fMWI0?l0fMWI0P3IfMT000h0fMWI00<000000=WIf@3IfMT00`3IfMT010000000fMWI0=WI
f@0000040=WIf@030000003IfMT0fMWI0<`0fMWI00<00;no0=WIf@3IfMT0<P3IfMT000l0fMWI00<0
00000=WIf@3IfMT00P3IfMT010000000fMWI0=WIf@0000040=WIf@800000c@3IfMT00`00_kl0fMWI
0=WIf@0b0=WIf@00203IfMT4000000@0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0c03IfMT00`00_kl0fMWI0=WIf@0b0=WIf@003P3I
fMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@3I
fMT0b`3IfMT2002o_c@0fMWI000?0=WIf@800000103IfMT2000000D0fMWI00<000000=WIf@3IfMT0
b`3IfMT00`00_kl0fMWI002o_`0c0=WIf@00703IfMT00`000000fMWI0=WIf@3;0=WIf@03002o_`3I
fMT00;no03<0fMWI000L0=WIf@030000003IfMT0fMWI0</0fMWI00<00;no0=WIf@00_kl0<`3IfMT0
01`0fMWI00<000000=WIf@3IfMT0bP3IfMT01000_kl0fMWI0=WIf@00_klc0=WIf@00703IfMT00`00
0000fMWI0=WIf@3:0=WIf@04002o_`3IfMT0fMWI002o_c<0fMWI000L0=WIf@030000003IfMT0fMWI
0<X0fMWI00@00;no0=WIf@3IfMT00;no<`3IfMT001`0fMWI00<000000=WIf@3IfMT0bP3IfMT01@00
_kl0fMWI0=WIf@3IfMT00;no0380fMWI000L0=WIf@030000003IfMT0fMWI0<T0fMWI00<00;no0=WI
f@3IfMT00P3IfMT00`00_kl0fMWI0=WIf@0`0=WIf@00703IfMT00`000000fMWI0=WIf@390=WIf@03
002o_`3IfMT0fMWI0080fMWI00<00;no0=WIf@3IfMT0<03IfMT001`0fMWI00<000000=WIf@3IfMT0
b@3IfMT00`00_kl0fMWI0=WIf@020=WIf@03002o_`3IfMT0fMWI0300fMWI000L0=WIf@030000003I
fMT0fMWI0<T0fMWI00<00;no0=WIf@3IfMT00P3IfMT00`00_kl0fMWI0=WIf@0`0=WIf@00703IfMT0
0`000000fMWI0=WIf@380=WIf@03002o_`3IfMT0fMWI00<0fMWI00<00;no0=WIf@3IfMT0<03IfMT0
01`0fMWI00<000000=WIf@3IfMT0b03IfMT00`00_kl0fMWI0=WIf@030=WIf@03002o_`3IfMT0fMWI
0300fMWI000L0=WIf@030000003IfMT0fMWI0<P0fMWI00<00;no0=WIf@3IfMT0103IfMT00`00_kl0
fMWI0=WIf@0_0=WIf@00703IfMT00`000000fMWI0=WIf@380=WIf@03002o_`3IfMT0fMWI00@0fMWI
00<00;no0=WIf@3IfMT0;`3IfMT001`0fMWI00<000000=WIf@3IfMT0a`3IfMT00`00_kl0fMWI0=WI
f@050=WIf@03002o_`3IfMT0fMWI02l0fMWI000L0=WIf@030000003IfMT0fMWI0<L0fMWI00<00;no
0=WIf@3IfMT01@3IfMT00`00_kl0fMWI0=WIf@0_0=WIf@003P3IfMT500000080fMWI0P0000050=WI
f@030000003IfMT0fMWI0<L0fMWI00<00;no0=WIf@3IfMT01@3IfMT00`00_kl0fMWI0=WIf@0_0=WI
f@00403IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@370=WIf@03002o_`3IfMT0fMWI00D0fMWI00<00;no0=WIf@3IfMT0;`3IfMT00100
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@800000a`3IfMT00`00_kl0
fMWI0=WIf@070=WIf@03002o_`3IfMT0fMWI02h0fMWI00080=WIf@@00000103IfMT00`000000fMWI
0=WIf@020=WIf@8000001@3IfMT00`000000fMWI0=WIf@360=WIf@03002o_`3IfMT0fMWI00L0fMWI
00<00;no0=WIf@3IfMT0;P3IfMT00100fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI0<H0fMWI00<00;no0=WIf@3IfMT01`3IfMT00`00_kl0fMWI0=WI
f@0^0=WIf@003`3IfMT2000000@0fMWI0`0000040=WIf@030000003IfMT0fMWI0<H0fMWI00<00;no
0=WIf@3IfMT01`3IfMT00`00_kl0fMWI0=WIf@0^0=WIf@00703IfMT00`000000fMWI0=WIf@360=WI
f@03002o_`3IfMT0fMWI00L0fMWI00<00;no0=WIf@3IfMT0;P3IfMT001`0fMWI00<000000=WIf@3I
fMT0a@3IfMT00`00_kl0fMWI0=WIf@080=WIf@03002o_`3IfMT0fMWI02h0fMWI000L0=WIf@030000
003IfMT0fMWI0<D0fMWI00<00;no0=WIf@3IfMT0203IfMT00`00_kl0fMWI0=WIf@0^0=WIf@00703I
fMT00`000000fMWI0=WIf@350=WIf@03002o_`3IfMT0fMWI00T0fMWI00<00;no0=WIf@3IfMT0;@3I
fMT001`0fMWI00<000000=WIf@3IfMT0503IfMT2002o_jl0fMWI00<00;no0=WIf@3IfMT02@3IfMT0
0`00_kl0fMWI0=WIf@0]0=WIf@00703IfMT00`000000fMWI0=WIf@0D0=WIf@03002o_`3IfMT00;no
00800;noZ`3IfMT00`00_kl0fMWI0=WIf@0:0=WIf@03002o_`3IfMT0fMWI02d0fMWI000L0=WIf@03
0000003IfMT0fMWI01@0fMWI00<00;no0=WIf@3IfMT00P3IfMT2002o_jT0fMWI00<00;no0=WIf@3I
fMT02P3IfMT00`00_kl0fMWI0=WIf@0]0=WIf@00703IfMT00`000000fMWI0=WIf@0C0=WIf@03002o
_`3IfMT0fMWI00D0fMWI0`00_knV0=WIf@03002o_`3IfMT0fMWI00X0fMWI00<00;no0=WIf@3IfMT0
;@3IfMT001`0fMWI00<000000=WIf@3IfMT04`3IfMT00`00_kl0fMWI0=WIf@080=WIf@800;noY03I
fMT00`00_kl0fMWI0=WIf@0:0=WIf@03002o_`3IfMT0fMWI02d0fMWI000L0=WIf@030000003IfMT0
fMWI01<0fMWI00<00;no0=WIf@3IfMT02P3IfMT00`00_kl0fMWI0=WIf@2P0=WIf@03002o_`3IfMT0
fMWI00`0fMWI00<00;no0=WIf@3IfMT0;03IfMT001`0fMWI00<000000=WIf@3IfMT04`3IfMT00`00
_kl0fMWI0=WIf@0:0=WIf@03002o_`3IfMT0fMWI0:00fMWI00<00;no0=WIf@3IfMT0303IfMT00`00
_kl0fMWI0=WIf@0/0=WIf@00703IfMT00`000000fMWI0=WIf@0B0=WIf@03002o_`3IfMT0fMWI00`0
fMWI00<00;no0=WIf@3IfMT0W`3IfMT00`00_kl0fMWI0=WIf@0<0=WIf@03002o_`3IfMT0fMWI02`0
fMWI000L0=WIf@030000003IfMT0fMWI0180fMWI00<00;no0=WIf@3IfMT0303IfMT00`00_kl0fMWI
0=WIf@2O0=WIf@03002o_`3IfMT0fMWI00`0fMWI00<00;no0=WIf@3IfMT0;03IfMT001`0fMWI00<0
00000=WIf@3IfMT04P3IfMT00`00_kl0fMWI0=WIf@0=0=WIf@03002o_`3IfMT0fMWI09d0fMWI00<0
0;no0=WIf@3IfMT03@3IfMT00`00_kl0fMWI0=WIf@0/0=WIf@00703IfMT00`000000fMWI0=WIf@0B
0=WIf@03002o_`3IfMT0fMWI00d0fMWI00<00;no0=WIf@3IfMT0W@3IfMT00`00_kl0fMWI0=WIf@0=
0=WIf@03002o_`3IfMT0fMWI02`0fMWI000L0=WIf@030000003IfMT0fMWI0140fMWI00<00;no0=WI
f@3IfMT03`3IfMT00`00_kl0fMWI0=WIf@2L0=WIf@03002o_`3IfMT0fMWI00h0fMWI00<00;no0=WI
f@3IfMT0:`3IfMT001`0fMWI00<000000=WIf@3IfMT04@3IfMT00`00_kl0fMWI0=WIf@0@0=WIf@03
002o_`3IfMT0fMWI05@0fMWI00<00;no0=WIf@3IfMT0A03IfMT00`00_kl0fMWI0=WIf@0>0=WIf@03
002o_`3IfMT0fMWI02/0fMWI000>0=WIf@D000000P3IfMT2000000D0fMWI00<000000=WIf@3IfMT0
4@3IfMT00`00_kl0fMWI0=WIf@0@0=WIf@03002o_`3IfMT0fMWI05@0fMWI00<00;no0=WIf@3IfMT0
@`3IfMT00`00_kl0fMWI0=WIf@0?0=WIf@03002o_`3IfMT0fMWI02/0fMWI000@0=WIf@050000003I
fMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI
00<00;no0=WIf@3IfMT04@3IfMT00`00_kl0fMWI0=WIf@1C0=WIf@03002o_`3IfMT0fMWI04<0fMWI
00<00;no0=WIf@3IfMT03`3IfMT00`00_kl0fMWI0=WIf@0[0=WIf@00403IfMT01@000000fMWI0=WI
f@3IfMT000000080fMWI00<000000=WIf@3IfMT00P3IfMT200000140fMWI00<00;no0=WIf@3IfMT0
4P3IfMT00`00_kl0fMWI0=WIf@1B0=WIf@03002o_`3IfMT00;no04@0fMWI00<00;no0=WIf@3IfMT0
3`3IfMT00`00_kl0fMWI0=WIf@0[0=WIf@00203IfMT4000000@0fMWI00D000000=WIf@3IfMT0fMWI
000000020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`00_kl0fMWI
0=WIf@0<0=WIf@030?l0003IfMT0fMWI00@0fMWI00<00;no0=WIf@3IfMT0D@3IfMT00`00_kl0fMWI
002o_`0@0=WIf@H0o`00;P3IfMT00`00_kl0fMWI0=WIf@0?0=WIf@03002o_`3IfMT0fMWI02/0fMWI
000@0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0100fMWI00<00;no0=WIf@3IfMT02P3IfMT30?l000H0fMWI00<00;no0=WIf@3IfMT0
;@3IfMT40?l00200fMWI00<00;no0=WIf@00_kl02P3IfMT60?l000H0fMWI00<0o`000=WIf@3IfMT0
:P3IfMT00`00_kl0fMWI0=WIf@0@0=WIf@03002o_`3IfMT0fMWI02/0fMWI000?0=WIf@800000103I
fMT2000000D0fMWI00<000000=WIf@3IfMT0403IfMT00`00_kl0fMWI0=WIf@080=WIf@80o`000`3I
fMT00`3o0000fMWI0=WIf@040=WIf@03002o_`3IfMT0fMWI02H0fMWI1P3o00040=WIf@030?l0003I
fMT0fMWI01d0fMWI00<00;no0=WIf@00_kl02@3IfMT00`3o0000fMWI0=WIf@0:0=WIf@030?l0003I
fMT0fMWI02X0fMWI00<00;no0?l0003o00002P3o00070=WIf@03002o_`3IfMT0fMWI02X0fMWI000L
0=WIf@030000003IfMT0fMWI0100fMWI00<00;no0=WIf@3IfMT01P3IfMT20?l000D0fMWI00<0o`00
0=WIf@3IfMT01@3IfMT00`00_kl0fMWI0=WIf@0R0=WIf@<0o`002P3IfMT00`3o0000fMWI0=WIf@0L
0=WIf@04002o_`3IfMT0fMWI002o_`T0fMWI00<0o`000=WIf@3IfMT02`3IfMT00`3o0000fMWI0=WI
f@0W0=WIf@80o`0000<00;no0=WIf@3IfMT02P3IfMT00`3o0000fMWI0=WIf@040=WIf@03002o_`3I
fMT0fMWI02X0fMWI000L0=WIf@030000003IfMT0fMWI00l0fMWI00<00;no0=WIf@3IfMT01@3IfMT2
0?l000P0fMWI00<0o`000=WIf@3IfMT0103IfMT00`00_kl0fMWI0=WIf@0Q0=WIf@030?l0003IfMT0
fMWI00`0fMWI00<0o`000=WIf@3IfMT06`3IfMT01@00_kl0fMWI0=WIf@3IfMT00;no00L0fMWI00<0
o`000=WIf@3IfMT0303IfMT00`3o0000fMWI0=WIf@0V0=WIf@030?l0003IfMT00;no00d0fMWI00<0
o`000=WIf@3IfMT0103IfMT00`00_kl0fMWI0=WIf@0Z0=WIf@00703IfMT00`000000fMWI0=WIf@0?
0=WIf@03002o_`3IfMT0fMWI00<0fMWI0P3o000:0=WIf@030?l0003IfMT0fMWI00D0fMWI00<00;no
0=WIf@3IfMT07`3IfMT00`3o0000fMWI0=WIf@0=0=WIf@030?l0003IfMT0fMWI01/0fMWI00D00;no
0=WIf@3IfMT0fMWI002o_`060=WIf@030?l0003IfMT0fMWI00h0fMWI00<0o`000=WIf@3IfMT08`3I
fMT20?l00080fMWI00<00;no0=WIf@3IfMT0303IfMT00`3o0000fMWI0=WIf@030=WIf@03002o_`3I
fMT0fMWI02X0fMWI000L0=WIf@030000003IfMT0fMWI00l0fMWI00<00;no0=WIf@3IfMT00P3IfMT0
0`3o0000fMWI0=WIf@0;0=WIf@030?l0003IfMT0fMWI00@0fMWI00<00;no0=WIf@3IfMT07`3IfMT0
0`3o0000fMWI0=WIf@0>0=WIf@030?l0003IfMT0fMWI01X0fMWI00D00;no0=WIf@3IfMT0fMWI002o
_`050=WIf@030?l0003IfMT0fMWI00l0fMWI00<0o`000=WIf@3IfMT08@3IfMT20?l000<0fMWI00<0
0;no0=WIf@3IfMT03P3IfMT00`3o0000fMWI0=WIf@020=WIf@03002o_`3IfMT0fMWI02X0fMWI000L
0=WIf@030000003IfMT0fMWI00l0fMWI00<00;no0=WIf@3IfMT00P3IfMT00`3o0000fMWI0=WIf@0;
0=WIf@030?l0003IfMT0fMWI00D0fMWI00<00;no0=WIf@3IfMT07@3IfMT00`3o0000fMWI0=WIf@0?
0=WIf@030?l0003IfMT0fMWI01X0fMWI00D00;no0=WIf@3IfMT0fMWI002o_`050=WIf@030?l0003I
fMT0fMWI0100fMWI00<0o`000=WIf@3IfMT07`3IfMT00`3o0000fMWI0=WIf@030=WIf@03002o_`3I
fMT0fMWI00h0fMWI00<0o`000=WIf@3IfMT00P3IfMT00`00_kl0fMWI0=WIf@0Z0=WIf@00703IfMT0
0`000000fMWI0=WIf@0>0=WIf@03002o_`3IfMT0fMWI0080fMWI00<0o`000=WIf@3IfMT03@3IfMT0
0`3o0000fMWI0=WIf@040=WIf@03002o_`3IfMT0fMWI01`0fMWI00<0o`000=WIf@3IfMT04@3IfMT0
0`3o0000fMWI0=WIf@0H0=WIf@03002o_`3IfMT0fMWI0080fMWI00<00;no0=WIf@3IfMT00P3IfMT0
0`3o0000fMWI0=WIf@0A0=WIf@030?l0003IfMT0fMWI01d0fMWI0P3o00050=WIf@03002o_`3IfMT0
fMWI0100fMWI00<0o`000=WIf@3IfMT00P3IfMT00`00_kl0fMWI0=WIf@0Y0=WIf@00703IfMT00`00
0000fMWI0=WIf@0>0=WIf@03002o_`3IfMT0fMWI0080fMWI00<0o`000=WIf@3IfMT03@3IfMT00`3o
0000fMWI0=WIf@050=WIf@03002o_`3IfMT0fMWI01X0fMWI00<0o`000=WIf@3IfMT04P3IfMT00`3o
0000fMWI0=WIf@040=WIf@03002o_`3IfMT0fMWI0140fMWI00<00;no0=WIf@3IfMT00P3IfMT01@00
_kl0fMWI0=WIf@3IfMT0o`0001D0fMWI00<0o`000=WIf@3IfMT06`3IfMT00`3o0000fMWI0=WIf@05
0=WIf@03002o_`3IfMT0fMWI0140fMWI00D0o`000=WIf@3IfMT0fMWI002o_`0[0=WIf@00703IfMT0
0`000000fMWI0=WIf@0>0=WIf@03002o_`3IfMT0fMWI0080fMWI00<0o`000=WIf@3IfMT03P3IfMT0
0`3o0000fMWI0=WIf@040=WIf@03002o_`3IfMT0fMWI01X0fMWI00<0o`000=WIf@3IfMT04`3IfMT0
0`3o0000fMWI0=WIf@030=WIf@03002o_`3IfMT0fMWI0140fMWI00<00;no0=WIf@3IfMT00`3IfMT0
1000_kl0fMWI0=WIf@3o000E0=WIf@030?l0003IfMT0fMWI01X0fMWI00<0o`000=WIf@3IfMT01@3I
fMT00`00_kl0fMWI0=WIf@0B0=WIf@050?l0003IfMT0fMWI0=WIf@00_kl0:`3IfMT001`0fMWI00<0
00000=WIf@3IfMT03P3IfMT01@00_kl0fMWI0=WIf@3IfMT0o`000140fMWI00<0o`000=WIf@3IfMT0
1@3IfMT00`00_kl0fMWI0=WIf@0H0=WIf@030?l0003IfMT0fMWI01@0fMWI00<0o`000=WIf@3IfMT0
0P3IfMT00`00_kl0fMWI002o_`0B0=WIf@03002o_`3IfMT0fMWI00<0fMWI00<00;no0=WIf@3o0000
5`3IfMT00`3o0000fMWI0=WIf@0I0=WIf@030?l0003IfMT0fMWI00D0fMWI00<00;no0=WIf@3IfMT0
4`3IfMT0103o0000fMWI0=WIf@00_kl[0=WIf@00703IfMT00`000000fMWI0=WIf@0=0=WIf@03002o
_`3IfMT0fMWI0080fMWI00<0o`000=WIf@3IfMT0403IfMT00`3o0000fMWI0=WIf@040=WIf@03002o
_`3IfMT0fMWI01L0fMWI00<0o`000=WIf@3IfMT05P3IfMT01`3o0000fMWI0=WIf@3IfMT00;no0=WI
f@00_kl04@3IfMT00`00_kl0fMWI0=WIf@040=WIf@03002o_`3o0000fMWI01P0fMWI00<0o`000=WI
f@3IfMT05`3IfMT00`3o0000fMWI0=WIf@050=WIf@03002o_`3IfMT0fMWI01@0fMWI00@0o`000=WI
f@3IfMT00;no:`3IfMT001`0fMWI00<000000=WIf@3IfMT03@3IfMT00`00_kl0fMWI0=WIf@020=WI
f@030?l0003IfMT0fMWI0100fMWI00<0o`000=WIf@3IfMT0103IfMT00`00_kl0fMWI0=WIf@0F0=WI
f@030?l0003IfMT0fMWI01L0fMWI00@0o`000=WIf@3IfMT00;no0P3IfMT00`00_kl0fMWI0=WIf@0?
0=WIf@03002o_`3IfMT0fMWI00@0fMWI00<00;no0?l0003IfMT0603IfMT00`3o0000fMWI0=WIf@0F
0=WIf@030?l0003IfMT0fMWI00H0fMWI00<00;no0=WIf@3IfMT05@3IfMT00`3o0000fMWI002o_`0[
0=WIf@00703IfMT00`000000fMWI0=WIf@0=0=WIf@05002o_`3IfMT0fMWI0=WIf@3o00004`3IfMT0
0`3o0000fMWI0=WIf@050=WIf@03002o_`3IfMT0fMWI01@0fMWI00<0o`000=WIf@3IfMT06@3IfMT0
0`3o0000fMWI002o_`030=WIf@03002o_`3IfMT0fMWI00h0fMWI00<00;no0=WIf@3IfMT0103IfMT0
0`00_kl0fMWI0=WIf@0I0=WIf@030?l0003IfMT0fMWI00800;no4`3IfMT00`3o0000fMWI0=WIf@05
0=WIf@03002o_`3IfMT0fMWI01L0fMWI00<0o`00002o_`3IfMT02`3IfMT20?l001d0fMWI000L0=WI
f@030000003IfMT0fMWI00d0fMWI00D00;no0=WIf@3IfMT0fMWI0?l0000D0=WIf@030?l0003IfMT0
fMWI00@0fMWI00<00;no0=WIf@3IfMT0503IfMT00`3o0000fMWI0=WIf@0I0=WIf@030?l00000_kl0
fMWI00<0fMWI00<00;no0=WIf@3IfMT03P3IfMT00`00_kl0fMWI0=WIf@030=WIf@030?l0003IfMT0
0;no01X0fMWI0`00_kl20=WIf@03002o_`3IfMT0fMWI00l0fMWI00<0o`000=WIf@3IfMT01P3IfMT0
0`00_kl0fMWI0=WIf@0G0=WIf@030?l0003IfMT00;no00T0fMWI0P3o000O0=WIf@00703IfMT00`00
0000fMWI0=WIf@0<0=WIf@03002o_`3IfMT0fMWI0080fMWI00<0o`000=WIf@3IfMT04P3IfMT00`3o
0000fMWI0=WIf@050=WIf@03002o_`3IfMT0fMWI0180fMWI00<0o`000=WIf@3IfMT06`3IfMT00`00
_kl0fMWI0=WIf@020=WIf@03002o_`3IfMT0fMWI00h0fMWI00<00;no0=WIf@3IfMT00P3IfMT0103o
0000fMWI0=WIf@00_klG0=WIf@<00;no00<0fMWI0?l0003IfMT00`3IfMT00`00_kl0fMWI0=WIf@0>
0=WIf@030?l0003IfMT0fMWI00D0fMWI00<00;no0=WIf@3IfMT06@3IfMT00`3o00000;no0=WIf@05
0=WIf@<0o`008@3IfMT001`0fMWI00<000000=WIf@3IfMT0303IfMT01@00_kl0fMWI0=WIf@3IfMT0
o`0001H0fMWI00<0o`000=WIf@3IfMT0103IfMT00`00_kl0fMWI0=WIf@0A0=WIf@030?l0003IfMT0
fMWI01/0fMWI00<00;no0?l0003IfMT0103IfMT00`00_kl0fMWI0=WIf@0<0=WIf@03002o_`3IfMT0
fMWI00<0fMWI00@0o`000=WIf@3IfMT00;no503IfMT3002o_`@0fMWI00<0o`000=WIf@3IfMT00`3I
fMT00`00_kl0fMWI0=WIf@0<0=WIf@030?l0003IfMT0fMWI00H0fMWI00<00;no0=WIf@3IfMT06P3I
fMT00`00_kl0fMWI0=WIf@020=WIf@80o`00903IfMT001`0fMWI00<000000=WIf@3IfMT0303IfMT0
1@00_kl0fMWI0=WIf@3IfMT0o`0001H0fMWI00<0o`000=WIf@3IfMT0103IfMT00`00_kl0fMWI0=WI
f@0@0=WIf@030?l0003IfMT0fMWI01`0fMWI00<00;no0=WIf@3o0000103IfMT00`00_kl0fMWI0=WI
f@0<0=WIf@03002o_`3IfMT0fMWI0080fMWI00D0o`000=WIf@3IfMT0fMWI002o_`0B0=WIf@800;no
203IfMT00`3o0000fMWI0=WIf@030=WIf@03002o_`3IfMT0fMWI00X0fMWI00<0o`000=WIf@3IfMT0
1P3IfMT00`00_kl0fMWI0=WIf@0K0=WIf@03002o_`3IfMT0fMWI0080o`009P3IfMT001D0fMWI0P00
00050=WIf@030000003IfMT0fMWI00`0fMWI00D00;no0=WIf@3IfMT0fMWI0?l0000G0=WIf@030?l0
003IfMT0fMWI00@0fMWI00<00;no0=WIf@3IfMT03P3IfMT00`3o0000fMWI0=WIf@0L0=WIf@04002o
_`3IfMT0fMWI0?l000@0fMWI00<00;no0=WIf@3IfMT0303IfMT00`00_kl0fMWI0=WIf@020=WIf@05
0?l0003IfMT0fMWI0=WIf@00_kl04P3IfMT00`00_kl0fMWI0=WIf@070=WIf@030?l0003IfMT0fMWI
00@0fMWI00<00;no0=WIf@3IfMT02@3IfMT00`3o0000fMWI0=WIf@060=WIf@03002o_`3IfMT0fMWI
01/0fMWI00<00;no0?l0003o0000:03IfMT001@0fMWI00@000000=WIf@3IfMT00000103IfMT00`00
0000fMWI0=WIf@0<0=WIf@04002o_`3IfMT0fMWI0?l001P0fMWI00<0o`000=WIf@3IfMT0103IfMT0
0`00_kl0fMWI0=WIf@0>0=WIf@030?l0003IfMT0fMWI01`0fMWI00D00;no0=WIf@3IfMT0fMWI0?l0
00040=WIf@03002o_`3IfMT0fMWI00/0fMWI00D00;no0=WIf@3IfMT0fMWI0?l000050=WIf@03002o
_`3IfMT0fMWI00h0fMWI00<00;no0=WIf@3IfMT02@3IfMT00`3o0000fMWI0=WIf@040=WIf@03002o
_`3IfMT0fMWI00L0fMWI00<0o`000=WIf@3IfMT01P3IfMT00`00_kl0fMWI0=WIf@0L0=WIf@03002o
_`3IfMT0fMWI02P0fMWI000G0=WIf@030000003IfMT0fMWI0080fMWI0P00000<0=WIf@05002o_`3I
fMT0fMWI0=WIf@3o00006@3IfMT00`3o0000fMWI0=WIf@030=WIf@03002o_`3IfMT0fMWI00d0fMWI
00<0o`000=WIf@3IfMT07@3IfMT01@00_kl0fMWI0=WIf@3IfMT0o`0000@0fMWI00<00;no0=WIf@3I
fMT02`3IfMT01@00_kl0fMWI0=WIf@3IfMT0o`0000D0fMWI00<00;no0=WIf@3IfMT03P3IfMT00`00
_kl0fMWI0=WIf@090=WIf@030?l0003IfMT0fMWI00@0fMWI00<00;no0=WIf@3IfMT01P3IfMT00`3o
0000fMWI0=WIf@070=WIf@03002o_`3IfMT0fMWI01d0fMWI00<00;no0=WIf@3IfMT09`3IfMT000h0
fMWI100000030=WIf@8000001@3IfMT00`000000fMWI0=WIf@0;0=WIf@05002o_`3IfMT0fMWI0=WI
f@3o00006@3IfMT00`3o0000fMWI0=WIf@040=WIf@03002o_`3IfMT0fMWI00/0fMWI00<0o`000=WI
f@3IfMT07@3IfMT00`00_kl0fMWI0=WIf@030=WIf@050?l0003IfMT0fMWI0=WIf@00_kl0303IfMT0
1@00_kl0fMWI0=WIf@3IfMT0o`0000H0fMWI00<00;no0=WIf@3IfMT03P3IfMT00`00_kl0fMWI0=WI
f@0:0=WIf@030?l0003IfMT0fMWI00@0fMWI00<00;no0=WIf@3IfMT01@3IfMT00`3o0000fMWI0=WI
f@060=WIf@03002o_`3IfMT0fMWI01h0fMWI00<00;no0=WIf@3IfMT01P3IfMT4002o_ad0fMWI000E
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02`3IfMT01000_kl0fMWI0=WIf@3o
000K0=WIf@030?l0003IfMT0fMWI00<0fMWI00<00;no0=WIf@3IfMT02P3IfMT00`3o0000fMWI0=WI
f@0N0=WIf@03002o_`3IfMT0fMWI00<0fMWI00<0o`000=WIf@3IfMT00P3IfMT00`00_kl0fMWI0=WI
f@090=WIf@05002o_`3IfMT0fMWI0=WIf@3o00001P3IfMT00`00_kl0fMWI0=WIf@0>0=WIf@03002o
_`3IfMT0fMWI00/0fMWI0P3o00050=WIf@03002o_`3IfMT0fMWI00<0fMWI00<0o`000=WIf@3IfMT0
1`3IfMT00`00_kl0fMWI0=WIf@0N0=WIf@03002o_`3IfMT0fMWI00H00;no8@3IfMT001D0fMWI0`00
00040=WIf@030000003IfMT0fMWI00/0fMWI00@00;no0=WIf@3IfMT0o`006`3IfMT00`3o0000fMWI
0=WIf@040=WIf@03002o_`3IfMT0fMWI00P0fMWI00<0o`000=WIf@3IfMT07P3IfMT00`00_kl0fMWI
0=WIf@050=WIf@050?l0003IfMT0fMWI0=WIf@00_kl02`3IfMT01000_kl0fMWI0=WIf@3o00070=WI
f@03002o_`3IfMT0fMWI00d0fMWI00<00;no0=WIf@3IfMT03P3IfMT20?l000@0fMWI00<00;no0=WI
f@3IfMT00P3IfMT00`3o0000fMWI0=WIf@030=WIf@@00;no8@3IfMT3002o_bL0fMWI000L0=WIf@03
0000003IfMT0fMWI00X0fMWI00D00;no0=WIf@3IfMT0fMWI0?l0000L0=WIf@030?l0003IfMT0fMWI
00<0fMWI00<00;no0=WIf@3IfMT0203IfMT00`3o0000fMWI0=WIf@0N0=WIf@03002o_`3IfMT0fMWI
00D0fMWI00D0o`000=WIf@3IfMT0fMWI002o_`0;0=WIf@04002o_`3IfMT0fMWI0?l000P0fMWI00<0
0;no0=WIf@3IfMT0303IfMT00`00_kl0fMWI0=WIf@0@0=WIf@80o`000`3IfMT01000_kl0fMWI0=WI
f@3o0006002o_dl0fMWI000L0=WIf@030000003IfMT0fMWI00X0fMWI00D00;no0=WIf@3IfMT0fMWI
0?l0000L0=WIf@030?l0003IfMT0fMWI00<0fMWI00<00;no0=WIf@3IfMT01`3IfMT00`3o0000fMWI
0=WIf@0N0=WIf@03002o_`3IfMT0fMWI00L0fMWI00D0o`000=WIf@3IfMT0fMWI002o_`090=WIf@04
002o_`3IfMT0fMWI0?l000T0fMWI00<00;no0=WIf@3IfMT0303IfMT00`00_kl0fMWI0=WIf@0B0=WI
f@80o`000P3IfMT3002o_eD0fMWI000L0=WIf@030000003IfMT0fMWI00X0fMWI00@00;no0=WIf@3I
fMT0o`007P3IfMT20?l000@0fMWI00<00;no0=WIf@3IfMT01@3IfMT00`3o0000fMWI0=WIf@0O0=WI
f@03002o_`3IfMT0fMWI00P0fMWI00@0o`000=WIf@3IfMT00;no2@3IfMT01000_kl0fMWI0=WIf@3o
00090=WIf@03002o_`3IfMT0fMWI00`0fMWI00<00;no0=WIf@3IfMT0503IfMT20?l000030=WIf@3o
0000fMWI05D0fMWI000L0=WIf@030000003IfMT0fMWI00X0fMWI00@00;no0=WIf@3IfMT0o`00803I
fMT20?l00080fMWI00<00;no0=WIf@3IfMT0103IfMT00`3o0000fMWI0=WIf@0O0=WIf@03002o_`3I
fMT0fMWI00X0fMWI00<0o`000=WIf@00_kl02@3IfMT00`00_kl0fMWI0?l0000:0=WIf@03002o_`3I
fMT0fMWI00/0fMWI00<00;no0=WIf@3IfMT05`3IfMT00`3o0000fMWI0=WIf@1E0=WIf@00703IfMT0
0`000000fMWI0=WIf@090=WIf@05002o_`3IfMT0fMWI0=WIf@3o00008P3IfMT20?l00003002o_`3I
fMT0fMWI00<0fMWI00<0o`000=WIf@3IfMT0803IfMT00`00_kl0fMWI0=WIf@0:0=WIf@030?l0003I
fMT00;no00T0fMWI00<00;no0=WIf@3o00002P3IfMT00`00_kl0fMWI0=WIf@0;0=WIf@03002o_`3I
fMT0fMWI06l0fMWI000L0=WIf@030000003IfMT0fMWI00T0fMWI00@00;no0=WIf@3IfMT0o`009@3I
fMT00`3o00000;no0=WIf@030=WIf@030?l0003IfMT0fMWI01l0fMWI00<00;no0=WIf@3IfMT0303I
fMT00`3o0000fMWI002o_`080=WIf@03002o_`3o0000fMWI00X0fMWI00<00;no0=WIf@3IfMT02`3I
fMT00`00_kl0fMWI0=WIf@1_0=WIf@00703IfMT00`000000fMWI0=WIf@090=WIf@04002o_`3IfMT0
fMWI0?l002@0fMWI0P000?l01P00_kl0o`000?l000000?l0o`000000ob40fMWI00<00;no0=WIf@3I
fMT03@3IfMT00`3o00000;no0=WIf@060=WIf@03002o_`3IfMT0o`0000`0fMWI00<00;no0=WIf@3I
fMT02P3IfMT00`00_kl0fMWI0=WIf@0B0=WIf@L0003oEP3IfMT001`0fMWI00<000000=WIf@3IfMT0
2@3IfMT01000_kl0fMWI0=WIf@3o000M0=WIf@L0003o0P3IfMT01000_kl0fMWI0=WIf@3o00020=WI
f@H0003o6P3IfMT00`00_kl0fMWI0=WIf@0>0=WIf@030?l00000_kl0fMWI00H0fMWI00<00;no0?l0
003IfMT0303IfMT00`00_kl0fMWI0=WIf@090=WIf@03002o_`3IfMT0fMWI00`0fMWI1`000?l70=WI
f@@0003oDP3IfMT001`0fMWI00<000000=WIf@3IfMT0203IfMT01000_kl0fMWI0=WIf@3o000K0=WI
f@<0003o2P3IfMT01000_kl000000000000000070=WIf@H0003o503IfMT00`00_kl0fMWI0=WIf@0?
0=WIf@030?l00000_kl0fMWI0080fMWI0`0000000`00_kl0o`000=WIf@0<0=WIf@03002o_`3IfMT0
fMWI00T0fMWI00<00;no0=WIf@3IfMT02P3IfMT20000o`X0fMWI0`0000050=WIf@@0003o;`3IfMT2
000001d0fMWI000L0=WIf@030000003IfMT0fMWI00P0fMWI00@00;no0=WIf@3IfMT0o`00603IfMT3
0000o`d0fMWI00<00;no0=WIf@3IfMT03P3IfMT60000o`h0fMWI00<00;no0=WIf@3IfMT0403IfMT0
0`00_kl0fMWI0=WIf@020=WIf@030000003IfMT00;no00h0fMWI00<00;no0=WIf@3IfMT02@3IfMT0
0`00_kl0fMWI0=WIf@070=WIf@<0003o303IfMT010000000fMWI0=WIf@0000080=WIf@P0003o9P3I
fMT010000000fMWI0=WIf@00000L0=WIf@00703IfMT00`000000fMWI0=WIf@080=WIf@04002o_`3I
fMT0fMWI0?l001D0fMWI0`000?lA0=WIf@03002o_`3IfMT0fMWI01<0fMWI20000?l60=WIf@03002o
_`3IfMT0fMWI0100fMWI00<00;no0=WIf@0000000`0000000`00_kl0o`000=WIf@0=0=WIf@03002o
_`3IfMT0fMWI00P0fMWI00<00;no0=WIf@3IfMT01P3IfMT20000o`l0fMWI00@000000=WIf@3IfMT0
0000403IfMT70000oal0fMWI00@000000=WIf@3IfMT00000703IfMT001`0fMWI00<000000=WIf@3I
fMT01`3IfMT01000_kl0fMWI0=WIf@3o000C0=WIf@<0003o503IfMT00`00_kl000000=WIf@0K0=WI
f@D0003o00<00;no0000o`3IfMT04P3IfMT01P00_kl000000=WIf@3IfMT00000002o_a00fMWI00<0
0;no0=WIf@3IfMT01`3IfMT00`00_kl0fMWI0=WIf@040=WIf@80003o4@3IfMT3000001P0fMWI1000
0?lL0=WIf@8000007@3IfMT001`0fMWI00<000000=WIf@3IfMT01@3IfMT2002o_`<0fMWI00<0o`00
0=WIf@3IfMT03@3IfMT40000oaH0fMWI00@00000002o_`3IfMT00000803IfMT01000_kl0fMWI0000
o`000?lA0=WIf@06002o_`3o000000000=WIf@0000000;no403IfMT00`00_kl0fMWI0=WIf@070=WI
f@03002o_`000?l0003o00@0003o503IfMT00`000000fMWI0=WIf@0K0=WIf@@0003o5`3IfMT01000
0000fMWI0=WIf@00000L0=WIf@00703IfMT00`000000fMWI0=WIf@040=WIf@03002o_`3IfMT0fMWI
00<0fMWI00<0o`000=WIf@3IfMT02@3IfMT40000oa/0fMWI00<00000002o_`3IfMT0803IfMT01000
_kl0fMWI0=WIf@3IfMT20000o`l0fMWI00H00;no0=WIf@3o000000000?l00000_kl@0=WIf@03002o
_`3IfMT0003o00L0003o00<00;no0=WIf@3IfMT0603IfMT3000001l0fMWI10000?lD0=WIf@800000
7@3IfMT001`0fMWI00<000000=WIf@3IfMT00`3IfMT00`00_kl0fMWI0=WIf@030=WIf@030?l0003I
fMT0fMWI00L0fMWI0`000?lP0=WIf@H00;no103IfMT8001o0100fMWI00<00;no0=WIf@3IfMT00`3I
fMT20000o`h0fMWI00D00;no0?l0003IfMT0o`00002o_`0>0=WIf@80003o00<00;no0000o`3IfMT0
1P3IfMT00`00_kl0fMWI0=WIf@0o0=WIf@@0003o;`3IfMT001`0fMWI00<000000=WIf@3IfMT00P3I
fMT00`00_kl0fMWI0=WIf@040=WIf@030?l0003IfMT0fMWI00D0fMWI0P000?lY0=WIf@L00;no1@3I
fMT6001o00X0fMWI00<00;no0=WIf@3IfMT01@3IfMT20000o`P0fMWI1000O`001000_kl007l00?l0
0000_kl;0=WIf@@0003o0P3IfMT00`00_kl0fMWI0=WIf@060=WIf@03002o_`3IfMT0fMWI04<0fMWI
10000?l[0=WIf@00703IfMT01@000000fMWI0=WIf@3IfMT00;no00L0fMWI00<0o`000=WIf@3IfMT0
0P3IfMT30000obL0fMWI1000O`060=WIf@03002o_`3IfMT0fMWI00T0fMWI0P00O`070=WIf@03002o
_`3IfMT0fMWI00P0fMWI0P000?l6001o00@0fMWI00@00;no0=WIf@3IfMT00;no0P00O`060=WIf@<0
003o1`3IfMT00`00_kl0fMWI0=WIf@050=WIf@03002o_`3IfMT0fMWI00<0fMWI0P00O`0P0=WIf@<0
07l07`3IfMT>0000oad0fMWI000L0=WIf@040000003IfMT00;no002o_`D0fMWI0P00O`00103o0000
07l00=WIf@3IfMT20000oa00fMWI0`00O`0D0=WIf@<007l02P3IfMT00`00_kl0fMWI0=WIf@0;0=WI
f@03001o003IfMT0fMWI00@0fMWI00<00;no0=WIf@3IfMT0203IfMT2001o00<0003o203IfMT00`00
_kl0fMWI002o_`020=WIf@8007l010000?l:0=WIf@03002o_`3IfMT0fMWI00D0fMWI00@00;no0=WI
f@3IfMT0fMWI0P00O`020=WIf@8007l06`3IfMT3001o00<0fMWI1000O`0g0=WIf@8000003@3IfMT0
01`0fMWI00<00000002o_`3IfMT00`00O`060?l000040=WIf@00O`0007l0001o00h0fMWI0`00O`03
0=WIf@@007l0303IfMT4001o00h0fMWI00<00;no0=WIf@3IfMT02`3IfMT2001o00@0fMWI00<00;no
0=WIf@3IfMT01`3IfMT00`00O`00fMWI0=WIf@030=WIf@H0003o0P3IfMT00`00_kl0fMWI002o_`04
0000o`8007l0303IfMT00`00_kl0fMWI0=WIf@040=WIf@03002o_`3IfMT0fMWI008007l01P3IfMT2
001o01H0fMWI0`00O`0:0=WIf@@007l05P3IfMT4001o01P0fMWI00@000000=WIf@3IfMT00000303I
fMT001H0fMWI1P0000000`00_kl0o`000?l000030?l000L0003o0`000003001o00T000000P00O`0:
000000@007l010000004001o0180000000<00;no0000000000003@0000001@00O`00000000000000
00000;no00L000000P00O`0<00000080003o0P00_kl00`000?l00000000000040000008007l02P00
00000`00_kl000000000000400000003002o_`00O`0007l000X000000`00O`0@000000<007l04@00
0007001o00T000001P00O`04000000@007l0300000080=WIf@030000003IfMT0fMWI00d0fMWI000L
0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00P3IfMT3001o00<0fMWI0`00O`00
0`000000fMWI0=WIf@0<0=WIf@0300000000O`0007l0008007l02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@03002o_`000000fMWI00d0fMWI00D00000001o0000O`00fMWI002o_`050=WIf@8007l00P3I
fMT00`000000fMWI0=WIf@0<0=WIf@03002o_`3IfMT0fMWI00L0fMWI1000O`000`000000fMWI0=WI
f@030=WIf@03002o_`3IfMT0fMWI00<0fMWI00<007l0002o_`0000003P3IfMT2001o00L0fMWI1`00
O`0<0=WIf@030000003IfMT0fMWI00`0fMWI2@00O`050=WIf@030000003IfMT0fMWI00H0fMWI1000
O`020=WIf@030000003IfMT0fMWI00X0fMWI1@00000<0=WIf@00703IfMT00`000000fMWI0=WIf@0C
0=WIf@<007l0;@3IfMT00`00_kl0fMWI0=WIf@0@0=WIf@03002o_`3IfMT0fMWI00<0fMWI00<007l0
0=WIf@3IfMT04@3IfMT00`00_kl0fMWI0=WIf@0;0=WIf@H007l000@0fMWI002o_`3IfMT0fMWI0P00
O`000`00_kl0fMWI0=WIf@0@0=WIf@L007l0?@3IfMT3001o00d0fMWI00<000000=WIf@3IfMT03@3I
fMT001`0fMWI00<000000=WIf@3IfMT0@`3IfMT00`00_kl0fMWI0=WIf@0@0=WIf@04002o_`00O`00
07l00=WIf@8007l0:03IfMT01000O`000;no001o0000O`020=WIf@03002o_`3IfMT0fMWI07@0fMWI
000L0=WIf@030000003IfMT0fMWI04@0fMWI00<00;no0=WIf@3IfMT03`3IfMT01000_kl0fMWI0=WI
f@00O`0[0=WIf@03002o_`3IfMT0fMWI0080fMWI00<00;no0=WIf@3IfMT0M03IfMT001`0fMWI00<0
00000=WIf@3IfMT0A03IfMT00`00_kl0fMWI0=WIf@0?0=WIf@03002o_`3IfMT0fMWI02`0fMWI00<0
0;no0=WIf@3IfMT00P3IfMT00`00_kl0fMWI0=WIf@1d0=WIf@00703IfMT00`000000fMWI0=WIf@14
0=WIf@03002o_`3IfMT0fMWI00l0fMWI00<00;no0=WIf@3IfMT0;03IfMT01@00_kl0fMWI0=WIf@3I
fMT00;no07L0fMWI000L0=WIf@030000003IfMT0fMWI04@0fMWI00<00;no0=WIf@3IfMT03`3IfMT0
0`00_kl0fMWI0=WIf@0/0=WIf@05002o_`3IfMT0fMWI0=WIf@00_kl0M`3IfMT001`0fMWI00<00000
0=WIf@3IfMT0A03IfMT00`00_kl0fMWI0=WIf@0>0=WIf@03002o_`3IfMT0fMWI02h0fMWI00@00;no
0=WIf@3IfMT00;noM`3IfMT001`0fMWI00<000000=WIf@3IfMT0A@3IfMT00`00_kl0fMWI0=WIf@0=
0=WIf@03002o_`3IfMT0fMWI02h0fMWI00@00;no0=WIf@3IfMT00;noM`3IfMT001`0fMWI00<00000
0=WIf@3IfMT0A@3IfMT00`00_kl0fMWI0=WIf@0=0=WIf@03002o_`3IfMT0fMWI02h0fMWI00<00;no
0=WIf@00_kl0N03IfMT001`0fMWI00<000000=WIf@3IfMT0A@3IfMT00`00_kl0fMWI0=WIf@0=0=WI
f@03002o_`3IfMT0fMWI02h0fMWI00<00;no0=WIf@00_kl0N03IfMT001`0fMWI00<000000=WIf@3I
fMT0A@3IfMT00`00_kl0fMWI0=WIf@0=0=WIf@03002o_`3IfMT0fMWI02h0fMWI00<00;no0=WIf@00
_kl0N03IfMT001`0fMWI00<000000=WIf@3IfMT0A@3IfMT00`00_kl0fMWI0=WIf@0<0=WIf@03002o
_`3IfMT0fMWI0300fMWI0P00_kmh0=WIf@00703IfMT00`000000fMWI0=WIf@160=WIf@03002o_`3I
fMT0fMWI00/0fMWI00<00;no0=WIf@3IfMT0<03IfMT00`00_kl0fMWI0=WIf@1g0=WIf@00703IfMT0
0`000000fMWI0=WIf@160=WIf@03002o_`3IfMT0fMWI00/0fMWI00<00;no0=WIf@3IfMT0<03IfMT0
0`00_kl0fMWI0=WIf@1g0=WIf@00703IfMT00`000000fMWI0=WIf@160=WIf@03002o_`3IfMT0fMWI
00/0fMWI00<00;no0=WIf@3IfMT0ZP3IfMT001`0fMWI00<000000=WIf@3IfMT0AP3IfMT00`00_kl0
fMWI0=WIf@0;0=WIf@03002o_`3IfMT0fMWI0:X0fMWI000L0=WIf@030000003IfMT0fMWI04H0fMWI
00<00;no0=WIf@3IfMT02P3IfMT00`00_kl0fMWI0=WIf@2[0=WIf@00703IfMT00`000000fMWI0=WI
f@170=WIf@03002o_`3IfMT0fMWI00T0fMWI00<00;no0=WIf@3IfMT0Z`3IfMT001D0fMWI0P000005
0=WIf@030000003IfMT0fMWI04L0fMWI00<00;no0=WIf@3IfMT02@3IfMT00`00_kl0fMWI0=WIf@2[
0=WIf@00503IfMT010000000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI04L0fMWI00<00;no
0=WIf@3IfMT02@3IfMT00`00_kl0fMWI0=WIf@2[0=WIf@005`3IfMT00`000000fMWI0=WIf@020=WI
f@800000B03IfMT00`00_kl0fMWI0=WIf@090=WIf@03002o_`3IfMT0fMWI0:/0fMWI000E0=WIf@80
00001@3IfMT00`000000fMWI0=WIf@170=WIf@03002o_`3IfMT0fMWI00P0fMWI00<00;no0=WIf@3I
fMT0[03IfMT001D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@180=WIf@03002o
_`3IfMT0fMWI00L0fMWI00<00;no0=WIf@3IfMT0[03IfMT001D0fMWI0`0000040=WIf@030000003I
fMT0fMWI04P0fMWI00<00;no0=WIf@3IfMT01`3IfMT00`00_kl0fMWI0=WIf@2/0=WIf@00703IfMT0
0`000000fMWI0=WIf@180=WIf@03002o_`3IfMT0fMWI00L0fMWI00<00;no0=WIf@3IfMT0[03IfMT0
01`0fMWI00<000000=WIf@3IfMT0B03IfMT00`00_kl0fMWI0=WIf@070=WIf@03002o_`3IfMT0fMWI
0:`0fMWI000L0=WIf@030000003IfMT0fMWI04P0fMWI00<00;no0=WIf@3IfMT01P3IfMT00`00_kl0
fMWI0=WIf@2]0=WIf@00703IfMT00`000000fMWI0=WIf@190=WIf@03002o_`3IfMT0fMWI00D0fMWI
00<00;no0=WIf@3IfMT0[@3IfMT001`0fMWI00<000000=WIf@3IfMT0B@3IfMT00`00_kl0fMWI0=WI
f@050=WIf@03002o_`3IfMT0fMWI0:d0fMWI000L0=WIf@030000003IfMT0fMWI04T0fMWI00<00;no
0=WIf@3IfMT01@3IfMT00`00_kl0fMWI0=WIf@2]0=WIf@00703IfMT00`000000fMWI0=WIf@190=WI
f@03002o_`3IfMT0fMWI00D0fMWI00<00;no0=WIf@3IfMT0[@3IfMT001`0fMWI00<000000=WIf@3I
fMT0B@3IfMT00`00_kl0fMWI0=WIf@040=WIf@03002o_`3IfMT0fMWI0:h0fMWI000L0=WIf@030000
003IfMT0fMWI04X0fMWI00<00;no0=WIf@3IfMT00`3IfMT00`00_kl0fMWI0=WIf@2^0=WIf@00703I
fMT00`000000fMWI0=WIf@1:0=WIf@03002o_`3IfMT0fMWI00<0fMWI00<00;no0=WIf@3IfMT0[P3I
fMT001`0fMWI00<000000=WIf@3IfMT0BP3IfMT00`00_kl0fMWI0=WIf@030=WIf@03002o_`3IfMT0
fMWI0:h0fMWI000L0=WIf@030000003IfMT0fMWI04X0fMWI00<00;no0=WIf@3IfMT00`3IfMT00`00
_kl0fMWI0=WIf@2^0=WIf@00703IfMT00`000000fMWI0=WIf@1:0=WIf@03002o_`3IfMT0fMWI00<0
fMWI00<00;no0=WIf@3IfMT0[P3IfMT001`0fMWI00<000000=WIf@3IfMT0B`3IfMT01@00_kl0fMWI
0=WIf@3IfMT00;no0;40fMWI000L0=WIf@030000003IfMT0fMWI04/0fMWI00D00;no0=WIf@3IfMT0
fMWI002o_`2a0=WIf@00703IfMT00`000000fMWI0=WIf@1;0=WIf@05002o_`3IfMT0fMWI0=WIf@00
_kl0/@3IfMT001`0fMWI00<000000=WIf@3IfMT0B`3IfMT01@00_kl0fMWI0=WIf@3IfMT00;no0;40
fMWI000>0=WIf@D000000P3IfMT2000000D0fMWI00<000000=WIf@3IfMT0B`3IfMT01@00_kl0fMWI
0=WIf@3IfMT00;no0;40fMWI000@0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI04`0fMWI00<00;no0=WIf@00_kl0/P3IfMT00100fMWI
00D000000=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI0080fMWI0P00001=0=WIf@03
002o_`3IfMT00;no0;80fMWI000@0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI04`0fMWI00<00;no0=WIf@00_kl0/P3IfMT00100fMWI
00D000000=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0C03IfMT00`00_kl0fMWI002o_`2b0=WIf@003`3IfMT2000000@0fMWI0P0000050=WIf@030000
003IfMT0fMWI04`0fMWI00<00;no0=WIf@00_kl0/P3IfMT001`0fMWI00<000000=WIf@3IfMT0C@3I
fMT00`00_kl0fMWI0=WIf@2a0=WIf@00703IfMT00`000000fMWI0=WIf@1=0=WIf@03002o_`3IfMT0
fMWI0;40fMWI000L0=WIf@030000003IfMT0fMWI04d0fMWI00<00;no0=WIf@3IfMT0/@3IfMT001`0
fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI
000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0
fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT004d0fMWI100000060=WIf@@000001@3IfMT2
000000P0fMWI0P00002d0=WIf@00C@3IfMT00`000000fMWI000000080=WIf@030000003IfMT00000
00D0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@2b0=WIf@008P3IfMT500000003
0=WIf@00000000000080000000P0fMWI000000000000fMWI0000003IfMT000000=WIf@@000000`3I
fMT2000000<0fMWI1@0000000`3IfMT000000000000300000080fMWI00<000000=WIf@0000000P3I
fMT5000000040=WIf@000000fMWI000000D0fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI
00<000000=WIf@3IfMT0/P3IfMT001H0fMWI2@00_kl30=WIf@@000000`3IfMT00`000000fMWI0=WI
f@020=WIf@070000003IfMT000000=WIf@000000fMWI0000000;0=WIf@@000000P3IfMT4000000<0
fMWI00<000000=WIf@000000103IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT0
1@000000fMWI0=WIf@3IfMT000000080fMWI00D000000=WIf@3IfMT0fMWI0000002d0=WIf@009@3I
fMT01@000000fMWI0=WIf@3IfMT0000000@0fMWI00D000000=WIf@000000fMWI000000020=WIf@03
0000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT01`000000fMWI0=WIf@3IfMT00000
0=WIf@000000103IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT01@000000fMWI
0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT002<0fMWI0`0000020=WIf@@00000
00H0fMWI00000000000000000=WIf@0000040=WIf@030000003IfMT0fMWI00P0fMWI0`0000030=WI
f@<000000`3IfMT00`000000fMWI000000040=WIf@070000003IfMT0fMWI0=WIf@000000fMWI0000
00050=WIf@030000003IfMT0fMWI00D000000`3IfMT00`000000fMWI0=WIf@2b0=WIf@00=03IfMT0
10000000fMWI0=WIf@00000E0=WIf@030000003IfMT0000000@0fMWI00L000000=WIf@3IfMT0fMWI
0000003IfMT0000000D0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI
0;80fMWI000e0=WIf@8000005P3IfMT400000080fMWI0P0000020=WIf@@000001@3IfMT2000000P0
fMWI0P00002d0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00C@3IfMT4000000H0fMWI10000005
0=WIf@800000203IfMT200000;@0fMWI001=0=WIf@030000003IfMT0000000P0fMWI00<000000=WI
f@0000001@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0;80fMWI000R0=WIf@D0
000000<0fMWI0000000000000P000000203IfMT000000000003IfMT000000=WIf@000000fMWI1@00
00020=WIf@8000000`3IfMT5000000030=WIf@000000000000<000000P3IfMT00`000000fMWI0000
00020=WIf@D0000000@0fMWI0000003IfMT000001@3IfMT00`000000fMWI0=WIf@020=WIf@800000
103IfMT00`000000fMWI0=WIf@2b0=WIf@005P3IfMT90?l000<0fMWI100000030=WIf@030000003I
fMT0fMWI0080fMWI00D000000=WIf@000000fMWI000000030=WIf@030000003IfMT0fMWI00L0fMWI
100000020=WIf@@000000`3IfMT00`000000fMWI000000040=WIf@070000003IfMT0fMWI0=WIf@00
0000fMWI000000050=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT01@000000fMWI0=WIf@3I
fMT000000;@0fMWI000U0=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT01@000000fMWI0000
003IfMT0000000<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@030=WIf@070000
003IfMT0fMWI0=WIf@000000fMWI000000040=WIf@070000003IfMT0fMWI0=WIf@000000fMWI0000
00050=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@2b0=WIf@008`3I
fMT300000080fMWI100000001P3IfMT00000000000000000fMWI000000@0fMWI00<000000=WIf@3I
fMT0203IfMT3000000<0fMWI0`0000030=WIf@030000003IfMT0000000@0fMWI00L000000=WIf@3I
fMT0fMWI0000003IfMT0000000D0fMWI00<000000=WIf@3IfMT01@0000030=WIf@030000003IfMT0
fMWI0;80fMWI000f0=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@000000103IfMT01`00
0000fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00<000000=WIf@3IfMT0/P3IfMT003D0fMWI0P00000F0=WIf@@000000P3IfMT200000080fMWI1000
00050=WIf@800000203IfMT200000;@0fMWI003o0=WIfB40fMWI000U0=WIf@030000003IfMT0fMWI
00@00000:03IfMT3000000030=WIf@000000fMWI00H0fMWI0P0000080=WIf@800000]03IfMT002@0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0W0=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0;80fMWI000S0=WIf@03
0000003IfMT0fMWI00D0fMWI00@000000=WIf@3IfMT0fMWI0P0000040=WIf@<0000000<0fMWI0000
000000000P3IfMT200000080fMWI0P0000030=WIf@@000000`3IfMT2000000@0fMWI0`0000040=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI00<000000=WI
f@3IfMT0/P3IfMT002<0fMWI00<000000=WIf@3IfMT01@3IfMT010000000fMWI0=WIf@0000020=WI
f@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0
fMWI00000080fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000040=WIf@03
0000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@050000003IfMT0fMWI
0=WIf@000000]03IfMT001H0fMWI2@00O`040=WIf@030000003IfMT0fMWI00D0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WIf@0000000P3I
fMT010000000fMWI0=WIf@0000060=WIf@030000003IfMT0fMWI00P0fMWI00@000000=WIf@3IfMT0
0000103IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`00
0000fMWI0=WIf@2b0=WIf@008`3IfMT00`000000fMWI0=WIf@020=WIf@@000000`3IfMT2000000@0
fMWI0P0000020=WIf@@000000P3IfMT5000000@0fMWI00<000000=WIf@3IfMT0203IfMT4000000<0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@05000000<0fMWI00<000000=WIf@3I
fMT0/P3IfMT002@0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@030=WIf@040000
003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT00000
00H0fMWI00<000000=WIf@3IfMT0/P3IfMT002D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@090=WIf@030000003IfMT0fMWI00h0fMWI0P00000?0=WIf@030000003IfMT0fMWI00D0
fMWI0P0000080=WIf@800000]03IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT002D0fMWI00<00000
0=WIf@3IfMT01000000X0=WIf@<0000000<0fMWI0000003IfMT01P3IfMT2000000P0fMWI0P00002d
0=WIf@00903IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI02L0fMWI00D000000=WI
f@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0/P3IfMT0
02<0fMWI00<000000=WIf@3IfMT01@3IfMT010000000fMWI0=WIf@3IfMT2000000@0fMWI0`000000
0`3IfMT00000000000020=WIf@8000000P3IfMT2000000<0fMWI1@0000020=WIf@800000103IfMT3
000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@800000103IfMT0
0`000000fMWI0=WIf@2b0=WIf@008`3IfMT00`000000fMWI0=WIf@050=WIf@040000003IfMT0fMWI
00000080fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00@0
00000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00L0fMWI
00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WI
f@0000000P3IfMT01@000000fMWI0=WIf@3IfMT000000;@0fMWI000F0=WIf@T0003o103IfMT00`00
0000fMWI0=WIf@050=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT00P3IfMT0
1@000000fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000001`3IfMT00`000000fMWI
0=WIf@070=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT002<0fMWI00<000000=WIf@3I
fMT00P3IfMT4000000<0fMWI0P0000040=WIf@8000000P3IfMT400000080fMWI1@0000040=WIf@03
0000003IfMT0fMWI00P0fMWI100000030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT01@0000030=WIf@030000003IfMT0fMWI0;80fMWI000T0=WIf@030000003IfMT0fMWI01T0fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00@0fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0;80fMWI000U0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0>0=WIf@800000
3`3IfMT00`000000fMWI0=WIf@050=WIf@800000203IfMT200000;@0fMWI003o0=WIfB40fMWI003o
0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o
0=WIfB40fMWI0000\
\>"],
  ImageRangeCache->{{{138, 425}, {617.25, 404}} -> {-2.06252, 2.30482, \
0.00732689, 0.00732689}, {{145, 417.938}, {612.125, 443.438}} -> {-5.7716, \
65.2898, 0.0347642, 0.221835}, {{158.625, 295.125}, {450, 409.063}} -> \
{-19.1203, 27.891, 0.119891, 0.11823}, {{160.125, 168.438}, {448.438, 440}} -> \
{-39.5267, 55.572, 0.240604, 0.240604}, {{160.125, 168.438}, {438.625, \
430.188}} -> {-39.5267, 53.2111, 0.240604, 0.240604}, {{160.125, 168.438}, \
{428.813, 420.375}} -> {-39.5267, 50.8501, 0.240604, 0.240604}, {{160.125, \
168.438}, {419, 410.563}} -> {-39.5267, 48.4892, 0.240604, 0.240604}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74402 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.312017 0.47619 [
[ 0 0 0 0 ]
[ 1 .74402 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0177147 0.97619 0.606318 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.574089 0.0367285 [
[.2619 .56159 -3 -9 ]
[.2619 .56159 3 0 ]
[.5 .56159 -3 -9 ]
[.5 .56159 3 0 ]
[.7381 .56159 -3 -9 ]
[.7381 .56159 3 0 ]
[.97619 .56159 -3 -9 ]
[.97619 .56159 3 0 ]
[1.025 .57409 0 -6.28125 ]
[1.025 .57409 10 6.28125 ]
[.01131 .02316 -18 -4.5 ]
[.01131 .02316 0 4.5 ]
[.01131 .11498 -30 -4.5 ]
[.01131 .11498 0 4.5 ]
[.01131 .2068 -18 -4.5 ]
[.01131 .2068 0 4.5 ]
[.01131 .29863 -24 -4.5 ]
[.01131 .29863 0 4.5 ]
[.01131 .39045 -12 -4.5 ]
[.01131 .39045 0 4.5 ]
[.01131 .48227 -24 -4.5 ]
[.01131 .48227 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .57409 m
.2619 .58034 L
s
[(2)] .2619 .56159 0 1 Mshowa
.5 .57409 m
.5 .58034 L
s
[(4)] .5 .56159 0 1 Mshowa
.7381 .57409 m
.7381 .58034 L
s
[(6)] .7381 .56159 0 1 Mshowa
.97619 .57409 m
.97619 .58034 L
s
[(8)] .97619 .56159 0 1 Mshowa
.125 Mabswid
.08333 .57409 m
.08333 .57784 L
s
.14286 .57409 m
.14286 .57784 L
s
.20238 .57409 m
.20238 .57784 L
s
.32143 .57409 m
.32143 .57784 L
s
.38095 .57409 m
.38095 .57784 L
s
.44048 .57409 m
.44048 .57784 L
s
.55952 .57409 m
.55952 .57784 L
s
.61905 .57409 m
.61905 .57784 L
s
.67857 .57409 m
.67857 .57784 L
s
.79762 .57409 m
.79762 .57784 L
s
.85714 .57409 m
.85714 .57784 L
s
.91667 .57409 m
.91667 .57784 L
s
.25 Mabswid
0 .57409 m
1 .57409 L
s
gsave
1.025 .57409 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .02316 m
.03006 .02316 L
s
[(-15)] .01131 .02316 1 0 Mshowa
.02381 .11498 m
.03006 .11498 L
s
[(-12.5)] .01131 .11498 1 0 Mshowa
.02381 .2068 m
.03006 .2068 L
s
[(-10)] .01131 .2068 1 0 Mshowa
.02381 .29863 m
.03006 .29863 L
s
[(-7.5)] .01131 .29863 1 0 Mshowa
.02381 .39045 m
.03006 .39045 L
s
[(-5)] .01131 .39045 1 0 Mshowa
.02381 .48227 m
.03006 .48227 L
s
[(-2.5)] .01131 .48227 1 0 Mshowa
.125 Mabswid
.02381 .04153 m
.02756 .04153 L
s
.02381 .05989 m
.02756 .05989 L
s
.02381 .07825 m
.02756 .07825 L
s
.02381 .09662 m
.02756 .09662 L
s
.02381 .13335 m
.02756 .13335 L
s
.02381 .15171 m
.02756 .15171 L
s
.02381 .17008 m
.02756 .17008 L
s
.02381 .18844 m
.02756 .18844 L
s
.02381 .22517 m
.02756 .22517 L
s
.02381 .24353 m
.02756 .24353 L
s
.02381 .2619 m
.02756 .2619 L
s
.02381 .28026 m
.02756 .28026 L
s
.02381 .31699 m
.02756 .31699 L
s
.02381 .33535 m
.02756 .33535 L
s
.02381 .35372 m
.02756 .35372 L
s
.02381 .37208 m
.02756 .37208 L
s
.02381 .40881 m
.02756 .40881 L
s
.02381 .42718 m
.02756 .42718 L
s
.02381 .44554 m
.02756 .44554 L
s
.02381 .4639 m
.02756 .4639 L
s
.02381 .50063 m
.02756 .50063 L
s
.02381 .519 m
.02756 .519 L
s
.02381 .53736 m
.02756 .53736 L
s
.02381 .55572 m
.02756 .55572 L
s
.02381 .0048 m
.02756 .0048 L
s
.02381 .59245 m
.02756 .59245 L
s
.02381 .61082 m
.02756 .61082 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 1 r
.001 w
.02381 .57409 m
.07143 .57092 L
.11905 .5591 L
.16667 .53532 L
.21429 .5064 L
.2619 .48863 L
.30952 .48467 L
.35714 .48968 L
.40476 .49857 L
.45238 .50681 L
.5 .51802 L
.54762 .5291 L
.59524 .53486 L
.64286 .53403 L
.69048 .52639 L
.7381 .51827 L
.78571 .51279 L
.83333 .50972 L
.88095 .50888 L
.92857 .50796 L
.97619 .5103 L
s
0 .5 0 r
.02381 .57409 m
.07143 .56238 L
.11905 .5379 L
.16667 .53821 L
.21429 .58007 L
.2619 .60332 L
.30952 .59592 L
.35714 .57964 L
.40476 .5741 L
.45238 .58619 L
.5 .58866 L
.54762 .57474 L
.59524 .55977 L
.64286 .55497 L
.69048 .56606 L
.7381 .57673 L
.78571 .57721 L
.83333 .57273 L
.88095 .57096 L
.92857 .5794 L
.97619 .58368 L
s
1 0 0 r
.02381 .57409 m
.07143 .54302 L
.11905 .43108 L
.16667 .26054 L
.21429 .22705 L
.2619 .3119 L
.30952 .34003 L
.35714 .30495 L
.40476 .25541 L
.45238 .22597 L
.5 .21413 L
.54762 .23514 L
.59524 .25835 L
.64286 .25451 L
.69048 .22704 L
.7381 .21425 L
.78571 .21552 L
.83333 .21972 L
.88095 .22129 L
.92857 .22325 L
.97619 .21874 L
s
0 .75 .75 r
.02381 .57409 m
.07143 .44856 L
.11905 .30019 L
.16667 .16128 L
.21429 .01472 L
.2619 .3132 L
.30952 .28888 L
.35714 .25748 L
.40476 .23072 L
.45238 .20462 L
.5 .19949 L
.54762 .21011 L
.59524 .24392 L
.64286 .25564 L
.69048 .1858 L
.7381 .20456 L
.78571 .20911 L
.83333 .22036 L
.88095 .22968 L
.92857 .22238 L
.97619 .21702 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0714286 0.583445 0.547619 0.726302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00611247 0.0611247 0.00619835 0.0619835 [
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0110024 0.011157 0.0721271 0.0731405 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .75 .75 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .04215 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arm2) show
87.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(aa) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(P) show
111.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(T) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.0830579 0.0721271 0.145041 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .11405 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arm1) show
87.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(aa) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(P) show
111.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(T) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.154959 0.0721271 0.216942 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .5 0 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .18595 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(joint2) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.22686 0.0721271 0.288843 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .25785 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(joint1) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(L) show
123.000 12.813 moveto
(@) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .74402 L
0 .74402 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 214.25},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eR000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@009`3IfMT00`000000fMWI0=WI
f@3f0=WIf@009`3IfMT200000?L0fMWI000W0=WIf@030000003IfMT0fMWI0?H0fMWI000J0=WIf@D0
00000P3IfMT2000000@0fMWI00<000000=WIf@3IfMT0:@3IfMT00`00_kl0fMWI0=WIf@3:0=WIf@00
703IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00D000000=WIf@3IfMT0fMWI0000000[0=WI
f@03002o_`3IfMT0fMWI0<X0fMWI000L0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3I
fMT0fMWI0`00000X0=WIf@800;noc03IfMT001@0fMWI100000040=WIf@030000003IfMT0fMWI0080
fMWI0P0000040=WIf@030000003IfMT0fMWI02P0fMWI0P00_ko<0=WIf@00703IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0:03IfMT00`00_kl0fMWI
002o_`3;0=WIf@006`3IfMT2000000@0fMWI0`0000030=WIf@030000003IfMT0fMWI02L0fMWI00@0
0;no0=WIf@3IfMT00;nob`3IfMT002L0fMWI0P00000X0=WIf@04002o_`3IfMT0fMWI002o_l/0fMWI
000W0=WIf@030000003IfMT0fMWI02L0fMWI00@00;no0=WIf@3IfMT00;nob`3IfMT002L0fMWI00<0
00000=WIf@3IfMT09P3IfMT01@00_kl0fMWI0=WIf@3IfMT00;no0</0fMWI000W0=WIf@030000003I
fMT0fMWI02H0fMWI00D00;no0=WIf@3IfMT0fMWI002o_`3;0=WIf@009`3IfMT2000002L0fMWI00<0
0;no0=WIf@3IfMT00P3IfMT00`00_kl0fMWI0=WIf@380=WIf@009`3IfMT00`000000fMWI0=WIf@0U
0=WIf@03002o_`3IfMT0fMWI00<0fMWI00<00;no0=WIf@3IfMT0b03IfMT002L0fMWI00<000000=WI
f@3IfMT09@3IfMT00`00_kl0fMWI0=WIf@030=WIf@03002o_`3IfMT0fMWI0<P0fMWI000W0=WIf@03
0000003IfMT0fMWI02D0fMWI00<00;no0=WIf@3IfMT00`3IfMT00`00_kl0fMWI0=WIf@380=WIf@00
9`3IfMT00`000000fMWI0=WIf@0T0=WIf@03002o_`3IfMT0fMWI00@0fMWI00<00;no0=WIf@3IfMT0
b03IfMT002L0fMWI0P00000U0=WIf@03002o_`3IfMT0fMWI00@0fMWI00<00;no0=WIf@3IfMT0b03I
fMT002L0fMWI00<000000=WIf@3IfMT0903IfMT00`00_kl0fMWI0=WIf@050=WIf@03002o_`3IfMT0
fMWI0<L0fMWI000W0=WIf@030000003IfMT0fMWI02@0fMWI00<00;no0=WIf@3IfMT01@3IfMT00`00
_kl0fMWI0=WIf@370=WIf@009`3IfMT00`000000fMWI0=WIf@0S0=WIf@03002o_`3IfMT0fMWI00H0
fMWI00<00;no0=WIf@3IfMT0a`3IfMT002L0fMWI0P00000T0=WIf@03002o_`3IfMT0fMWI00H0fMWI
00<00;no0=WIf@3IfMT0a`3IfMT002L0fMWI00<000000=WIf@3IfMT08`3IfMT00`00_kl0fMWI0=WI
f@060=WIf@03002o_`3IfMT0fMWI0<L0fMWI000>0=WIf@D0000000<0fMWI0000000000000P000003
0=WIf@800000103IfMT2000000@0fMWI00<000000=WIf@3IfMT08P3IfMT00`00_kl0fMWI0=WIf@07
0=WIf@03002o_`3IfMT0fMWI0<L0fMWI000@0=WIf@050000003IfMT0fMWI0=WIf@0000002`3IfMT0
10000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI0280fMWI00<00;no0=WIf@3IfMT0203I
fMT00`00_kl0fMWI0=WIf@360=WIf@00403IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00/0fMWI00@000000=WIf@3IfMT0fMWI0`00000R0=WIf@03002o_`3IfMT0fMWI00P0fMWI00<0
0;no0=WIf@3IfMT0aP3IfMT000P0fMWI100000040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0203IfMT2000000@0fMWI00<000000=WIf@3IfMT08@3IfMT00`00_kl0fMWI0=WIf@09
0=WIf@03002o_`3IfMT0fMWI0<H0fMWI000@0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT0
0`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`00_kl0fMWI0=WIf@090=WIf@03002o_`3IfMT0fMWI0<H0fMWI000?0=WIf@800000103IfMT20000
00X0fMWI0`0000030=WIf@030000003IfMT0fMWI0240fMWI00<00;no0=WIf@3IfMT02@3IfMT00`00
_kl0fMWI0=WIf@360=WIf@009`3IfMT200000240fMWI00<00;no0=WIf@3IfMT02P3IfMT00`00_kl0
fMWI0=WIf@360=WIf@009`3IfMT00`000000fMWI0=WIf@0P0=WIf@03002o_`3IfMT0fMWI00X0fMWI
00<00;no0=WIf@3IfMT0aP3IfMT002L0fMWI00<000000=WIf@3IfMT0803IfMT00`00_kl0fMWI0=WI
f@0;0=WIf@03002o_`3IfMT0fMWI0<D0fMWI000W0=WIf@030000003IfMT0fMWI01l0fMWI00<00;no
0=WIf@3IfMT0303IfMT00`00_kl0fMWI0=WIf@350=WIf@009`3IfMT00`000000fMWI0=WIf@0O0=WI
f@03002o_`3IfMT0fMWI00`0fMWI00<00;no0=WIf@3IfMT0a@3IfMT002L0fMWI0P00000P0=WIf@03
002o_`3IfMT0fMWI00`0fMWI00<00;no0=WIf@3IfMT0a@3IfMT002L0fMWI00<000000=WIf@3IfMT0
7P3IfMT00`00_kl0fMWI0=WIf@0=0=WIf@03002o_`3IfMT0fMWI0<D0fMWI000W0=WIf@030000003I
fMT0fMWI01h0fMWI00<00;no0=WIf@3IfMT03@3IfMT00`00_kl0fMWI0=WIf@350=WIf@009`3IfMT0
0`000000fMWI0=WIf@0N0=WIf@03002o_`3IfMT0fMWI00h0fMWI00<00;no0=WIf@3IfMT0a03IfMT0
02L0fMWI0P00000N0=WIf@03002o_`3IfMT0fMWI00l0fMWI00<00;no0=WIf@3IfMT0a03IfMT002L0
fMWI00<000000=WIf@3IfMT07@3IfMT00`00_kl0fMWI0=WIf@0?0=WIf@03002o_`3IfMT0fMWI0<@0
fMWI000W0=WIf@030000003IfMT0fMWI01d0fMWI00<00;no0=WIf@3IfMT03`3IfMT00`00_kl0fMWI
0=WIf@340=WIf@009`3IfMT00`000000fMWI0=WIf@0L0=WIf@03002o_`3IfMT0fMWI0100fMWI00<0
0;no0=WIf@3IfMT0I@3IfMT2002o_ed0fMWI000W0=WIf@8000007@3IfMT00`00_kl0fMWI0=WIf@0@
0=WIf@03002o_`3IfMT0fMWI06@0fMWI00<00;no0=WIf@3IfMT00P00_kmK0=WIf@009`3IfMT00`00
0000fMWI0=WIf@0L0=WIf@03002o_`3IfMT0fMWI0140fMWI00<00;no0=WIf@3IfMT0H`3IfMT00`00
_kl0fMWI0=WIf@020=WIf@800;noF@3IfMT001X0fMWI1@0000020=WIf@800000103IfMT00`000000
fMWI0=WIf@0K0=WIf@03002o_`3IfMT0fMWI0180fMWI00<00;no0=WIf@3IfMT0HP3IfMT00`00_kl0
fMWI0=WIf@050=WIf@800;noE`3IfMT001`0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@05
0000003IfMT0fMWI0=WIf@0000007@3IfMT00`00_kl0fMWI0=WIf@0B0=WIf@03002o_`3IfMT0fMWI
03<0fMWI2000_klV0=WIf@03002o_`3IfMT0fMWI00P0fMWI0P00_kmE0=WIf@00703IfMT01@000000
fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT0fMWI0`00000K0=WIf@03002o_`3IfMT0
fMWI0180fMWI00<00;no0=WIf@3IfMT0;@3IfMT6002o_`P0fMWI1P00_klP0=WIf@03002o_`3IfMT0
fMWI00X0fMWI1P00_km?0=WIf@00503IfMT4000000@0fMWI00D000000=WIf@3IfMT0fMWI00000002
0=WIf@050000003IfMT0fMWI0=WIf@000000703IfMT00`00_kl0fMWI0=WIf@0C0=WIf@03002o_`3I
fMT0fMWI02/0fMWI0P00_klD0=WIf@<00;no703IfMT00`00_kl0fMWI0=WIf@0A0=WIf@P00;noA`3I
fMT001`0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@050000003IfMT0fMWI0=WIf@000000
703IfMT00`00_kl0fMWI0=WIf@0C0=WIf@03002o_`3IfMT0fMWI02T0fMWI0P00_kl<0=WIf@<0o`00
2P3IfMT2002o_aT0fMWI00<00;no0=WIf@3IfMT0303IfMT>0?l000H00;no@@3IfMT001/0fMWI0P00
00040=WIf@800000103IfMT00`000000fMWI0=WIf@0J0=WIf@03002o_`3IfMT0fMWI01<0fMWI00<0
0;no0=WIf@3IfMT09`3IfMT2002o_`X0fMWI103o00030=WIf@80o`002P3IfMT00`00_kl0fMWI0=WI
f@0F0=WIf@03002o_`3IfMT0fMWI00P0fMWI103o000A0=WIf@<0o`001@00_kl30?l001H0fMWI1P00
_klM0=WIf@009`3IfMT2000001X0fMWI00<00;no0=WIf@3IfMT05@3IfMT00`00_kl0fMWI0=WIf@0T
0=WIf@800;no203IfMT40?l000T0fMWI0P3o00090=WIf@03002o_`3IfMT0fMWI01@0fMWI00<00;no
0=WIf@3IfMT01@3IfMT40?l001d0fMWI1P00_kl80?l000/00;no8`3IfMT002L0fMWI00<000000=WI
f@3IfMT06@3IfMT00`00_kl0fMWI0=WIf@0=0=WIf@030?l0003IfMT0fMWI00D0fMWI00<00;no0=WI
f@3IfMT08P3IfMT2002o_`P0fMWI0P3o000?0=WIf@80o`00203IfMT2002o_a<0fMWI00<00;no0=WI
f@3IfMT0103IfMT20?l002L0fMWI2000_kl^0=WIf@009`3IfMT00`000000fMWI0=WIf@0I0=WIf@03
002o_`3IfMT0fMWI00/0fMWI0P3o00000`3IfMT0o`000=WIf@050=WIf@03002o_`3IfMT0fMWI0240
fMWI00<00;no0=WIf@3IfMT01P3IfMT20?l001<0fMWI0P3o00080=WIf@03002o_`3IfMT0fMWI00l0
fMWI00<00;no0=WIf@3IfMT00`3IfMT20?l005l0fMWI000W0=WIf@030000003IfMT0fMWI01P0fMWI
00<00;no0=WIf@3IfMT02`3IfMT01@3o0000fMWI0=WIf@3IfMT0o`0000H0fMWI00<00;no0=WIf@3I
fMT07`3IfMT2002o_`L0fMWI0P3o000G0=WIf@<0o`001P3IfMT00`00_kl0fMWI0=WIf@0>0=WIf@04
002o_`3IfMT0fMWI0=WIf@80o`00H@3IfMT002L0fMWI00<000000=WIf@3IfMT0603IfMT00`00_kl0
fMWI0=WIf@0:0=WIf@030?l0003IfMT0fMWI00<0fMWI00<0o`000=WIf@3IfMT00`3IfMT00`00_kl0
fMWI0=WIf@0M0=WIf@800;no1`3IfMT20?l001`0fMWI0P3o00050=WIf@800;no3@3IfMT00`00_kl0
fMWI0=WIf@020?l006<0fMWI000W0=WIf@800000603IfMT00`00_kl0fMWI0=WIf@090=WIf@80o`00
1P3IfMT00`3o0000fMWI0=WIf@030=WIf@03002o_`3IfMT0fMWI01/0fMWI0P00_kl70=WIf@80o`00
803IfMT20?l000D0fMWI0`00_kl90=WIf@04002o_`3IfMT0o`000?l006D0fMWI000W0=WIf@030000
003IfMT0fMWI01L0fMWI00<00;no0=WIf@3IfMT0203IfMT00`3o0000fMWI0=WIf@070=WIf@030?l0
003IfMT0fMWI00<0fMWI00<00;no0=WIf@3IfMT0603IfMT2002o_`L0fMWI0P3o000T0=WIf@80o`00
1P3IfMT6002o_`<0fMWI00<00;no0?l0003IfMT0IP3IfMT002L0fMWI00<000000=WIf@3IfMT05`3I
fMT00`00_kl0fMWI0=WIf@070=WIf@030?l0003IfMT0fMWI00P0fMWI00<0o`000=WIf@3IfMT00`3I
fMT00`00_kl0fMWI0=WIf@0F0=WIf@800;no203IfMT00`3o0000fMWI0=WIf@0V0=WIf@80o`001`3I
fMT30?l000<00;noJ@3IfMT002L0fMWI00<000000=WIf@3IfMT05P3IfMT00`00_kl0fMWI0=WIf@06
0=WIf@80o`00303IfMT00`3o0000fMWI0=WIf@020=WIf@03002o_`3IfMT0fMWI01D0fMWI00<00;no
0=WIf@3IfMT01`3IfMT00`3o0000fMWI0=WIf@0Y0=WIf@L0o`00K`3IfMT002L0fMWI0P00000G0=WI
f@03002o_`3IfMT0fMWI00D0fMWI00<0o`000=WIf@3IfMT03@3IfMT01@3o0000fMWI0=WIf@3IfMT0
0;no01D0fMWI0P00_kl90=WIf@030?l0003IfMT0fMWI0:00fMWI000W0=WIf@030000003IfMT0fMWI
01H0fMWI00<00;no0=WIf@3IfMT01@3IfMT00`3o0000fMWI0=WIf@0=0=WIf@050?l0003IfMT0fMWI
0=WIf@00_kl0503IfMT00`00_kl0fMWI0=WIf@080=WIf@030?l0003IfMT0fMWI0:40fMWI000W0=WI
f@030000003IfMT0fMWI01D0fMWI00<00;no0=WIf@3IfMT01@3IfMT00`3o0000fMWI0=WIf@0?0=WI
f@040?l0003IfMT0fMWI002o_a80fMWI0P00_kl:0=WIf@030?l0003IfMT0fMWI0:80fMWI000W0=WI
f@030000003IfMT0fMWI01D0fMWI00<00;no0=WIf@3IfMT01@3IfMT00`3o0000fMWI0=WIf@0?0=WI
f@050?l0003IfMT0fMWI0=WIf@00_kl03`3IfMT2002o_`/0fMWI00<0o`000=WIf@3IfMT0X`3IfMT0
02L0fMWI0P00000F0=WIf@03002o_`3IfMT0fMWI00D0fMWI00<0o`000=WIf@3IfMT0403IfMT0103o
0000fMWI0=WIf@00_kl>0=WIf@03002o_`3IfMT0fMWI00/0fMWI00<0o`000=WIf@3IfMT0X`3IfMT0
02L0fMWI00<000000=WIf@3IfMT0503IfMT00`00_kl0fMWI0=WIf@060=WIf@030?l0003IfMT0fMWI
0140fMWI00<0o`000=WIf@00_kl0303IfMT2002o_`d0fMWI00<0o`000=WIf@3IfMT0Y03IfMT001H0
fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI0P0000040=WIf@030000003IfMT0fMWI01@0
fMWI00<00;no0=WIf@3IfMT01@3IfMT00`3o0000fMWI0=WIf@0B0=WIf@030?l0003IfMT00;no00/0
fMWI00<00;no0=WIf@3IfMT0303IfMT00`3o0000fMWI0=WIf@2U0=WIf@005P3IfMT00`000000fMWI
0=WIf@070=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0503IfMT00`00_kl0
fMWI0=WIf@050=WIf@030?l0003IfMT0fMWI01<0fMWI00<0o`00002o_`3IfMT0203IfMT2002o_`h0
fMWI00<0o`000=WIf@3IfMT0YP3IfMT001H0fMWI00<000000=WIf@3IfMT02P3IfMT010000000fMWI
0=WIf@3IfMT3000001<0fMWI00<00;no0=WIf@3IfMT01P3IfMT00`3o0000fMWI0=WIf@0C0=WIf@03
0?l00000_kl0fMWI00H0fMWI0P00_kl?0=WIf@030?l0003IfMT0fMWI0:L0fMWI000>0=WIf@@00000
1@3IfMT00`000000fMWI0=WIf@070=WIf@800000103IfMT00`000000fMWI0=WIf@0C0=WIf@03002o
_`3IfMT0fMWI00D0fMWI00<0o`000=WIf@3IfMT05@3IfMT00`3o00000;no0=WIf@030=WIf@800;no
403IfMT00`3o0000fMWI0=WIf@2X0=WIf@00503IfMT010000000fMWI0=WIf@0000090=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT04`3IfMT00`00_kl0fMWI0=WIf@050=WIf@030?l0
003IfMT0fMWI01D0fMWI00@0o`00002o_`3IfMT0fMWI0P00_klA0=WIf@030?l0003IfMT0fMWI0:T0
fMWI000D0=WIf@@000002@3IfMT3000000<0fMWI00<000000=WIf@3IfMT04P3IfMT00`00_kl0fMWI
0=WIf@060=WIf@030?l0003IfMT0fMWI01H0fMWI0`00_klA0=WIf@80o`00[03IfMT002L0fMWI00<0
00000=WIf@3IfMT04P3IfMT00`00_kl0fMWI0=WIf@060=WIf@030?l0003IfMT0fMWI01H0fMWI00<0
0;no0?l0003o0000403IfMT00`3o0000fMWI0=WIf@2/0=WIf@009`3IfMT2000001<0fMWI00<00;no
0=WIf@3IfMT01@3IfMT00`3o0000fMWI0=WIf@0J0=WIf@030?l0003IfMT0fMWI00`0fMWI00<0o`00
0=WIf@3IfMT0[@3IfMT002L0fMWI00<000000=WIf@3IfMT04@3IfMT00`00_kl0fMWI0=WIf@060=WI
f@030?l0003IfMT0fMWI01/0fMWI0P3o000:0=WIf@80o`00/03IfMT002L0fMWI00<000000=WIf@3I
fMT04@3IfMT00`00_kl0fMWI0=WIf@060=WIf@030?l0003IfMT0fMWI01d0fMWI0P3o00070=WIf@03
0?l0003IfMT0fMWI0;00fMWI000W0=WIf@030000003IfMT0fMWI0140fMWI00<00;no0=WIf@3IfMT0
1@3IfMT00`3o0000fMWI0=WIf@0P0=WIf@030?l0003IfMT0fMWI00<0fMWI00<0o`000=WIf@3IfMT0
/@3IfMT002L0fMWI0P00000A0=WIf@03002o_`3IfMT0fMWI00H0fMWI00<0o`000=WIf@3IfMT08@3I
fMT20?l000030=WIf@3o0000o`000;@0fMWI000W0=WIf@030000003IfMT0fMWI0100fMWI00<00;no
0=WIf@3IfMT01P3IfMT00`3o0000fMWI0=WIf@0S0=WIf@030?l0003IfMT0fMWI0;@0fMWI000W0=WI
f@030000003IfMT0fMWI0100fMWI00<00;no0=WIf@3IfMT01P3IfMT00`3o0000fMWI0=WIf@3J0=WI
f@009`3IfMT00`000000fMWI0=WIf@0?0=WIf@03002o_`3IfMT0fMWI00H0fMWI00<0o`000=WIf@3I
fMT0f`3IfMT002L0fMWI0P00000@0=WIf@03002o_`3IfMT0fMWI00H0fMWI00<0o`000=WIf@3IfMT0
f`3IfMT002L0fMWI00<000000=WIf@3IfMT03`3IfMT00`00_kl0fMWI0=WIf@060=WIf@030?l0003I
fMT0fMWI0=/0fMWI000W0=WIf@030000003IfMT0fMWI00h0fMWI00<00;no0=WIf@3IfMT01`3IfMT0
0`3o0000fMWI0=WIf@3K0=WIf@009`3IfMT00`000000fMWI0=WIf@0>0=WIf@03002o_`3IfMT0fMWI
00H0fMWI00<0o`000=WIf@3IfMT0g03IfMT002L0fMWI0P00000?0=WIf@03002o_`3IfMT0fMWI00H0
fMWI00<0o`000=WIf@3IfMT0g03IfMT002L0fMWI00<000000=WIf@3IfMT03P3IfMT00`00_kl0fMWI
0=WIf@060=WIf@030?l0003IfMT0fMWI0=`0fMWI000Q0=WIf@800000103IfMT00`000000fMWI0=WI
f@0=0=WIf@03002o_`3IfMT0fMWI00H0fMWI00<0o`000=WIf@3IfMT0g@3IfMT00200fMWI00@00000
0=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0=0=WIf@03002o_`3IfMT0fMWI00H0fMWI00<0
o`000=WIf@3IfMT0g@3IfMT002<0fMWI00@000000=WIf@3IfMT0fMWI0`00000=0=WIf@03002o_`3I
fMT0fMWI00H0fMWI00<0o`000=WIf@3IfMT0g@3IfMT001X0fMWI100000030=WIf@800000103IfMT0
0`000000fMWI0=WIf@0<0=WIf@03002o_`3IfMT0fMWI00L0fMWI00<0o`000=WIf@3IfMT0g@3IfMT0
0240fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0<0=WIf@03002o_`3IfMT0fMWI
00H0fMWI00<0o`000=WIf@3IfMT0gP3IfMT00240fMWI0`0000030=WIf@030000003IfMT0fMWI00`0
fMWI00<00;no0=WIf@3IfMT01P3IfMT00`3o0000fMWI0=WIf@3N0=WIf@009`3IfMT00`000000fMWI
0=WIf@0;0=WIf@03002o_`3IfMT0fMWI00L0fMWI00<0o`000=WIf@3IfMT0gP3IfMT002L0fMWI0P00
000<0=WIf@03002o_`3IfMT0fMWI00H0fMWI00<0o`000=WIf@3IfMT0g`3IfMT002L0fMWI00<00000
0=WIf@3IfMT02`3IfMT00`00_kl0fMWI0=WIf@060=WIf@030?l0003IfMT0fMWI0=l0fMWI000W0=WI
f@030000003IfMT0fMWI00X0fMWI00<00;no0=WIf@3IfMT01`3IfMT00`3o0000fMWI0=WIf@3O0=WI
f@009`3IfMT00`000000fMWI0=WIf@0:0=WIf@03002o_`3IfMT0fMWI00L0fMWI00<0o`000=WIf@3I
fMT0g`3IfMT002L0fMWI0P00000;0=WIf@03002o_`3IfMT0fMWI00H0fMWI00<0o`000=WIf@3IfMT0
h03IfMT002L0fMWI00<000000=WIf@3IfMT02@3IfMT00`00_kl0fMWI0=WIf@070=WIf@030?l0003I
fMT0fMWI0>00fMWI000W0=WIf@030000003IfMT0fMWI00T0fMWI00<00;no0=WIf@3IfMT01`3IfMT0
0`3o0000fMWI0=WIf@3P0=WIf@009`3IfMT00`000000fMWI0=WIf@090=WIf@03002o_`3IfMT0fMWI
00H0fMWI00<0o`000=WIf@3IfMT0h@3IfMT002L0fMWI0P0000090=WIf@03002o_`3IfMT0fMWI00L0
fMWI00<0o`000=WIf@3IfMT0h@3IfMT002L0fMWI00<000000=WIf@3IfMT0203IfMT00`00_kl0fMWI
0=WIf@060=WIf@030?l0003IfMT0fMWI0>80fMWI000W0=WIf@030000003IfMT0fMWI00P0fMWI00<0
0;no0=WIf@3IfMT01P3IfMT00`3o0000fMWI0=WIf@3R0=WIf@009`3IfMT00`000000fMWI0=WIf@07
0=WIf@03002o_`3IfMT0fMWI00H0fMWI00<0o`000=WIf@3IfMT0h`3IfMT002L0fMWI0P0000080=WI
f@03002o_`3IfMT0fMWI00H0fMWI00<0o`000=WIf@3IfMT0h`3IfMT002L0fMWI00<000000=WIf@3I
fMT01P3IfMT00`00_kl0fMWI0=WIf@060=WIf@030?l0003IfMT0fMWI0>@0fMWI000W0=WIf@030000
003IfMT0fMWI00H0fMWI00<00;no0=WIf@3IfMT01P3IfMT00`3o0000fMWI0=WIf@3T0=WIf@00503I
fMT4000000<0fMWI0P0000040=WIf@800000103IfMT00`000000fMWI0=WIf@060=WIf@03002o_`3I
fMT0fMWI00H0fMWI00<0o`000=WIf@3IfMT0i03IfMT001@0fMWI00<000000=WIf@3IfMT02@3IfMT0
10000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00D0fMWI00<00;no0=WIf@3IfMT01P3I
fMT00`3o0000fMWI0=WIf@3U0=WIf@005@3IfMT00`000000fMWI0=WIf@0;0=WIf@040000003IfMT0
fMWI0=WIf@<000001@3IfMT00`00_kl0fMWI0=WIf@060=WIf@030?l0003IfMT0fMWI02T0fMWI2`00
0?na0=WIf@003P3IfMT4000000@0fMWI00<000000=WIf@3IfMT0203IfMT2000000@0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`00_kl0fMWI0=WIf@050=WIf@030?l0003IfMT0fMWI02<0fMWI1`000?l;
0=WIf@P0003oZ@3IfMT001@0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<00;no0=WIf@3IfMT01P3IfMT00`3o0000fMWI0=WIf@0P
0=WIf@<0003o6P3IfMT60000oj<0fMWI000E0=WIf@8000002P3IfMT3000000<0fMWI00<000000=WI
f@3IfMT0103IfMT00`00_kl0fMWI0=WIf@050=WIf@030?l0003IfMT0fMWI01l0fMWI0P000?lS0=WI
f@D0003oWP3IfMT002L0fMWI0P0000040=WIf@03002o_`3IfMT0fMWI00H0fMWI00<0o`000=WIf@3I
fMT0703IfMT30000obX0fMWI1P000?nH0=WIf@009`3IfMT00`000000fMWI0=WIf@030=WIf@03002o
_`3IfMT0fMWI00H0fMWI00<0o`000=WIf@3IfMT06P3IfMT20000oc<0fMWI10000?mV0=WIf@/0003o
8`3IfMT002L0fMWI00<000000=WIf@3IfMT00`3IfMT00`00_kl0fMWI0=WIf@050=WIf@030?l0003I
fMT0fMWI01T0fMWI0P000?li0=WIf@@0003oC03IfMTF0000o`/0fMWI1P000?lM0=WIf@009`3IfMT0
0`000000fMWI0=WIf@020=WIf@03002o_`3IfMT0fMWI00H0fMWI00<0o`000=WIf@3IfMT0603IfMT0
0`000?l0fMWI0=WIf@0m0=WIf@@0003o?@3IfMT;0000od@0fMWI000W0=WIf@8000000`3IfMT00`00
_kl0fMWI0=WIf@050=WIf@030?l0003IfMT0fMWI01L0fMWI0P000?m40=WIf@@0003o<P3IfMT70000
odl0fMWI000W0=WIf@030000003IfMT0fMWI0080fMWI00<00;no0=WIf@3IfMT01@3IfMT00`3o0000
fMWI0=WIf@0E0=WIf@80003oBP3IfMT60000obH0fMWI1P000?mF0=WIf@009`3IfMT01@000000fMWI
0=WIf@3IfMT00;no00L0fMWI00<0o`000=WIf@3IfMT05@3IfMT00`000?l0fMWI0=WIf@0>0=WIf@@0
0000=@3IfMT3000000H0fMWI1@000?lI0=WIf@P0003o1P3IfMT3000003@0fMWI0P00000M0=WIf@00
9`3IfMT01@000000fMWI0=WIf@3IfMT00;no00L0fMWI00<0o`000=WIf@3IfMT04`3IfMT20000oa40
fMWI00<000000=WIf@3IfMT0=`3IfMT00`000000fMWI0=WIf@0:0=WIf@H0003o203IfMT;0000o`h0
fMWI00@000000=WIf@3IfMT00000<P3IfMT010000000fMWI0=WIf@00000L0=WIf@009`3IfMT20000
00030=WIf@00_kl0fMWI00H0fMWI00<0o`000=WIf@3IfMT0203IfMT<001o01@0fMWI00<000000=WI
f@3IfMT0<`3IfMT500000140fMWI20000?lI0=WIf@040000003IfMT0fMWI00000380fMWI00@00000
0=WIf@3IfMT00000703IfMT002L0fMWI00@000000=WIf@3IfMT00;no1`3IfMT00`3o0000fMWI0=WI
f@060=WIf@8007l0203IfMT20000o`80fMWI00<007l00=WIf@3IfMT04P3IfMT00`000000fMWI0=WI
f@0b0=WIf@040000003IfMT0fMWI000003<0fMWI0`00000d0=WIf@8000007@3IfMT002L0fMWI00@0
00000=WIf@3IfMT00;no1@3IfMT20?l000L0fMWI0P00O`080=WIf@80003o1@3IfMT00`00O`00fMWI
0=WIf@0?0=WIf@040000003IfMT0fMWI000003@0fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0b0=WIf@040000003IfMT0fMWI000001`0fMWI000W0=WIf@030000003IfMT00;no00D0
fMWI00<0o`000=WIf@3IfMT01@3IfMT2001o00P0fMWI0P000?l80=WIf@03001o003IfMT0fMWI00l0
fMWI0P00000f0=WIf@800000=03IfMT3000003<0fMWI0P00000M0=WIf@009`3IfMT200000003002o
_`3IfMT0fMWI0080fMWI00<0o`000=WIf@3IfMT0103IfMT2001o00P0fMWI0P000?l;0=WIf@03001o
003IfMT0fMWI0680fMWI1`00O`1X0=WIf@009`3IfMT00`000000fMWI002o_`020=WIf@80o`001@3I
fMT2001o00L0fMWI0`000?l>0=WIf@8007l0F`3IfMT7001o00L0fMWI1000O`1T0=WIf@009`3IfMT0
1@0000000;no0=WIf@3IfMT0o`0000D0fMWI0P00O`050=WIf@@0003o4`3IfMT00`00O`00fMWI0=WI
f@1E0=WIf@<007l04P3IfMT4001o0600fMWI000W0=WIf@0400000000_kl0fMWI0?l00080fMWI1000
O`030=WIf@@0003o603IfMT00`00O`00fMWI0=WIf@1B0=WIf@8007l06@3IfMT4001o04d0fMWI0P00
000=0=WIf@009`3IfMT00`00_kl0o`000?l00003001o00L0003o7@3IfMT00`00O`00fMWI0=WIf@1>
0=WIf@<007l07`3IfMT6001o0180fMWI4`00O`0Q0=WIf@040000003IfMT0fMWI000000`0fMWI000R
0=WIf@D0000000<00;no001o00000?l00`000?lU00000003001o00000000000002D000002000O`0M
000000<007l0:000000B001o01<000001P00O`0D000000L0fMWI00<000000=WIf@3IfMT03@3IfMT0
02L0fMWI00<000000=WIf@3IfMT0:@3IfMT2001o00T0fMWI00<000000=WIf@3IfMT04P3IfMT7001o
00P0fMWI1P00O`0=0=WIf@030000003IfMT0fMWI00<0fMWI1000O`0]0=WIf@030000003IfMT0fMWI
02H0fMWI2000O`050=WIf@030000003IfMT0fMWI00X0fMWI1@00000<0=WIf@009`3IfMT00`000000
fMWI0=WIf@0[0=WIf@8007l06@3IfMT3001o01D0fMWI2000O`070=WIf@@007l0HP3IfMT6001o00d0
fMWI00<000000=WIf@3IfMT03@3IfMT002L0fMWI00<000000=WIf@3IfMT0;@3IfMT2001o01D0fMWI
0P00O`0P0=WIf@L007l0R@3IfMT002L0fMWI0P00000`0=WIf@8007l0403IfMT3001o0;80fMWI000W
0=WIf@030000003IfMT0fMWI0340fMWI0P00O`070=WIf@L007l0]@3IfMT002L0fMWI00<000000=WI
f@3IfMT0<`3IfMT7001o0;`0fMWI000W0=WIf@030000003IfMT0fMWI0?H0fMWI000W0=WIf@800000
m`3IfMT002L0fMWI00<000000=WIf@3IfMT0mP3IfMT002L0fMWI00<000000=WIf@3IfMT0mP3IfMT0
0?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT0
0?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT004d0fMWI100000060=WIf@@000001@3I
fMT2000000P0fMWI0P00002d0=WIf@00C@3IfMT00`000000fMWI000000080=WIf@030000003IfMT0
000000D0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@2b0=WIf@008P3IfMT50000
00030=WIf@00000000000080000000P0fMWI000000000000fMWI0000003IfMT000000=WIf@@00000
0`3IfMT2000000<0fMWI1@0000000`3IfMT000000000000300000080fMWI00<000000=WIf@000000
0P3IfMT5000000040=WIf@000000fMWI000000D0fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0
fMWI00<000000=WIf@3IfMT0/P3IfMT001H0fMWI2@00_kl30=WIf@@000000`3IfMT00`000000fMWI
0=WIf@020=WIf@070000003IfMT000000=WIf@000000fMWI0000000;0=WIf@@000000P3IfMT40000
00<0fMWI00<000000=WIf@000000103IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000001@3I
fMT01@000000fMWI0=WIf@3IfMT000000080fMWI00D000000=WIf@3IfMT0fMWI0000002d0=WIf@00
9@3IfMT01@000000fMWI0=WIf@3IfMT0000000@0fMWI00D000000=WIf@000000fMWI000000020=WI
f@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT01`000000fMWI0=WIf@3IfMT0
00000=WIf@000000103IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT002<0fMWI0`0000020=WIf@@0
000000H0fMWI00000000000000000=WIf@0000040=WIf@030000003IfMT0fMWI00P0fMWI0`000003
0=WIf@<000000`3IfMT00`000000fMWI000000040=WIf@070000003IfMT0fMWI0=WIf@000000fMWI
000000050=WIf@030000003IfMT0fMWI00D000000`3IfMT00`000000fMWI0=WIf@2b0=WIf@00=03I
fMT010000000fMWI0=WIf@00000E0=WIf@030000003IfMT0000000@0fMWI00L000000=WIf@3IfMT0
fMWI0000003IfMT0000000D0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0
fMWI0;80fMWI000e0=WIf@8000005P3IfMT400000080fMWI0P0000020=WIf@@000001@3IfMT20000
00P0fMWI0P00002d0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00C@3IfMT4000000H0fMWI1000
00050=WIf@800000203IfMT200000;@0fMWI001=0=WIf@030000003IfMT0000000P0fMWI00<00000
0=WIf@0000001@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0;80fMWI000R0=WI
f@D0000000<0fMWI0000000000000P000000203IfMT000000000003IfMT000000=WIf@000000fMWI
1@0000020=WIf@8000000`3IfMT5000000030=WIf@000000000000<000000P3IfMT00`000000fMWI
000000020=WIf@D0000000@0fMWI0000003IfMT000001@3IfMT00`000000fMWI0=WIf@020=WIf@80
0000103IfMT00`000000fMWI0=WIf@2b0=WIf@005P3IfMT90?l000<0fMWI100000030=WIf@030000
003IfMT0fMWI0080fMWI00D000000=WIf@000000fMWI000000030=WIf@030000003IfMT0fMWI00L0
fMWI100000020=WIf@@000000`3IfMT00`000000fMWI000000040=WIf@070000003IfMT0fMWI0=WI
f@000000fMWI000000050=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT01@000000fMWI0=WI
f@3IfMT000000;@0fMWI000U0=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT01@000000fMWI
0000003IfMT0000000<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@030=WIf@07
0000003IfMT0fMWI0=WIf@000000fMWI000000040=WIf@070000003IfMT0fMWI0=WIf@000000fMWI
000000050=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@2b0=WIf@00
8`3IfMT300000080fMWI100000001P3IfMT00000000000000000fMWI000000@0fMWI00<000000=WI
f@3IfMT0203IfMT3000000<0fMWI0`0000030=WIf@030000003IfMT0000000@0fMWI00L000000=WI
f@3IfMT0fMWI0000003IfMT0000000D0fMWI00<000000=WIf@3IfMT01@0000030=WIf@030000003I
fMT0fMWI0;80fMWI000f0=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@000000103IfMT0
1`000000fMWI0=WIf@3IfMT000000=WIf@0000001@3IfMT01@000000fMWI0=WIf@3IfMT0000000H0
fMWI00<000000=WIf@3IfMT0/P3IfMT003D0fMWI0P00000F0=WIf@@000000P3IfMT200000080fMWI
100000050=WIf@800000203IfMT200000;@0fMWI003o0=WIfB40fMWI000U0=WIf@030000003IfMT0
fMWI00@00000:03IfMT3000000030=WIf@000000fMWI00H0fMWI0P0000080=WIf@800000]03IfMT0
02@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0W0=WIf@050000003IfMT0fMWI
0=WIf@0000001P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0;80fMWI000S0=WI
f@030000003IfMT0fMWI00D0fMWI00@000000=WIf@3IfMT0fMWI0P0000040=WIf@<0000000<0fMWI
0000000000000P3IfMT200000080fMWI0P0000030=WIf@@000000`3IfMT2000000@0fMWI0`000004
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI00<00000
0=WIf@3IfMT0/P3IfMT002<0fMWI00<000000=WIf@3IfMT01@3IfMT010000000fMWI0=WIf@000002
0=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003I
fMT0fMWI00000080fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000040=WI
f@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@050000003IfMT0
fMWI0=WIf@000000]03IfMT001H0fMWI2@00O`040=WIf@030000003IfMT0fMWI00D0fMWI00@00000
0=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WIf@000000
0P3IfMT010000000fMWI0=WIf@0000060=WIf@030000003IfMT0fMWI00P0fMWI00@000000=WIf@3I
fMT00000103IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT0
0`000000fMWI0=WIf@2b0=WIf@008`3IfMT00`000000fMWI0=WIf@020=WIf@@000000`3IfMT20000
00@0fMWI0P0000020=WIf@@000000P3IfMT5000000@0fMWI00<000000=WIf@3IfMT0203IfMT40000
00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@05000000<0fMWI00<000000=WI
f@3IfMT0/P3IfMT002@0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@030=WIf@04
0000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0
000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT002D0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00h0fMWI0P00000?0=WIf@030000003IfMT0fMWI
00D0fMWI0P0000080=WIf@800000]03IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT002D0fMWI00<0
00000=WIf@3IfMT01000000X0=WIf@<0000000<0fMWI0000003IfMT01P3IfMT2000000P0fMWI0P00
002d0=WIf@00903IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI02L0fMWI00D00000
0=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0/P3I
fMT002<0fMWI00<000000=WIf@3IfMT01@3IfMT010000000fMWI0=WIf@3IfMT2000000@0fMWI0`00
00000`3IfMT00000000000020=WIf@8000000P3IfMT2000000<0fMWI1@0000020=WIf@800000103I
fMT3000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@800000103I
fMT00`000000fMWI0=WIf@2b0=WIf@008`3IfMT00`000000fMWI0=WIf@050=WIf@040000003IfMT0
fMWI00000080fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI
00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00L0
fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI
0=WIf@0000000P3IfMT01@000000fMWI0=WIf@3IfMT000000;@0fMWI000F0=WIf@T0003o103IfMT0
0`000000fMWI0=WIf@050=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT00P3I
fMT01@000000fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000001`3IfMT00`000000
fMWI0=WIf@070=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@3IfMT00`3IfMT01@00
0000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT002<0fMWI00<000000=WI
f@3IfMT00P3IfMT4000000<0fMWI0P0000040=WIf@8000000P3IfMT400000080fMWI1@0000040=WI
f@030000003IfMT0fMWI00P0fMWI100000030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT01@0000030=WIf@030000003IfMT0fMWI0;80fMWI000T0=WIf@030000003IfMT0fMWI01T0
fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00@0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0;80fMWI000U0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0>0=WIf@80
00003`3IfMT00`000000fMWI0=WIf@050=WIf@800000203IfMT200000;@0fMWI003o0=WIfB40fMWI
003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI
003o0=WIfB40fMWI0000\
\>"],
  ImageRangeCache->{{{138, 425}, {278.25, 65}} -> {-2.06252, -0.178996, \
0.00732689, 0.00732689}, {{145, 417.938}, {273.125, 104.438}} -> {-6.50218, \
-10.1163, 0.0365551, 0.118486}, {{158.625, 295.125}, {111, 70.0625}} -> \
{-19.1203, -12.1891, 0.119891, 0.11823}, {{160.125, 168.438}, {109.438, 101}} -> \
{-39.5267, -25.9927, 0.240604, 0.240604}, {{160.125, 168.438}, {99.625, \
91.1875}} -> {-39.5267, -28.3537, 0.240604, 0.240604}, {{160.125, 168.438}, \
{89.8125, 81.375}} -> {-39.5267, -30.7146, 0.240604, 0.240604}, {{160.125, \
168.438}, {80, 71.5625}} -> {-39.5267, -33.0755, 0.240604, 0.240604}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
A: The movement of arm1 is atenuated in time (after the initial start) when \
the parameter IdealGear.ratio increases.  The same goes for arm2. 

(c) A: the number of initial conditions are not diffrent from (a)  and (b).
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Colliding spheres", "Section"],

Cell["\<\
model CollidingSpheres \"Collision modeling class\" 
  parameter Real distance=1 \"the distance between spheres\";
  parameter Real e=0.2 \"the restitution coefficient\";
  parameter Real mass=1 \"mass of each sphere\";
  parameter Real diameter=1 \"diameter of each sphere\";
  parameter Real velocity=1 \"initial collision of s1 with s2\";
  parameter Real m1=mass;
  parameter Real m2=mass;
  parameter Real m3=mass;
  parameter Real m4=mass;
  Real x1(start=0);
  Real x2;
  Real x3;
  Real x4;
  Real y1(start=distance);
  Real y2(start=distance);
  Real y3(start=distance);
  Real x1der(start=velocity);
  Real y1der(start=-velocity);
  Real y2der(start=0);
  Real y3der(start=0);
  Real x1derder(start=0);
  Real y1derder(start=0);
  Real y2derder(start=0);
  Real y3derder(start=0);
equation 
  y1 = x2 - x1 - distance;
  y2 = x3 - x2 - distance;
  y3 = x4 - x3 - distance;
  x1der = der(x1);
  y1der = der(y1);
  y2der = der(y2);
  y3der = der(y3);
  x1derder = der(x1der);
  y1derder = der(y1der);
  y2derder = der(y2der);
  y3derder = der(y3der);
  x1derder = 0;
  y1derder = 0;
  y2derder = 0;
  y3derder = 0;
  
  when x2 - x1 <= diameter then
    reinit(x1der, pre(x1der) + (1 + e)*m2/(m1 + m2)*pre(y1der));
    reinit(y2der, pre(y2der) + (1 + e)*m1/(m1 + m2)*pre(y1der));
    reinit(y1der, -e*pre(y1der));
  end when;
  
  when x3 - x2 <= diameter then
    reinit(y1der, pre(y1der) + (1 + e)*m3/(m2 + m3)*pre(y2der));
    reinit(y3der, pre(y3der) + (1 + e)*m2/(m2 + m3)*pre(y2der));
    reinit(y2der, -e*pre(y2der));
  end when;
  
  when x4 - x3 <= diameter then
    reinit(y2der, pre(y2der) + (1 + e)*m4/(m3 + m4)*pre(y3der));
    reinit(y3der, -e*pre(y3der));
  end when;  
end CollidingSpheres;\
\>", "ModelicaInput"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simulate[CollidingSpheres, \ {t, \ 0, \ 15}]\)], "Input"],

Cell[BoxData["\<\"<SimulationData: \\!\\(CollidingSpheres\\) : 2003-5-7 \
21:58:58 : \\!\\({0.`, 15.`}\\) : 541 data points : 32 \
variables>\\n\\!\\({\\*TagBox[\\\"diameter\\\", HoldForm], \
\\*TagBox[\\\"distance\\\", HoldForm], \\*TagBox[\\\"e\\\", HoldForm], \
\\*TagBox[\\\"m1\\\", HoldForm], \\*TagBox[\\\"m2\\\", HoldForm], \
\\*TagBox[\\\"m3\\\", HoldForm], \\*TagBox[\\\"m4\\\", HoldForm], \
\\*TagBox[\\\"mass\\\", HoldForm], \\*TagBox[\\\"velocity\\\", HoldForm], \
\\*TagBox[\\\"x1\\\", HoldForm], \\*TagBox[\\\"x1der\\\", HoldForm], \
\\*TagBox[\\\"x1derder\\\", HoldForm], \\*TagBox[\\\"x2\\\", HoldForm], \
\\*TagBox[\\\"x3\\\", HoldForm], \\*TagBox[\\\"x4\\\", HoldForm], \
\\*TagBox[\\\"y1\\\", HoldForm], \\*TagBox[\\\"y1der\\\", HoldForm], \
\\*TagBox[\\\"y1derder\\\", HoldForm], \\*TagBox[\\\"y2\\\", HoldForm], \
\\*TagBox[\\\"y2der\\\", HoldForm], \\*TagBox[\\\"y2derder\\\", HoldForm], \
\\*TagBox[\\\"y3\\\", HoldForm], \\*TagBox[\\\"y3der\\\", HoldForm], \
\\*TagBox[\\\"y3derder\\\", HoldForm], \\*TagBox[SuperscriptBox[\\\"x1\\\", \
\\\"\[Prime]\\\", Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\\"x1der\\\", \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\\"y1\\\", \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \\*TagBox[SuperscriptBox[\\\"y1der\
\\\", \\\"\[Prime]\\\", Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\\"y2\\\", \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \\*TagBox[SuperscriptBox[\\\"y2der\
\\\", \\\"\[Prime]\\\", Rule[MultilineFunction, None]], HoldForm], \
\\*TagBox[SuperscriptBox[\\\"y3\\\", \\\"\[Prime]\\\", \
Rule[MultilineFunction, None]], HoldForm], \\*TagBox[SuperscriptBox[\\\"y3der\
\\\", \\\"\[Prime]\\\", Rule[MultilineFunction, None]], HoldForm]}\\)\"\>"], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(PlotSimulation[{x1[t], \ x2[t], \ x3[t], \ x4[t]}, \ {t, 0, 
          20}];\)\), "\[IndentingNewLine]", 
    \(\(PlotSimulation[{y1[t], \ y2[t], \ y3[t]}, \ {t, 0, 
          20}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74402 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.312017 0.47619 [
[ 0 0 0 0 ]
[ 1 .74402 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0177147 0.97619 0.606318 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.0147151 0.0712646 [
[.15079 .00222 -3 -9 ]
[.15079 .00222 3 0 ]
[.27778 .00222 -3 -9 ]
[.27778 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.53175 .00222 -3 -9 ]
[.53175 .00222 3 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.9127 .00222 -6 -9 ]
[.9127 .00222 6 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 10 6.28125 ]
[.01131 .15724 -6 -4.5 ]
[.01131 .15724 0 4.5 ]
[.01131 .29977 -6 -4.5 ]
[.01131 .29977 0 4.5 ]
[.01131 .4423 -6 -4.5 ]
[.01131 .4423 0 4.5 ]
[.01131 .58483 -6 -4.5 ]
[.01131 .58483 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .01472 m
.15079 .02097 L
s
[(2)] .15079 .00222 0 1 Mshowa
.27778 .01472 m
.27778 .02097 L
s
[(4)] .27778 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(6)] .40476 .00222 0 1 Mshowa
.53175 .01472 m
.53175 .02097 L
s
[(8)] .53175 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(10)] .65873 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(12)] .78571 .00222 0 1 Mshowa
.9127 .01472 m
.9127 .02097 L
s
[(14)] .9127 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.18254 .01472 m
.18254 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.34127 .01472 m
.34127 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.81746 .01472 m
.81746 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .15724 m
.03006 .15724 L
s
[(2)] .01131 .15724 1 0 Mshowa
.02381 .29977 m
.03006 .29977 L
s
[(4)] .01131 .29977 1 0 Mshowa
.02381 .4423 m
.03006 .4423 L
s
[(6)] .01131 .4423 1 0 Mshowa
.02381 .58483 m
.03006 .58483 L
s
[(8)] .01131 .58483 1 0 Mshowa
.125 Mabswid
.02381 .05035 m
.02756 .05035 L
s
.02381 .08598 m
.02756 .08598 L
s
.02381 .12161 m
.02756 .12161 L
s
.02381 .19288 m
.02756 .19288 L
s
.02381 .22851 m
.02756 .22851 L
s
.02381 .26414 m
.02756 .26414 L
s
.02381 .33541 m
.02756 .33541 L
s
.02381 .37104 m
.02756 .37104 L
s
.02381 .40667 m
.02756 .40667 L
s
.02381 .47793 m
.02756 .47793 L
s
.02381 .51357 m
.02756 .51357 L
s
.02381 .5492 m
.02756 .5492 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 1 r
.001 w
.02381 .01472 m
.02571 .01685 L
.02762 .01899 L
.02952 .02113 L
.03143 .02327 L
.03333 .0254 L
.03524 .02754 L
.03714 .02968 L
.03905 .03182 L
.04095 .03396 L
.04286 .03609 L
.04476 .03823 L
.04667 .04037 L
.04857 .04251 L
.05048 .04465 L
.05238 .04678 L
.05429 .04892 L
.05619 .05106 L
.0581 .0532 L
.06 .05534 L
.0619 .05747 L
.06381 .05961 L
.06571 .06175 L
.06762 .06389 L
.06952 .06603 L
.07143 .06816 L
.07333 .0703 L
.07524 .07244 L
.07714 .07458 L
.07905 .07672 L
.08095 .07885 L
.08286 .08099 L
.08476 .08313 L
.08667 .08527 L
.0873 .08598 L
.0873 .08598 L
.0873 .08598 L
.08857 .08655 L
.09048 .0874 L
.09238 .08826 L
.09429 .08912 L
.09619 .08997 L
.0981 .09083 L
.1 .09168 L
.1019 .09254 L
.10381 .09339 L
.10571 .09425 L
.10762 .0951 L
.10952 .09596 L
.11143 .09681 L
Mistroke
.11333 .09767 L
.11524 .09852 L
.11714 .09938 L
.11905 .10023 L
.12095 .10109 L
.12286 .10194 L
.12476 .1028 L
.12667 .10365 L
.12857 .10451 L
.13048 .10536 L
.13238 .10622 L
.13429 .10707 L
.13619 .10793 L
.1381 .10878 L
.14 .10964 L
.1419 .11049 L
.14381 .11135 L
.14571 .11221 L
.14762 .11306 L
.14952 .11392 L
.15143 .11477 L
.15333 .11563 L
.15524 .11648 L
.15714 .11734 L
.15905 .11819 L
.16095 .11905 L
.16286 .1199 L
.16476 .12076 L
.16667 .12161 L
.16857 .12247 L
.17048 .12332 L
.17238 .12418 L
.17429 .12503 L
.17619 .12589 L
.1781 .12674 L
.18 .1276 L
.1819 .12845 L
.18381 .12931 L
.18571 .13016 L
.18762 .13102 L
.18952 .13187 L
.19143 .13273 L
.19312 .13349 L
.19312 .13349 L
.19312 .13349 L
.19333 .13358 L
.19524 .13444 L
.19714 .13529 L
.19905 .13615 L
.20095 .13701 L
Mistroke
.20286 .13786 L
.20476 .13872 L
.20667 .13957 L
.20857 .14043 L
.21048 .14128 L
.21238 .14214 L
.21429 .14299 L
.21619 .14385 L
.2181 .1447 L
.22 .14556 L
.2219 .14641 L
.22381 .14727 L
.22571 .14812 L
.22762 .14898 L
.22952 .14983 L
.23143 .15069 L
.23333 .15154 L
.23524 .1524 L
.23714 .15325 L
.23905 .15411 L
.24095 .15496 L
.24286 .15582 L
.24476 .15667 L
.24667 .15753 L
.24857 .15838 L
.25048 .15924 L
.25238 .16009 L
.25429 .16095 L
.25619 .16181 L
.2581 .16266 L
.26 .16352 L
.2619 .16437 L
.26381 .16523 L
.26571 .16608 L
.26762 .16694 L
.26952 .16779 L
.27143 .16865 L
.27333 .1695 L
.27524 .17036 L
.27714 .17121 L
.27905 .17207 L
.28095 .17292 L
.28286 .17378 L
.28476 .17463 L
.28667 .17549 L
.28857 .17634 L
.29048 .1772 L
.29238 .17805 L
.29429 .17891 L
.29619 .17976 L
Mistroke
.2981 .18062 L
.3 .18147 L
.3019 .18233 L
.30381 .18318 L
.30571 .18404 L
.30762 .18489 L
.30952 .18575 L
.31143 .18661 L
.31333 .18746 L
.31524 .18832 L
.31714 .18917 L
.31905 .19003 L
.32095 .19088 L
.32286 .19174 L
.32476 .19259 L
.3254 .19288 L
.3254 .19288 L
.3254 .19288 L
.32667 .19331 L
.32857 .19396 L
.33048 .19461 L
.33238 .19526 L
.33429 .19591 L
.33619 .19656 L
.3381 .19721 L
.34 .19786 L
.3419 .19851 L
.34381 .19916 L
.34571 .19981 L
.34762 .20046 L
.34952 .20111 L
.35143 .20176 L
.35333 .20241 L
.35524 .20306 L
.35714 .20371 L
.35905 .20436 L
.36095 .20501 L
.36286 .20566 L
.36476 .20631 L
.36667 .20696 L
.36857 .20761 L
.36949 .20792 L
.36949 .20792 L
.36949 .20792 L
.37048 .20826 L
.37238 .20891 L
.37429 .20956 L
.37619 .21021 L
.3781 .21086 L
.38 .21151 L
Mistroke
.3819 .21216 L
.38381 .21281 L
.38571 .21346 L
.38762 .21411 L
.38952 .21476 L
.39143 .21541 L
.39333 .21606 L
.39524 .21671 L
.39714 .21736 L
.39905 .21801 L
.40095 .21866 L
.40286 .21931 L
.40476 .21996 L
.40667 .22061 L
.40857 .22126 L
.41048 .22191 L
.41238 .22256 L
.41429 .22321 L
.41619 .22386 L
.4181 .22451 L
.42 .22516 L
.4219 .22581 L
.42381 .22646 L
.42571 .22711 L
.42762 .22776 L
.42952 .22841 L
.43143 .22906 L
.43333 .22971 L
.43524 .23036 L
.43714 .23101 L
.43905 .23166 L
.44095 .23231 L
.44286 .23296 L
.44476 .23361 L
.44667 .23426 L
.44857 .23491 L
.45048 .23556 L
.45238 .23621 L
.45429 .23686 L
.45619 .23751 L
.45767 .23801 L
.45767 .23801 L
.45767 .23801 L
.4581 .23816 L
.46 .23881 L
.4619 .23946 L
.46381 .2401 L
.46571 .24075 L
.46762 .2414 L
.46952 .24205 L
Mistroke
.47143 .2427 L
.47333 .24335 L
.47524 .244 L
.47714 .24465 L
.47905 .2453 L
.48095 .24595 L
.48286 .2466 L
.48476 .24725 L
.48667 .2479 L
.48857 .24855 L
.49048 .2492 L
.49238 .24985 L
.49429 .2505 L
.49619 .25115 L
.4981 .2518 L
.5 .25245 L
.5019 .2531 L
.50381 .25375 L
.50571 .2544 L
.50762 .25505 L
.50855 .25537 L
.50855 .25537 L
.50855 .25537 L
.50952 .25565 L
.51143 .25619 L
.51333 .25674 L
.51524 .25728 L
.51714 .25782 L
.51905 .25836 L
.52095 .25891 L
.52286 .25945 L
.52476 .25999 L
.52667 .26054 L
.52857 .26108 L
.53048 .26162 L
.53238 .26217 L
.53429 .26271 L
.53619 .26325 L
.5381 .2638 L
.54 .26434 L
.5419 .26488 L
.54381 .26543 L
.54571 .26597 L
.54762 .26651 L
.54952 .26706 L
.55143 .2676 L
.55333 .26814 L
.55524 .26869 L
.55714 .26923 L
.55905 .26977 L
Mistroke
.56095 .27032 L
.56286 .27086 L
.56476 .2714 L
.56667 .27194 L
.56857 .27249 L
.57048 .27303 L
.57238 .27357 L
.57429 .27412 L
.57619 .27466 L
.5781 .2752 L
.58 .27575 L
.5819 .27629 L
.58381 .27683 L
.58571 .27738 L
.58762 .27792 L
.58952 .27846 L
.59143 .27901 L
.59333 .27955 L
.59524 .28009 L
.59714 .28064 L
.59905 .28118 L
.60095 .28172 L
.60286 .28227 L
.60464 .28278 L
.60464 .28278 L
.60464 .28278 L
.60476 .28281 L
.60667 .28335 L
.60857 .2839 L
.61048 .28444 L
.61238 .28498 L
.61429 .28553 L
.61619 .28607 L
.6181 .28661 L
.62 .28715 L
.6219 .2877 L
.62381 .28824 L
.62571 .28878 L
.62726 .28922 L
.62726 .28922 L
.62726 .28922 L
.62762 .28933 L
.62952 .28987 L
.63143 .29041 L
.63333 .29096 L
.63524 .2915 L
.63714 .29204 L
.63905 .29259 L
.64095 .29313 L
.64139 .29325 L
Mistroke
.64139 .29325 L
.64139 .29325 L
.64286 .29367 L
.64476 .29422 L
.64667 .29476 L
.64857 .2953 L
.65048 .29585 L
.65238 .29639 L
.65429 .29693 L
.65619 .29748 L
.6581 .29802 L
.66 .29856 L
.6619 .29911 L
.66381 .29965 L
.66571 .30019 L
.66762 .30073 L
.66952 .30128 L
.67143 .30182 L
.67333 .30236 L
.67524 .30291 L
.67714 .30345 L
.67905 .30399 L
.68095 .30454 L
.68286 .30508 L
.68476 .30562 L
.68667 .30617 L
.68857 .30671 L
.69048 .30725 L
.69238 .3078 L
.69429 .30834 L
.69619 .30888 L
.6981 .30943 L
.7 .30997 L
.7019 .31051 L
.70381 .31106 L
.70571 .3116 L
.70762 .31214 L
.70952 .31269 L
.71143 .31323 L
.71333 .31377 L
.71524 .31431 L
.71714 .31486 L
.71905 .3154 L
.72095 .31594 L
.72286 .31649 L
.72476 .31703 L
.72667 .31757 L
.72857 .31812 L
.73048 .31866 L
.73238 .3192 L
Mistroke
.73429 .31975 L
.73619 .32029 L
.7381 .32083 L
.74 .32138 L
.7419 .32192 L
.74381 .32246 L
.74571 .32301 L
.74762 .32355 L
.74952 .32409 L
.75143 .32464 L
.75333 .32518 L
.75524 .32572 L
.75714 .32627 L
.75905 .32681 L
.76095 .32735 L
.76286 .3279 L
.76476 .32844 L
.76667 .32898 L
.76857 .32952 L
.77048 .33007 L
.77238 .33061 L
.77261 .33068 L
.77261 .33068 L
.77261 .33068 L
.77429 .33115 L
.77619 .3317 L
.7781 .33224 L
.78 .33278 L
.7819 .33333 L
.78381 .33387 L
.78571 .33441 L
.78762 .33496 L
.78952 .3355 L
.79143 .33604 L
.79333 .33659 L
.79524 .33713 L
.79714 .33767 L
.79905 .33822 L
.80095 .33876 L
.80286 .3393 L
.80476 .33985 L
.80667 .34039 L
.80857 .34093 L
.81048 .34148 L
.81238 .34202 L
.81429 .34256 L
.81619 .3431 L
.8181 .34365 L
.82 .34419 L
.8219 .34473 L
Mistroke
.82381 .34528 L
.82571 .34582 L
.82762 .34636 L
.82952 .34691 L
.83143 .34745 L
.83333 .34799 L
.83524 .34854 L
.83714 .34908 L
.83905 .34962 L
.84095 .35017 L
.84286 .35071 L
.84476 .35125 L
.84667 .3518 L
.84857 .35234 L
.85048 .35288 L
.85238 .35343 L
.85429 .35397 L
.85619 .35451 L
.8581 .35506 L
.86 .3556 L
.8619 .35614 L
.86381 .35669 L
.86571 .35723 L
.86762 .35777 L
.86952 .35831 L
.87143 .35886 L
.87333 .3594 L
.87524 .35994 L
.87714 .36049 L
.87905 .36103 L
.88095 .36157 L
.88286 .36212 L
.88476 .36266 L
.88667 .3632 L
.88857 .36375 L
.89048 .36429 L
.89238 .36483 L
.89429 .36538 L
.89619 .36592 L
.8981 .36646 L
.9 .36701 L
.9019 .36755 L
.90381 .36809 L
.90571 .36864 L
.90762 .36918 L
.90952 .36972 L
.91143 .37027 L
.91333 .37081 L
.91524 .37135 L
.91714 .37189 L
Mistroke
.91905 .37244 L
.92095 .37298 L
.92286 .37352 L
.92476 .37407 L
.92667 .37461 L
.92857 .37515 L
.93048 .3757 L
.93238 .37624 L
.93429 .37678 L
.93619 .37733 L
.9381 .37787 L
.94 .37841 L
.9419 .37896 L
.94381 .3795 L
.94571 .38004 L
.94762 .38059 L
.94952 .38113 L
.95143 .38167 L
.95156 .38171 L
.95156 .38171 L
.95156 .38171 L
.95333 .38221 L
.95524 .38274 L
.95714 .38328 L
.95905 .38381 L
.95952 .38395 L
.95952 .38395 L
.95952 .38395 L
.96095 .38435 L
.96286 .38488 L
.96476 .38542 L
.96667 .38595 L
.96857 .38649 L
.97048 .38702 L
.97053 .38704 L
.97053 .38704 L
.97053 .38704 L
.97238 .38756 L
.97429 .38809 L
.97619 .38863 L
.97619 .38863 L
Mfstroke
0 .5 0 r
.02381 .15724 m
.02571 .15724 L
.02762 .15724 L
.02952 .15724 L
.03143 .15724 L
.03333 .15724 L
.03524 .15724 L
.03714 .15724 L
.03905 .15724 L
.04095 .15724 L
.04286 .15724 L
.04476 .15724 L
.04667 .15724 L
.04857 .15724 L
.05048 .15724 L
.05238 .15724 L
.05429 .15724 L
.05619 .15724 L
.0581 .15724 L
.06 .15724 L
.0619 .15724 L
.06381 .15724 L
.06571 .15724 L
.06762 .15724 L
.06952 .15724 L
.07143 .15724 L
.07333 .15724 L
.07524 .15724 L
.07714 .15724 L
.07905 .15724 L
.08095 .15724 L
.08286 .15724 L
.08476 .15724 L
.08667 .15724 L
.0873 .15724 L
.0873 .15724 L
.0873 .15724 L
.08857 .1581 L
.09048 .15938 L
.09238 .16066 L
.09429 .16195 L
.09619 .16323 L
.0981 .16451 L
.1 .1658 L
.1019 .16708 L
.10381 .16836 L
.10571 .16964 L
.10762 .17093 L
.10952 .17221 L
.11143 .17349 L
Mistroke
.11333 .17478 L
.11524 .17606 L
.11714 .17734 L
.11905 .17862 L
.12095 .17991 L
.12286 .18119 L
.12476 .18247 L
.12667 .18375 L
.12857 .18504 L
.13048 .18632 L
.13238 .1876 L
.13429 .18889 L
.13619 .19017 L
.1381 .19145 L
.14 .19273 L
.1419 .19402 L
.14381 .1953 L
.14571 .19658 L
.14762 .19787 L
.14952 .19915 L
.15143 .20043 L
.15333 .20171 L
.15524 .203 L
.15714 .20428 L
.15905 .20556 L
.16095 .20684 L
.16286 .20813 L
.16476 .20941 L
.16667 .21069 L
.16857 .21198 L
.17048 .21326 L
.17238 .21454 L
.17429 .21582 L
.17619 .21711 L
.1781 .21839 L
.18 .21967 L
.1819 .22095 L
.18381 .22224 L
.18571 .22352 L
.18762 .2248 L
.18952 .22609 L
.19143 .22737 L
.19312 .22851 L
.19312 .22851 L
.19312 .22851 L
.19333 .22857 L
.19524 .22908 L
.19714 .22959 L
.19905 .23011 L
.20095 .23062 L
Mistroke
.20286 .23113 L
.20476 .23164 L
.20667 .23216 L
.20857 .23267 L
.21048 .23318 L
.21238 .2337 L
.21429 .23421 L
.21619 .23472 L
.2181 .23524 L
.22 .23575 L
.2219 .23626 L
.22381 .23678 L
.22571 .23729 L
.22762 .2378 L
.22952 .23831 L
.23143 .23883 L
.23333 .23934 L
.23524 .23985 L
.23714 .24037 L
.23905 .24088 L
.24095 .24139 L
.24286 .24191 L
.24476 .24242 L
.24667 .24293 L
.24857 .24345 L
.25048 .24396 L
.25238 .24447 L
.25429 .24499 L
.25619 .2455 L
.2581 .24601 L
.26 .24652 L
.2619 .24704 L
.26381 .24755 L
.26571 .24806 L
.26762 .24858 L
.26952 .24909 L
.27143 .2496 L
.27333 .25012 L
.27524 .25063 L
.27714 .25114 L
.27905 .25166 L
.28095 .25217 L
.28286 .25268 L
.28476 .25319 L
.28667 .25371 L
.28857 .25422 L
.29048 .25473 L
.29238 .25525 L
.29429 .25576 L
.29619 .25627 L
Mistroke
.2981 .25679 L
.3 .2573 L
.3019 .25781 L
.30381 .25833 L
.30571 .25884 L
.30762 .25935 L
.30952 .25987 L
.31143 .26038 L
.31333 .26089 L
.31524 .2614 L
.31714 .26192 L
.31905 .26243 L
.32095 .26294 L
.32286 .26346 L
.32476 .26397 L
.3254 .26414 L
.3254 .26414 L
.3254 .26414 L
.32667 .26462 L
.32857 .26534 L
.33048 .26606 L
.33238 .26678 L
.33429 .26749 L
.33619 .26821 L
.3381 .26893 L
.34 .26965 L
.3419 .27037 L
.34381 .27109 L
.34571 .2718 L
.34762 .27252 L
.34952 .27324 L
.35143 .27396 L
.35333 .27468 L
.35524 .2754 L
.35714 .27611 L
.35905 .27683 L
.36095 .27755 L
.36286 .27827 L
.36476 .27899 L
.36667 .27971 L
.36857 .28042 L
.36949 .28077 L
.36949 .28077 L
.36949 .28077 L
.37048 .28114 L
.37238 .28186 L
.37429 .28258 L
.37619 .2833 L
.3781 .28402 L
.38 .28473 L
Mistroke
.3819 .28545 L
.38381 .28617 L
.38571 .28689 L
.38762 .28761 L
.38952 .28833 L
.39143 .28904 L
.39333 .28976 L
.39524 .29048 L
.39714 .2912 L
.39905 .29192 L
.40095 .29264 L
.40286 .29335 L
.40476 .29407 L
.40667 .29479 L
.40857 .29551 L
.41048 .29623 L
.41238 .29695 L
.41429 .29766 L
.41619 .29838 L
.4181 .2991 L
.42 .29982 L
.4219 .30054 L
.42381 .30126 L
.42571 .30197 L
.42762 .30269 L
.42952 .30341 L
.43143 .30413 L
.43333 .30485 L
.43524 .30557 L
.43714 .30628 L
.43905 .307 L
.44095 .30772 L
.44286 .30844 L
.44476 .30916 L
.44667 .30988 L
.44857 .31059 L
.45048 .31131 L
.45238 .31203 L
.45429 .31275 L
.45619 .31347 L
.45767 .31403 L
.45767 .31403 L
.45767 .31403 L
.4581 .31413 L
.46 .3146 L
.4619 .31508 L
.46381 .31555 L
.46571 .31602 L
.46762 .31649 L
.46952 .31696 L
Mistroke
.47143 .31744 L
.47333 .31791 L
.47524 .31838 L
.47714 .31885 L
.47905 .31932 L
.48095 .3198 L
.48286 .32027 L
.48476 .32074 L
.48667 .32121 L
.48857 .32168 L
.49048 .32216 L
.49238 .32263 L
.49429 .3231 L
.49619 .32357 L
.4981 .32404 L
.5 .32452 L
.5019 .32499 L
.50381 .32546 L
.50571 .32593 L
.50762 .3264 L
.50855 .32663 L
.50855 .32663 L
.50855 .32663 L
.50952 .32693 L
.51143 .32751 L
.51333 .32809 L
.51524 .32867 L
.51714 .32925 L
.51905 .32983 L
.52095 .3304 L
.52286 .33098 L
.52476 .33156 L
.52667 .33214 L
.52857 .33272 L
.53048 .3333 L
.53238 .33388 L
.53429 .33446 L
.53619 .33503 L
.5381 .33561 L
.54 .33619 L
.5419 .33677 L
.54381 .33735 L
.54571 .33793 L
.54762 .33851 L
.54952 .33909 L
.55143 .33966 L
.55333 .34024 L
.55524 .34082 L
.55714 .3414 L
.55905 .34198 L
Mistroke
.56095 .34256 L
.56286 .34314 L
.56476 .34372 L
.56667 .34429 L
.56857 .34487 L
.57048 .34545 L
.57238 .34603 L
.57429 .34661 L
.57619 .34719 L
.5781 .34777 L
.58 .34835 L
.5819 .34893 L
.58381 .3495 L
.58571 .35008 L
.58762 .35066 L
.58952 .35124 L
.59143 .35182 L
.59333 .3524 L
.59524 .35298 L
.59714 .35356 L
.59905 .35413 L
.60095 .35471 L
.60286 .35529 L
.60464 .35583 L
.60464 .35583 L
.60464 .35583 L
.60476 .35587 L
.60667 .35645 L
.60857 .35703 L
.61048 .35761 L
.61238 .35819 L
.61429 .35876 L
.61619 .35934 L
.6181 .35992 L
.62 .3605 L
.6219 .36108 L
.62381 .36166 L
.62571 .36224 L
.62726 .36271 L
.62726 .36271 L
.62726 .36271 L
.62762 .36281 L
.62952 .36334 L
.63143 .36387 L
.63333 .3644 L
.63524 .36493 L
.63714 .36546 L
.63905 .36599 L
.64095 .36652 L
.64139 .36664 L
Mistroke
.64139 .36664 L
.64139 .36664 L
.64286 .36705 L
.64476 .36758 L
.64667 .36811 L
.64857 .36865 L
.65048 .36918 L
.65238 .36971 L
.65429 .37024 L
.65619 .37077 L
.6581 .3713 L
.66 .37183 L
.6619 .37236 L
.66381 .37289 L
.66571 .37342 L
.66762 .37395 L
.66952 .37448 L
.67143 .37501 L
.67333 .37554 L
.67524 .37608 L
.67714 .37661 L
.67905 .37714 L
.68095 .37767 L
.68286 .3782 L
.68476 .37873 L
.68667 .37926 L
.68857 .37979 L
.69048 .38032 L
.69238 .38085 L
.69429 .38138 L
.69619 .38191 L
.6981 .38244 L
.7 .38298 L
.7019 .38351 L
.70381 .38404 L
.70571 .38457 L
.70762 .3851 L
.70952 .38563 L
.71143 .38616 L
.71333 .38669 L
.71524 .38722 L
.71714 .38775 L
.71905 .38828 L
.72095 .38881 L
.72286 .38934 L
.72476 .38988 L
.72667 .39041 L
.72857 .39094 L
.73048 .39147 L
.73238 .392 L
Mistroke
.73429 .39253 L
.73619 .39306 L
.7381 .39359 L
.74 .39412 L
.7419 .39465 L
.74381 .39518 L
.74571 .39571 L
.74762 .39624 L
.74952 .39678 L
.75143 .39731 L
.75333 .39784 L
.75524 .39837 L
.75714 .3989 L
.75905 .39943 L
.76095 .39996 L
.76286 .40049 L
.76476 .40102 L
.76667 .40155 L
.76857 .40208 L
.77048 .40261 L
.77238 .40314 L
.77261 .40321 L
.77261 .40321 L
.77261 .40321 L
.77429 .40367 L
.77619 .4042 L
.7781 .40473 L
.78 .40526 L
.7819 .40579 L
.78381 .40632 L
.78571 .40685 L
.78762 .40738 L
.78952 .40791 L
.79143 .40844 L
.79333 .40897 L
.79524 .4095 L
.79714 .41003 L
.79905 .41056 L
.80095 .41109 L
.80286 .41162 L
.80476 .41215 L
.80667 .41268 L
.80857 .41321 L
.81048 .41374 L
.81238 .41427 L
.81429 .4148 L
.81619 .41533 L
.8181 .41586 L
.82 .41639 L
.8219 .41692 L
Mistroke
.82381 .41745 L
.82571 .41798 L
.82762 .41851 L
.82952 .41904 L
.83143 .41957 L
.83333 .4201 L
.83524 .42063 L
.83714 .42115 L
.83905 .42168 L
.84095 .42221 L
.84286 .42274 L
.84476 .42327 L
.84667 .4238 L
.84857 .42433 L
.85048 .42486 L
.85238 .42539 L
.85429 .42592 L
.85619 .42645 L
.8581 .42698 L
.86 .42751 L
.8619 .42804 L
.86381 .42857 L
.86571 .4291 L
.86762 .42963 L
.86952 .43016 L
.87143 .43069 L
.87333 .43122 L
.87524 .43175 L
.87714 .43228 L
.87905 .43281 L
.88095 .43334 L
.88286 .43387 L
.88476 .4344 L
.88667 .43493 L
.88857 .43546 L
.89048 .43599 L
.89238 .43652 L
.89429 .43705 L
.89619 .43758 L
.8981 .43811 L
.9 .43864 L
.9019 .43917 L
.90381 .4397 L
.90571 .44022 L
.90762 .44075 L
.90952 .44128 L
.91143 .44181 L
.91333 .44234 L
.91524 .44287 L
.91714 .4434 L
Mistroke
.91905 .44393 L
.92095 .44446 L
.92286 .44499 L
.92476 .44552 L
.92667 .44605 L
.92857 .44658 L
.93048 .44711 L
.93238 .44764 L
.93429 .44817 L
.93619 .4487 L
.9381 .44923 L
.94 .44976 L
.9419 .45029 L
.94381 .45082 L
.94571 .45135 L
.94762 .45188 L
.94952 .45241 L
.95143 .45294 L
.95156 .45297 L
.95156 .45297 L
.95156 .45297 L
.95333 .45348 L
.95524 .45401 L
.95714 .45455 L
.95905 .45509 L
.95952 .45522 L
.95952 .45522 L
.95952 .45522 L
.96095 .45562 L
.96286 .45616 L
.96476 .45669 L
.96667 .45722 L
.96857 .45776 L
.97048 .45829 L
.97053 .4583 L
.97053 .4583 L
.97053 .4583 L
.97238 .45882 L
.97429 .45936 L
.97619 .45989 L
.97619 .45989 L
Mfstroke
1 0 0 r
.02381 .29977 m
.02571 .29977 L
.02762 .29977 L
.02952 .29977 L
.03143 .29977 L
.03333 .29977 L
.03524 .29977 L
.03714 .29977 L
.03905 .29977 L
.04095 .29977 L
.04286 .29977 L
.04476 .29977 L
.04667 .29977 L
.04857 .29977 L
.05048 .29977 L
.05238 .29977 L
.05429 .29977 L
.05619 .29977 L
.0581 .29977 L
.06 .29977 L
.0619 .29977 L
.06381 .29977 L
.06571 .29977 L
.06762 .29977 L
.06952 .29977 L
.07143 .29977 L
.07333 .29977 L
.07524 .29977 L
.07714 .29977 L
.07905 .29977 L
.08095 .29977 L
.08286 .29977 L
.08476 .29977 L
.08667 .29977 L
.0873 .29977 L
.0873 .29977 L
.0873 .29977 L
.08857 .29977 L
.09048 .29977 L
.09238 .29977 L
.09429 .29977 L
.09619 .29977 L
.0981 .29977 L
.1 .29977 L
.1019 .29977 L
.10381 .29977 L
.10571 .29977 L
.10762 .29977 L
.10952 .29977 L
.11143 .29977 L
Mistroke
.11333 .29977 L
.11524 .29977 L
.11714 .29977 L
.11905 .29977 L
.12095 .29977 L
.12286 .29977 L
.12476 .29977 L
.12667 .29977 L
.12857 .29977 L
.13048 .29977 L
.13238 .29977 L
.13429 .29977 L
.13619 .29977 L
.1381 .29977 L
.14 .29977 L
.1419 .29977 L
.14381 .29977 L
.14571 .29977 L
.14762 .29977 L
.14952 .29977 L
.15143 .29977 L
.15333 .29977 L
.15524 .29977 L
.15714 .29977 L
.15905 .29977 L
.16095 .29977 L
.16286 .29977 L
.16476 .29977 L
.16667 .29977 L
.16857 .29977 L
.17048 .29977 L
.17238 .29977 L
.17429 .29977 L
.17619 .29977 L
.1781 .29977 L
.18 .29977 L
.1819 .29977 L
.18381 .29977 L
.18571 .29977 L
.18762 .29977 L
.18952 .29977 L
.19143 .29977 L
.19312 .29977 L
.19312 .29977 L
.19312 .29977 L
.19333 .29986 L
.19524 .30063 L
.19714 .3014 L
.19905 .30217 L
.20095 .30294 L
Mistroke
.20286 .30371 L
.20476 .30448 L
.20667 .30525 L
.20857 .30602 L
.21048 .30679 L
.21238 .30756 L
.21429 .30833 L
.21619 .30909 L
.2181 .30986 L
.22 .31063 L
.2219 .3114 L
.22381 .31217 L
.22571 .31294 L
.22762 .31371 L
.22952 .31448 L
.23143 .31525 L
.23333 .31602 L
.23524 .31679 L
.23714 .31756 L
.23905 .31833 L
.24095 .3191 L
.24286 .31987 L
.24476 .32064 L
.24667 .32141 L
.24857 .32218 L
.25048 .32295 L
.25238 .32372 L
.25429 .32449 L
.25619 .32526 L
.2581 .32603 L
.26 .3268 L
.2619 .32757 L
.26381 .32834 L
.26571 .32911 L
.26762 .32988 L
.26952 .33065 L
.27143 .33141 L
.27333 .33218 L
.27524 .33295 L
.27714 .33372 L
.27905 .33449 L
.28095 .33526 L
.28286 .33603 L
.28476 .3368 L
.28667 .33757 L
.28857 .33834 L
.29048 .33911 L
.29238 .33988 L
.29429 .34065 L
.29619 .34142 L
Mistroke
.2981 .34219 L
.3 .34296 L
.3019 .34373 L
.30381 .3445 L
.30571 .34527 L
.30762 .34604 L
.30952 .34681 L
.31143 .34758 L
.31333 .34835 L
.31524 .34912 L
.31714 .34989 L
.31905 .35066 L
.32095 .35143 L
.32286 .3522 L
.32476 .35297 L
.3254 .35322 L
.3254 .35322 L
.3254 .35322 L
.32667 .35373 L
.32857 .3545 L
.33048 .35527 L
.33238 .35604 L
.33429 .35681 L
.33619 .35758 L
.3381 .35835 L
.34 .35912 L
.3419 .35989 L
.34381 .36066 L
.34571 .36143 L
.34762 .3622 L
.34952 .36297 L
.35143 .36374 L
.35333 .36451 L
.35524 .36528 L
.35714 .36605 L
.35905 .36682 L
.36095 .36759 L
.36286 .36836 L
.36476 .36913 L
.36667 .3699 L
.36857 .37067 L
.36949 .37104 L
.36949 .37104 L
.36949 .37104 L
.37048 .3712 L
.37238 .37151 L
.37429 .37181 L
.37619 .37212 L
.3781 .37243 L
.38 .37274 L
Mistroke
.3819 .37304 L
.38381 .37335 L
.38571 .37366 L
.38762 .37397 L
.38952 .37428 L
.39143 .37458 L
.39333 .37489 L
.39524 .3752 L
.39714 .37551 L
.39905 .37582 L
.40095 .37612 L
.40286 .37643 L
.40476 .37674 L
.40667 .37705 L
.40857 .37735 L
.41048 .37766 L
.41238 .37797 L
.41429 .37828 L
.41619 .37859 L
.4181 .37889 L
.42 .3792 L
.4219 .37951 L
.42381 .37982 L
.42571 .38013 L
.42762 .38043 L
.42952 .38074 L
.43143 .38105 L
.43333 .38136 L
.43524 .38166 L
.43714 .38197 L
.43905 .38228 L
.44095 .38259 L
.44286 .3829 L
.44476 .3832 L
.44667 .38351 L
.44857 .38382 L
.45048 .38413 L
.45238 .38444 L
.45429 .38474 L
.45619 .38505 L
.45767 .38529 L
.45767 .38529 L
.45767 .38529 L
.4581 .38541 L
.46 .38597 L
.4619 .38652 L
.46381 .38708 L
.46571 .38763 L
.46762 .38818 L
.46952 .38874 L
Mistroke
.47143 .38929 L
.47333 .38985 L
.47524 .3904 L
.47714 .39096 L
.47905 .39151 L
.48095 .39206 L
.48286 .39262 L
.48476 .39317 L
.48667 .39373 L
.48857 .39428 L
.49048 .39483 L
.49238 .39539 L
.49429 .39594 L
.49619 .3965 L
.4981 .39705 L
.5 .39761 L
.5019 .39816 L
.50381 .39871 L
.50571 .39927 L
.50762 .39982 L
.50855 .40009 L
.50855 .40009 L
.50855 .40009 L
.50952 .40038 L
.51143 .40093 L
.51333 .40148 L
.51524 .40204 L
.51714 .40259 L
.51905 .40315 L
.52095 .4037 L
.52286 .40426 L
.52476 .40481 L
.52667 .40536 L
.52857 .40592 L
.53048 .40647 L
.53238 .40703 L
.53429 .40758 L
.53619 .40813 L
.5381 .40869 L
.54 .40924 L
.5419 .4098 L
.54381 .41035 L
.54571 .41091 L
.54762 .41146 L
.54952 .41201 L
.55143 .41257 L
.55333 .41312 L
.55524 .41368 L
.55714 .41423 L
.55905 .41478 L
Mistroke
.56095 .41534 L
.56286 .41589 L
.56476 .41645 L
.56667 .417 L
.56857 .41755 L
.57048 .41811 L
.57238 .41866 L
.57429 .41922 L
.57619 .41977 L
.5781 .42033 L
.58 .42088 L
.5819 .42143 L
.58381 .42199 L
.58571 .42254 L
.58762 .4231 L
.58952 .42365 L
.59143 .4242 L
.59333 .42476 L
.59524 .42531 L
.59714 .42587 L
.59905 .42642 L
.60095 .42698 L
.60286 .42753 L
.60464 .42805 L
.60464 .42805 L
.60464 .42805 L
.60476 .42808 L
.60667 .42858 L
.60857 .42908 L
.61048 .42958 L
.61238 .43008 L
.61429 .43057 L
.61619 .43107 L
.6181 .43157 L
.62 .43207 L
.6219 .43257 L
.62381 .43307 L
.62571 .43357 L
.62726 .43397 L
.62726 .43397 L
.62726 .43397 L
.62762 .43407 L
.62952 .43462 L
.63143 .43517 L
.63333 .43571 L
.63524 .43626 L
.63714 .43681 L
.63905 .43735 L
.64095 .4379 L
.64139 .43803 L
Mistroke
.64139 .43803 L
.64139 .43803 L
.64286 .43843 L
.64476 .43896 L
.64667 .43949 L
.64857 .44002 L
.65048 .44055 L
.65238 .44108 L
.65429 .44161 L
.65619 .44214 L
.6581 .44267 L
.66 .4432 L
.6619 .44373 L
.66381 .44425 L
.66571 .44478 L
.66762 .44531 L
.66952 .44584 L
.67143 .44637 L
.67333 .4469 L
.67524 .44743 L
.67714 .44796 L
.67905 .44849 L
.68095 .44902 L
.68286 .44954 L
.68476 .45007 L
.68667 .4506 L
.68857 .45113 L
.69048 .45166 L
.69238 .45219 L
.69429 .45272 L
.69619 .45325 L
.6981 .45378 L
.7 .45431 L
.7019 .45483 L
.70381 .45536 L
.70571 .45589 L
.70762 .45642 L
.70952 .45695 L
.71143 .45748 L
.71333 .45801 L
.71524 .45854 L
.71714 .45907 L
.71905 .4596 L
.72095 .46013 L
.72286 .46065 L
.72476 .46118 L
.72667 .46171 L
.72857 .46224 L
.73048 .46277 L
.73238 .4633 L
Mistroke
.73429 .46383 L
.73619 .46436 L
.7381 .46489 L
.74 .46542 L
.7419 .46594 L
.74381 .46647 L
.74571 .467 L
.74762 .46753 L
.74952 .46806 L
.75143 .46859 L
.75333 .46912 L
.75524 .46965 L
.75714 .47018 L
.75905 .47071 L
.76095 .47123 L
.76286 .47176 L
.76476 .47229 L
.76667 .47282 L
.76857 .47335 L
.77048 .47388 L
.77238 .47441 L
.77261 .47447 L
.77261 .47447 L
.77261 .47447 L
.77429 .47494 L
.77619 .47547 L
.7781 .476 L
.78 .47653 L
.7819 .47706 L
.78381 .47759 L
.78571 .47812 L
.78762 .47865 L
.78952 .47918 L
.79143 .47971 L
.79333 .48024 L
.79524 .48077 L
.79714 .4813 L
.79905 .48183 L
.80095 .48236 L
.80286 .48289 L
.80476 .48342 L
.80667 .48395 L
.80857 .48448 L
.81048 .48501 L
.81238 .48554 L
.81429 .48607 L
.81619 .4866 L
.8181 .48713 L
.82 .48766 L
.8219 .48819 L
Mistroke
.82381 .48872 L
.82571 .48925 L
.82762 .48978 L
.82952 .49031 L
.83143 .49084 L
.83333 .49137 L
.83524 .4919 L
.83714 .49243 L
.83905 .49296 L
.84095 .49349 L
.84286 .49402 L
.84476 .49455 L
.84667 .49508 L
.84857 .49561 L
.85048 .49614 L
.85238 .49667 L
.85429 .4972 L
.85619 .49773 L
.8581 .49826 L
.86 .49879 L
.8619 .49932 L
.86381 .49985 L
.86571 .50038 L
.86762 .50091 L
.86952 .50144 L
.87143 .50197 L
.87333 .5025 L
.87524 .50303 L
.87714 .50356 L
.87905 .50409 L
.88095 .50462 L
.88286 .50515 L
.88476 .50568 L
.88667 .50621 L
.88857 .50674 L
.89048 .50727 L
.89238 .5078 L
.89429 .50833 L
.89619 .50886 L
.8981 .50939 L
.9 .50992 L
.9019 .51045 L
.90381 .51098 L
.90571 .51151 L
.90762 .51204 L
.90952 .51257 L
.91143 .5131 L
.91333 .51363 L
.91524 .51416 L
.91714 .51469 L
Mistroke
.91905 .51522 L
.92095 .51575 L
.92286 .51628 L
.92476 .51681 L
.92667 .51734 L
.92857 .51787 L
.93048 .5184 L
.93238 .51893 L
.93429 .51946 L
.93619 .51999 L
.9381 .52052 L
.94 .52105 L
.9419 .52158 L
.94381 .52211 L
.94571 .52264 L
.94762 .52317 L
.94952 .5237 L
.95143 .52424 L
.95156 .52427 L
.95156 .52427 L
.95156 .52427 L
.95333 .52477 L
.95524 .5253 L
.95714 .52583 L
.95905 .52636 L
.95952 .52649 L
.95952 .52649 L
.95952 .52649 L
.96095 .52689 L
.96286 .52742 L
.96476 .52796 L
.96667 .52849 L
.96857 .52903 L
.97048 .52956 L
.97053 .52958 L
.97053 .52958 L
.97053 .52958 L
.97238 .5301 L
.97429 .53063 L
.97619 .53117 L
.97619 .53117 L
Mfstroke
0 .75 .75 r
.02381 .4423 m
.02571 .4423 L
.02762 .4423 L
.02952 .4423 L
.03143 .4423 L
.03333 .4423 L
.03524 .4423 L
.03714 .4423 L
.03905 .4423 L
.04095 .4423 L
.04286 .4423 L
.04476 .4423 L
.04667 .4423 L
.04857 .4423 L
.05048 .4423 L
.05238 .4423 L
.05429 .4423 L
.05619 .4423 L
.0581 .4423 L
.06 .4423 L
.0619 .4423 L
.06381 .4423 L
.06571 .4423 L
.06762 .4423 L
.06952 .4423 L
.07143 .4423 L
.07333 .4423 L
.07524 .4423 L
.07714 .4423 L
.07905 .4423 L
.08095 .4423 L
.08286 .4423 L
.08476 .4423 L
.08667 .4423 L
.0873 .4423 L
.0873 .4423 L
.0873 .4423 L
.08857 .4423 L
.09048 .4423 L
.09238 .4423 L
.09429 .4423 L
.09619 .4423 L
.0981 .4423 L
.1 .4423 L
.1019 .4423 L
.10381 .4423 L
.10571 .4423 L
.10762 .4423 L
.10952 .4423 L
.11143 .4423 L
Mistroke
.11333 .4423 L
.11524 .4423 L
.11714 .4423 L
.11905 .4423 L
.12095 .4423 L
.12286 .4423 L
.12476 .4423 L
.12667 .4423 L
.12857 .4423 L
.13048 .4423 L
.13238 .4423 L
.13429 .4423 L
.13619 .4423 L
.1381 .4423 L
.14 .4423 L
.1419 .4423 L
.14381 .4423 L
.14571 .4423 L
.14762 .4423 L
.14952 .4423 L
.15143 .4423 L
.15333 .4423 L
.15524 .4423 L
.15714 .4423 L
.15905 .4423 L
.16095 .4423 L
.16286 .4423 L
.16476 .4423 L
.16667 .4423 L
.16857 .4423 L
.17048 .4423 L
.17238 .4423 L
.17429 .4423 L
.17619 .4423 L
.1781 .4423 L
.18 .4423 L
.1819 .4423 L
.18381 .4423 L
.18571 .4423 L
.18762 .4423 L
.18952 .4423 L
.19143 .4423 L
.19312 .4423 L
.19312 .4423 L
.19312 .4423 L
.19333 .4423 L
.19524 .4423 L
.19714 .4423 L
.19905 .4423 L
.20095 .4423 L
Mistroke
.20286 .4423 L
.20476 .4423 L
.20667 .4423 L
.20857 .4423 L
.21048 .4423 L
.21238 .4423 L
.21429 .4423 L
.21619 .4423 L
.2181 .4423 L
.22 .4423 L
.2219 .4423 L
.22381 .4423 L
.22571 .4423 L
.22762 .4423 L
.22952 .4423 L
.23143 .4423 L
.23333 .4423 L
.23524 .4423 L
.23714 .4423 L
.23905 .4423 L
.24095 .4423 L
.24286 .4423 L
.24476 .4423 L
.24667 .4423 L
.24857 .4423 L
.25048 .4423 L
.25238 .4423 L
.25429 .4423 L
.25619 .4423 L
.2581 .4423 L
.26 .4423 L
.2619 .4423 L
.26381 .4423 L
.26571 .4423 L
.26762 .4423 L
.26952 .4423 L
.27143 .4423 L
.27333 .4423 L
.27524 .4423 L
.27714 .4423 L
.27905 .4423 L
.28095 .4423 L
.28286 .4423 L
.28476 .4423 L
.28667 .4423 L
.28857 .4423 L
.29048 .4423 L
.29238 .4423 L
.29429 .4423 L
.29619 .4423 L
Mistroke
.2981 .4423 L
.3 .4423 L
.3019 .4423 L
.30381 .4423 L
.30571 .4423 L
.30762 .4423 L
.30952 .4423 L
.31143 .4423 L
.31333 .4423 L
.31524 .4423 L
.31714 .4423 L
.31905 .4423 L
.32095 .4423 L
.32286 .4423 L
.32476 .4423 L
.3254 .4423 L
.3254 .4423 L
.3254 .4423 L
.32667 .4423 L
.32857 .4423 L
.33048 .4423 L
.33238 .4423 L
.33429 .4423 L
.33619 .4423 L
.3381 .4423 L
.34 .4423 L
.3419 .4423 L
.34381 .4423 L
.34571 .4423 L
.34762 .4423 L
.34952 .4423 L
.35143 .4423 L
.35333 .4423 L
.35524 .4423 L
.35714 .4423 L
.35905 .4423 L
.36095 .4423 L
.36286 .4423 L
.36476 .4423 L
.36667 .4423 L
.36857 .4423 L
.36949 .4423 L
.36949 .4423 L
.36949 .4423 L
.37048 .44254 L
.37238 .443 L
.37429 .44347 L
.37619 .44393 L
.3781 .44439 L
.38 .44485 L
Mistroke
.3819 .44531 L
.38381 .44577 L
.38571 .44624 L
.38762 .4467 L
.38952 .44716 L
.39143 .44762 L
.39333 .44808 L
.39524 .44855 L
.39714 .44901 L
.39905 .44947 L
.40095 .44993 L
.40286 .45039 L
.40476 .45085 L
.40667 .45132 L
.40857 .45178 L
.41048 .45224 L
.41238 .4527 L
.41429 .45316 L
.41619 .45363 L
.4181 .45409 L
.42 .45455 L
.4219 .45501 L
.42381 .45547 L
.42571 .45593 L
.42762 .4564 L
.42952 .45686 L
.43143 .45732 L
.43333 .45778 L
.43524 .45824 L
.43714 .4587 L
.43905 .45917 L
.44095 .45963 L
.44286 .46009 L
.44476 .46055 L
.44667 .46101 L
.44857 .46148 L
.45048 .46194 L
.45238 .4624 L
.45429 .46286 L
.45619 .46332 L
.45767 .46368 L
.45767 .46368 L
.45767 .46368 L
.4581 .46378 L
.46 .46425 L
.4619 .46471 L
.46381 .46517 L
.46571 .46563 L
.46762 .46609 L
.46952 .46656 L
Mistroke
.47143 .46702 L
.47333 .46748 L
.47524 .46794 L
.47714 .4684 L
.47905 .46886 L
.48095 .46933 L
.48286 .46979 L
.48476 .47025 L
.48667 .47071 L
.48857 .47117 L
.49048 .47163 L
.49238 .4721 L
.49429 .47256 L
.49619 .47302 L
.4981 .47348 L
.5 .47394 L
.5019 .47441 L
.50381 .47487 L
.50571 .47533 L
.50762 .47579 L
.50855 .47602 L
.50855 .47602 L
.50855 .47602 L
.50952 .47625 L
.51143 .47671 L
.51333 .47718 L
.51524 .47764 L
.51714 .4781 L
.51905 .47856 L
.52095 .47902 L
.52286 .47949 L
.52476 .47995 L
.52667 .48041 L
.52857 .48087 L
.53048 .48133 L
.53238 .48179 L
.53429 .48226 L
.53619 .48272 L
.5381 .48318 L
.54 .48364 L
.5419 .4841 L
.54381 .48457 L
.54571 .48503 L
.54762 .48549 L
.54952 .48595 L
.55143 .48641 L
.55333 .48687 L
.55524 .48734 L
.55714 .4878 L
.55905 .48826 L
Mistroke
.56095 .48872 L
.56286 .48918 L
.56476 .48964 L
.56667 .49011 L
.56857 .49057 L
.57048 .49103 L
.57238 .49149 L
.57429 .49195 L
.57619 .49242 L
.5781 .49288 L
.58 .49334 L
.5819 .4938 L
.58381 .49426 L
.58571 .49472 L
.58762 .49519 L
.58952 .49565 L
.59143 .49611 L
.59333 .49657 L
.59524 .49703 L
.59714 .4975 L
.59905 .49796 L
.60095 .49842 L
.60286 .49888 L
.60464 .49931 L
.60464 .49931 L
.60464 .49931 L
.60476 .49935 L
.60667 .49986 L
.60857 .50038 L
.61048 .5009 L
.61238 .50141 L
.61429 .50193 L
.61619 .50245 L
.6181 .50297 L
.62 .50348 L
.6219 .504 L
.62381 .50452 L
.62571 .50504 L
.62726 .50545 L
.62726 .50545 L
.62726 .50545 L
.62762 .50555 L
.62952 .50607 L
.63143 .50659 L
.63333 .5071 L
.63524 .50762 L
.63714 .50814 L
.63905 .50866 L
.64095 .50917 L
.64139 .50929 L
Mistroke
.64139 .50929 L
.64139 .50929 L
.64286 .5097 L
.64476 .51024 L
.64667 .51077 L
.64857 .51131 L
.65048 .51184 L
.65238 .51238 L
.65429 .51291 L
.65619 .51345 L
.6581 .51398 L
.66 .51452 L
.6619 .51505 L
.66381 .51559 L
.66571 .51612 L
.66762 .51666 L
.66952 .51719 L
.67143 .51773 L
.67333 .51826 L
.67524 .5188 L
.67714 .51933 L
.67905 .51987 L
.68095 .5204 L
.68286 .52094 L
.68476 .52147 L
.68667 .52201 L
.68857 .52254 L
.69048 .52308 L
.69238 .52361 L
.69429 .52415 L
.69619 .52468 L
.6981 .52522 L
.7 .52575 L
.7019 .52629 L
.70381 .52682 L
.70571 .52736 L
.70762 .52789 L
.70952 .52843 L
.71143 .52896 L
.71333 .5295 L
.71524 .53003 L
.71714 .53057 L
.71905 .5311 L
.72095 .53164 L
.72286 .53217 L
.72476 .53271 L
.72667 .53324 L
.72857 .53378 L
.73048 .53431 L
.73238 .53485 L
Mistroke
.73429 .53538 L
.73619 .53592 L
.7381 .53645 L
.74 .53699 L
.7419 .53752 L
.74381 .53806 L
.74571 .53859 L
.74762 .53913 L
.74952 .53966 L
.75143 .5402 L
.75333 .54073 L
.75524 .54127 L
.75714 .5418 L
.75905 .54234 L
.76095 .54287 L
.76286 .54341 L
.76476 .54394 L
.76667 .54448 L
.76857 .54501 L
.77048 .54555 L
.77238 .54608 L
.77261 .54615 L
.77261 .54615 L
.77261 .54615 L
.77429 .54661 L
.77619 .54715 L
.7781 .54768 L
.78 .54822 L
.7819 .54875 L
.78381 .54929 L
.78571 .54982 L
.78762 .55036 L
.78952 .55089 L
.79143 .55143 L
.79333 .55196 L
.79524 .5525 L
.79714 .55303 L
.79905 .55357 L
.80095 .5541 L
.80286 .55464 L
.80476 .55517 L
.80667 .55571 L
.80857 .55624 L
.81048 .55678 L
.81238 .55731 L
.81429 .55785 L
.81619 .55838 L
.8181 .55892 L
.82 .55945 L
.8219 .55999 L
Mistroke
.82381 .56052 L
.82571 .56106 L
.82762 .56159 L
.82952 .56213 L
.83143 .56266 L
.83333 .5632 L
.83524 .56373 L
.83714 .56427 L
.83905 .5648 L
.84095 .56534 L
.84286 .56587 L
.84476 .56641 L
.84667 .56694 L
.84857 .56748 L
.85048 .56801 L
.85238 .56855 L
.85429 .56908 L
.85619 .56962 L
.8581 .57015 L
.86 .57069 L
.8619 .57122 L
.86381 .57176 L
.86571 .57229 L
.86762 .57283 L
.86952 .57336 L
.87143 .5739 L
.87333 .57443 L
.87524 .57497 L
.87714 .5755 L
.87905 .57604 L
.88095 .57657 L
.88286 .57711 L
.88476 .57764 L
.88667 .57818 L
.88857 .57871 L
.89048 .57925 L
.89238 .57978 L
.89429 .58032 L
.89619 .58085 L
.8981 .58139 L
.9 .58192 L
.9019 .58246 L
.90381 .58299 L
.90571 .58353 L
.90762 .58406 L
.90952 .5846 L
.91143 .58513 L
.91333 .58567 L
.91524 .5862 L
.91714 .58674 L
Mistroke
.91905 .58727 L
.92095 .58781 L
.92286 .58834 L
.92476 .58888 L
.92667 .58941 L
.92857 .58995 L
.93048 .59048 L
.93238 .59102 L
.93429 .59155 L
.93619 .59209 L
.9381 .59262 L
.94 .59315 L
.9419 .59369 L
.94381 .59422 L
.94571 .59476 L
.94762 .59529 L
.94952 .59583 L
.95143 .59636 L
.95156 .5964 L
.95156 .5964 L
.95156 .5964 L
.95333 .5969 L
.95524 .59743 L
.95714 .59797 L
.95905 .5985 L
.95952 .59864 L
.95952 .59864 L
.95952 .59864 L
.96095 .59904 L
.96286 .59957 L
.96476 .60011 L
.96667 .60064 L
.96857 .60118 L
.97048 .60171 L
.97053 .60173 L
.97053 .60173 L
.97053 .60173 L
.97238 .60225 L
.97429 .60278 L
.97619 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0714286 0.583445 0.547619 0.726302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00611247 0.0611247 0.00619835 0.0619835 [
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0110024 0.011157 0.0721271 0.0731405 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .75 .75 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .04215 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 12.813 moveto
(@) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.0830579 0.0721271 0.145041 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .11405 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 12.813 moveto
(@) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.154959 0.0721271 0.216942 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .5 0 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .18595 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 12.813 moveto
(@) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.22686 0.0721271 0.288843 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .25785 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 12.813 moveto
(@) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .74402 L
0 .74402 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 214.25},
  ImageMargins->{{93, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eR000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00;P3IfMT4000001h0fMWI0`00000K0=WIf@<00000
7P3IfMT2000001/0fMWI1@0000020=WIf@8000005`3IfMT5000000030=WIf@000000000000800000
5P3IfMT5000000<0fMWI0`00000Y0=WIf@00;P3IfMT00`000000fMWI0=WIf@0P0=WIf@030000003I
fMT0fMWI01X0fMWI00@000000=WIf@3IfMT00000703IfMT010000000fMWI0=WIf@00000L0=WIf@05
0000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WIf@0F0=WIf@050000003IfMT0fMWI
0=WIf@0000006`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI02P0fMWI000_0=WI
f@030000003IfMT0fMWI01`0fMWI1@00000K0=WIf@040000003IfMT0fMWI000001`0fMWI00@00000
0=WIf@3IfMT00000703IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT0
5P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI01P0fMWI00@000000=WIf@3IfMT0
fMWI1@00000Y0=WIf@00<03IfMT00`000000fMWI0=WIf@0K0=WIf@040000003IfMT0fMWI000001`0
fMWI0`00000N0=WIf@8000007@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WI
f@3IfMT05P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI01L0fMWI00D000000=WI
f@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI02P0fMWI000^0=WIf@040000003IfMT0fMWI
000001d0fMWI00<000000=WIf@0000007@3IfMT00`000000fMWI0=WIf@0L0=WIf@040000003IfMT0
fMWI000001`0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI01H0fMWI
00D000000=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0000000Z0=WIf@00;`3IfMT2000001l0fMWI0P00000M0=WIf@<00000
7@3IfMT2000001`0fMWI0P0000040=WIf@800000603IfMT2000000@0fMWI0P00000H0=WIf@800000
1@3IfMT2000002X0fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI000@0=WIf@030000003IfMT0fMWI
0?l0fMWI3P3IfMT00100fMWI00<000000=WIf@3IfMT0o`3IfMT>0=WIf@00403IfMT00`000000fMWI
0=WIf@3n0=WIf@8000003@3IfMT000X0fMWI1P0000000`000?l000000000003e000000P0fMWI00@0
00000=WIf@3IfMT00000303IfMT00100fMWI0P000?l60=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00d0fMWI000@
0=WIf@03000000000?l0fMWI01d0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0M
0=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0M
0=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT06`3IfMT5000000`0fMWI000@0=WI
f@030000003IfMT0003o0?d0fMWI00<000000=WIf@3IfMT03@3IfMT00100fMWI00@000000=WIf@3I
fMT0003oo`3IfMT=0=WIf@00403IfMT01@000000fMWI0=WIf@3IfMT0003o0?l0fMWI303IfMT00100
fMWI00<000000=WIf@3IfMT00P3IfMT00`000?l0fMWI0=WIf@3o0=WIf@T0fMWI000@0=WIf@030000
003IfMT0fMWI0080fMWI0P000?oo0=WIf@X0fMWI000@0=WIf@030000003IfMT0fMWI00<0fMWI0P00
0?oo0=WIf@T0fMWI000@0=WIf@8000001@3IfMT00`000?l0fMWI0=WIf@3o0=WIf@L0fMWI000@0=WI
f@030000003IfMT0fMWI00D0fMWI00<0003o0=WIf@3IfMT0o`3IfMT60=WIf@00403IfMT00`000000
fMWI0=WIf@060=WIf@030000o`3IfMT0fMWI0?l0fMWI1@3IfMT00100fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000?l0fMWI0=WIf@3o0=WIf@@0fMWI000@0=WIf@030000003IfMT0fMWI00P0fMWI00<0
003o0=WIf@3IfMT0o`3IfMT30=WIf@00403IfMT00`000000fMWI0=WIf@090=WIf@030000o`3IfMT0
fMWI0?l0fMWI0P3IfMT00100fMWI00<000000=WIf@3IfMT02P3IfMT00`000?l0fMWI0=WIf@3o0=WI
f@40fMWI000@0=WIf@030000003IfMT0fMWI00X0fMWI0P000?oo0=WIf@80fMWI000@0=WIf@030000
003IfMT0fMWI00/0fMWI0P000?oo0=WIf@40fMWI000@0=WIf@8000003@3IfMT20000ool0fMWI000@
0=WIf@030000003IfMT0fMWI00d0fMWI0`000?om0=WIf@00403IfMT00`000000fMWI0=WIf@0@0=WI
f@80003on`3IfMT00100fMWI00<000000=WIf@3IfMT04@3IfMT30000ooT0fMWI000@0=WIf@030000
003IfMT0fMWI01@0fMWI0`000?of0=WIf@00403IfMT00`000000fMWI0=WIf@0F0=WIf@<0003om03I
fMT00100fMWI00<000000=WIf@3IfMT0603IfMT30000oo80fMWI000@0=WIf@030000003IfMT0fMWI
01/0fMWI0`000?o_0=WIf@00403IfMT00`000000fMWI0=WIf@0M0=WIf@80003okP3IfMT00100fMWI
0P00000P0=WIf@<0003oj`3IfMT00100fMWI00<000000=WIf@3IfMT08@3IfMT30000onT0fMWI000@
0=WIf@030000003IfMT0fMWI02<0fMWI0`000?oW0=WIf@00403IfMT00`000000fMWI0=WIf@0V0=WI
f@<0003oi03IfMT00100fMWI00<000000=WIf@3IfMT0:03IfMT30000on80fMWI000@0=WIf@030000
003IfMT0fMWI02X0fMWI0`000?oP0=WIf@00403IfMT00`000000fMWI0=WIf@0/0=WIf@<0003ogP3I
fMT000P0fMWI100000040=WIf@030000003IfMT0fMWI02h0fMWI0`000?oL0=WIf@00203IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0340fMWI0`000?oI0=WIf@002@3IfMT00`000000
fMWI0=WIf@040=WIfA4007l09@3IfMT30000omL0fMWI000:0=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT03@3IfMT2001o02H0fMWI0`000?oE0=WIf@00203IfMT010000000fMWI0=WI
f@0000040=WIf@030000003IfMT0fMWI00l0fMWI0P00O`0W0=WIf@<0003odP3IfMT000T0fMWI0P00
00050=WIf@030000003IfMT0fMWI0100fMWI0P00O`0X0=WIf@80003od@3IfMT00100fMWI00<00000
0=WIf@3IfMT04@3IfMT2001o02T0fMWI0`000?o>0=WIf@00403IfMT00`000000fMWI0=WIf@0C0=WI
f@8007l0:@3IfMT30000ol`0fMWI000@0=WIf@030000003IfMT0fMWI01@0fMWI0P00O`0Z0=WIf@<0
003obP3IfMT00100fMWI00<000000=WIf@3IfMT05P3IfMT2001o02/0fMWI0`000?o70=WIf@00403I
fMT00`000000fMWI0=WIf@0G0=WIf@<007l0:`3IfMT30000olD0fMWI000@0=WIf@8000006P3IfMT2
001o02`0fMWI0`000?o30=WIf@00403IfMT00`000000fMWI0=WIf@0K0=WIf@8007l0;03IfMT40000
ol00fMWI000@0=WIf@030000003IfMT0fMWI01`0fMWI0P00O`0^0=WIf@@0003o_@3IfMT00100fMWI
00<000000=WIf@3IfMT07P3IfMT00`00O`00fMWI0=WIf@0^0=WIf@@0003o^P3IfMT00100fMWI00<0
00000=WIf@3IfMT07`3IfMT2001o0340fMWI10000?ng0=WIf@00403IfMT00`000000fMWI0=WIf@0P
0=WIf@8007l0<`3IfMT30000okD0fMWI000@0=WIf@030000003IfMT0fMWI0280fMWI0P00O`0d0=WI
f@<0003o/P3IfMT00100fMWI00<000000=WIf@3IfMT08`3IfMT2001o03H0fMWI0`000?n_0=WIf@00
403IfMT00`000000fMWI0=WIf@0U0=WIf@8007l0=`3IfMT30000oj`0fMWI000@0=WIf@030000003I
fMT0fMWI02H0fMWI0`00O`0h0=WIf@<0003oZ@3IfMT00100fMWI0P00000Y0=WIf@@007l0>03IfMT3
0000ojH0fMWI000@0=WIf@030000003IfMT0fMWI02`0fMWI1000O`0g0=WIf@<0003oX`3IfMT00100
fMWI00<000000=WIf@3IfMT0;`3IfMT4001o03L0fMWI0`000?nP0=WIf@00403IfMT00`000000fMWI
0=WIf@0c0=WIf@@007l0=P3IfMT30000oid0fMWI000@0=WIf@030000003IfMT0fMWI03L0fMWI1000
O`0e0=WIf@<0003oVP3IfMT00100fMWI00<000000=WIf@3IfMT0>P3IfMT4001o03@0fMWI10000?nG
0=WIf@00403IfMT00`000000fMWI0=WIf@0n0=WIf@@007l0<`3IfMT40000oi@0fMWI000@0=WIf@03
0000003IfMT0fMWI0480fMWI1000O`0b0=WIf@@0003oT@3IfMT00100fMWI00<000000=WIf@3IfMT0
AP3IfMT4001o0380fMWI10000?n=0=WIf@00403IfMT2000004X0fMWI0`00O`0d0=WIf@<0003oRP3I
fMT00100fMWI00<000000=WIf@3IfMT0C03IfMT3001o03@0fMWI10000?n60=WIf@00403IfMT00`00
0000fMWI0=WIf@1>0=WIf@@007l0=03IfMT40000oh<0fMWI000@0=WIf@030000003IfMT0fMWI0540
fMWI0`00O`000`3IfMT007l00=WIf@0c0=WIf@@0003oO`3IfMT00100fMWI00<000000=WIf@3IfMT0
E03IfMT3001o03L0fMWI0`000?ml0=WIf@00403IfMT00`000000fMWI0=WIf@1F0=WIf@<007l0>03I
fMT40000ogP0fMWI000@0=WIf@030000003IfMT0fMWI05T0fMWI0`00O`0h0=WIf@D0003oM03IfMT0
00X0fMWI0`0000030=WIf@030000003IfMT0fMWI05`0fMWI0`00O`0i0=WIf@@0003oL@3IfMT000/0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@030?l0003IfMT0fMWI01P0
fMWI00<0o`000=WIf@3IfMT0<`3IfMT4001o03X0fMWI0`000?m^0=WIf@00203IfMT5000000<0fMWI
;P3o000f0=WIf@<007l0>`3IfMT40000ofX0fMWI00080=WIf@040000003IfMT0fMWI000000@0fMWI
00<000000=WIf@3IfMT0:P3IfMT30?l003L0fMWI0`00O`0k0=WIf@D0003oIP3IfMT000T0fMWI00<0
00000=WIf@000000103IfMT00`000000fMWI0=WIf@0/0=WIf@<0o`00=`3IfMT3001o03d0fMWI1000
0?mS0=WIf@002P3IfMT2000000@0fMWI00<000000=WIf@3IfMT0;`3IfMT30?l003L0fMWI1000O`0m
0=WIf@<0003oH03IfMT00100fMWI00<000000=WIf@3IfMT0<@3IfMT40?l003L0fMWI1@00O`0l0=WI
f@@0003oG03IfMT00100fMWI00<000000=WIf@3IfMT0=03IfMT30?l003T0fMWI1000O`0l0=WIf@D0
003oF03IfMT00100fMWI00<000000=WIf@3IfMT0=`3IfMT30?l003X0fMWI1@00O`0k0=WIf@@0003o
E@3IfMT00100fMWI00<000000=WIf@3IfMT0>@3IfMT30?l003`0fMWI1000O`0l0=WIf@@0003oD@3I
fMT00100fMWI00<000000=WIf@3IfMT0>`3IfMT30?l003d0fMWI1000O`0l0=WIf@@0003oCP3IfMT0
0100fMWI0P00000o0=WIf@<0o`00?P3IfMT3001o03`0fMWI1@000?m:0=WIf@00403IfMT00`000000
fMWI0=WIf@100=WIf@<0o`00?`3IfMT4001o03`0fMWI10000?m70=WIf@00403IfMT00`000000fMWI
0=WIf@130=WIf@<0o`00?`3IfMT4001o03d0fMWI0`000?m40=WIf@00403IfMT00`000000fMWI0=WI
f@150=WIf@@0o`00@03IfMT4001o03`0fMWI10000?m00=WIf@00403IfMT00`000000fMWI0=WIf@18
0=WIf@<0o`00@@3IfMT3001o00030=WIf@00O`00fMWI03X0fMWI1@000?ll0=WIf@00403IfMT00`00
0000fMWI0=WIf@1:0=WIf@<0o`00@P3IfMT4001o03d0fMWI10000?li0=WIf@00403IfMT00`000000
fMWI0=WIf@1=0=WIf@<0o`00@P3IfMT5001o03d0fMWI0`000?lf0=WIf@00403IfMT00`000000fMWI
0=WIf@1?0=WIf@<0o`00A03IfMT5001o03`0fMWI10000?lb0=WIf@00403IfMT00`000000fMWI0=WI
f@1B0=WIf@@0o`00@`3IfMT4001o03h0fMWI10000?l^0=WIf@00403IfMT2000005D0fMWI1P3o0013
0=WIf@@007l0?@3IfMT40000ob/0fMWI000@0=WIf@030000003IfMT0fMWI05X0fMWI1`3o000o0=WI
f@D007l0?@3IfMT30000obP0fMWI000@0=WIf@030000003IfMT0fMWI0600fMWI1P3o000n0=WIf@@0
07l0?@3IfMT40000ob@0fMWI000@0=WIf@030000003IfMT0fMWI06H0fMWI1P3o000l0=WIf@@007l0
?@3IfMT50000oal0fMWI000@0=WIf@030000003IfMT0fMWI06`0fMWI103o000k0=WIf@@007l0?@3I
fMT30000oah0fMWI000@0=WIf@030000003IfMT0fMWI06l0fMWI103o000l0=WIf@@007l0FP3IfMT0
0100fMWI00<000000=WIf@3IfMT0LP3IfMT40?l003`0fMWI1@00O`1F0=WIf@00403IfMT00`000000
fMWI0=WIf@1f0=WIf@@0o`00?03IfMT4001o00030=WIf@00O`00fMWI0500fMWI000@0=WIf@030000
003IfMT0fMWI07T0fMWI1@3o000k0=WIf@D007l0C`3IfMT00100fMWI0P00001n0=WIf@@0o`00?03I
fMT4001o04`0fMWI000@0=WIf@030000003IfMT0fMWI0800fMWI103o000m0=WIf@@007l0B03IfMT0
0100fMWI00<000000=WIf@3IfMT0Q03IfMT40?l003d0fMWI0`00O`150=WIf@00403IfMT00`000000
fMWI0=WIf@270=WIf@@0o`00?@3IfMT4001o0440fMWI000@0=WIf@030000003IfMT0fMWI08/0fMWI
103o000m0=WIf@@007l0?@3IfMT00100fMWI00<000000=WIf@3IfMT0SP3IfMT40?l003d0fMWI1000
O`0j0=WIf@00403IfMT00`000000fMWI0=WIf@2B0=WIf@D0o`00?03IfMT4001o03H0fMWI00080=WI
f@<000001@3IfMT00`000000fMWI0=WIf@2E0=WIf@H0o`00>`3IfMT4001o03<0fMWI00080=WIf@04
0000003IfMT0fMWI000000@0fMWI00<000000=WIf@3IfMT03@3IfMT00`00_kl0fMWI0=WIf@0H0=WI
f@03002o_`3IfMT0fMWI01h0fMWI00<00;no0=WIf@3IfMT02@3IfMT00`00_kl0fMWI0=WIf@110=WI
f@@0o`00?@3IfMT4001o02l0fMWI00080=WIf@040000003IfMT0fMWI000000@0fMWIF`00_km40=WI
f@D0o`00?@3IfMT4001o02/0fMWI00080=WIf@<000001@3IfMT00`000000fMWI0=WIf@1H0=WIf@@0
0;noA03IfMT40?l003d0fMWI1000O`0X0=WIf@002@3IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0fMWI05`0fMWI1@00_km30=WIf@@0o`00?@3IfMT4001o02@0fMWI00090=WIf@<00000103I
fMT00`000000fMWI0=WIf@1P0=WIf@D00;no@`3IfMT30?l003d0fMWI1000O`000`3IfMT007l00=WI
f@0N0=WIf@00403IfMT00`000000fMWI0=WIf@1T0=WIf@D00;no@P3IfMT40?l003d0fMWI0`00O`0N
0=WIf@00403IfMT00`000000fMWI0=WIf@1X0=WIf@D00;no@@3IfMT50?l005X0fMWI000@0=WIf@03
0000003IfMT0fMWI06`0fMWI1@00_km10=WIf@@0o`00E`3IfMT00100fMWI00<000000=WIf@3IfMT0
L@3IfMT4002o_d40fMWI103o00000`3IfMT0o`000=WIf@1@0=WIf@00403IfMT00`000000fMWI0=WI
f@1d0=WIf@D00;no@03IfMT40?l00500fMWI000@0=WIf@800000NP3IfMT5002o_cl0fMWI103o001<
0=WIf@00403IfMT00`000000fMWI0=WIf@1m0=WIf@@00;no@03IfMT40?l004P0fMWI000@0=WIf@03
0000003IfMT0fMWI0840fMWI1@00_kln0=WIf@@0o`00A@3IfMT00100fMWI00<000000=WIf@3IfMT0
Q@3IfMT5002o_ch0fMWI103o00110=WIf@00403IfMT00`000000fMWI0=WIf@290=WIf@D00;no?@3I
fMT50?l003d0fMWI000@0=WIf@030000003IfMT0fMWI08h0fMWI1000_klm0=WIf@@0o`00>P3IfMT0
0100fMWI00<000000=WIf@3IfMT0T@3IfMT6002o_c`0fMWI0`3o000g0=WIf@00403IfMT00`000000
fMWI0=WIf@2E0=WIf@@00;no00<0fMWI002o_`3IfMT0>P3IfMT40?l003<0fMWI000@0=WIf@030000
003IfMT0fMWI09T0fMWI1000_klm0=WIf@@0o`00;`3IfMT00100fMWI0P00002M0=WIf@@00;no?@3I
fMT50?l002/0fMWI000@0=WIf@030000003IfMT0fMWI0:00fMWI1000_klm0=WIf@@0o`00:03IfMT0
0100fMWI00<000000=WIf@3IfMT0X`3IfMT5002o_c`0fMWI1@3o000T0=WIf@00403IfMT00`000000
fMWI0=WIf@2W0=WIf@@00;no?@3IfMT40?l000030=WIf@3o0000fMWI01h0fMWI000@0=WIf@030000
003IfMT0fMWI0:X0fMWI1@00_klm0=WIf@<0o`007P3IfMT00100fMWI00<000000=WIf@3IfMT0[P3I
fMT4002o_e/0fMWI000@0=WIf@030000003IfMT0fMWI0;80fMWI1000_kmG0=WIf@00403IfMT00`00
0000fMWI0=WIf@2e0=WIf@@00;noE03IfMT00100fMWI00<000000=WIf@3IfMT0^@3IfMT4002o_e00
fMWI000@0=WIf@800000_@3IfMT4002o_dd0fMWI000@0=WIf@030000003IfMT0fMWI0<00fMWI1000
_km90=WIf@00403IfMT00`000000fMWI0=WIf@340=WIf@<00;noAP3IfMT00100fMWI00<000000=WI
f@3IfMT0a`3IfMT4002o_d80fMWI000@0=WIf@030000003IfMT0fMWI0</0fMWI1000_kln0=WIf@00
403IfMT00`000000fMWI0=WIf@3>0=WIf@@00;no>`3IfMT00100fMWI00<000000=WIf@3IfMT0dP3I
fMT4002o_cL0fMWI00090=WIf@8000001@3IfMT00`000000fMWI0=WIf@3E0=WIf@@00;no=03IfMT0
00P0fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@3I0=WIf@@00;no<03IfMT0
00P0fMWI00@000000=WIf@3IfMT00000103IfMT200000=d0fMWI1@00_kl/0=WIf@002@3IfMT20000
00D0fMWI00<000000=WIf@3IfMT0h03IfMT4002o_bT0fMWI00080=WIf@040000003IfMT0fMWI0000
00@0fMWI00<000000=WIf@3IfMT0h`3IfMT6002o_b@0fMWI00090=WIf@8000001@3IfMT00`000000
fMWI0=WIf@3W0=WIf@@00;no8P3IfMT00100fMWI00<000000=WIf@3IfMT0j`3IfMT4002o_ah0fMWI
000@0=WIf@030000003IfMT0fMWI0>h0fMWI00<00;no0=WIf@3IfMT0703IfMT00100fMWI00<00000
0=WIf@3IfMT07@3IfMT2000000P0fMWI0P00003T0=WIf@00403IfMT00`000000fMWI0=WIf@0M0=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0hP3IfMT00100fMWI00<000000=WIf@3I
fMT03P3IfMT2000000030=WIf@000000000000@0fMWI0`0000030=WIf@030000003IfMT0fMWI0080
fMWI0P0000040=WIf@030000003IfMT0fMWI0>80fMWI000F0=WIf@T00;no0`3IfMT00`000000fMWI
000000060=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@05
0000003IfMT0fMWI0=WIf@000000i03IfMT002<0fMWI00<000000=WIf@3IfMT00P3IfMT5000000<0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0>80fMWI000Q0=WIf@80
000000<0fMWI0000000000000P3IfMT010000000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI
00D000000`3IfMT00`000000fMWI0=WIf@3R0=WIf@00:@3IfMT00`000000fMWI000000040=WIf@05
0000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@3R0=WIf@00:P3IfMT2000000@0
fMWI0P0000080=WIf@800000i03IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00300fMWI0P000008
0=WIf@800000i03IfMT00300fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3R0=WI
f@008@3IfMT2000000030=WIf@000000000000<0fMWI0P0000050=WIf@030000003IfMT0fMWI0080
fMWI0P0000040=WIf@030000003IfMT0fMWI0>80fMWI000F0=WIf@T0o`000`3IfMT00`000000fMWI
000000030=WIf@040000003IfMT0fMWI000000@0fMWI00D000000=WIf@3IfMT0fMWI000000020=WI
f@050000003IfMT0fMWI0=WIf@000000i03IfMT002<0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@3R
0=WIf@008@3IfMT2000000030=WIf@000000000000D0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@05000000<0fMWI00<000000=WIf@3IfMT0hP3IfMT002P0fMWI00@000000=WIf@3I
fMT00000103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0hP3IfMT0
02T0fMWI0P0000050=WIf@800000203IfMT200000>@0fMWI003o0=WIfB40fMWI000`0=WIf@800000
203IfMT200000>@0fMWI000`0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0hP3I
fMT00240fMWI0P0000000`3IfMT00000000000020=WIf@@00000103IfMT00`000000fMWI0=WIf@02
0=WIf@800000103IfMT00`000000fMWI0=WIf@3R0=WIf@008P3IfMT00`000000fMWI000000030=WI
f@030000003IfMT0fMWI00D0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@050000003IfMT0
fMWI0=WIf@000000i03IfMT001H0fMWI2@00O`040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0hP3I
fMT00240fMWI0P0000000`3IfMT00000000000040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT01@0000030=WIf@030000003IfMT0fMWI0>80fMWI000X0=WIf@040000003IfMT0fMWI
000000@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0>80fMWI000Y
0=WIf@8000001@3IfMT2000000P0fMWI0P00003T0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00
<03IfMT2000000P0fMWI0P00003T0=WIf@00<03IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI0>80fMWI000Q0=WIf@80000000<0fMWI0000000000000P3IfMT5000000<0fMWI00<00000
0=WIf@3IfMT00P3IfMT2000000@0fMWI00<000000=WIf@3IfMT0hP3IfMT00280fMWI00<000000=WI
f@0000001@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT0
1@000000fMWI0=WIf@3IfMT000000>@0fMWI000F0=WIf@T0003o103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003I
fMT0fMWI0>80fMWI000Q0=WIf@80000000<0fMWI000000000000103IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00D000000`3IfMT00`000000fMWI0=WIf@3R0=WIf@00:P3IfMT00`00
0000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@3R
0=WIf@00:@3IfMT2000000D0fMWI0P0000080=WIf@800000i03IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00001\
\>"],
  ImageRangeCache->{{{196, 483}, {278.25, 65}} -> {-2.48748, -0.178996, \
0.00732689, 0.00732689}, {{203, 475.938}, {273.125, 104.438}} -> {-13.1839, \
2.5415, 0.0621387, 0.0553615}, {{216.625, 353.125}, {111, 70.0625}} -> \
{-26.074, -12.1891, 0.119891, 0.11823}, {{218.125, 226.438}, {109.438, 101}} -> \
{-53.4817, -25.9927, 0.240604, 0.240604}, {{218.125, 226.438}, {99.625, \
91.1875}} -> {-53.4817, -28.3537, 0.240604, 0.240604}, {{218.125, 226.438}, \
{89.8125, 81.375}} -> {-53.4817, -30.7146, 0.240604, 0.240604}, {{218.125, \
226.438}, {80, 71.5625}} -> {-53.4817, -33.0755, 0.240604, 0.240604}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74402 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.312017 0.47619 [
[ 0 0 0 0 ]
[ 1 .74402 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0177147 0.97619 0.606318 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.0147151 0.588604 [
[.15079 .00222 -3 -9 ]
[.15079 .00222 3 0 ]
[.27778 .00222 -3 -9 ]
[.27778 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.53175 .00222 -3 -9 ]
[.53175 .00222 3 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.9127 .00222 -6 -9 ]
[.9127 .00222 6 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 10 6.28125 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .01472 m
.15079 .02097 L
s
[(2)] .15079 .00222 0 1 Mshowa
.27778 .01472 m
.27778 .02097 L
s
[(4)] .27778 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(6)] .40476 .00222 0 1 Mshowa
.53175 .01472 m
.53175 .02097 L
s
[(8)] .53175 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(10)] .65873 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(12)] .78571 .00222 0 1 Mshowa
.9127 .01472 m
.9127 .02097 L
s
[(14)] .9127 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.18254 .01472 m
.18254 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.34127 .01472 m
.34127 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.81746 .01472 m
.81746 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 1 r
.001 w
.02381 .60332 m
.02571 .58566 L
.02762 .568 L
.02952 .55034 L
.03143 .53269 L
.03333 .51503 L
.03524 .49737 L
.03714 .47971 L
.03905 .46205 L
.04095 .4444 L
.04286 .42674 L
.04476 .40908 L
.04667 .39142 L
.04857 .37376 L
.05048 .35611 L
.05238 .33845 L
.05429 .32079 L
.05619 .30313 L
.0581 .28547 L
.06 .26781 L
.0619 .25016 L
.06381 .2325 L
.06571 .21484 L
.06762 .19718 L
.06952 .17952 L
.07143 .16187 L
.07333 .14421 L
.07524 .12655 L
.07714 .10889 L
.07905 .09123 L
.08095 .07358 L
.08286 .05592 L
.08476 .03826 L
.08667 .0206 L
.0873 .01472 L
.0873 .01472 L
.0873 .01472 L
.08857 .01707 L
.09048 .0206 L
.09238 .02413 L
.09429 .02766 L
.09619 .0312 L
.0981 .03473 L
.1 .03826 L
.1019 .04179 L
.10381 .04532 L
.10571 .04885 L
.10762 .05239 L
.10952 .05592 L
.11143 .05945 L
Mistroke
.11333 .06298 L
.11524 .06651 L
.11714 .07004 L
.11905 .07358 L
.12095 .07711 L
.12286 .08064 L
.12476 .08417 L
.12667 .0877 L
.12857 .09123 L
.13048 .09477 L
.13238 .0983 L
.13429 .10183 L
.13619 .10536 L
.1381 .10889 L
.14 .11242 L
.1419 .11595 L
.14381 .11949 L
.14571 .12302 L
.14762 .12655 L
.14952 .13008 L
.15143 .13361 L
.15333 .13714 L
.15524 .14068 L
.15714 .14421 L
.15905 .14774 L
.16095 .15127 L
.16286 .1548 L
.16476 .15833 L
.16667 .16187 L
.16857 .1654 L
.17048 .16893 L
.17238 .17246 L
.17429 .17599 L
.17619 .17952 L
.1781 .18306 L
.18 .18659 L
.1819 .19012 L
.18381 .19365 L
.18571 .19718 L
.18762 .20071 L
.18952 .20425 L
.19143 .20778 L
.19312 .21092 L
.19312 .21092 L
.19312 .21092 L
.19333 .2106 L
.19524 .20778 L
.19714 .20495 L
.19905 .20213 L
.20095 .1993 L
Mistroke
.20286 .19648 L
.20476 .19365 L
.20667 .19083 L
.20857 .188 L
.21048 .18517 L
.21238 .18235 L
.21429 .17952 L
.21619 .1767 L
.2181 .17387 L
.22 .17105 L
.2219 .16822 L
.22381 .1654 L
.22571 .16257 L
.22762 .15975 L
.22952 .15692 L
.23143 .1541 L
.23333 .15127 L
.23524 .14845 L
.23714 .14562 L
.23905 .1428 L
.24095 .13997 L
.24286 .13714 L
.24476 .13432 L
.24667 .13149 L
.24857 .12867 L
.25048 .12584 L
.25238 .12302 L
.25429 .12019 L
.25619 .11737 L
.2581 .11454 L
.26 .11172 L
.2619 .10889 L
.26381 .10607 L
.26571 .10324 L
.26762 .10042 L
.26952 .09759 L
.27143 .09477 L
.27333 .09194 L
.27524 .08911 L
.27714 .08629 L
.27905 .08346 L
.28095 .08064 L
.28286 .07781 L
.28476 .07499 L
.28667 .07216 L
.28857 .06934 L
.29048 .06651 L
.29238 .06369 L
.29429 .06086 L
.29619 .05804 L
Mistroke
.2981 .05521 L
.3 .05239 L
.3019 .04956 L
.30381 .04674 L
.30571 .04391 L
.30762 .04108 L
.30952 .03826 L
.31143 .03543 L
.31333 .03261 L
.31524 .02978 L
.31714 .02696 L
.31905 .02413 L
.32095 .02131 L
.32286 .01848 L
.32476 .01566 L
.3254 .01472 L
.3254 .01472 L
.3254 .01472 L
.32667 .01509 L
.32857 .01566 L
.33048 .01622 L
.33238 .01679 L
.33429 .01735 L
.33619 .01792 L
.3381 .01848 L
.34 .01905 L
.3419 .01961 L
.34381 .02018 L
.34571 .02074 L
.34762 .02131 L
.34952 .02187 L
.35143 .02244 L
.35333 .023 L
.35524 .02357 L
.35714 .02413 L
.35905 .0247 L
.36095 .02526 L
.36286 .02583 L
.36476 .02639 L
.36667 .02696 L
.36857 .02752 L
.36949 .0278 L
.36949 .0278 L
.36949 .0278 L
.37048 .02809 L
.37238 .02865 L
.37429 .02922 L
.37619 .02978 L
.3781 .03035 L
.38 .03091 L
Mistroke
.3819 .03148 L
.38381 .03204 L
.38571 .03261 L
.38762 .03317 L
.38952 .03374 L
.39143 .0343 L
.39333 .03487 L
.39524 .03543 L
.39714 .036 L
.39905 .03656 L
.40095 .03713 L
.40286 .03769 L
.40476 .03826 L
.40667 .03882 L
.40857 .03939 L
.41048 .03995 L
.41238 .04052 L
.41429 .04108 L
.41619 .04165 L
.4181 .04221 L
.42 .04278 L
.4219 .04334 L
.42381 .04391 L
.42571 .04447 L
.42762 .04504 L
.42952 .04561 L
.43143 .04617 L
.43333 .04674 L
.43524 .0473 L
.43714 .04787 L
.43905 .04843 L
.44095 .049 L
.44286 .04956 L
.44476 .05013 L
.44667 .05069 L
.44857 .05126 L
.45048 .05182 L
.45238 .05239 L
.45429 .05295 L
.45619 .05352 L
.45767 .05396 L
.45767 .05396 L
.45767 .05396 L
.4581 .05363 L
.46 .05216 L
.4619 .05069 L
.46381 .04922 L
.46571 .04775 L
.46762 .04628 L
.46952 .04481 L
Mistroke
.47143 .04334 L
.47333 .04188 L
.47524 .04041 L
.47714 .03894 L
.47905 .03747 L
.48095 .036 L
.48286 .03453 L
.48476 .03306 L
.48667 .03159 L
.48857 .03012 L
.49048 .02865 L
.49238 .02718 L
.49429 .02571 L
.49619 .02425 L
.4981 .02278 L
.5 .02131 L
.5019 .01984 L
.50381 .01837 L
.50571 .0169 L
.50762 .01543 L
.50855 .01472 L
.50855 .01472 L
.50855 .01472 L
.50952 .01487 L
.51143 .01516 L
.51333 .01545 L
.51524 .01575 L
.51714 .01604 L
.51905 .01633 L
.52095 .01663 L
.52286 .01692 L
.52476 .01722 L
.52667 .01751 L
.52857 .0178 L
.53048 .0181 L
.53238 .01839 L
.53429 .01869 L
.53619 .01898 L
.5381 .01927 L
.54 .01957 L
.5419 .01986 L
.54381 .02015 L
.54571 .02045 L
.54762 .02074 L
.54952 .02104 L
.55143 .02133 L
.55333 .02162 L
.55524 .02192 L
.55714 .02221 L
.55905 .02251 L
Mistroke
.56095 .0228 L
.56286 .02309 L
.56476 .02339 L
.56667 .02368 L
.56857 .02397 L
.57048 .02427 L
.57238 .02456 L
.57429 .02486 L
.57619 .02515 L
.5781 .02544 L
.58 .02574 L
.5819 .02603 L
.58381 .02633 L
.58571 .02662 L
.58762 .02691 L
.58952 .02721 L
.59143 .0275 L
.59333 .02779 L
.59524 .02809 L
.59714 .02838 L
.59905 .02868 L
.60095 .02897 L
.60286 .02926 L
.60464 .02954 L
.60464 .02954 L
.60464 .02954 L
.60476 .02956 L
.60667 .02985 L
.60857 .03014 L
.61048 .03044 L
.61238 .03073 L
.61429 .03103 L
.61619 .03132 L
.6181 .03161 L
.62 .03191 L
.6219 .0322 L
.62381 .0325 L
.62571 .03279 L
.62726 .03303 L
.62726 .03303 L
.62726 .03303 L
.62762 .03301 L
.62952 .0329 L
.63143 .0328 L
.63333 .0327 L
.63524 .0326 L
.63714 .03249 L
.63905 .03239 L
.64095 .03229 L
.64139 .03226 L
Mistroke
.64139 .03226 L
.64139 .03226 L
.64286 .03218 L
.64476 .03208 L
.64667 .03198 L
.64857 .03188 L
.65048 .03177 L
.65238 .03167 L
.65429 .03157 L
.65619 .03146 L
.6581 .03136 L
.66 .03126 L
.6619 .03116 L
.66381 .03105 L
.66571 .03095 L
.66762 .03085 L
.66952 .03075 L
.67143 .03064 L
.67333 .03054 L
.67524 .03044 L
.67714 .03033 L
.67905 .03023 L
.68095 .03013 L
.68286 .03003 L
.68476 .02992 L
.68667 .02982 L
.68857 .02972 L
.69048 .02961 L
.69238 .02951 L
.69429 .02941 L
.69619 .02931 L
.6981 .0292 L
.7 .0291 L
.7019 .029 L
.70381 .02889 L
.70571 .02879 L
.70762 .02869 L
.70952 .02859 L
.71143 .02848 L
.71333 .02838 L
.71524 .02828 L
.71714 .02817 L
.71905 .02807 L
.72095 .02797 L
.72286 .02787 L
.72476 .02776 L
.72667 .02766 L
.72857 .02756 L
.73048 .02745 L
.73238 .02735 L
Mistroke
.73429 .02725 L
.73619 .02715 L
.7381 .02704 L
.74 .02694 L
.7419 .02684 L
.74381 .02673 L
.74571 .02663 L
.74762 .02653 L
.74952 .02643 L
.75143 .02632 L
.75333 .02622 L
.75524 .02612 L
.75714 .02601 L
.75905 .02591 L
.76095 .02581 L
.76286 .02571 L
.76476 .0256 L
.76667 .0255 L
.76857 .0254 L
.77048 .02529 L
.77238 .02519 L
.77261 .02518 L
.77261 .02518 L
.77261 .02518 L
.77429 .02508 L
.77619 .02497 L
.7781 .02486 L
.78 .02475 L
.7819 .02464 L
.78381 .02452 L
.78571 .02441 L
.78762 .0243 L
.78952 .02419 L
.79143 .02408 L
.79333 .02397 L
.79524 .02386 L
.79714 .02374 L
.79905 .02363 L
.80095 .02352 L
.80286 .02341 L
.80476 .0233 L
.80667 .02319 L
.80857 .02308 L
.81048 .02297 L
.81238 .02285 L
.81429 .02274 L
.81619 .02263 L
.8181 .02252 L
.82 .02241 L
.8219 .0223 L
Mistroke
.82381 .02219 L
.82571 .02207 L
.82762 .02196 L
.82952 .02185 L
.83143 .02174 L
.83333 .02163 L
.83524 .02152 L
.83714 .02141 L
.83905 .02129 L
.84095 .02118 L
.84286 .02107 L
.84476 .02096 L
.84667 .02085 L
.84857 .02074 L
.85048 .02063 L
.85238 .02051 L
.85429 .0204 L
.85619 .02029 L
.8581 .02018 L
.86 .02007 L
.8619 .01996 L
.86381 .01985 L
.86571 .01973 L
.86762 .01962 L
.86952 .01951 L
.87143 .0194 L
.87333 .01929 L
.87524 .01918 L
.87714 .01907 L
.87905 .01896 L
.88095 .01884 L
.88286 .01873 L
.88476 .01862 L
.88667 .01851 L
.88857 .0184 L
.89048 .01829 L
.89238 .01818 L
.89429 .01806 L
.89619 .01795 L
.8981 .01784 L
.9 .01773 L
.9019 .01762 L
.90381 .01751 L
.90571 .0174 L
.90762 .01728 L
.90952 .01717 L
.91143 .01706 L
.91333 .01695 L
.91524 .01684 L
.91714 .01673 L
Mistroke
.91905 .01662 L
.92095 .0165 L
.92286 .01639 L
.92476 .01628 L
.92667 .01617 L
.92857 .01606 L
.93048 .01595 L
.93238 .01584 L
.93429 .01573 L
.93619 .01561 L
.9381 .0155 L
.94 .01539 L
.9419 .01528 L
.94381 .01517 L
.94571 .01506 L
.94762 .01495 L
.94952 .01483 L
.95143 .01472 L
.95156 .01472 L
.95156 .01472 L
.95156 .01472 L
.95333 .01474 L
.95524 .01476 L
.95714 .01478 L
.95905 .0148 L
.95952 .01481 L
.95952 .01481 L
.95952 .01481 L
.96095 .0148 L
.96286 .01478 L
.96476 .01476 L
.96667 .01475 L
.96857 .01473 L
.97048 .01472 L
.97053 .01472 L
.97053 .01472 L
.97053 .01472 L
.97238 .01472 L
.97429 .01472 L
.97619 .01472 L
.97619 .01472 L
Mfstroke
0 .5 0 r
.02381 .60332 m
.02571 .60332 L
.02762 .60332 L
.02952 .60332 L
.03143 .60332 L
.03333 .60332 L
.03524 .60332 L
.03714 .60332 L
.03905 .60332 L
.04095 .60332 L
.04286 .60332 L
.04476 .60332 L
.04667 .60332 L
.04857 .60332 L
.05048 .60332 L
.05238 .60332 L
.05429 .60332 L
.05619 .60332 L
.0581 .60332 L
.06 .60332 L
.0619 .60332 L
.06381 .60332 L
.06571 .60332 L
.06762 .60332 L
.06952 .60332 L
.07143 .60332 L
.07333 .60332 L
.07524 .60332 L
.07714 .60332 L
.07905 .60332 L
.08095 .60332 L
.08286 .60332 L
.08476 .60332 L
.08667 .60332 L
.0873 .60332 L
.0873 .60332 L
.0873 .60332 L
.08857 .59626 L
.09048 .58566 L
.09238 .57507 L
.09429 .56447 L
.09619 .55388 L
.0981 .54328 L
.1 .53269 L
.1019 .52209 L
.10381 .5115 L
.10571 .5009 L
.10762 .49031 L
.10952 .47971 L
.11143 .46912 L
Mistroke
.11333 .45852 L
.11524 .44793 L
.11714 .43733 L
.11905 .42674 L
.12095 .41614 L
.12286 .40555 L
.12476 .39495 L
.12667 .38436 L
.12857 .37376 L
.13048 .36317 L
.13238 .35257 L
.13429 .34198 L
.13619 .33138 L
.1381 .32079 L
.14 .31019 L
.1419 .2996 L
.14381 .289 L
.14571 .27841 L
.14762 .26781 L
.14952 .25722 L
.15143 .24662 L
.15333 .23603 L
.15524 .22544 L
.15714 .21484 L
.15905 .20425 L
.16095 .19365 L
.16286 .18306 L
.16476 .17246 L
.16667 .16187 L
.16857 .15127 L
.17048 .14068 L
.17238 .13008 L
.17429 .11949 L
.17619 .10889 L
.1781 .0983 L
.18 .0877 L
.1819 .07711 L
.18381 .06651 L
.18571 .05592 L
.18762 .04532 L
.18952 .03473 L
.19143 .02413 L
.19312 .01472 L
.19312 .01472 L
.19312 .01472 L
.19333 .01495 L
.19524 .01707 L
.19714 .01919 L
.19905 .02131 L
.20095 .02343 L
Mistroke
.20286 .02555 L
.20476 .02766 L
.20667 .02978 L
.20857 .0319 L
.21048 .03402 L
.21238 .03614 L
.21429 .03826 L
.21619 .04038 L
.2181 .0425 L
.22 .04462 L
.2219 .04674 L
.22381 .04885 L
.22571 .05097 L
.22762 .05309 L
.22952 .05521 L
.23143 .05733 L
.23333 .05945 L
.23524 .06157 L
.23714 .06369 L
.23905 .06581 L
.24095 .06792 L
.24286 .07004 L
.24476 .07216 L
.24667 .07428 L
.24857 .0764 L
.25048 .07852 L
.25238 .08064 L
.25429 .08276 L
.25619 .08488 L
.2581 .087 L
.26 .08911 L
.2619 .09123 L
.26381 .09335 L
.26571 .09547 L
.26762 .09759 L
.26952 .09971 L
.27143 .10183 L
.27333 .10395 L
.27524 .10607 L
.27714 .10819 L
.27905 .1103 L
.28095 .11242 L
.28286 .11454 L
.28476 .11666 L
.28667 .11878 L
.28857 .1209 L
.29048 .12302 L
.29238 .12514 L
.29429 .12726 L
.29619 .12938 L
Mistroke
.2981 .13149 L
.3 .13361 L
.3019 .13573 L
.30381 .13785 L
.30571 .13997 L
.30762 .14209 L
.30952 .14421 L
.31143 .14633 L
.31333 .14845 L
.31524 .15056 L
.31714 .15268 L
.31905 .1548 L
.32095 .15692 L
.32286 .15904 L
.32476 .16116 L
.3254 .16187 L
.3254 .16187 L
.3254 .16187 L
.32667 .16215 L
.32857 .16257 L
.33048 .163 L
.33238 .16342 L
.33429 .16384 L
.33619 .16427 L
.3381 .16469 L
.34 .16512 L
.3419 .16554 L
.34381 .16596 L
.34571 .16639 L
.34762 .16681 L
.34952 .16723 L
.35143 .16766 L
.35333 .16808 L
.35524 .16851 L
.35714 .16893 L
.35905 .16935 L
.36095 .16978 L
.36286 .1702 L
.36476 .17062 L
.36667 .17105 L
.36857 .17147 L
.36949 .17168 L
.36949 .17168 L
.36949 .17168 L
.37048 .16992 L
.37238 .16653 L
.37429 .16314 L
.37619 .15975 L
.3781 .15636 L
.38 .15297 L
Mistroke
.3819 .14958 L
.38381 .14619 L
.38571 .1428 L
.38762 .1394 L
.38952 .13601 L
.39143 .13262 L
.39333 .12923 L
.39524 .12584 L
.39714 .12245 L
.39905 .11906 L
.40095 .11567 L
.40286 .11228 L
.40476 .10889 L
.40667 .1055 L
.40857 .10211 L
.41048 .09872 L
.41238 .09533 L
.41429 .09194 L
.41619 .08855 L
.4181 .08516 L
.42 .08177 L
.4219 .07838 L
.42381 .07499 L
.42571 .0716 L
.42762 .06821 L
.42952 .06482 L
.43143 .06143 L
.43333 .05804 L
.43524 .05465 L
.43714 .05126 L
.43905 .04787 L
.44095 .04447 L
.44286 .04108 L
.44476 .03769 L
.44667 .0343 L
.44857 .03091 L
.45048 .02752 L
.45238 .02413 L
.45429 .02074 L
.45619 .01735 L
.45767 .01472 L
.45767 .01472 L
.45767 .01472 L
.4581 .01487 L
.46 .01554 L
.4619 .01622 L
.46381 .0169 L
.46571 .01758 L
.46762 .01826 L
.46952 .01893 L
Mistroke
.47143 .01961 L
.47333 .02029 L
.47524 .02097 L
.47714 .02165 L
.47905 .02232 L
.48095 .023 L
.48286 .02368 L
.48476 .02436 L
.48667 .02504 L
.48857 .02571 L
.49048 .02639 L
.49238 .02707 L
.49429 .02775 L
.49619 .02843 L
.4981 .02911 L
.5 .02978 L
.5019 .03046 L
.50381 .03114 L
.50571 .03182 L
.50762 .0325 L
.50855 .03283 L
.50855 .03283 L
.50855 .03283 L
.50952 .03272 L
.51143 .03252 L
.51333 .03231 L
.51524 .03211 L
.51714 .03191 L
.51905 .0317 L
.52095 .0315 L
.52286 .0313 L
.52476 .03109 L
.52667 .03089 L
.52857 .03069 L
.53048 .03048 L
.53238 .03028 L
.53429 .03008 L
.53619 .02987 L
.5381 .02967 L
.54 .02947 L
.5419 .02926 L
.54381 .02906 L
.54571 .02886 L
.54762 .02865 L
.54952 .02845 L
.55143 .02825 L
.55333 .02804 L
.55524 .02784 L
.55714 .02764 L
.55905 .02743 L
Mistroke
.56095 .02723 L
.56286 .02703 L
.56476 .02682 L
.56667 .02662 L
.56857 .02642 L
.57048 .02621 L
.57238 .02601 L
.57429 .02581 L
.57619 .0256 L
.5781 .0254 L
.58 .0252 L
.5819 .02499 L
.58381 .02479 L
.58571 .02458 L
.58762 .02438 L
.58952 .02418 L
.59143 .02397 L
.59333 .02377 L
.59524 .02357 L
.59714 .02336 L
.59905 .02316 L
.60095 .02296 L
.60286 .02275 L
.60464 .02256 L
.60464 .02256 L
.60464 .02256 L
.60476 .02252 L
.60667 .02186 L
.60857 .0212 L
.61048 .02054 L
.61238 .01988 L
.61429 .01922 L
.61619 .01856 L
.6181 .01789 L
.62 .01723 L
.6219 .01657 L
.62381 .01591 L
.62571 .01525 L
.62726 .01472 L
.62726 .01472 L
.62726 .01472 L
.62762 .01474 L
.62952 .01487 L
.63143 .015 L
.63333 .01514 L
.63524 .01527 L
.63714 .0154 L
.63905 .01553 L
.64095 .01567 L
.64139 .0157 L
Mistroke
.64139 .0157 L
.64139 .0157 L
.64286 .01569 L
.64476 .01567 L
.64667 .01566 L
.64857 .01564 L
.65048 .01563 L
.65238 .01561 L
.65429 .0156 L
.65619 .01559 L
.6581 .01557 L
.66 .01556 L
.6619 .01554 L
.66381 .01553 L
.66571 .01551 L
.66762 .0155 L
.66952 .01549 L
.67143 .01547 L
.67333 .01546 L
.67524 .01544 L
.67714 .01543 L
.67905 .01541 L
.68095 .0154 L
.68286 .01539 L
.68476 .01537 L
.68667 .01536 L
.68857 .01534 L
.69048 .01533 L
.69238 .01531 L
.69429 .0153 L
.69619 .01529 L
.6981 .01527 L
.7 .01526 L
.7019 .01524 L
.70381 .01523 L
.70571 .01522 L
.70762 .0152 L
.70952 .01519 L
.71143 .01517 L
.71333 .01516 L
.71524 .01514 L
.71714 .01513 L
.71905 .01512 L
.72095 .0151 L
.72286 .01509 L
.72476 .01507 L
.72667 .01506 L
.72857 .01504 L
.73048 .01503 L
.73238 .01502 L
Mistroke
.73429 .015 L
.73619 .01499 L
.7381 .01497 L
.74 .01496 L
.7419 .01494 L
.74381 .01493 L
.74571 .01492 L
.74762 .0149 L
.74952 .01489 L
.75143 .01487 L
.75333 .01486 L
.75524 .01484 L
.75714 .01483 L
.75905 .01482 L
.76095 .0148 L
.76286 .01479 L
.76476 .01477 L
.76667 .01476 L
.76857 .01475 L
.77048 .01473 L
.77238 .01472 L
.77261 .01472 L
.77261 .01472 L
.77261 .01472 L
.77429 .01472 L
.77619 .01472 L
.7781 .01472 L
.78 .01473 L
.7819 .01473 L
.78381 .01473 L
.78571 .01473 L
.78762 .01474 L
.78952 .01474 L
.79143 .01474 L
.79333 .01475 L
.79524 .01475 L
.79714 .01475 L
.79905 .01475 L
.80095 .01476 L
.80286 .01476 L
.80476 .01476 L
.80667 .01477 L
.80857 .01477 L
.81048 .01477 L
.81238 .01477 L
.81429 .01478 L
.81619 .01478 L
.8181 .01478 L
.82 .01479 L
.8219 .01479 L
Mistroke
.82381 .01479 L
.82571 .01479 L
.82762 .0148 L
.82952 .0148 L
.83143 .0148 L
.83333 .01481 L
.83524 .01481 L
.83714 .01481 L
.83905 .01481 L
.84095 .01482 L
.84286 .01482 L
.84476 .01482 L
.84667 .01483 L
.84857 .01483 L
.85048 .01483 L
.85238 .01483 L
.85429 .01484 L
.85619 .01484 L
.8581 .01484 L
.86 .01485 L
.8619 .01485 L
.86381 .01485 L
.86571 .01485 L
.86762 .01486 L
.86952 .01486 L
.87143 .01486 L
.87333 .01487 L
.87524 .01487 L
.87714 .01487 L
.87905 .01487 L
.88095 .01488 L
.88286 .01488 L
.88476 .01488 L
.88667 .01489 L
.88857 .01489 L
.89048 .01489 L
.89238 .01489 L
.89429 .0149 L
.89619 .0149 L
.8981 .0149 L
.9 .01491 L
.9019 .01491 L
.90381 .01491 L
.90571 .01491 L
.90762 .01492 L
.90952 .01492 L
.91143 .01492 L
.91333 .01493 L
.91524 .01493 L
.91714 .01493 L
Mistroke
.91905 .01493 L
.92095 .01494 L
.92286 .01494 L
.92476 .01494 L
.92667 .01495 L
.92857 .01495 L
.93048 .01495 L
.93238 .01495 L
.93429 .01496 L
.93619 .01496 L
.9381 .01496 L
.94 .01497 L
.9419 .01497 L
.94381 .01497 L
.94571 .01497 L
.94762 .01498 L
.94952 .01498 L
.95143 .01498 L
.95156 .01498 L
.95156 .01498 L
.95156 .01498 L
.95333 .01492 L
.95524 .01486 L
.95714 .01479 L
.95905 .01473 L
.95952 .01472 L
.95952 .01472 L
.95952 .01472 L
.96095 .01472 L
.96286 .01474 L
.96476 .01475 L
.96667 .01476 L
.96857 .01478 L
.97048 .01479 L
.97053 .01479 L
.97053 .01479 L
.97053 .01479 L
.97238 .01479 L
.97429 .0148 L
.97619 .0148 L
.97619 .0148 L
Mfstroke
1 0 0 r
.02381 .60332 m
.02571 .60332 L
.02762 .60332 L
.02952 .60332 L
.03143 .60332 L
.03333 .60332 L
.03524 .60332 L
.03714 .60332 L
.03905 .60332 L
.04095 .60332 L
.04286 .60332 L
.04476 .60332 L
.04667 .60332 L
.04857 .60332 L
.05048 .60332 L
.05238 .60332 L
.05429 .60332 L
.05619 .60332 L
.0581 .60332 L
.06 .60332 L
.0619 .60332 L
.06381 .60332 L
.06571 .60332 L
.06762 .60332 L
.06952 .60332 L
.07143 .60332 L
.07333 .60332 L
.07524 .60332 L
.07714 .60332 L
.07905 .60332 L
.08095 .60332 L
.08286 .60332 L
.08476 .60332 L
.08667 .60332 L
.0873 .60332 L
.0873 .60332 L
.0873 .60332 L
.08857 .60332 L
.09048 .60332 L
.09238 .60332 L
.09429 .60332 L
.09619 .60332 L
.0981 .60332 L
.1 .60332 L
.1019 .60332 L
.10381 .60332 L
.10571 .60332 L
.10762 .60332 L
.10952 .60332 L
.11143 .60332 L
Mistroke
.11333 .60332 L
.11524 .60332 L
.11714 .60332 L
.11905 .60332 L
.12095 .60332 L
.12286 .60332 L
.12476 .60332 L
.12667 .60332 L
.12857 .60332 L
.13048 .60332 L
.13238 .60332 L
.13429 .60332 L
.13619 .60332 L
.1381 .60332 L
.14 .60332 L
.1419 .60332 L
.14381 .60332 L
.14571 .60332 L
.14762 .60332 L
.14952 .60332 L
.15143 .60332 L
.15333 .60332 L
.15524 .60332 L
.15714 .60332 L
.15905 .60332 L
.16095 .60332 L
.16286 .60332 L
.16476 .60332 L
.16667 .60332 L
.16857 .60332 L
.17048 .60332 L
.17238 .60332 L
.17429 .60332 L
.17619 .60332 L
.1781 .60332 L
.18 .60332 L
.1819 .60332 L
.18381 .60332 L
.18571 .60332 L
.18762 .60332 L
.18952 .60332 L
.19143 .60332 L
.19312 .60332 L
.19312 .60332 L
.19312 .60332 L
.19333 .60261 L
.19524 .59626 L
.19714 .5899 L
.19905 .58354 L
.20095 .57718 L
Mistroke
.20286 .57083 L
.20476 .56447 L
.20667 .55811 L
.20857 .55176 L
.21048 .5454 L
.21238 .53904 L
.21429 .53269 L
.21619 .52633 L
.2181 .51997 L
.22 .51362 L
.2219 .50726 L
.22381 .5009 L
.22571 .49454 L
.22762 .48819 L
.22952 .48183 L
.23143 .47547 L
.23333 .46912 L
.23524 .46276 L
.23714 .4564 L
.23905 .45005 L
.24095 .44369 L
.24286 .43733 L
.24476 .43098 L
.24667 .42462 L
.24857 .41826 L
.25048 .4119 L
.25238 .40555 L
.25429 .39919 L
.25619 .39283 L
.2581 .38648 L
.26 .38012 L
.2619 .37376 L
.26381 .36741 L
.26571 .36105 L
.26762 .35469 L
.26952 .34834 L
.27143 .34198 L
.27333 .33562 L
.27524 .32926 L
.27714 .32291 L
.27905 .31655 L
.28095 .31019 L
.28286 .30384 L
.28476 .29748 L
.28667 .29112 L
.28857 .28477 L
.29048 .27841 L
.29238 .27205 L
.29429 .2657 L
.29619 .25934 L
Mistroke
.2981 .25298 L
.3 .24662 L
.3019 .24027 L
.30381 .23391 L
.30571 .22755 L
.30762 .2212 L
.30952 .21484 L
.31143 .20848 L
.31333 .20213 L
.31524 .19577 L
.31714 .18941 L
.31905 .18306 L
.32095 .1767 L
.32286 .17034 L
.32476 .16399 L
.3254 .16187 L
.3254 .16187 L
.3254 .16187 L
.32667 .15763 L
.32857 .15127 L
.33048 .14491 L
.33238 .13856 L
.33429 .1322 L
.33619 .12584 L
.3381 .11949 L
.34 .11313 L
.3419 .10677 L
.34381 .10042 L
.34571 .09406 L
.34762 .0877 L
.34952 .08135 L
.35143 .07499 L
.35333 .06863 L
.35524 .06227 L
.35714 .05592 L
.35905 .04956 L
.36095 .0432 L
.36286 .03685 L
.36476 .03049 L
.36667 .02413 L
.36857 .01778 L
.36949 .01472 L
.36949 .01472 L
.36949 .01472 L
.37048 .01537 L
.37238 .01665 L
.37429 .01792 L
.37619 .01919 L
.3781 .02046 L
.38 .02173 L
Mistroke
.3819 .023 L
.38381 .02427 L
.38571 .02555 L
.38762 .02682 L
.38952 .02809 L
.39143 .02936 L
.39333 .03063 L
.39524 .0319 L
.39714 .03317 L
.39905 .03445 L
.40095 .03572 L
.40286 .03699 L
.40476 .03826 L
.40667 .03953 L
.40857 .0408 L
.41048 .04207 L
.41238 .04334 L
.41429 .04462 L
.41619 .04589 L
.4181 .04716 L
.42 .04843 L
.4219 .0497 L
.42381 .05097 L
.42571 .05224 L
.42762 .05352 L
.42952 .05479 L
.43143 .05606 L
.43333 .05733 L
.43524 .0586 L
.43714 .05987 L
.43905 .06114 L
.44095 .06242 L
.44286 .06369 L
.44476 .06496 L
.44667 .06623 L
.44857 .0675 L
.45048 .06877 L
.45238 .07004 L
.45429 .07132 L
.45619 .07259 L
.45767 .07358 L
.45767 .07358 L
.45767 .07358 L
.4581 .07341 L
.46 .07264 L
.4619 .07188 L
.46381 .07112 L
.46571 .07035 L
.46762 .06959 L
.46952 .06883 L
Mistroke
.47143 .06807 L
.47333 .0673 L
.47524 .06654 L
.47714 .06578 L
.47905 .06501 L
.48095 .06425 L
.48286 .06349 L
.48476 .06273 L
.48667 .06196 L
.48857 .0612 L
.49048 .06044 L
.49238 .05968 L
.49429 .05891 L
.49619 .05815 L
.4981 .05739 L
.5 .05662 L
.5019 .05586 L
.50381 .0551 L
.50571 .05434 L
.50762 .05357 L
.50855 .0532 L
.50855 .0532 L
.50855 .0532 L
.50952 .05281 L
.51143 .05205 L
.51333 .05128 L
.51524 .05052 L
.51714 .04976 L
.51905 .049 L
.52095 .04823 L
.52286 .04747 L
.52476 .04671 L
.52667 .04594 L
.52857 .04518 L
.53048 .04442 L
.53238 .04366 L
.53429 .04289 L
.53619 .04213 L
.5381 .04137 L
.54 .0406 L
.5419 .03984 L
.54381 .03908 L
.54571 .03832 L
.54762 .03755 L
.54952 .03679 L
.55143 .03603 L
.55333 .03526 L
.55524 .0345 L
.55714 .03374 L
.55905 .03298 L
Mistroke
.56095 .03221 L
.56286 .03145 L
.56476 .03069 L
.56667 .02992 L
.56857 .02916 L
.57048 .0284 L
.57238 .02764 L
.57429 .02687 L
.57619 .02611 L
.5781 .02535 L
.58 .02458 L
.5819 .02382 L
.58381 .02306 L
.58571 .0223 L
.58762 .02153 L
.58952 .02077 L
.59143 .02001 L
.59333 .01924 L
.59524 .01848 L
.59714 .01772 L
.59905 .01696 L
.60095 .01619 L
.60286 .01543 L
.60464 .01472 L
.60464 .01472 L
.60464 .01472 L
.60476 .01472 L
.60667 .01488 L
.60857 .01503 L
.61048 .01518 L
.61238 .01533 L
.61429 .01549 L
.61619 .01564 L
.6181 .01579 L
.62 .01595 L
.6219 .0161 L
.62381 .01625 L
.62571 .0164 L
.62726 .01653 L
.62726 .01653 L
.62726 .01653 L
.62762 .01648 L
.62952 .01624 L
.63143 .01599 L
.63333 .01575 L
.63524 .0155 L
.63714 .01526 L
.63905 .01501 L
.64095 .01477 L
.64139 .01472 L
Mistroke
.64139 .01472 L
.64139 .01472 L
.64286 .01475 L
.64476 .0148 L
.64667 .01485 L
.64857 .0149 L
.65048 .01495 L
.65238 .015 L
.65429 .01505 L
.65619 .01509 L
.6581 .01514 L
.66 .01519 L
.6619 .01524 L
.66381 .01529 L
.66571 .01534 L
.66762 .01539 L
.66952 .01544 L
.67143 .01549 L
.67333 .01553 L
.67524 .01558 L
.67714 .01563 L
.67905 .01568 L
.68095 .01573 L
.68286 .01578 L
.68476 .01583 L
.68667 .01588 L
.68857 .01592 L
.69048 .01597 L
.69238 .01602 L
.69429 .01607 L
.69619 .01612 L
.6981 .01617 L
.7 .01622 L
.7019 .01627 L
.70381 .01632 L
.70571 .01636 L
.70762 .01641 L
.70952 .01646 L
.71143 .01651 L
.71333 .01656 L
.71524 .01661 L
.71714 .01666 L
.71905 .01671 L
.72095 .01675 L
.72286 .0168 L
.72476 .01685 L
.72667 .0169 L
.72857 .01695 L
.73048 .017 L
.73238 .01705 L
Mistroke
.73429 .0171 L
.73619 .01715 L
.7381 .01719 L
.74 .01724 L
.7419 .01729 L
.74381 .01734 L
.74571 .01739 L
.74762 .01744 L
.74952 .01749 L
.75143 .01754 L
.75333 .01758 L
.75524 .01763 L
.75714 .01768 L
.75905 .01773 L
.76095 .01778 L
.76286 .01783 L
.76476 .01788 L
.76667 .01793 L
.76857 .01797 L
.77048 .01802 L
.77238 .01807 L
.77261 .01808 L
.77261 .01808 L
.77261 .01808 L
.77429 .01811 L
.77619 .01815 L
.7781 .01819 L
.78 .01823 L
.7819 .01828 L
.78381 .01832 L
.78571 .01836 L
.78762 .0184 L
.78952 .01844 L
.79143 .01848 L
.79333 .01852 L
.79524 .01856 L
.79714 .0186 L
.79905 .01864 L
.80095 .01868 L
.80286 .01872 L
.80476 .01876 L
.80667 .0188 L
.80857 .01884 L
.81048 .01888 L
.81238 .01892 L
.81429 .01896 L
.81619 .019 L
.8181 .01904 L
.82 .01908 L
.8219 .01912 L
Mistroke
.82381 .01916 L
.82571 .0192 L
.82762 .01924 L
.82952 .01928 L
.83143 .01932 L
.83333 .01936 L
.83524 .0194 L
.83714 .01944 L
.83905 .01948 L
.84095 .01952 L
.84286 .01956 L
.84476 .0196 L
.84667 .01964 L
.84857 .01968 L
.85048 .01973 L
.85238 .01977 L
.85429 .01981 L
.85619 .01985 L
.8581 .01989 L
.86 .01993 L
.8619 .01997 L
.86381 .02001 L
.86571 .02005 L
.86762 .02009 L
.86952 .02013 L
.87143 .02017 L
.87333 .02021 L
.87524 .02025 L
.87714 .02029 L
.87905 .02033 L
.88095 .02037 L
.88286 .02041 L
.88476 .02045 L
.88667 .02049 L
.88857 .02053 L
.89048 .02057 L
.89238 .02061 L
.89429 .02065 L
.89619 .02069 L
.8981 .02073 L
.9 .02077 L
.9019 .02081 L
.90381 .02085 L
.90571 .02089 L
.90762 .02093 L
.90952 .02097 L
.91143 .02101 L
.91333 .02105 L
.91524 .02109 L
.91714 .02113 L
Mistroke
.91905 .02118 L
.92095 .02122 L
.92286 .02126 L
.92476 .0213 L
.92667 .02134 L
.92857 .02138 L
.93048 .02142 L
.93238 .02146 L
.93429 .0215 L
.93619 .02154 L
.9381 .02158 L
.94 .02162 L
.9419 .02166 L
.94381 .0217 L
.94571 .02174 L
.94762 .02178 L
.94952 .02182 L
.95143 .02186 L
.95156 .02186 L
.95156 .02186 L
.95156 .02186 L
.95333 .0219 L
.95524 .02194 L
.95714 .02198 L
.95905 .02202 L
.95952 .02203 L
.95952 .02203 L
.95952 .02203 L
.96095 .02203 L
.96286 .02203 L
.96476 .02204 L
.96667 .02204 L
.96857 .02204 L
.97048 .02204 L
.97053 .02204 L
.97053 .02204 L
.97053 .02204 L
.97238 .02204 L
.97429 .02205 L
.97619 .02205 L
.97619 .02205 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0714286 0.583445 0.547619 0.726302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00611247 0.0611247 0.00815217 0.0815217 [
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0110024 0.0146739 0.0721271 0.0961957 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.00561 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .05543 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 12.813 moveto
(@) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.109239 0.0721271 0.190761 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .5 0 r
.00561 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .15 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 12.813 moveto
(@) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.203804 0.0721271 0.285326 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.00561 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .24457 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 12.813 moveto
(@) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .74402 L
0 .74402 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 214.25},
  ImageMargins->{{93, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eR000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00>03IfMT4000001d0fMWI0`00000J0=WIf@<00000703IfMT2000001T0fMWI1@0000020=WI
f@8000005P3IfMT5000000030=WIf@000000000000800000503IfMT5000000<0fMWI0`00000X0=WI
f@00>03IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01T0fMWI00@000000=WIf@3I
fMT000006P3IfMT010000000fMWI0=WIf@00000J0=WIf@050000003IfMT0fMWI0=WIf@0000000P3I
fMT00`000000fMWI0=WIf@0E0=WIf@050000003IfMT0fMWI0=WIf@0000006@3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI02L0fMWI000i0=WIf@030000003IfMT0fMWI01/0fMWI1@00
000J0=WIf@040000003IfMT0fMWI000001X0fMWI00@000000=WIf@3IfMT000006P3IfMT01@000000
fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI01H0fMWI00@000000=WIf@3IfMT0fMWI1@00000X0=WIf@00>P3IfMT00`00
0000fMWI0=WIf@0J0=WIf@040000003IfMT0fMWI000001/0fMWI0`00000L0=WIf@8000006`3IfMT0
1@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI01D0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@030000
003IfMT0fMWI02L0fMWI000h0=WIf@040000003IfMT0fMWI000001`0fMWI00<000000=WIf@000000
703IfMT00`000000fMWI0=WIf@0J0=WIf@040000003IfMT0fMWI000001X0fMWI00D000000=WIf@3I
fMT0fMWI000000020=WIf@030000003IfMT0fMWI01D0fMWI00D000000=WIf@3IfMT0fMWI00000002
0=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0000000Y
0=WIf@00>@3IfMT2000001h0fMWI0P00000L0=WIf@<000006`3IfMT2000001X0fMWI0P0000040=WI
f@8000005`3IfMT2000000@0fMWI0P00000F0=WIf@8000001@3IfMT2000002T0fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<00000
0=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3b0=WIf@8000003@3IfMT001H0
fMWI5@0000000`000?l000000000000F0000008007l07P0000020000o`T0000000<0o`0000000000
00004P000002001o00/0000000<0003o000000000000500000020?l000<0000000<007l00?l00000
O`001`3o0007000004D007l01@0000080=WIf@040000003IfMT0fMWI000000`0fMWI000L0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT01@3IfMT00`000?l0fMWI0=WIf@050=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT01@3IfMT010000000fMWI001o0000O`040=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WI
f@030000003IfMT0fMWI00D0003o1P3IfMT30?l000H0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@020=WIf@@007l01`3IfMT00`000000003o0=WIf@070000o`D0fMWI00<000000=WI
f@3IfMT0103IfMT30?l00080fMWI1P3o0006001o02/0o`000P3IfMT00`000000fMWI0=WIf@020=WI
fA80003o00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI
00d0fMWI000L0=WIf@030000003IfMT0fMWI00`0fMWI0P000?l=0=WIf@030000003IfMT0fMWI00L0
fMWI00<007l00=WIf@00O`004P3IfMT00`000000fMWI0=WIf@070=WIf@030000o`3IfMT0fMWI0080
fMWI10000?l30=WIf@040?l0003IfMT0o`000?l000D0fMWI00<000000=WIf@3IfMT02@3IfMT01000
O`00fMWI0=WIf@3IfMT3001o00<0fMWI0P000?l60=WIf@030000003IfMT0003o00H0003o103IfMT3
0?l000D007l02P3IfMT00`000000fMWI0=WIf@0I0=WIf@040000o`3IfMT0fMWI00000080fMWI2@00
0?lS0?l000`0fMWI1@00000<0=WIf@00703IfMT00`000000fMWI0=WIf@0<0=WIf@<0003o5P3IfMT0
1000O`00fMWI0=WIf@00O`0J0=WIf@80003o203IfMT20000o`030?l000000?l0fMWI0080fMWI00<0
o`000=WIf@3IfMT03@3IfMT00`00O`00fMWI0=WIf@040=WIf@@007l000<0003o0=WIf@3IfMT02`3I
fMT4001o00<0o`001000O`0N0=WIfA<0003o>03IfMT00`000000fMWI0=WIf@0=0=WIf@00703IfMT0
0`000000fMWI0=WIf@0<0=WIf@030000o`3IfMT0003o01H0fMWI00D007l00=WIf@3IfMT0fMWI001o
000I0=WIf@030000o`3IfMT0fMWI00T0fMWI00<0o`000000o`000?l00P000?l00`3IfMT0o`000?l0
000<0=WIf@03001o003IfMT0fMWI00H0fMWI0P000?l5001o00030=WIf@00O`0007l000P007l000@0
fMWI0?l0003o0000o`00103IfMT70000o`80fMWI00D0003o0=WIf@3IfMT0003o0=WIf@0C0000oeX0
fMWI000L0=WIf@030000003IfMT0fMWI00/0fMWI00@0003o0=WIf@3IfMT0003o5P3IfMT01000O`00
fMWI0=WIf@3IfMT2001o01L0fMWI00<0003o0=WIf@3IfMT02P3IfMT00`3o0000fMWI0=WIf@020=WI
f@80003o0`3o000:0=WIf@03001o003IfMT0fMWI00D0fMWI0P000?l40=WIf@@007l01`3IfMT30?l0
00h0fMWI1`000?m]0=WIf@00703IfMT00`000000fMWI0=WIf@0;0=WIf@050000o`3IfMT0fMWI0=WI
f@000?l05@3IfMT00`00O`00fMWI0=WIf@020=WIf@8007l05P3IfMT00`000?l0fMWI0=WIf@090=WI
f@030?l0003IfMT0fMWI00H0fMWI00@0003o0?l0003o0000003o1`3IfMT00`00O`00fMWI0=WIf@05
0=WIf@80003o3P3IfMT30?l008@0fMWI000L0=WIf@030000003IfMT0fMWI00/0fMWI00D0003o0=WI
f@3IfMT0fMWI0000o`0D0=WIf@03001o003IfMT0fMWI00@0fMWI00<007l00=WIf@3IfMT04`3IfMT0
0`000?l0fMWI0=WIf@0:0=WIf@030?l0003IfMT0fMWI00P0fMWI0P3o00030000o`@0fMWI00<007l0
0=WIf@3IfMT0103IfMT20000o``0fMWI0`3o00270=WIf@00703IfMT00`000000fMWI0=WIf@0;0=WI
f@030000o`3IfMT0fMWI0080fMWI00<0003o0=WIf@3IfMT04@3IfMT00`00O`00fMWI0=WIf@050=WI
f@03001o003IfMT0fMWI0140fMWI00<0003o0=WIf@3IfMT02`3IfMT00`3o0000fMWI0=WIf@0:0=WI
f@80o`0000D0fMWI0000o`000?l0003o001o00050=WIf@80003o303IfMT30?l008T0fMWI000L0=WI
f@030000003IfMT0fMWI00/0fMWI00<0003o0=WIf@3IfMT00P3IfMT20000oa80fMWI00<007l00=WI
f@3IfMT01P3IfMT00`00O`00fMWI0=WIf@0?0=WIf@80003o3@3IfMT00`3o0000fMWI0=WIf@0;0=WI
f@<0o`0000<0fMWI001o00000?l00`000?l00`3IfMT0003o0000o`0:0=WIf@<0o`00S03IfMT001`0
fMWI00<000000=WIf@3IfMT02`3IfMT00`000?l0fMWI0=WIf@030=WIf@030000o`3IfMT0fMWI0100
fMWI00<007l00=WIf@3IfMT01`3IfMT00`00O`00fMWI0=WIf@0>0=WIf@030000o`3IfMT0fMWI00/0
fMWI00<0o`000=WIf@3IfMT03P3IfMT20?l00003001o003IfMT0fMWI0080fMWI00<0003o0=WIf@3I
fMT0203IfMT30?l008h0fMWI000L0=WIf@030000003IfMT0fMWI00/0fMWI00<0003o0=WIf@3IfMT0
103IfMT00`000?l0fMWI0=WIf@0?0=WIf@03001o003IfMT0fMWI00P0fMWI00<007l00=WIf@3IfMT0
303IfMT00`000?l0fMWI0=WIf@0<0=WIf@030?l0003IfMT0fMWI00l0fMWI0P3o000<0=WIf@<0o`00
T@3IfMT001`0fMWI00<000000=WIf@3IfMT02`3IfMT00`000?l0fMWI0=WIf@040=WIf@030000o`3I
fMT0fMWI00h0fMWI00<007l00=WIf@3IfMT02P3IfMT00`00O`00fMWI0=WIf@0:0=WIf@80003o3P3I
fMT00`3o0000fMWI0=WIf@0?0=WIf@04001o003IfMT0o`000?l000P0fMWI0`3o002C0=WIf@00703I
fMT00`000000fMWI0=WIf@0:0=WIf@030000o`3IfMT0fMWI00H0fMWI00<0003o0=WIf@3IfMT03@3I
fMT00`00O`00fMWI0=WIf@0;0=WIf@03001o003IfMT0fMWI00T0fMWI00<0003o0=WIf@3IfMT0303I
fMT00`3o0000fMWI0=WIf@0?0=WIf@04001o003IfMT0fMWI0=WIf@<0o`000`3IfMT40?l009D0fMWI
000L0=WIf@030000003IfMT0fMWI00X0fMWI00<0003o0=WIf@3IfMT01P3IfMT00`000?l0fMWI0=WI
f@0=0=WIf@03001o003IfMT0fMWI00/0fMWI0P00O`090=WIf@030000o`3IfMT0fMWI00d0fMWI00<0
o`000=WIf@3IfMT03`3IfMT00`00O`00fMWI0=WIf@030=WIf@D0o`00V03IfMT001`0fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000?l0fMWI0=WIf@070=WIf@030000o`3IfMT0fMWI00`0fMWI00<007l0
0=WIf@3IfMT0303IfMT2001o00P0fMWI00<0003o0=WIf@3IfMT03@3IfMT00`3o0000fMWI0=WIf@0>
0=WIf@03001o003IfMT0fMWI00D0fMWI00<0o`000=WIf@3IfMT0V@3IfMT001`0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000?l0fMWI0=WIf@070=WIf@030000o`3IfMT0fMWI00`0fMWI00<007l00=WI
f@3IfMT03@3IfMT2001o00H0fMWI00<0003o0=WIf@3IfMT03@3IfMT00`3o0000fMWI0=WIf@0?0=WI
f@03001o003IfMT0fMWI0:40fMWI000L0=WIf@030000003IfMT0fMWI00X0fMWI00<0003o0=WIf@3I
fMT0203IfMT00`000?l0fMWI0=WIf@0:0=WIf@03001o003IfMT0fMWI00l0fMWI0P00O`040=WIf@03
0000o`3IfMT0fMWI00h0fMWI00<0o`000=WIf@3IfMT03P3IfMT00`00O`00fMWI0=WIf@2R0=WIf@00
703IfMT00`000000fMWI0=WIf@0:0=WIf@030000o`3IfMT0fMWI00P0fMWI00<0003o0=WIf@3IfMT0
2P3IfMT00`00O`00fMWI0=WIf@0@0=WIf@8007l00P3IfMT20000oa00fMWI00<0o`000=WIf@3IfMT0
3@3IfMT00`00O`00fMWI0=WIf@2S0=WIf@00703IfMT00`000000fMWI0=WIf@0:0=WIf@030000o`3I
fMT0fMWI00T0fMWI00<0003o0=WIf@3IfMT02@3IfMT00`00O`00fMWI0=WIf@0A0=WIf@8007l000<0
fMWI0000o`3IfMT0403IfMT00`3o0000fMWI0=WIf@0=0=WIf@03001o003IfMT0fMWI0:<0fMWI000L
0=WIf@030000003IfMT0fMWI00X0fMWI00<0003o0=WIf@3IfMT02@3IfMT00`000?l0fMWI0=WIf@09
0=WIf@03001o003IfMT0fMWI0180fMWI00<007l00000o`3IfMT0403IfMT00`3o0000fMWI0=WIf@0=
0=WIf@03001o003IfMT0fMWI0:@0fMWI000L0=WIf@030000003IfMT0fMWI00X0fMWI00<0003o0=WI
f@3IfMT02P3IfMT00`000?l0fMWI0=WIf@080=WIf@03001o003IfMT0fMWI0180fMWI00<0003o001o
003IfMT0403IfMT00`3o0000fMWI0=WIf@0<0=WIf@8007l0YP3IfMT001`0fMWI00<000000=WIf@3I
fMT02@3IfMT00`000?l0fMWI0=WIf@0<0=WIf@030000o`3IfMT0fMWI00L0fMWI00<007l00=WIf@3I
fMT04P3IfMT00`000?l0fMWI001o000@0=WIf@030?l0003IfMT0fMWI00`0fMWI00<007l00=WIf@3I
fMT0Y@3IfMT001`0fMWI00<000000=WIf@3IfMT02@3IfMT00`000?l0fMWI0=WIf@0<0=WIf@030000
o`3IfMT0fMWI00H0fMWI00<007l00=WIf@3IfMT04P3IfMT01@000?l0fMWI0=WIf@3IfMT007l000h0
fMWI00<0o`000=WIf@3IfMT03@3IfMT00`00O`00fMWI0=WIf@2U0=WIf@00703IfMT00`000000fMWI
0=WIf@090=WIf@030000o`3IfMT0fMWI00d0fMWI00<0003o0=WIf@3IfMT01@3IfMT00`00O`00fMWI
0=WIf@0A0=WIf@80003o103IfMT00`00O`00fMWI0=WIf@0;0=WIf@030?l0003IfMT0fMWI00`0fMWI
00<007l00=WIf@3IfMT0YP3IfMT001`0fMWI00<000000=WIf@3IfMT02@3IfMT00`000?l0fMWI0=WI
f@0=0=WIf@030000o`3IfMT0fMWI00D0fMWI00<007l00=WIf@3IfMT04@3IfMT00`000?l0fMWI0=WI
f@040=WIf@03001o003IfMT0fMWI00X0fMWI00<0o`000=WIf@3IfMT0303IfMT00`00O`00fMWI0=WI
f@2V0=WIf@00703IfMT00`000000fMWI0=WIf@090=WIf@030000o`3IfMT0fMWI00h0fMWI00<0003o
0=WIf@3IfMT0103IfMT00`00O`00fMWI0=WIf@0@0=WIf@030000o`3IfMT0fMWI00D0fMWI00<007l0
0=WIf@3IfMT02@3IfMT00`3o0000fMWI0=WIf@0<0=WIf@03001o003IfMT0fMWI0:L0fMWI00090=WI
f@800000103IfMT2000000<0fMWI100000040=WIf@030000003IfMT0fMWI00T0fMWI00<0003o0=WI
f@3IfMT03P3IfMT00`000?l0fMWI0=WIf@040=WIf@03001o003IfMT0fMWI00l0fMWI0P000?l80=WI
f@03001o003IfMT0fMWI00P0fMWI00<0o`000=WIf@3IfMT02`3IfMT00`00O`00fMWI0=WIf@2X0=WI
f@00203IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000?l0fMWI0=WIf@0?0=WIf@030000o`3IfMT0fMWI0080fMWI00<007l00=WI
f@3IfMT0403IfMT00`000?l0fMWI0=WIf@080=WIf@03001o003IfMT0fMWI00L0fMWI00<0o`000=WI
f@3IfMT02`3IfMT00`00O`00fMWI0=WIf@2X0=WIf@00203IfMT010000000fMWI0=WIf@0000090=WI
f@030000003IfMT0fMWI00@0fMWI0P00000:0=WIf@030000o`3IfMT0fMWI00l0fMWI00<0003o0=WI
f@3IfMT00P3IfMT00`00O`00fMWI0=WIf@0?0=WIf@030000o`3IfMT0fMWI00X0fMWI00<007l00=WI
f@3IfMT01P3IfMT00`3o0000fMWI0=WIf@0:0=WIf@03001o003IfMT0fMWI0:T0fMWI00080=WIf@04
0000003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@080=WI
f@030000o`3IfMT0fMWI0140fMWI00D0003o0=WIf@3IfMT0fMWI001o000@0=WIf@030000o`3IfMT0
fMWI00`0fMWI00<007l00=WIf@3IfMT0103IfMT00`3o0000fMWI0=WIf@0:0=WIf@8007l0Z`3IfMT0
00P0fMWI00@000000=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@0000040=WIf@030000003I
fMT0fMWI00P0fMWI00<0003o0=WIf@3IfMT04@3IfMT01@000?l0fMWI0=WIf@3IfMT007l00100fMWI
00<0003o0=WIf@3IfMT03@3IfMT00`00O`00fMWI0=WIf@030=WIf@030?l0003IfMT0fMWI00X0fMWI
00<007l00=WIf@3IfMT0ZP3IfMT000T0fMWI0P00000:0=WIf@8000001@3IfMT00`000000fMWI0=WI
f@080=WIf@030000o`3IfMT0fMWI0180fMWI00@0003o0=WIf@3IfMT007l03`3IfMT00`000?l0fMWI
0=WIf@0?0=WIf@03001o003IfMT0fMWI0080fMWI00<0o`000=WIf@3IfMT02P3IfMT00`00O`00fMWI
0=WIf@2Z0=WIf@00703IfMT00`000000fMWI0=WIf@080=WIf@030000o`3IfMT0fMWI0180fMWI0P00
0?l00`3IfMT007l00=WIf@0=0=WIf@80003o4@3IfMT2001o0080fMWI00<0o`000=WIf@3IfMT02P3I
fMT00`00O`00fMWI0=WIf@2[0=WIf@00703IfMT00`000000fMWI0=WIf@080=WIf@030000o`3IfMT0
fMWI01<0fMWI00<0003o0=WIf@00O`003P3IfMT00`000?l0fMWI0=WIf@0A0=WIf@8007l000<0fMWI
0?l0003IfMT02`3IfMT00`00O`00fMWI0=WIf@2[0=WIf@00703IfMT00`000000fMWI0=WIf@080=WI
f@030000o`3IfMT0fMWI01@0fMWI00<007l00=WIf@3IfMT0303IfMT00`000?l0fMWI0=WIf@0C0=WI
f@8007l000<0o`000=WIf@3IfMT02@3IfMT00`00O`00fMWI0=WIf@2/0=WIf@00703IfMT00`000000
fMWI0=WIf@080=WIf@030000o`3IfMT0fMWI01@0fMWI00<007l00=WIf@3IfMT02`3IfMT00`000?l0
fMWI0=WIf@0E0=WIf@040?l00000O`0007l0001o00P0fMWI00<007l00=WIf@3IfMT0[@3IfMT001`0
fMWI00<000000=WIf@3IfMT0203IfMT00`000?l0fMWI0=WIf@0D0=WIf@03001o00000?l0fMWI00X0
fMWI0P000?lG0=WIf@030?l0003IfMT0fMWI00D007l0103IfMT00`00O`00fMWI0=WIf@2]0=WIf@00
703IfMT00`000000fMWI0=WIf@080=WIf@030000o`3IfMT0fMWI01@0fMWI00<007l00000o`3IfMT0
2P3IfMT00`000?l0fMWI0=WIf@0F0=WIf@030?l0003IfMT0fMWI00D0fMWI1000O`2`0=WIf@00703I
fMT00`000000fMWI0=WIf@080=WIf@030000o`3IfMT0fMWI01@0fMWI00<007l00=WIf@000?l02@3I
fMT00`000?l0fMWI0=WIf@0G0=WIf@030?l0003IfMT0fMWI0;T0fMWI000L0=WIf@030000003IfMT0
fMWI00P0fMWI00<0003o0=WIf@3IfMT04`3IfMT01000O`00fMWI0=WIf@000?l90=WIf@030000o`3I
fMT0fMWI01H0fMWI00<0o`000=WIf@3IfMT0^P3IfMT001`0fMWI00<000000=WIf@3IfMT0203IfMT0
0`000?l0fMWI0=WIf@0C0=WIf@05001o003IfMT0fMWI0=WIf@000?l01`3IfMT00`000?l0fMWI0=WI
f@0G0=WIf@030?l0003IfMT0fMWI0;X0fMWI000L0=WIf@030000003IfMT0fMWI00P0fMWI00<0003o
0=WIf@3IfMT04`3IfMT01@00O`00fMWI0=WIf@3IfMT0003o00H0fMWI0P000?lI0=WIf@030?l0003I
fMT0fMWI0;X0fMWI000L0=WIf@030000003IfMT0fMWI00L0fMWI00<0003o0=WIf@3IfMT0503IfMT0
0`00O`00fMWI0=WIf@020=WIf@030000o`3IfMT0fMWI00<0fMWI00<0003o0=WIf@3IfMT05`3IfMT0
0`3o0000fMWI0=WIf@2k0=WIf@00703IfMT00`000000fMWI0=WIf@070=WIf@030000o`3IfMT0fMWI
01@0fMWI00<007l00=WIf@3IfMT00P3IfMT20000o`<0fMWI00<0003o0=WIf@3IfMT0603IfMT00`3o
0000fMWI0=WIf@2k0=WIf@00703IfMT00`000000fMWI0=WIf@070=WIf@030000o`3IfMT0fMWI01@0
fMWI00<007l00=WIf@3IfMT00`3IfMT010000?l0fMWI0=WIf@000?lK0=WIf@030?l0003IfMT0fMWI
0;/0fMWI000L0=WIf@030000003IfMT0fMWI00L0fMWI00<0003o0=WIf@3IfMT04`3IfMT00`00O`00
fMWI0=WIf@050=WIf@<0003o6P3IfMT00`3o0000fMWI0=WIf@2l0=WIf@00703IfMT00`000000fMWI
0=WIf@070=WIf@030000o`3IfMT0fMWI01<0fMWI00<007l00=WIf@3IfMT01@3IfMT20000oa/0fMWI
00<0o`000=WIf@3IfMT0_03IfMT001`0fMWI00<000000=WIf@3IfMT01`3IfMT00`000?l0fMWI0=WI
f@0C0=WIf@03001o003IfMT0fMWI00D0fMWI00<0003o0=WIf@3IfMT06P3IfMT00`3o0000fMWI0=WI
f@2l0=WIf@00703IfMT00`000000fMWI0=WIf@070=WIf@030000o`3IfMT0fMWI01<0fMWI00<007l0
0=WIf@3IfMT08P3IfMT00`3o0000fMWI0=WIf@2l0=WIf@00703IfMT00`000000fMWI0=WIf@070=WI
f@030000o`3IfMT0fMWI01<0fMWI00<007l00=WIf@3IfMT08@3IfMT00`3o0000fMWI0=WIf@2m0=WI
f@00703IfMT00`000000fMWI0=WIf@070=WIf@030000o`3IfMT0fMWI0180fMWI00<007l00=WIf@3I
fMT08P3IfMT00`3o0000fMWI0=WIf@2m0=WIf@00703IfMT00`000000fMWI0=WIf@060=WIf@030000
o`3IfMT0fMWI01<0fMWI00<007l00=WIf@3IfMT08P3IfMT00`3o0000fMWI0=WIf@2m0=WIf@00703I
fMT00`000000fMWI0=WIf@060=WIf@030000o`3IfMT0fMWI01<0fMWI00<007l00=WIf@3IfMT08@3I
fMT00`3o0000fMWI0=WIf@2n0=WIf@00703IfMT00`000000fMWI0=WIf@060=WIf@030000o`3IfMT0
fMWI01<0fMWI00<007l00=WIf@3IfMT08@3IfMT00`3o0000fMWI0=WIf@2n0=WIf@002@3IfMT20000
00@0fMWI0P0000050=WIf@<000000`3IfMT00`000000fMWI0=WIf@060=WIf@030000o`3IfMT0fMWI
01<0fMWI00<007l00=WIf@3IfMT08@3IfMT00`3o0000fMWI0=WIf@2n0=WIf@00203IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0?l0fMWI0=WIf@0B0=WIf@03001o003IfMT0fMWI0240fMWI00<0o`000=WIf@3IfMT0_`3IfMT000P0
fMWI00@000000=WIf@3IfMT00000203IfMT5000000<0fMWI0P0000070=WIf@030000o`3IfMT0fMWI
0180fMWI00<007l00=WIf@3IfMT08@3IfMT00`3o0000fMWI0=WIf@2o0=WIf@00203IfMT010000000
fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@3IfMT01P3IfMT0
0`000?l0fMWI0=WIf@0B0=WIf@03001o003IfMT0fMWI0240fMWI00<0o`000=WIf@3IfMT0_`3IfMT0
00P0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI000000040=WIf@030000003IfMT0
fMWI00H0fMWI00<0003o0=WIf@3IfMT04P3IfMT00`00O`00fMWI0=WIf@0P0=WIf@030?l0003IfMT0
fMWI0<00fMWI00090=WIf@8000002`3IfMT2000000@0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0?l0fMWI0=WIf@0C0=WIf@03001o003IfMT0fMWI0200fMWI00<0o`000=WIf@3IfMT0`03IfMT001`0
fMWI00<000000=WIf@3IfMT01@3IfMT00`000?l0fMWI0=WIf@0B0=WIf@03001o003IfMT0fMWI0240
fMWI00<0o`000=WIf@3IfMT0`03IfMT001`0fMWI00<000000=WIf@3IfMT01@3IfMT00`000?l0fMWI
0=WIf@0B0=WIf@03001o003IfMT0fMWI0240fMWI00<0o`000=WIf@3IfMT0`03IfMT001`0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000?l0fMWI0=WIf@0B0=WIf@03001o003IfMT0fMWI0200fMWI00<0
o`000=WIf@3IfMT0`@3IfMT001`0fMWI00<000000=WIf@3IfMT01@3IfMT00`000?l0fMWI0=WIf@0B
0=WIf@03001o003IfMT0fMWI0200fMWI00<0o`000=WIf@3IfMT0`@3IfMT001`0fMWI00<000000=WI
f@3IfMT01@3IfMT00`000?l0fMWI0=WIf@0B0=WIf@03001o003IfMT0fMWI0200fMWI00<0o`000=WI
f@3IfMT0`@3IfMT001`0fMWI00<000000=WIf@3IfMT01@3IfMT00`000?l0fMWI0=WIf@0B0=WIf@03
001o003IfMT0fMWI01l0fMWI00<0o`000=WIf@3IfMT0`P3IfMT001`0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000?l0fMWI0=WIf@0B0=WIf@03001o003IfMT0fMWI01l0fMWI00<0o`000=WIf@3IfMT0
`P3IfMT001`0fMWI00<000000=WIf@3IfMT01@3IfMT00`000?l0fMWI0=WIf@0B0=WIf@03001o003I
fMT0fMWI01l0fMWI00<0o`000=WIf@3IfMT0`P3IfMT001`0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000?l0fMWI0=WIf@0B0=WIf@03001o003IfMT0fMWI0200fMWI00<0o`000=WIf@3IfMT0`P3IfMT0
01`0fMWI00<000000=WIf@3IfMT0103IfMT00`000?l0fMWI0=WIf@0B0=WIf@03001o003IfMT0fMWI
01l0fMWI00<0o`000=WIf@3IfMT0``3IfMT001`0fMWI00<000000=WIf@3IfMT0103IfMT00`000?l0
fMWI0=WIf@0B0=WIf@03001o003IfMT0fMWI01l0fMWI00<0o`000=WIf@3IfMT0``3IfMT001`0fMWI
00<000000=WIf@3IfMT0103IfMT00`000?l0fMWI0=WIf@0B0=WIf@03001o003IfMT0fMWI01l0fMWI
00<0o`000=WIf@3IfMT0``3IfMT001`0fMWI00<000000=WIf@3IfMT0103IfMT00`000?l0fMWI0=WI
f@0B0=WIf@03001o003IfMT0fMWI01h0fMWI00<0o`000=WIf@3IfMT0a03IfMT001`0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000?l0fMWI0=WIf@0A0=WIf@03001o003IfMT0fMWI01l0fMWI00<0o`00
0=WIf@3IfMT0a03IfMT001`0fMWI00<000000=WIf@3IfMT0103IfMT00`000?l0fMWI0=WIf@0A0=WI
f@03001o003IfMT0fMWI01l0fMWI00<0o`000=WIf@3IfMT0a03IfMT001`0fMWI00<000000=WIf@3I
fMT0103IfMT00`000?l0fMWI0=WIf@0A0=WIf@03001o003IfMT0fMWI01h0fMWI00<0o`000=WIf@3I
fMT0a@3IfMT001`0fMWI00<000000=WIf@3IfMT00`3IfMT00`000?l0fMWI0=WIf@0B0=WIf@03001o
003IfMT0fMWI01h0fMWI00<0o`000=WIf@3IfMT0a@3IfMT001`0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000?l0fMWI0=WIf@0B0=WIf@03001o003IfMT0fMWI01h0fMWI00<0o`000=WIf@3IfMT0a@3I
fMT001`0fMWI00<000000=WIf@3IfMT00`3IfMT00`000?l0fMWI0=WIf@0A0=WIf@03001o003IfMT0
fMWI01h0fMWI00<0o`000=WIf@3IfMT0aP3IfMT001`0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0?l0fMWI0=WIf@0A0=WIf@03001o003IfMT0fMWI01h0fMWI00<0o`000=WIf@3IfMT0aP3IfMT001`0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000?l0fMWI0=WIf@0A0=WIf@03001o003IfMT0fMWI01h0
fMWI00<0o`000=WIf@3IfMT0aP3IfMT001`0fMWI00<000000=WIf@3IfMT00`3IfMT00`000?l0fMWI
0=WIf@0A0=WIf@03001o003IfMT0fMWI01h0fMWI00<0o`000=WIf@3IfMT0aP3IfMT001`0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000?l0fMWI0=WIf@0A0=WIf@03001o003IfMT0fMWI01d0fMWI00<0
o`000=WIf@3IfMT0a`3IfMT000T0fMWI0P0000040=WIf@8000000`3IfMT3000000D0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000?l0fMWI0=WIf@0@0=WIf@03001o003IfMT0fMWI01h0fMWI00<0o`00
0=WIf@3IfMT0a`3IfMT000P0fMWI00@000000=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@00
00040=WIf@030000003IfMT0fMWI00<0fMWI00<0003o0=WIf@3IfMT0403IfMT00`00O`00fMWI0=WI
f@0N0=WIf@030?l0003IfMT0fMWI0<L0fMWI00080=WIf@040000003IfMT0fMWI000000P0fMWI00@0
00000=WIf@3IfMT00000103IfMT2000000@0fMWI00<0003o0=WIf@3IfMT0403IfMT00`00O`00fMWI
0=WIf@0N0=WIf@030?l0003IfMT0fMWI0<L0fMWI00080=WIf@040000003IfMT0fMWI000000P0fMWI
0`0000050=WIf@030000003IfMT0fMWI00<0fMWI00<0003o0=WIf@3IfMT0403IfMT00`00O`00fMWI
0=WIf@0M0=WIf@030?l0003IfMT0fMWI0<P0fMWI00080=WIf@040000003IfMT0fMWI000000T0fMWI
00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000o`3IfMT0fMWI0100fMWI
00<007l00=WIf@3IfMT07@3IfMT00`3o0000fMWI0=WIf@380=WIf@002@3IfMT2000000X0fMWI0`00
00040=WIf@030000003IfMT0fMWI00<0fMWI00<0003o0=WIf@3IfMT03`3IfMT00`00O`00fMWI0=WI
f@0N0=WIf@030?l0003IfMT0fMWI0<P0fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<0003o
0=WIf@3IfMT0403IfMT00`00O`00fMWI0=WIf@0M0=WIf@030?l0003IfMT0fMWI0<T0fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI00<0003o0=WIf@3IfMT0403IfMT00`00O`00fMWI0=WIf@0M0=WI
f@030?l0003IfMT0fMWI0<T0fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<0003o0=WIf@3I
fMT0403IfMT00`00O`00fMWI0=WIf@0M0=WIf@030?l0003IfMT0fMWI0<T0fMWI000L0=WIf@030000
003IfMT0fMWI0080fMWI00<0003o0=WIf@3IfMT0403IfMT00`00O`00fMWI0=WIf@0L0=WIf@030?l0
003IfMT0fMWI0<X0fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<0003o0=WIf@3IfMT03`3I
fMT00`00O`00fMWI0=WIf@0M0=WIf@030?l0003IfMT0fMWI0<X0fMWI000L0=WIf@030000003IfMT0
fMWI0080fMWI00<0003o0=WIf@3IfMT03`3IfMT00`00O`00fMWI0=WIf@0M0=WIf@030?l0003IfMT0
fMWI0<X0fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<0003o0=WIf@3IfMT03`3IfMT00`00
O`00fMWI0=WIf@0L0=WIf@030?l0003IfMT0fMWI0</0fMWI000L0=WIf@030000003IfMT0fMWI0080
fMWI00<0003o0=WIf@3IfMT03`3IfMT00`00O`00fMWI0=WIf@0L0=WIf@030?l0003IfMT0fMWI0</0
fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<0003o0=WIf@3IfMT03`3IfMT00`00O`00fMWI
0=WIf@0L0=WIf@030?l0003IfMT0fMWI0</0fMWI000L0=WIf@050000003IfMT0fMWI0=WIf@000?l0
4P3IfMT00`00O`00fMWI0=WIf@0K0=WIf@030?l0003IfMT0fMWI0<`0fMWI000L0=WIf@050000003I
fMT0fMWI0=WIf@000?l04P3IfMT00`00O`00fMWI0=WIf@0K0=WIf@030?l0003IfMT0fMWI0<`0fMWI
000L0=WIf@050000003IfMT0fMWI0=WIf@000?l04P3IfMT00`00O`00fMWI0=WIf@0K0=WIf@030?l0
003IfMT0fMWI0<`0fMWI000L0=WIf@050000003IfMT0fMWI0=WIf@000?l04@3IfMT00`00O`00fMWI
0=WIf@0K0=WIf@030?l0003IfMT0fMWI0<d0fMWI000L0=WIf@050000003IfMT0fMWI0=WIf@000?l0
4@3IfMT00`00O`00fMWI0=WIf@0K0=WIf@030?l0003IfMT0fMWI0<d0fMWI000L0=WIf@050000003I
fMT0fMWI0=WIf@000?l04@3IfMT00`00O`00fMWI0=WIf@0K0=WIf@030?l0003IfMT0fMWI0<d0fMWI
000L0=WIf@050000003IfMT0fMWI0=WIf@000?l04@3IfMT00`00O`00fMWI0=WIf@0K0=WIf@030?l0
003IfMT0fMWI0<d0fMWI000L0=WIf@050000003IfMT0fMWI0=WIf@000?l04@3IfMT00`00O`00fMWI
0=WIf@0K0=WIf@030?l0003IfMT0fMWI0<d0fMWI000L0=WIf@040000003IfMT0fMWI0000oa40fMWI
00<007l00=WIf@3IfMT06`3IfMT00`3o0000fMWI0=WIf@3>0=WIf@00703IfMT010000000fMWI0=WI
f@000?lA0=WIf@03001o003IfMT0fMWI01/0fMWI00<0o`000=WIf@3IfMT0cP3IfMT001`0fMWI00@0
00000=WIf@3IfMT0003o4@3IfMT00`00O`00fMWI0=WIf@0K0=WIf@030?l0003IfMT0fMWI0<h0fMWI
000L0=WIf@040000003IfMT0fMWI0000oa40fMWI00<007l00=WIf@3IfMT06P3IfMT00`3o0000fMWI
0=WIf@3?0=WIf@00703IfMT010000000fMWI0=WIf@000?lA0=WIf@03001o003IfMT0fMWI01X0fMWI
00<0o`000=WIf@3IfMT0c`3IfMT000T0fMWI0P0000040=WIf@800000103IfMT2000000D0fMWI00@0
00000=WIf@3IfMT0003o403IfMT00`00O`00fMWI0=WIf@0K0=WIf@030?l0003IfMT0fMWI0<l0fMWI
00080=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT00000103IfMT010000000
fMWI0=WIf@000?l@0=WIf@03001o003IfMT0fMWI01X0fMWI00<0o`000=WIf@3IfMT0d03IfMT000P0
fMWI00@000000=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@0000040=WIf@80000000<0fMWI
0000o`3IfMT03`3IfMT00`00O`00fMWI0=WIf@0J0=WIf@030?l0003IfMT0fMWI0=00fMWI00080=WI
f@040000003IfMT0fMWI000000T0fMWI0P0000050=WIf@040000003IfMT0fMWI0000oa00fMWI00<0
07l00=WIf@3IfMT06P3IfMT00`3o0000fMWI0=WIf@3@0=WIf@00203IfMT010000000fMWI0=WIf@00
00080=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@000?l04@3IfMT00`00O`00fMWI
0=WIf@0I0=WIf@030?l0003IfMT0fMWI0=40fMWI00090=WIf@8000002P3IfMT2000000D0fMWI00<0
00000=WIf@000?l0403IfMT00`00O`00fMWI0=WIf@0J0=WIf@030?l0003IfMT0fMWI0=40fMWI000L
0=WIf@030000003IfMT0003o0100fMWI00<007l00=WIf@3IfMT06P3IfMT00`3o0000fMWI0=WIf@3A
0=WIf@00703IfMT00`000000fMWI0000o`0@0=WIf@03001o003IfMT0fMWI01T0fMWI00<0o`000=WI
f@3IfMT0dP3IfMT001`0fMWI00<000000=WIf@000?l0403IfMT00`00O`00fMWI0=WIf@0I0=WIf@03
0?l0003IfMT0fMWI0=80fMWI000L0=WIf@030000003IfMT0003o0100fMWI00<007l00=WIf@3IfMT0
6@3IfMT00`3o0000fMWI0=WIf@3B0=WIf@00703IfMT00`000000fMWI0000o`0?0=WIf@03001o003I
fMT0fMWI01T0fMWI00<0o`000=WIf@3IfMT0d`3IfMT001`0fMWI00<000000=WIf@000?l03`3IfMT0
0`00O`00fMWI0=WIf@0I0=WIf@030?l0003IfMT0fMWI0=<0fMWI000L0=WIf@03000000000?l0fMWI
00l0fMWI00<007l00=WIf@3IfMT06@3IfMT00`3o0000fMWI0=WIf@3C0=WIf@00703IfMT00`000000
003o0=WIf@0?0=WIf@03001o003IfMT0fMWI01T0fMWI00<0o`000=WIf@3IfMT0d`3IfMT001`0fMWI
00<000000000o`3IfMT03`3IfMT00`00O`00fMWI0=WIf@0I0=WIf@030?l0003IfMT0fMWI0=<0fMWI
000L0=WIf@03000000000?l0fMWI00l0fMWI00<007l00=WIf@3IfMT0603IfMT00`3o0000fMWI0=WI
f@3D0=WIf@00703IfMT00`000000003o0=WIf@0>0=WIf@03001o003IfMT0fMWI01T0fMWI00<0o`00
0=WIf@3IfMT0e03IfMT001`0fMWI00<000000000o`3IfMT03P3IfMT00`00O`00fMWI0=WIf@0I0=WI
f@030?l0003IfMT0fMWI0=@0fMWI000L0=WIf@03000000000?l0fMWI00h0fMWI00<007l00=WIf@3I
fMT0603IfMT00`3o0000fMWI0=WIf@3E0=WIf@00703IfMT00`000000003o0=WIf@0>0=WIf@03001o
003IfMT0fMWI01P0fMWI00<0o`000=WIf@3IfMT0e@3IfMT001`0fMWI00<000000000o`3IfMT03P3I
fMT00`00O`00fMWI0=WIf@0H0=WIf@030?l0003IfMT0fMWI0=D0fMWI000L0=WIf@030000o`3IfMT0
fMWI00h0fMWI00<007l00=WIf@3IfMT05`3IfMT00`3o0000fMWI0=WIf@3F0=WIf@00703IfMT00`00
0?l0fMWI0=WIf@0>0=WIf@03001o003IfMT0fMWI01L0fMWI00<0o`000=WIf@3IfMT0eP3IfMT001`0
fMWI00<0003o0=WIf@3IfMT03@3IfMT00`00O`00fMWI0=WIf@0H0=WIf@030?l0003IfMT0fMWI0=H0
fMWI000L0=WIf@030000o`3IfMT0fMWI00d0fMWI00<007l00=WIf@3IfMT05`3IfMT00`3o0000fMWI
0=WIf@3G0=WIf@00703IfMT00`000?l0fMWI0=WIf@0=0=WIf@03001o003IfMT0fMWI01L0fMWI00<0
o`000=WIf@3IfMT0e`3IfMT001`0fMWI00<0003o0=WIf@3IfMT03@3IfMT00`00O`00fMWI0=WIf@0G
0=WIf@030?l0003IfMT0fMWI0=L0fMWI000L0=WIf@030000o`3IfMT0fMWI00d0fMWI00<007l00=WI
f@3IfMT05P3IfMT00`3o0000fMWI0=WIf@3H0=WIf@00703IfMT00`000?l0fMWI0=WIf@0<0=WIf@03
001o003IfMT0fMWI01L0fMWI00<0o`000=WIf@3IfMT0f03IfMT001@0fMWI1@0000030=WIf@030000
o`3IfMT0fMWI00`0fMWI00<007l00=WIf@3IfMT05`3IfMT00`3o0000fMWI0=WIf@3H0=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@030000o`3IfMT0fMWI00`0fMWI00<0o`000=WIf@3IfMT05P3I
fMT20?l00=X0fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI:@3o003K0=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000E0=WIf@8000001@3IfMT00`000000fMWI
0=WIf@3o0=WIf@80fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI000R0=WIf@80
0000303IfMT2000000P0fMWI0P00003T0=WIf@008`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0hP3IfMT002@0fMWI00<000000=WIf@3IfMT00P3I
fMT2000000D0fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI00<000000=WIf@3IfMT0hP3I
fMT001H0fMWI2@3o00040=WIf@030000003IfMT000000080fMWI00@000000=WIf@3IfMT00000103I
fMT01@000000fMWI0=WIf@3IfMT000000080fMWI00D000000=WIf@3IfMT0fMWI0000003T0=WIf@00
8P3IfMT010000000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3I
fMT0fMWI000000060=WIf@030000003IfMT0fMWI0>80fMWI000Q0=WIf@<0000000<0fMWI00000000
0000103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00D000000`3IfMT00`000000
fMWI0=WIf@3R0=WIf@00:03IfMT010000000fMWI0=WIf@0000040=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT00`000000fMWI0=WIf@3R0=WIf@00:@3IfMT2000000D0fMWI0P0000080=WIf@80
0000i03IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00280
fMWI0P00000<0=WIf@800000203IfMT200000>@0fMWI000S0=WIf@030000003IfMT0fMWI00X0fMWI
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3R0=WIf@00903IfMT010000000fMWI0=WI
f@3IfMT4000000@0fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI00<000000=WIf@3IfMT0
hP3IfMT002<0fMWI00<000000=WIf@0000000P3IfMT00`000000fMWI0=WIf@050=WIf@050000003I
fMT0fMWI0=WIf@0000000P3IfMT01@000000fMWI0=WIf@3IfMT000000>@0fMWI000F0=WIf@T007l0
0`3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3I
fMT0fMWI000000060=WIf@030000003IfMT0fMWI0>80fMWI000Q0=WIf@<0000000<0fMWI00000000
00000`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D000000`3IfMT00`000000
fMWI0=WIf@3R0=WIf@00:03IfMT010000000fMWI0=WIf@0000040=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT00`000000fMWI0=WIf@3R0=WIf@00:@3IfMT2000000D0fMWI0P0000080=WIf@80
0000i03IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0
fMWI8@3IfMT00280fMWI0P00000<0=WIf@800000203IfMT200000>@0fMWI000S0=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3R0=WIf@00903IfMT0
10000000fMWI0=WIf@3IfMT5000000<0fMWI00<000000=WIf@3IfMT00P3IfMT2000000@0fMWI00<0
00000=WIf@3IfMT0hP3IfMT002<0fMWI00<000000=WIf@000000103IfMT00`000000fMWI0=WIf@03
0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT01@000000fMWI0=WIf@3IfMT000000>@0fMWI
000F0=WIf@T0003o0`3IfMT010000000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI00<0fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0>80fMWI000Q0=WIf@<00000
00<0fMWI0000000000000`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D00000
0`3IfMT00`000000fMWI0=WIf@3R0=WIf@00:P3IfMT00`000000fMWI0=WIf@030=WIf@050000003I
fMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@3R0=WIf@00:@3IfMT2000000D0fMWI0P00
00080=WIf@800000i03IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00001\
\>"],
  ImageRangeCache->{{{196, 483}, {508.5, 295.25}} -> {-2.48748, 1.50802, \
0.00732689, 0.00732689}, {{203, 475.938}, {503.375, 334.688}} -> {-14.6024, \
1.92046, 0.065183, 0.00703123}, {{216.625, 353.125}, {341.25, 300.313}} -> \
{-26.074, 11.4064, 0.119891, 0.0898941}, {{218.125, 226.438}, {339.188, \
328.125}} -> {-53.4817, 28.9702, 0.240604, 0.240604}, {{218.125, 226.438}, \
{326.313, 315.188}} -> {-53.4817, 25.8649, 0.240604, 0.240604}, {{218.125, \
226.438}, {313.438, 302.313}} -> {-53.4817, 22.7671, 0.240604, 0.240604}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bubble Sort", "Section"],

Cell["\<\
class BubbleSort
   parameter Real [:] elements;
   Real sorted[size(elements,1)];
  function bubblesortfunc
     input Real [:] unorderedElements;
     output Real [size(unorderedElements, 1)] orderedElements;
    protected 
     Real temporaryValue;
     Boolean isOver = false;
    algorithm
     orderedElements := unorderedElements;
     while not isOver loop
         isOver := true;
         for i in 1:size(orderedElements, 1)-1 loop
             if orderedElements[i] > orderedElements[i+1] 
             then  
               temporaryValue := orderedElements[i];
               orderedElements[i] := orderedElements[i+1];
               orderedElements[i+1] := temporaryValue;
               isOver := false;
             end if;
         end for;
       end while;
    end bubblesortfunc;
  algorithm
   sorted := bubblesortfunc(elements);    
 end BubbleSort;
            
     \
\>", "ModelicaInput"],

Cell["\<\
class BubbleSortSimulation
  BubbleSort b(elements[:]={31231, 231, 3493, 9349, 8985, 586, 69, 34, 9, \
122});
end BubbleSortSimulation;\
\>", "ModelicaInput"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simulate[BubbleSortSimulation, \ {t, \ 0, \ 1}]\)], "Input"],

Cell[BoxData["\<\"<SimulationData: \\!\\(BubbleSortSimulation\\) : 2003-5-7 \
21:56:17 : \\!\\({0.`, 1.`}\\) : 502 data points : 22 \
variables>\\n\\!\\({\\*TagBox[\\(\\(\\(b . elements\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(b . elements\\)\\) \[LeftDoubleBracket] \\(\\(10\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(b . elements\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(b . elements\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(b . elements\\)\\) \
\[LeftDoubleBracket] \\(\\(4\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(b . elements\\)\\) \[LeftDoubleBracket] \\(\\(5\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(b . elements\\)\\) \
\[LeftDoubleBracket] \\(\\(6\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(b . elements\\)\\) \[LeftDoubleBracket] \\(\\(7\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(b . elements\\)\\) \
\[LeftDoubleBracket] \\(\\(8\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(b . elements\\)\\) \[LeftDoubleBracket] \\(\\(9\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(b . sorted\\)\\) \
\[LeftDoubleBracket] \\(\\(1\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(b . sorted\\)\\) \[LeftDoubleBracket] \\(\\(10\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(b . sorted\\)\\) \
\[LeftDoubleBracket] \\(\\(2\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(b . sorted\\)\\) \[LeftDoubleBracket] \\(\\(3\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(b . sorted\\)\\) \
\[LeftDoubleBracket] \\(\\(4\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(b . sorted\\)\\) \[LeftDoubleBracket] \\(\\(5\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(b . sorted\\)\\) \
\[LeftDoubleBracket] \\(\\(6\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(b . sorted\\)\\) \[LeftDoubleBracket] \\(\\(7\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \\*TagBox[\\(\\(\\(b . sorted\\)\\) \
\[LeftDoubleBracket] \\(\\(8\\)\\) \[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\(\\(\\(b . sorted\\)\\) \[LeftDoubleBracket] \\(\\(9\\)\\) \
\[RightDoubleBracket]\\), HoldForm], \
\\*TagBox[\\\"\[UnderBracket]derdummy\\\", HoldForm], \\*TagBox[\\\"\
\[UnderBracket]dummy\\\", HoldForm]}\\)\"\>"], "Output"]
}, Open  ]],

Cell["\<\
Result of the bubblesort:
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\ b . \(sorted[\([i]\)]\)[0], \ {i\ , 1, \ \ 10}]\)], "Input"],

Cell[BoxData[
    \({9.`, 34.`, 69.`, 122.`, 231.`, 586.`, 3493.`, 8985.`, 9349.`, 
      31231.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Modelica vs. (C++ or Java)", "Section"],

Cell["\<\
The main difference between Modelica and C++/Java is the mathematical way you \
use to specify equations. You don't give the operational (algorithmical) \
solution to the problem (but if it is needed you can do so), you just state \
the problem declaratively. In other words the data flow in the program is not \
specified.
Useful in modelling because 
  - it uses the object-oriented paradigm and because of that the \
reuse/evolution of the models is increased.
  - it supports modelling of multiple domains (electrical, mechanical, etc) \
with connections between domains.
  - it supports both textual and visual building of models. 
Useful in simulation
  - simulation is based on visual environments like MathModelica and Dymola
  - the Modelica code is compiled and the simulation runs fast\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Redeclare and Replaceable", "Section"],

Cell["\<\
class Vehicle
   Real mass;
end Vehicle;

class Plane
   replaceable Real mass;
   Real velocity = 0;
end Plane;

class FlyingPlane extends Plane(velocity = 100);
    Real altitude = 11000;
end FlyingPlane;

type MyReal = Real;\
\>", "ModelicaInput"],

Cell["\<\

Create a class containing an instance plane1, of the class Plane and give the \
mass variable a value;

(a) we need the Plane instance to be replaceable for the next part of problem \
to work.
\
\>", "Text"],

Cell["\<\
class Container
   replaceable Plane plane1(mass=100);
end Container;\
\>", "ModelicaInput"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simulate[Container, \ {t, \ 0, \ 1}]\)], "Input"],

Cell[BoxData["\<\"<SimulationData: \\!\\(Container\\) : 2003-5-8 12:35:8 : \
\\!\\({0.`, 1.`}\\) : 502 data points : 4 variables>\\n\\!\\({\\*TagBox[\\\"\
\[UnderBracket]derdummy\\\", HoldForm], \
\\*TagBox[\\\"\[UnderBracket]dummy\\\", HoldForm], \\*TagBox[\\(plane1 . mass\
\\), HoldForm], \\*TagBox[\\(plane1 . velocity\\), HoldForm]}\\)\"\>"], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Print[plane1 . mass[0]];\)\)], "Input"],

Cell[BoxData[
    \(100.`\)], "Print"]
}, Open  ]],

Cell["\<\
(b) for the class below to work we need to make Plane.mass replaceable
      to be able to make new modification on plane1 we use \"replacable\" \
prefix in the extend clause.\
\>", "Text"],

Cell["\<\
class InheritsContainer 
   extends Container(redeclare replaceable FlyingPlane plane1(redeclare \
parameter MyReal mass, velocity=200));
end InheritsContainer;\
\>", "ModelicaInput"],

Cell[BoxData[
    \(\(Simulate[InheritsContainer, \ {t, \ 0, \ 1}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Print["\<velocity: \>", \ 
        plane1 . velocity[0], \ "\< altitude: \>", \ 
        plane1 . altitude[0], \ "\<mass: \>", \ 
        plane1 . mass[0]];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("velocity: "\[InvisibleSpace]200.`\[InvisibleSpace]" \
altitude: "\[InvisibleSpace]11000.`\[InvisibleSpace]"mass: \
"\[InvisibleSpace]100.`\),
      SequenceForm[ 
      "velocity: ", .2*^3, " altitude: ", .11*^5, "mass: ", .1*^3],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["noEvent operator usage", "Section"],

Cell["\<\
noEvent(expression) operator prevent generation of events for an expression \
and is used for 2 purposes:
  - to prevent expressions like log(x) to go outside their domain of \
valability
  - improve performance when the expresion are not discontinous by not \
generating events.
  
 Examples
   functions like log(x) are protected by guards like x>0. The solver will \
try to search for the values of x where the event occurs by making the step \
smaller and trying in both
   sides of the 0, meaning small positive values and small negative values. \
The small negative values will pose problems for functions like log(x).
   noEvent(x) will prevent these problems 
   (a) z = if noEvent(x>0) then log(x) else 0;
   
   The expression below if used without noEvent will generate an event at x=0 \
even if the expression (and derivatives) exists and are countinous in x=0.
   Therefore using noEvent will improve preformace by not generating any \
events for x=0. 
   (b) z= if noEvent(x<0) then -x^2 else x^2
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Correct the classes and explain why", "Section"],

Cell["(a) ", "Text"],

Cell["\<\
function Double   // was \"record\" Double before and that's not legal to \
have equation of algorithm in record declarations
   input Real x;  // was Real x before
   output Real y; // was no output Real y before
algorithm         // was equation before
   y := 2*x;
end Double;\
\>", "ModelicaInput"],

Cell["\<\
class DoubleCall
   Real double;
equation
  double=Double(12);
end DoubleCall;
    \
\>", "ModelicaInput"],

Cell[BoxData[
    \(\(Simulate[DoubleCall, \ {t, \ 0, \ 1}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Print[double[0]];\)\)], "Input"],

Cell[BoxData[
    \(24.`\)], "Print"]
}, Open  ]],

Cell["(b) ", "Text"],

Cell["\<\
function Divide
   input Integer numerator;
   output Real result;
   input Real denominator; // was parameter Real denominator = 10; before and \
that's not legal
                           // either should be declared as an input parameter \
or as a constant
algorithm // was \"equation\" before
   result := numerator / denominator;
end Divide;

class DivideCall
   Real divide;
 equation
   divide = Divide(12, 10);
 end DivideCall;\
\>", "ModelicaInput"],

Cell[BoxData[
    \(\(Simulate[DivideCall, \ {t, \ 0, \ 1}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Print[divide[0]];\)\)], "Input"],

Cell[BoxData[
    \(1.2000000476837158`\)], "Print"]
}, Open  ]],

Cell["\<\
(c) The system is correct syntactically but it doesn't do much since y \
doesn't vary at all because u is a constant.
     If there is no more information on how the system should behave there's \
nothing more that one can do about it.
     \
\>", "Text"],

Cell["\<\
model C
  Real x;
  Real y;
  constant Real u = 7;
  parameter Real high = 12;
  parameter Real low = 3;
equation
  y = if u > high then high else if u < low then low else u;
algorithm
  when time <= 2 then
    x := 4;
  end when;
  when x <= y then 
    x := 6;
  end when;
end C;\
\>", "ModelicaInput"],

Cell[BoxData[
    \(\(Simulate[C, \ {t, \ 0, \ 10}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotSimulation[{x[t], \ y[t]}, \ {t, \ 0, \ 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74402 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.312017 0.47619 [
[ 0 0 0 0 ]
[ 1 .74402 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0177147 0.97619 0.606318 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -3.51691 0.588604 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 10 6.28125 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(6.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(6.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(6.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(6.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(7)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 1 r
.001 w
.02381 .01472 m
.02571 .01472 L
.02762 .01472 L
.02952 .01472 L
.03143 .01472 L
.03333 .01472 L
.03524 .01472 L
.03714 .01472 L
.03905 .01472 L
.04095 .01472 L
.04286 .01472 L
.04476 .01472 L
.04667 .01472 L
.04857 .01472 L
.05048 .01472 L
.05238 .01472 L
.05429 .01472 L
.05619 .01472 L
.0581 .01472 L
.06 .01472 L
.0619 .01472 L
.06381 .01472 L
.06571 .01472 L
.06762 .01472 L
.06952 .01472 L
.07143 .01472 L
.07333 .01472 L
.07524 .01472 L
.07714 .01472 L
.07905 .01472 L
.08095 .01472 L
.08286 .01472 L
.08476 .01472 L
.08667 .01472 L
.08857 .01472 L
.09048 .01472 L
.09238 .01472 L
.09429 .01472 L
.09619 .01472 L
.0981 .01472 L
.1 .01472 L
.1019 .01472 L
.10381 .01472 L
.10571 .01472 L
.10762 .01472 L
.10952 .01472 L
.11143 .01472 L
.11333 .01472 L
.11524 .01472 L
.11714 .01472 L
Mistroke
.11905 .01472 L
.12095 .01472 L
.12286 .01472 L
.12476 .01472 L
.12667 .01472 L
.12857 .01472 L
.13048 .01472 L
.13238 .01472 L
.13429 .01472 L
.13619 .01472 L
.1381 .01472 L
.14 .01472 L
.1419 .01472 L
.14381 .01472 L
.14571 .01472 L
.14762 .01472 L
.14952 .01472 L
.15143 .01472 L
.15333 .01472 L
.15524 .01472 L
.15714 .01472 L
.15905 .01472 L
.16095 .01472 L
.16286 .01472 L
.16476 .01472 L
.16667 .01472 L
.16857 .01472 L
.17048 .01472 L
.17238 .01472 L
.17429 .01472 L
.17619 .01472 L
.1781 .01472 L
.18 .01472 L
.1819 .01472 L
.18381 .01472 L
.18571 .01472 L
.18762 .01472 L
.18952 .01472 L
.19143 .01472 L
.19333 .01472 L
.19524 .01472 L
.19714 .01472 L
.19905 .01472 L
.20095 .01472 L
.20286 .01472 L
.20476 .01472 L
.20667 .01472 L
.20857 .01472 L
.21048 .01472 L
.21238 .01472 L
Mistroke
.21429 .01472 L
.21429 .01472 L
.21619 .01472 L
.2181 .01472 L
.22 .01472 L
.2219 .01472 L
.22381 .01472 L
.22571 .01472 L
.22762 .01472 L
.22952 .01472 L
.23143 .01472 L
.23333 .01472 L
.23524 .01472 L
.23714 .01472 L
.23905 .01472 L
.24095 .01472 L
.24286 .01472 L
.24476 .01472 L
.24667 .01472 L
.24857 .01472 L
.25048 .01472 L
.25238 .01472 L
.25429 .01472 L
.25619 .01472 L
.2581 .01472 L
.26 .01472 L
.2619 .01472 L
.26381 .01472 L
.26571 .01472 L
.26762 .01472 L
.26952 .01472 L
.27143 .01472 L
.27333 .01472 L
.27524 .01472 L
.27714 .01472 L
.27905 .01472 L
.28095 .01472 L
.28286 .01472 L
.28476 .01472 L
.28667 .01472 L
.28857 .01472 L
.29048 .01472 L
.29238 .01472 L
.29429 .01472 L
.29619 .01472 L
.2981 .01472 L
.3 .01472 L
.3019 .01472 L
.30381 .01472 L
.30571 .01472 L
Mistroke
.30762 .01472 L
.30952 .01472 L
.31143 .01472 L
.31333 .01472 L
.31524 .01472 L
.31714 .01472 L
.31905 .01472 L
.32095 .01472 L
.32286 .01472 L
.32476 .01472 L
.32667 .01472 L
.32857 .01472 L
.33048 .01472 L
.33238 .01472 L
.33429 .01472 L
.33619 .01472 L
.3381 .01472 L
.34 .01472 L
.3419 .01472 L
.34381 .01472 L
.34571 .01472 L
.34762 .01472 L
.34952 .01472 L
.35143 .01472 L
.35333 .01472 L
.35524 .01472 L
.35714 .01472 L
.35905 .01472 L
.36095 .01472 L
.36286 .01472 L
.36476 .01472 L
.36667 .01472 L
.36857 .01472 L
.37048 .01472 L
.37238 .01472 L
.37429 .01472 L
.37619 .01472 L
.3781 .01472 L
.38 .01472 L
.3819 .01472 L
.38381 .01472 L
.38571 .01472 L
.38762 .01472 L
.38952 .01472 L
.39143 .01472 L
.39333 .01472 L
.39524 .01472 L
.39714 .01472 L
.39905 .01472 L
.40095 .01472 L
Mistroke
.40286 .01472 L
.40476 .01472 L
.40667 .01472 L
.40857 .01472 L
.41048 .01472 L
.41238 .01472 L
.41429 .01472 L
.41619 .01472 L
.4181 .01472 L
.42 .01472 L
.4219 .01472 L
.42381 .01472 L
.42571 .01472 L
.42762 .01472 L
.42952 .01472 L
.43143 .01472 L
.43333 .01472 L
.43524 .01472 L
.43714 .01472 L
.43905 .01472 L
.44095 .01472 L
.44286 .01472 L
.44476 .01472 L
.44667 .01472 L
.44857 .01472 L
.45048 .01472 L
.45238 .01472 L
.45429 .01472 L
.45619 .01472 L
.4581 .01472 L
.46 .01472 L
.4619 .01472 L
.46381 .01472 L
.46571 .01472 L
.46762 .01472 L
.46952 .01472 L
.47143 .01472 L
.47333 .01472 L
.47524 .01472 L
.47714 .01472 L
.47905 .01472 L
.48095 .01472 L
.48286 .01472 L
.48476 .01472 L
.48667 .01472 L
.48857 .01472 L
.49048 .01472 L
.49238 .01472 L
.49429 .01472 L
.49619 .01472 L
Mistroke
.4981 .01472 L
.5 .01472 L
.5019 .01472 L
.50381 .01472 L
.50571 .01472 L
.50762 .01472 L
.50952 .01472 L
.51143 .01472 L
.51333 .01472 L
.51524 .01472 L
.51714 .01472 L
.51905 .01472 L
.52095 .01472 L
.52286 .01472 L
.52476 .01472 L
.52667 .01472 L
.52857 .01472 L
.53048 .01472 L
.53238 .01472 L
.53429 .01472 L
.53619 .01472 L
.5381 .01472 L
.54 .01472 L
.5419 .01472 L
.54381 .01472 L
.54571 .01472 L
.54762 .01472 L
.54952 .01472 L
.55143 .01472 L
.55333 .01472 L
.55524 .01472 L
.55714 .01472 L
.55905 .01472 L
.56095 .01472 L
.56286 .01472 L
.56476 .01472 L
.56667 .01472 L
.56857 .01472 L
.57048 .01472 L
.57238 .01472 L
.57429 .01472 L
.57619 .01472 L
.5781 .01472 L
.58 .01472 L
.5819 .01472 L
.58381 .01472 L
.58571 .01472 L
.58762 .01472 L
.58952 .01472 L
.59143 .01472 L
Mistroke
.59333 .01472 L
.59524 .01472 L
.59714 .01472 L
.59905 .01472 L
.60095 .01472 L
.60286 .01472 L
.60476 .01472 L
.60667 .01472 L
.60857 .01472 L
.61048 .01472 L
.61238 .01472 L
.61429 .01472 L
.61619 .01472 L
.6181 .01472 L
.62 .01472 L
.6219 .01472 L
.62381 .01472 L
.62571 .01472 L
.62762 .01472 L
.62952 .01472 L
.63143 .01472 L
.63333 .01472 L
.63524 .01472 L
.63714 .01472 L
.63905 .01472 L
.64095 .01472 L
.64286 .01472 L
.64476 .01472 L
.64667 .01472 L
.64857 .01472 L
.65048 .01472 L
.65238 .01472 L
.65429 .01472 L
.65619 .01472 L
.6581 .01472 L
.66 .01472 L
.6619 .01472 L
.66381 .01472 L
.66571 .01472 L
.66762 .01472 L
.66952 .01472 L
.67143 .01472 L
.67333 .01472 L
.67524 .01472 L
.67714 .01472 L
.67905 .01472 L
.68095 .01472 L
.68286 .01472 L
.68476 .01472 L
.68667 .01472 L
Mistroke
.68857 .01472 L
.69048 .01472 L
.69238 .01472 L
.69429 .01472 L
.69619 .01472 L
.6981 .01472 L
.7 .01472 L
.7019 .01472 L
.70381 .01472 L
.70571 .01472 L
.70762 .01472 L
.70952 .01472 L
.71143 .01472 L
.71333 .01472 L
.71524 .01472 L
.71714 .01472 L
.71905 .01472 L
.72095 .01472 L
.72286 .01472 L
.72476 .01472 L
.72667 .01472 L
.72857 .01472 L
.73048 .01472 L
.73238 .01472 L
.73429 .01472 L
.73619 .01472 L
.7381 .01472 L
.74 .01472 L
.7419 .01472 L
.74381 .01472 L
.74571 .01472 L
.74762 .01472 L
.74952 .01472 L
.75143 .01472 L
.75333 .01472 L
.75524 .01472 L
.75714 .01472 L
.75905 .01472 L
.76095 .01472 L
.76286 .01472 L
.76476 .01472 L
.76667 .01472 L
.76857 .01472 L
.77048 .01472 L
.77238 .01472 L
.77429 .01472 L
.77619 .01472 L
.7781 .01472 L
.78 .01472 L
.7819 .01472 L
Mistroke
.78381 .01472 L
.78571 .01472 L
.78762 .01472 L
.78952 .01472 L
.79143 .01472 L
.79333 .01472 L
.79524 .01472 L
.79714 .01472 L
.79905 .01472 L
.80095 .01472 L
.80286 .01472 L
.80476 .01472 L
.80667 .01472 L
.80857 .01472 L
.81048 .01472 L
.81238 .01472 L
.81429 .01472 L
.81619 .01472 L
.8181 .01472 L
.82 .01472 L
.8219 .01472 L
.82381 .01472 L
.82571 .01472 L
.82762 .01472 L
.82952 .01472 L
.83143 .01472 L
.83333 .01472 L
.83524 .01472 L
.83714 .01472 L
.83905 .01472 L
.84095 .01472 L
.84286 .01472 L
.84476 .01472 L
.84667 .01472 L
.84857 .01472 L
.85048 .01472 L
.85238 .01472 L
.85429 .01472 L
.85619 .01472 L
.8581 .01472 L
.86 .01472 L
.8619 .01472 L
.86381 .01472 L
.86571 .01472 L
.86762 .01472 L
.86952 .01472 L
.87143 .01472 L
.87333 .01472 L
.87524 .01472 L
.87714 .01472 L
Mistroke
.87905 .01472 L
.88095 .01472 L
.88286 .01472 L
.88476 .01472 L
.88667 .01472 L
.88857 .01472 L
.89048 .01472 L
.89238 .01472 L
.89429 .01472 L
.89619 .01472 L
.8981 .01472 L
.9 .01472 L
.9019 .01472 L
.90381 .01472 L
.90571 .01472 L
.90762 .01472 L
.90952 .01472 L
.91143 .01472 L
.91333 .01472 L
.91524 .01472 L
.91714 .01472 L
.91905 .01472 L
.92095 .01472 L
.92286 .01472 L
.92476 .01472 L
.92667 .01472 L
.92857 .01472 L
.93048 .01472 L
.93238 .01472 L
.93429 .01472 L
.93619 .01472 L
.9381 .01472 L
.94 .01472 L
.9419 .01472 L
.94381 .01472 L
.94571 .01472 L
.94762 .01472 L
.94952 .01472 L
.95143 .01472 L
.95333 .01472 L
.95524 .01472 L
.95714 .01472 L
.95905 .01472 L
.96095 .01472 L
.96286 .01472 L
.96476 .01472 L
.96667 .01472 L
.96857 .01472 L
.97048 .01472 L
.97238 .01472 L
Mistroke
.97429 .01472 L
.97619 .01472 L
Mfstroke
0 .5 0 r
.02381 .60332 m
.02571 .60332 L
.02762 .60332 L
.02952 .60332 L
.03143 .60332 L
.03333 .60332 L
.03524 .60332 L
.03714 .60332 L
.03905 .60332 L
.04095 .60332 L
.04286 .60332 L
.04476 .60332 L
.04667 .60332 L
.04857 .60332 L
.05048 .60332 L
.05238 .60332 L
.05429 .60332 L
.05619 .60332 L
.0581 .60332 L
.06 .60332 L
.0619 .60332 L
.06381 .60332 L
.06571 .60332 L
.06762 .60332 L
.06952 .60332 L
.07143 .60332 L
.07333 .60332 L
.07524 .60332 L
.07714 .60332 L
.07905 .60332 L
.08095 .60332 L
.08286 .60332 L
.08476 .60332 L
.08667 .60332 L
.08857 .60332 L
.09048 .60332 L
.09238 .60332 L
.09429 .60332 L
.09619 .60332 L
.0981 .60332 L
.1 .60332 L
.1019 .60332 L
.10381 .60332 L
.10571 .60332 L
.10762 .60332 L
.10952 .60332 L
.11143 .60332 L
.11333 .60332 L
.11524 .60332 L
.11714 .60332 L
Mistroke
.11905 .60332 L
.12095 .60332 L
.12286 .60332 L
.12476 .60332 L
.12667 .60332 L
.12857 .60332 L
.13048 .60332 L
.13238 .60332 L
.13429 .60332 L
.13619 .60332 L
.1381 .60332 L
.14 .60332 L
.1419 .60332 L
.14381 .60332 L
.14571 .60332 L
.14762 .60332 L
.14952 .60332 L
.15143 .60332 L
.15333 .60332 L
.15524 .60332 L
.15714 .60332 L
.15905 .60332 L
.16095 .60332 L
.16286 .60332 L
.16476 .60332 L
.16667 .60332 L
.16857 .60332 L
.17048 .60332 L
.17238 .60332 L
.17429 .60332 L
.17619 .60332 L
.1781 .60332 L
.18 .60332 L
.1819 .60332 L
.18381 .60332 L
.18571 .60332 L
.18762 .60332 L
.18952 .60332 L
.19143 .60332 L
.19333 .60332 L
.19524 .60332 L
.19714 .60332 L
.19905 .60332 L
.20095 .60332 L
.20286 .60332 L
.20476 .60332 L
.20667 .60332 L
.20857 .60332 L
.21048 .60332 L
.21238 .60332 L
Mistroke
.21429 .60332 L
.21429 .60332 L
.21619 .60332 L
.2181 .60332 L
.22 .60332 L
.2219 .60332 L
.22381 .60332 L
.22571 .60332 L
.22762 .60332 L
.22952 .60332 L
.23143 .60332 L
.23333 .60332 L
.23524 .60332 L
.23714 .60332 L
.23905 .60332 L
.24095 .60332 L
.24286 .60332 L
.24476 .60332 L
.24667 .60332 L
.24857 .60332 L
.25048 .60332 L
.25238 .60332 L
.25429 .60332 L
.25619 .60332 L
.2581 .60332 L
.26 .60332 L
.2619 .60332 L
.26381 .60332 L
.26571 .60332 L
.26762 .60332 L
.26952 .60332 L
.27143 .60332 L
.27333 .60332 L
.27524 .60332 L
.27714 .60332 L
.27905 .60332 L
.28095 .60332 L
.28286 .60332 L
.28476 .60332 L
.28667 .60332 L
.28857 .60332 L
.29048 .60332 L
.29238 .60332 L
.29429 .60332 L
.29619 .60332 L
.2981 .60332 L
.3 .60332 L
.3019 .60332 L
.30381 .60332 L
.30571 .60332 L
Mistroke
.30762 .60332 L
.30952 .60332 L
.31143 .60332 L
.31333 .60332 L
.31524 .60332 L
.31714 .60332 L
.31905 .60332 L
.32095 .60332 L
.32286 .60332 L
.32476 .60332 L
.32667 .60332 L
.32857 .60332 L
.33048 .60332 L
.33238 .60332 L
.33429 .60332 L
.33619 .60332 L
.3381 .60332 L
.34 .60332 L
.3419 .60332 L
.34381 .60332 L
.34571 .60332 L
.34762 .60332 L
.34952 .60332 L
.35143 .60332 L
.35333 .60332 L
.35524 .60332 L
.35714 .60332 L
.35905 .60332 L
.36095 .60332 L
.36286 .60332 L
.36476 .60332 L
.36667 .60332 L
.36857 .60332 L
.37048 .60332 L
.37238 .60332 L
.37429 .60332 L
.37619 .60332 L
.3781 .60332 L
.38 .60332 L
.3819 .60332 L
.38381 .60332 L
.38571 .60332 L
.38762 .60332 L
.38952 .60332 L
.39143 .60332 L
.39333 .60332 L
.39524 .60332 L
.39714 .60332 L
.39905 .60332 L
.40095 .60332 L
Mistroke
.40286 .60332 L
.40476 .60332 L
.40667 .60332 L
.40857 .60332 L
.41048 .60332 L
.41238 .60332 L
.41429 .60332 L
.41619 .60332 L
.4181 .60332 L
.42 .60332 L
.4219 .60332 L
.42381 .60332 L
.42571 .60332 L
.42762 .60332 L
.42952 .60332 L
.43143 .60332 L
.43333 .60332 L
.43524 .60332 L
.43714 .60332 L
.43905 .60332 L
.44095 .60332 L
.44286 .60332 L
.44476 .60332 L
.44667 .60332 L
.44857 .60332 L
.45048 .60332 L
.45238 .60332 L
.45429 .60332 L
.45619 .60332 L
.4581 .60332 L
.46 .60332 L
.4619 .60332 L
.46381 .60332 L
.46571 .60332 L
.46762 .60332 L
.46952 .60332 L
.47143 .60332 L
.47333 .60332 L
.47524 .60332 L
.47714 .60332 L
.47905 .60332 L
.48095 .60332 L
.48286 .60332 L
.48476 .60332 L
.48667 .60332 L
.48857 .60332 L
.49048 .60332 L
.49238 .60332 L
.49429 .60332 L
.49619 .60332 L
Mistroke
.4981 .60332 L
.5 .60332 L
.5019 .60332 L
.50381 .60332 L
.50571 .60332 L
.50762 .60332 L
.50952 .60332 L
.51143 .60332 L
.51333 .60332 L
.51524 .60332 L
.51714 .60332 L
.51905 .60332 L
.52095 .60332 L
.52286 .60332 L
.52476 .60332 L
.52667 .60332 L
.52857 .60332 L
.53048 .60332 L
.53238 .60332 L
.53429 .60332 L
.53619 .60332 L
.5381 .60332 L
.54 .60332 L
.5419 .60332 L
.54381 .60332 L
.54571 .60332 L
.54762 .60332 L
.54952 .60332 L
.55143 .60332 L
.55333 .60332 L
.55524 .60332 L
.55714 .60332 L
.55905 .60332 L
.56095 .60332 L
.56286 .60332 L
.56476 .60332 L
.56667 .60332 L
.56857 .60332 L
.57048 .60332 L
.57238 .60332 L
.57429 .60332 L
.57619 .60332 L
.5781 .60332 L
.58 .60332 L
.5819 .60332 L
.58381 .60332 L
.58571 .60332 L
.58762 .60332 L
.58952 .60332 L
.59143 .60332 L
Mistroke
.59333 .60332 L
.59524 .60332 L
.59714 .60332 L
.59905 .60332 L
.60095 .60332 L
.60286 .60332 L
.60476 .60332 L
.60667 .60332 L
.60857 .60332 L
.61048 .60332 L
.61238 .60332 L
.61429 .60332 L
.61619 .60332 L
.6181 .60332 L
.62 .60332 L
.6219 .60332 L
.62381 .60332 L
.62571 .60332 L
.62762 .60332 L
.62952 .60332 L
.63143 .60332 L
.63333 .60332 L
.63524 .60332 L
.63714 .60332 L
.63905 .60332 L
.64095 .60332 L
.64286 .60332 L
.64476 .60332 L
.64667 .60332 L
.64857 .60332 L
.65048 .60332 L
.65238 .60332 L
.65429 .60332 L
.65619 .60332 L
.6581 .60332 L
.66 .60332 L
.6619 .60332 L
.66381 .60332 L
.66571 .60332 L
.66762 .60332 L
.66952 .60332 L
.67143 .60332 L
.67333 .60332 L
.67524 .60332 L
.67714 .60332 L
.67905 .60332 L
.68095 .60332 L
.68286 .60332 L
.68476 .60332 L
.68667 .60332 L
Mistroke
.68857 .60332 L
.69048 .60332 L
.69238 .60332 L
.69429 .60332 L
.69619 .60332 L
.6981 .60332 L
.7 .60332 L
.7019 .60332 L
.70381 .60332 L
.70571 .60332 L
.70762 .60332 L
.70952 .60332 L
.71143 .60332 L
.71333 .60332 L
.71524 .60332 L
.71714 .60332 L
.71905 .60332 L
.72095 .60332 L
.72286 .60332 L
.72476 .60332 L
.72667 .60332 L
.72857 .60332 L
.73048 .60332 L
.73238 .60332 L
.73429 .60332 L
.73619 .60332 L
.7381 .60332 L
.74 .60332 L
.7419 .60332 L
.74381 .60332 L
.74571 .60332 L
.74762 .60332 L
.74952 .60332 L
.75143 .60332 L
.75333 .60332 L
.75524 .60332 L
.75714 .60332 L
.75905 .60332 L
.76095 .60332 L
.76286 .60332 L
.76476 .60332 L
.76667 .60332 L
.76857 .60332 L
.77048 .60332 L
.77238 .60332 L
.77429 .60332 L
.77619 .60332 L
.7781 .60332 L
.78 .60332 L
.7819 .60332 L
Mistroke
.78381 .60332 L
.78571 .60332 L
.78762 .60332 L
.78952 .60332 L
.79143 .60332 L
.79333 .60332 L
.79524 .60332 L
.79714 .60332 L
.79905 .60332 L
.80095 .60332 L
.80286 .60332 L
.80476 .60332 L
.80667 .60332 L
.80857 .60332 L
.81048 .60332 L
.81238 .60332 L
.81429 .60332 L
.81619 .60332 L
.8181 .60332 L
.82 .60332 L
.8219 .60332 L
.82381 .60332 L
.82571 .60332 L
.82762 .60332 L
.82952 .60332 L
.83143 .60332 L
.83333 .60332 L
.83524 .60332 L
.83714 .60332 L
.83905 .60332 L
.84095 .60332 L
.84286 .60332 L
.84476 .60332 L
.84667 .60332 L
.84857 .60332 L
.85048 .60332 L
.85238 .60332 L
.85429 .60332 L
.85619 .60332 L
.8581 .60332 L
.86 .60332 L
.8619 .60332 L
.86381 .60332 L
.86571 .60332 L
.86762 .60332 L
.86952 .60332 L
.87143 .60332 L
.87333 .60332 L
.87524 .60332 L
.87714 .60332 L
Mistroke
.87905 .60332 L
.88095 .60332 L
.88286 .60332 L
.88476 .60332 L
.88667 .60332 L
.88857 .60332 L
.89048 .60332 L
.89238 .60332 L
.89429 .60332 L
.89619 .60332 L
.8981 .60332 L
.9 .60332 L
.9019 .60332 L
.90381 .60332 L
.90571 .60332 L
.90762 .60332 L
.90952 .60332 L
.91143 .60332 L
.91333 .60332 L
.91524 .60332 L
.91714 .60332 L
.91905 .60332 L
.92095 .60332 L
.92286 .60332 L
.92476 .60332 L
.92667 .60332 L
.92857 .60332 L
.93048 .60332 L
.93238 .60332 L
.93429 .60332 L
.93619 .60332 L
.9381 .60332 L
.94 .60332 L
.9419 .60332 L
.94381 .60332 L
.94571 .60332 L
.94762 .60332 L
.94952 .60332 L
.95143 .60332 L
.95333 .60332 L
.95524 .60332 L
.95714 .60332 L
.95905 .60332 L
.96095 .60332 L
.96286 .60332 L
.96476 .60332 L
.96667 .60332 L
.96857 .60332 L
.97048 .60332 L
.97238 .60332 L
Mistroke
.97429 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0714286 0.583445 0.547619 0.726302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00611247 0.0611247 0.0119048 0.119048 [
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0110024 0.0214286 0.0721271 0.140476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .5 0 r
.00374 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .08095 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 12.813 moveto
(@) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.159524 0.0721271 0.278571 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.00374 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .21905 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 12.813 moveto
(@) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .74402 L
0 .74402 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 214.25},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eR000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00B03IfMT4000002`0fMWI0`00000Y0=WIf@<00000;03IfMT2000002P0fMWI1@0000020=WI
f@8000006P3IfMT004P0fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@0X0=WIf@04
0000003IfMT0fMWI000002X0fMWI00@000000=WIf@3IfMT00000:@3IfMT01@000000fMWI0=WIf@3I
fMT000000080fMWI00<000000=WIf@3IfMT05`3IfMT004T0fMWI00<000000=WIf@3IfMT0:P3IfMT5
000002T0fMWI00@000000=WIf@3IfMT00000:P3IfMT010000000fMWI0=WIf@00000Y0=WIf@050000
003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI0=WIf@0G0=WIf@00BP3IfMT00`000000fMWI
0=WIf@0Y0=WIf@040000003IfMT0fMWI000002X0fMWI0`00000/0=WIf@800000:P3IfMT01@000000
fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT05`3IfMT004P0fMWI00@000000=WIf@3I
fMT00000:`3IfMT00`000000fMWI0000000[0=WIf@030000003IfMT0fMWI02X0fMWI00@000000=WI
f@3IfMT00000:@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT05`3I
fMT004T0fMWI0P00000]0=WIf@800000:`3IfMT3000002/0fMWI0P00000Y0=WIf@800000103IfMT2
000001X0fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI
0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3b
0=WIf@8000003@3IfMT001H0fMWI1P00003W0000o`D00000203IfMT010000000fMWI0=WIf@00000<
0=WIf@00703IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT02`3IfMT00`000000fMWI0=WIf@0=0=WIf@00703IfMT00`000000fMWI0=WIf@0[0=WIf@03
0000003IfMT0fMWI02/0fMWI00<000000=WIf@3IfMT0:`3IfMT00`000000fMWI0=WIf@0[0=WIf@03
0000003IfMT0fMWI02/0fMWI00<000000=WIf@3IfMT02P3IfMT5000000`0fMWI000L0=WIf@030000
003IfMT0fMWI0?40fMWI00<000000=WIf@3IfMT03@3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3I
fMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI
0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI
0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<00000
0=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@03
0000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703I
fMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT0
01`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80
fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3I
fMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI
0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI
0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<00000
0=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI00080=WIf@<0
0000103IfMT2000000<0fMWI100000040=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT000P0fMWI
00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0
fMWI0P3IfMT000P0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@040=WIf@80
0000o`3IfMT30=WIf@00203IfMT3000000/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@3o0=WIf@80fMWI00090=WIf@030000003IfMT0fMWI00P0fMWI00@000000=WIf@3IfMT00000
103IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI00090=WIf@<000002@3IfMT2000000D0fMWI00<0
00000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WI
f@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00
703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3I
fMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WI
f@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0
o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0
fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000
fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<0
00000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WI
f@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00
703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3I
fMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WI
f@80fMWI00080=WIf@<00000103IfMT2000000D0fMWI0`0000030=WIf@030000003IfMT0fMWI0?l0
fMWI0P3IfMT000P0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0?l0fMWI0P3IfMT000P0fMWI00@000000=WIf@3IfMT00000203IfMT5000000<0
fMWI0P00003o0=WIf@<0fMWI00080=WIf@<000002@3IfMT010000000fMWI0=WIf@0000040=WIf@03
0000003IfMT0fMWI0?l0fMWI0P3IfMT000T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI
000000040=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT000T0fMWI0`00000:0=WIf@800000103I
fMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT0
01`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80
fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3I
fMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI
0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI
0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<00000
0=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@03
0000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703I
fMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT0
01`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80
fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3I
fMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI
0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00203IfMT3000000@0fMWI
0P0000030=WIf@<000001@3IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI00080=WIf@040000003I
fMT0fMWI000000P0fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@3o0=WIf@80
fMWI00080=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT00000103IfMT20000
0?l0fMWI0`3IfMT000P0fMWI0`0000090=WIf@<000001@3IfMT00`000000fMWI0=WIf@3o0=WIf@80
fMWI00090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@3o0=WIf@80fMWI00090=WIf@<000002@3IfMT3000000@0fMWI00<000000=WIf@3IfMT0o`3I
fMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI
0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI
0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<00000
0=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@03
0000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703I
fMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT0
01`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80
fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3I
fMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI
0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI
0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<00000
0=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI00080=WIf@<0
0000103IfMT2000000@0fMWI0P0000050=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT000P0fMWI
00@000000=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI
0?l0fMWI0P3IfMT000P0fMWI00@000000=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@000004
0=WIf@800000o`3IfMT30=WIf@00203IfMT3000000X0fMWI0P0000050=WIf@030000003IfMT0fMWI
0?l0fMWI0P3IfMT000T0fMWI00<000000=WIf@3IfMT0203IfMT010000000fMWI0=WIf@0000040=WI
f@030000003IfMT0fMWI0?l0fMWI0P3IfMT000T0fMWI0`0000090=WIf@8000001@3IfMT00`000000
fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<0
00000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WI
f@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00
703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3I
fMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WI
f@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0
o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0
fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000
fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<0
00000=WIf@3IfMT0o`3IfMT20=WIf@00703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WI
f@030000003IfMT0fMWI0?l0fMWI0P3IfMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@00
703IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000L0=WIf@030000003IfMT0fMWI0?l0fMWI0P3I
fMT001`0fMWI00<000000=WIf@3IfMT0o`3IfMT20=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI0?l0fMWI0P3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@0[0=WIf@03001o003IfMT0fMWI0=<0fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
i`00O`0M0=WIf@005`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0?l0fMWI0P3I
fMT001@0fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI000D
0=WIf@@00000103IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI000R0=WIf@80
00001P3IfMT2000000P0fMWI0P00003Z0=WIf@008`3IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0j03IfMT002@0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@020=WIf@800000103IfMT00`000000fMWI0=WIf@3X0=WIf@008`3IfMT0
0`000000fMWI000000040=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT01@000000fMWI0=WI
f@3IfMT000000>X0fMWI000F0=WIf@T007l00`3IfMT010000000fMWI0=WIf@0000040=WIf@050000
003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@3X0=WIf@008@3IfMT3000000030=WI
f@000000000000<0fMWI00<000000=WIf@3IfMT01@0000030=WIf@030000003IfMT0fMWI0>P0fMWI
000Z0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@3X0=WIf@00:P3I
fMT2000000P0fMWI0P00003Z0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00
o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00
o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00:P3IfMT2000000P0fMWI0P00003Z0=WI
f@00:P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0>P0fMWI000Q0=WIf@800000
00<0fMWI000000000000103IfMT00`000000fMWI0=WIf@020=WIf@800000103IfMT00`000000fMWI
0=WIf@3X0=WIf@005P3IfMT90000o`<0fMWI00<000000=WIf@0000001@3IfMT01@000000fMWI0=WI
f@3IfMT000000080fMWI00D000000=WIf@3IfMT0fMWI0000003Z0=WIf@008`3IfMT00`000000fMWI
0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@3X0=WIf@00
8@3IfMT2000000030=WIf@000000000000@0fMWI00<000000=WIf@3IfMT01@0000030=WIf@030000
003IfMT0fMWI0>P0fMWI000Z0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI
0=WIf@3X0=WIf@00:P3IfMT2000000P0fMWI0P00003Z0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WI
f@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WI
f@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WI
f@00\
\>"],
  ImageRangeCache->{{{138, 425}, {519.875, 306.625}} -> {-2.06252, 1.59136, \
0.00732689, 0.00732689}, {{145, 417.938}, {514.75, 346.063}} -> {-7.21452, \
8.00044, 0.0434554, 0.00703123}, {{158.625, 295.125}, {352.625, 311.688}} -> \
{-19.1203, 8.47959, 0.119891, 0.0615577}, {{160.125, 168.438}, {349.688, \
333.438}} -> {-39.5267, 30.8725, 0.240604, 0.240604}, {{160.125, 168.438}, \
{330.813, 314.563}} -> {-39.5267, 26.3311, 0.240604, 0.240604}}]
}, Open  ]],

Cell["\<\
(d) Is not legal to have updates of y that has parameter variability. In the \
second if there is y=7 witch is illegal. 
     If there is no more information on how the system should behave there's \
nothing more that one can do about it.
     \
\>", "Text"],

Cell["\<\
class D
  Real x;
  parameter Real y = 4;
equation
  if y >= 20 
  then 
     x = 5;
  end if; 
  if y <= 20 
  then 
     x = 10; 
     //y = 7; 
  end if;
end D;\
\>", "ModelicaInput"],

Cell[BoxData[
    \(\(Simulate[D, \ {t, \ 0, \ 10}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotSimulation[{x[t], \ y[t]}, \ {t, \ 0, \ 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74402 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.312017 0.47619 [
[ 0 0 0 0 ]
[ 1 .74402 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0177147 0.97619 0.606318 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.377687 0.0981006 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 10 6.28125 ]
[.01131 .11282 -6 -4.5 ]
[.01131 .11282 0 4.5 ]
[.01131 .21092 -6 -4.5 ]
[.01131 .21092 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .40712 -6 -4.5 ]
[.01131 .40712 0 4.5 ]
[.01131 .50522 -6 -4.5 ]
[.01131 .50522 0 4.5 ]
[.01131 .60332 -12 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .11282 m
.03006 .11282 L
s
[(5)] .01131 .11282 1 0 Mshowa
.02381 .21092 m
.03006 .21092 L
s
[(6)] .01131 .21092 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(7)] .01131 .30902 1 0 Mshowa
.02381 .40712 m
.03006 .40712 L
s
[(8)] .01131 .40712 1 0 Mshowa
.02381 .50522 m
.03006 .50522 L
s
[(9)] .01131 .50522 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(10)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03434 m
.02756 .03434 L
s
.02381 .05396 m
.02756 .05396 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .0932 m
.02756 .0932 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .15206 m
.02756 .15206 L
s
.02381 .17168 m
.02756 .17168 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .23054 m
.02756 .23054 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .26978 m
.02756 .26978 L
s
.02381 .2894 m
.02756 .2894 L
s
.02381 .32864 m
.02756 .32864 L
s
.02381 .34826 m
.02756 .34826 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .3875 m
.02756 .3875 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .44636 m
.02756 .44636 L
s
.02381 .46598 m
.02756 .46598 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .52484 m
.02756 .52484 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .56408 m
.02756 .56408 L
s
.02381 .5837 m
.02756 .5837 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 1 r
.001 w
.02381 .60332 m
.02571 .60332 L
.02762 .60332 L
.02952 .60332 L
.03143 .60332 L
.03333 .60332 L
.03524 .60332 L
.03714 .60332 L
.03905 .60332 L
.04095 .60332 L
.04286 .60332 L
.04476 .60332 L
.04667 .60332 L
.04857 .60332 L
.05048 .60332 L
.05238 .60332 L
.05429 .60332 L
.05619 .60332 L
.0581 .60332 L
.06 .60332 L
.0619 .60332 L
.06381 .60332 L
.06571 .60332 L
.06762 .60332 L
.06952 .60332 L
.07143 .60332 L
.07333 .60332 L
.07524 .60332 L
.07714 .60332 L
.07905 .60332 L
.08095 .60332 L
.08286 .60332 L
.08476 .60332 L
.08667 .60332 L
.08857 .60332 L
.09048 .60332 L
.09238 .60332 L
.09429 .60332 L
.09619 .60332 L
.0981 .60332 L
.1 .60332 L
.1019 .60332 L
.10381 .60332 L
.10571 .60332 L
.10762 .60332 L
.10952 .60332 L
.11143 .60332 L
.11333 .60332 L
.11524 .60332 L
.11714 .60332 L
Mistroke
.11905 .60332 L
.12095 .60332 L
.12286 .60332 L
.12476 .60332 L
.12667 .60332 L
.12857 .60332 L
.13048 .60332 L
.13238 .60332 L
.13429 .60332 L
.13619 .60332 L
.1381 .60332 L
.14 .60332 L
.1419 .60332 L
.14381 .60332 L
.14571 .60332 L
.14762 .60332 L
.14952 .60332 L
.15143 .60332 L
.15333 .60332 L
.15524 .60332 L
.15714 .60332 L
.15905 .60332 L
.16095 .60332 L
.16286 .60332 L
.16476 .60332 L
.16667 .60332 L
.16857 .60332 L
.17048 .60332 L
.17238 .60332 L
.17429 .60332 L
.17619 .60332 L
.1781 .60332 L
.18 .60332 L
.1819 .60332 L
.18381 .60332 L
.18571 .60332 L
.18762 .60332 L
.18952 .60332 L
.19143 .60332 L
.19333 .60332 L
.19524 .60332 L
.19714 .60332 L
.19905 .60332 L
.20095 .60332 L
.20286 .60332 L
.20476 .60332 L
.20667 .60332 L
.20857 .60332 L
.21048 .60332 L
.21238 .60332 L
Mistroke
.21429 .60332 L
.21619 .60332 L
.2181 .60332 L
.22 .60332 L
.2219 .60332 L
.22381 .60332 L
.22571 .60332 L
.22762 .60332 L
.22952 .60332 L
.23143 .60332 L
.23333 .60332 L
.23524 .60332 L
.23714 .60332 L
.23905 .60332 L
.24095 .60332 L
.24286 .60332 L
.24476 .60332 L
.24667 .60332 L
.24857 .60332 L
.25048 .60332 L
.25238 .60332 L
.25429 .60332 L
.25619 .60332 L
.2581 .60332 L
.26 .60332 L
.2619 .60332 L
.26381 .60332 L
.26571 .60332 L
.26762 .60332 L
.26952 .60332 L
.27143 .60332 L
.27333 .60332 L
.27524 .60332 L
.27714 .60332 L
.27905 .60332 L
.28095 .60332 L
.28286 .60332 L
.28476 .60332 L
.28667 .60332 L
.28857 .60332 L
.29048 .60332 L
.29238 .60332 L
.29429 .60332 L
.29619 .60332 L
.2981 .60332 L
.3 .60332 L
.3019 .60332 L
.30381 .60332 L
.30571 .60332 L
.30762 .60332 L
Mistroke
.30952 .60332 L
.31143 .60332 L
.31333 .60332 L
.31524 .60332 L
.31714 .60332 L
.31905 .60332 L
.32095 .60332 L
.32286 .60332 L
.32476 .60332 L
.32667 .60332 L
.32857 .60332 L
.33048 .60332 L
.33238 .60332 L
.33429 .60332 L
.33619 .60332 L
.3381 .60332 L
.34 .60332 L
.3419 .60332 L
.34381 .60332 L
.34571 .60332 L
.34762 .60332 L
.34952 .60332 L
.35143 .60332 L
.35333 .60332 L
.35524 .60332 L
.35714 .60332 L
.35905 .60332 L
.36095 .60332 L
.36286 .60332 L
.36476 .60332 L
.36667 .60332 L
.36857 .60332 L
.37048 .60332 L
.37238 .60332 L
.37429 .60332 L
.37619 .60332 L
.3781 .60332 L
.38 .60332 L
.3819 .60332 L
.38381 .60332 L
.38571 .60332 L
.38762 .60332 L
.38952 .60332 L
.39143 .60332 L
.39333 .60332 L
.39524 .60332 L
.39714 .60332 L
.39905 .60332 L
.40095 .60332 L
.40286 .60332 L
Mistroke
.40476 .60332 L
.40667 .60332 L
.40857 .60332 L
.41048 .60332 L
.41238 .60332 L
.41429 .60332 L
.41619 .60332 L
.4181 .60332 L
.42 .60332 L
.4219 .60332 L
.42381 .60332 L
.42571 .60332 L
.42762 .60332 L
.42952 .60332 L
.43143 .60332 L
.43333 .60332 L
.43524 .60332 L
.43714 .60332 L
.43905 .60332 L
.44095 .60332 L
.44286 .60332 L
.44476 .60332 L
.44667 .60332 L
.44857 .60332 L
.45048 .60332 L
.45238 .60332 L
.45429 .60332 L
.45619 .60332 L
.4581 .60332 L
.46 .60332 L
.4619 .60332 L
.46381 .60332 L
.46571 .60332 L
.46762 .60332 L
.46952 .60332 L
.47143 .60332 L
.47333 .60332 L
.47524 .60332 L
.47714 .60332 L
.47905 .60332 L
.48095 .60332 L
.48286 .60332 L
.48476 .60332 L
.48667 .60332 L
.48857 .60332 L
.49048 .60332 L
.49238 .60332 L
.49429 .60332 L
.49619 .60332 L
.4981 .60332 L
Mistroke
.5 .60332 L
.5019 .60332 L
.50381 .60332 L
.50571 .60332 L
.50762 .60332 L
.50952 .60332 L
.51143 .60332 L
.51333 .60332 L
.51524 .60332 L
.51714 .60332 L
.51905 .60332 L
.52095 .60332 L
.52286 .60332 L
.52476 .60332 L
.52667 .60332 L
.52857 .60332 L
.53048 .60332 L
.53238 .60332 L
.53429 .60332 L
.53619 .60332 L
.5381 .60332 L
.54 .60332 L
.5419 .60332 L
.54381 .60332 L
.54571 .60332 L
.54762 .60332 L
.54952 .60332 L
.55143 .60332 L
.55333 .60332 L
.55524 .60332 L
.55714 .60332 L
.55905 .60332 L
.56095 .60332 L
.56286 .60332 L
.56476 .60332 L
.56667 .60332 L
.56857 .60332 L
.57048 .60332 L
.57238 .60332 L
.57429 .60332 L
.57619 .60332 L
.5781 .60332 L
.58 .60332 L
.5819 .60332 L
.58381 .60332 L
.58571 .60332 L
.58762 .60332 L
.58952 .60332 L
.59143 .60332 L
.59333 .60332 L
Mistroke
.59524 .60332 L
.59714 .60332 L
.59905 .60332 L
.60095 .60332 L
.60286 .60332 L
.60476 .60332 L
.60667 .60332 L
.60857 .60332 L
.61048 .60332 L
.61238 .60332 L
.61429 .60332 L
.61619 .60332 L
.6181 .60332 L
.62 .60332 L
.6219 .60332 L
.62381 .60332 L
.62571 .60332 L
.62762 .60332 L
.62952 .60332 L
.63143 .60332 L
.63333 .60332 L
.63524 .60332 L
.63714 .60332 L
.63905 .60332 L
.64095 .60332 L
.64286 .60332 L
.64476 .60332 L
.64667 .60332 L
.64857 .60332 L
.65048 .60332 L
.65238 .60332 L
.65429 .60332 L
.65619 .60332 L
.6581 .60332 L
.66 .60332 L
.6619 .60332 L
.66381 .60332 L
.66571 .60332 L
.66762 .60332 L
.66952 .60332 L
.67143 .60332 L
.67333 .60332 L
.67524 .60332 L
.67714 .60332 L
.67905 .60332 L
.68095 .60332 L
.68286 .60332 L
.68476 .60332 L
.68667 .60332 L
.68857 .60332 L
Mistroke
.69048 .60332 L
.69238 .60332 L
.69429 .60332 L
.69619 .60332 L
.6981 .60332 L
.7 .60332 L
.7019 .60332 L
.70381 .60332 L
.70571 .60332 L
.70762 .60332 L
.70952 .60332 L
.71143 .60332 L
.71333 .60332 L
.71524 .60332 L
.71714 .60332 L
.71905 .60332 L
.72095 .60332 L
.72286 .60332 L
.72476 .60332 L
.72667 .60332 L
.72857 .60332 L
.73048 .60332 L
.73238 .60332 L
.73429 .60332 L
.73619 .60332 L
.7381 .60332 L
.74 .60332 L
.7419 .60332 L
.74381 .60332 L
.74571 .60332 L
.74762 .60332 L
.74952 .60332 L
.75143 .60332 L
.75333 .60332 L
.75524 .60332 L
.75714 .60332 L
.75905 .60332 L
.76095 .60332 L
.76286 .60332 L
.76476 .60332 L
.76667 .60332 L
.76857 .60332 L
.77048 .60332 L
.77238 .60332 L
.77429 .60332 L
.77619 .60332 L
.7781 .60332 L
.78 .60332 L
.7819 .60332 L
.78381 .60332 L
Mistroke
.78571 .60332 L
.78762 .60332 L
.78952 .60332 L
.79143 .60332 L
.79333 .60332 L
.79524 .60332 L
.79714 .60332 L
.79905 .60332 L
.80095 .60332 L
.80286 .60332 L
.80476 .60332 L
.80667 .60332 L
.80857 .60332 L
.81048 .60332 L
.81238 .60332 L
.81429 .60332 L
.81619 .60332 L
.8181 .60332 L
.82 .60332 L
.8219 .60332 L
.82381 .60332 L
.82571 .60332 L
.82762 .60332 L
.82952 .60332 L
.83143 .60332 L
.83333 .60332 L
.83524 .60332 L
.83714 .60332 L
.83905 .60332 L
.84095 .60332 L
.84286 .60332 L
.84476 .60332 L
.84667 .60332 L
.84857 .60332 L
.85048 .60332 L
.85238 .60332 L
.85429 .60332 L
.85619 .60332 L
.8581 .60332 L
.86 .60332 L
.8619 .60332 L
.86381 .60332 L
.86571 .60332 L
.86762 .60332 L
.86952 .60332 L
.87143 .60332 L
.87333 .60332 L
.87524 .60332 L
.87714 .60332 L
.87905 .60332 L
Mistroke
.88095 .60332 L
.88286 .60332 L
.88476 .60332 L
.88667 .60332 L
.88857 .60332 L
.89048 .60332 L
.89238 .60332 L
.89429 .60332 L
.89619 .60332 L
.8981 .60332 L
.9 .60332 L
.9019 .60332 L
.90381 .60332 L
.90571 .60332 L
.90762 .60332 L
.90952 .60332 L
.91143 .60332 L
.91333 .60332 L
.91524 .60332 L
.91714 .60332 L
.91905 .60332 L
.92095 .60332 L
.92286 .60332 L
.92476 .60332 L
.92667 .60332 L
.92857 .60332 L
.93048 .60332 L
.93238 .60332 L
.93429 .60332 L
.93619 .60332 L
.9381 .60332 L
.94 .60332 L
.9419 .60332 L
.94381 .60332 L
.94571 .60332 L
.94762 .60332 L
.94952 .60332 L
.95143 .60332 L
.95333 .60332 L
.95524 .60332 L
.95714 .60332 L
.95905 .60332 L
.96095 .60332 L
.96286 .60332 L
.96476 .60332 L
.96667 .60332 L
.96857 .60332 L
.97048 .60332 L
.97238 .60332 L
.97429 .60332 L
Mistroke
.97619 .60332 L
Mfstroke
0 .5 0 r
.02381 .01472 m
.02571 .01472 L
.02762 .01472 L
.02952 .01472 L
.03143 .01472 L
.03333 .01472 L
.03524 .01472 L
.03714 .01472 L
.03905 .01472 L
.04095 .01472 L
.04286 .01472 L
.04476 .01472 L
.04667 .01472 L
.04857 .01472 L
.05048 .01472 L
.05238 .01472 L
.05429 .01472 L
.05619 .01472 L
.0581 .01472 L
.06 .01472 L
.0619 .01472 L
.06381 .01472 L
.06571 .01472 L
.06762 .01472 L
.06952 .01472 L
.07143 .01472 L
.07333 .01472 L
.07524 .01472 L
.07714 .01472 L
.07905 .01472 L
.08095 .01472 L
.08286 .01472 L
.08476 .01472 L
.08667 .01472 L
.08857 .01472 L
.09048 .01472 L
.09238 .01472 L
.09429 .01472 L
.09619 .01472 L
.0981 .01472 L
.1 .01472 L
.1019 .01472 L
.10381 .01472 L
.10571 .01472 L
.10762 .01472 L
.10952 .01472 L
.11143 .01472 L
.11333 .01472 L
.11524 .01472 L
.11714 .01472 L
Mistroke
.11905 .01472 L
.12095 .01472 L
.12286 .01472 L
.12476 .01472 L
.12667 .01472 L
.12857 .01472 L
.13048 .01472 L
.13238 .01472 L
.13429 .01472 L
.13619 .01472 L
.1381 .01472 L
.14 .01472 L
.1419 .01472 L
.14381 .01472 L
.14571 .01472 L
.14762 .01472 L
.14952 .01472 L
.15143 .01472 L
.15333 .01472 L
.15524 .01472 L
.15714 .01472 L
.15905 .01472 L
.16095 .01472 L
.16286 .01472 L
.16476 .01472 L
.16667 .01472 L
.16857 .01472 L
.17048 .01472 L
.17238 .01472 L
.17429 .01472 L
.17619 .01472 L
.1781 .01472 L
.18 .01472 L
.1819 .01472 L
.18381 .01472 L
.18571 .01472 L
.18762 .01472 L
.18952 .01472 L
.19143 .01472 L
.19333 .01472 L
.19524 .01472 L
.19714 .01472 L
.19905 .01472 L
.20095 .01472 L
.20286 .01472 L
.20476 .01472 L
.20667 .01472 L
.20857 .01472 L
.21048 .01472 L
.21238 .01472 L
Mistroke
.21429 .01472 L
.21619 .01472 L
.2181 .01472 L
.22 .01472 L
.2219 .01472 L
.22381 .01472 L
.22571 .01472 L
.22762 .01472 L
.22952 .01472 L
.23143 .01472 L
.23333 .01472 L
.23524 .01472 L
.23714 .01472 L
.23905 .01472 L
.24095 .01472 L
.24286 .01472 L
.24476 .01472 L
.24667 .01472 L
.24857 .01472 L
.25048 .01472 L
.25238 .01472 L
.25429 .01472 L
.25619 .01472 L
.2581 .01472 L
.26 .01472 L
.2619 .01472 L
.26381 .01472 L
.26571 .01472 L
.26762 .01472 L
.26952 .01472 L
.27143 .01472 L
.27333 .01472 L
.27524 .01472 L
.27714 .01472 L
.27905 .01472 L
.28095 .01472 L
.28286 .01472 L
.28476 .01472 L
.28667 .01472 L
.28857 .01472 L
.29048 .01472 L
.29238 .01472 L
.29429 .01472 L
.29619 .01472 L
.2981 .01472 L
.3 .01472 L
.3019 .01472 L
.30381 .01472 L
.30571 .01472 L
.30762 .01472 L
Mistroke
.30952 .01472 L
.31143 .01472 L
.31333 .01472 L
.31524 .01472 L
.31714 .01472 L
.31905 .01472 L
.32095 .01472 L
.32286 .01472 L
.32476 .01472 L
.32667 .01472 L
.32857 .01472 L
.33048 .01472 L
.33238 .01472 L
.33429 .01472 L
.33619 .01472 L
.3381 .01472 L
.34 .01472 L
.3419 .01472 L
.34381 .01472 L
.34571 .01472 L
.34762 .01472 L
.34952 .01472 L
.35143 .01472 L
.35333 .01472 L
.35524 .01472 L
.35714 .01472 L
.35905 .01472 L
.36095 .01472 L
.36286 .01472 L
.36476 .01472 L
.36667 .01472 L
.36857 .01472 L
.37048 .01472 L
.37238 .01472 L
.37429 .01472 L
.37619 .01472 L
.3781 .01472 L
.38 .01472 L
.3819 .01472 L
.38381 .01472 L
.38571 .01472 L
.38762 .01472 L
.38952 .01472 L
.39143 .01472 L
.39333 .01472 L
.39524 .01472 L
.39714 .01472 L
.39905 .01472 L
.40095 .01472 L
.40286 .01472 L
Mistroke
.40476 .01472 L
.40667 .01472 L
.40857 .01472 L
.41048 .01472 L
.41238 .01472 L
.41429 .01472 L
.41619 .01472 L
.4181 .01472 L
.42 .01472 L
.4219 .01472 L
.42381 .01472 L
.42571 .01472 L
.42762 .01472 L
.42952 .01472 L
.43143 .01472 L
.43333 .01472 L
.43524 .01472 L
.43714 .01472 L
.43905 .01472 L
.44095 .01472 L
.44286 .01472 L
.44476 .01472 L
.44667 .01472 L
.44857 .01472 L
.45048 .01472 L
.45238 .01472 L
.45429 .01472 L
.45619 .01472 L
.4581 .01472 L
.46 .01472 L
.4619 .01472 L
.46381 .01472 L
.46571 .01472 L
.46762 .01472 L
.46952 .01472 L
.47143 .01472 L
.47333 .01472 L
.47524 .01472 L
.47714 .01472 L
.47905 .01472 L
.48095 .01472 L
.48286 .01472 L
.48476 .01472 L
.48667 .01472 L
.48857 .01472 L
.49048 .01472 L
.49238 .01472 L
.49429 .01472 L
.49619 .01472 L
.4981 .01472 L
Mistroke
.5 .01472 L
.5019 .01472 L
.50381 .01472 L
.50571 .01472 L
.50762 .01472 L
.50952 .01472 L
.51143 .01472 L
.51333 .01472 L
.51524 .01472 L
.51714 .01472 L
.51905 .01472 L
.52095 .01472 L
.52286 .01472 L
.52476 .01472 L
.52667 .01472 L
.52857 .01472 L
.53048 .01472 L
.53238 .01472 L
.53429 .01472 L
.53619 .01472 L
.5381 .01472 L
.54 .01472 L
.5419 .01472 L
.54381 .01472 L
.54571 .01472 L
.54762 .01472 L
.54952 .01472 L
.55143 .01472 L
.55333 .01472 L
.55524 .01472 L
.55714 .01472 L
.55905 .01472 L
.56095 .01472 L
.56286 .01472 L
.56476 .01472 L
.56667 .01472 L
.56857 .01472 L
.57048 .01472 L
.57238 .01472 L
.57429 .01472 L
.57619 .01472 L
.5781 .01472 L
.58 .01472 L
.5819 .01472 L
.58381 .01472 L
.58571 .01472 L
.58762 .01472 L
.58952 .01472 L
.59143 .01472 L
.59333 .01472 L
Mistroke
.59524 .01472 L
.59714 .01472 L
.59905 .01472 L
.60095 .01472 L
.60286 .01472 L
.60476 .01472 L
.60667 .01472 L
.60857 .01472 L
.61048 .01472 L
.61238 .01472 L
.61429 .01472 L
.61619 .01472 L
.6181 .01472 L
.62 .01472 L
.6219 .01472 L
.62381 .01472 L
.62571 .01472 L
.62762 .01472 L
.62952 .01472 L
.63143 .01472 L
.63333 .01472 L
.63524 .01472 L
.63714 .01472 L
.63905 .01472 L
.64095 .01472 L
.64286 .01472 L
.64476 .01472 L
.64667 .01472 L
.64857 .01472 L
.65048 .01472 L
.65238 .01472 L
.65429 .01472 L
.65619 .01472 L
.6581 .01472 L
.66 .01472 L
.6619 .01472 L
.66381 .01472 L
.66571 .01472 L
.66762 .01472 L
.66952 .01472 L
.67143 .01472 L
.67333 .01472 L
.67524 .01472 L
.67714 .01472 L
.67905 .01472 L
.68095 .01472 L
.68286 .01472 L
.68476 .01472 L
.68667 .01472 L
.68857 .01472 L
Mistroke
.69048 .01472 L
.69238 .01472 L
.69429 .01472 L
.69619 .01472 L
.6981 .01472 L
.7 .01472 L
.7019 .01472 L
.70381 .01472 L
.70571 .01472 L
.70762 .01472 L
.70952 .01472 L
.71143 .01472 L
.71333 .01472 L
.71524 .01472 L
.71714 .01472 L
.71905 .01472 L
.72095 .01472 L
.72286 .01472 L
.72476 .01472 L
.72667 .01472 L
.72857 .01472 L
.73048 .01472 L
.73238 .01472 L
.73429 .01472 L
.73619 .01472 L
.7381 .01472 L
.74 .01472 L
.7419 .01472 L
.74381 .01472 L
.74571 .01472 L
.74762 .01472 L
.74952 .01472 L
.75143 .01472 L
.75333 .01472 L
.75524 .01472 L
.75714 .01472 L
.75905 .01472 L
.76095 .01472 L
.76286 .01472 L
.76476 .01472 L
.76667 .01472 L
.76857 .01472 L
.77048 .01472 L
.77238 .01472 L
.77429 .01472 L
.77619 .01472 L
.7781 .01472 L
.78 .01472 L
.7819 .01472 L
.78381 .01472 L
Mistroke
.78571 .01472 L
.78762 .01472 L
.78952 .01472 L
.79143 .01472 L
.79333 .01472 L
.79524 .01472 L
.79714 .01472 L
.79905 .01472 L
.80095 .01472 L
.80286 .01472 L
.80476 .01472 L
.80667 .01472 L
.80857 .01472 L
.81048 .01472 L
.81238 .01472 L
.81429 .01472 L
.81619 .01472 L
.8181 .01472 L
.82 .01472 L
.8219 .01472 L
.82381 .01472 L
.82571 .01472 L
.82762 .01472 L
.82952 .01472 L
.83143 .01472 L
.83333 .01472 L
.83524 .01472 L
.83714 .01472 L
.83905 .01472 L
.84095 .01472 L
.84286 .01472 L
.84476 .01472 L
.84667 .01472 L
.84857 .01472 L
.85048 .01472 L
.85238 .01472 L
.85429 .01472 L
.85619 .01472 L
.8581 .01472 L
.86 .01472 L
.8619 .01472 L
.86381 .01472 L
.86571 .01472 L
.86762 .01472 L
.86952 .01472 L
.87143 .01472 L
.87333 .01472 L
.87524 .01472 L
.87714 .01472 L
.87905 .01472 L
Mistroke
.88095 .01472 L
.88286 .01472 L
.88476 .01472 L
.88667 .01472 L
.88857 .01472 L
.89048 .01472 L
.89238 .01472 L
.89429 .01472 L
.89619 .01472 L
.8981 .01472 L
.9 .01472 L
.9019 .01472 L
.90381 .01472 L
.90571 .01472 L
.90762 .01472 L
.90952 .01472 L
.91143 .01472 L
.91333 .01472 L
.91524 .01472 L
.91714 .01472 L
.91905 .01472 L
.92095 .01472 L
.92286 .01472 L
.92476 .01472 L
.92667 .01472 L
.92857 .01472 L
.93048 .01472 L
.93238 .01472 L
.93429 .01472 L
.93619 .01472 L
.9381 .01472 L
.94 .01472 L
.9419 .01472 L
.94381 .01472 L
.94571 .01472 L
.94762 .01472 L
.94952 .01472 L
.95143 .01472 L
.95333 .01472 L
.95524 .01472 L
.95714 .01472 L
.95905 .01472 L
.96095 .01472 L
.96286 .01472 L
.96476 .01472 L
.96667 .01472 L
.96857 .01472 L
.97048 .01472 L
.97238 .01472 L
.97429 .01472 L
Mistroke
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0714286 0.583445 0.547619 0.726302 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00611247 0.0611247 0.0119048 0.119048 [
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0110024 0.0214286 0.0721271 0.140476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .5 0 r
.00374 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .08095 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 12.813 moveto
(@) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0110024 0.159524 0.0721271 0.278571 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.00374 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.08007 .21905 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 12.813 moveto
(@) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 12.813 moveto
(D) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .74402 L
0 .74402 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 214.25},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eR000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00@`3IfMT4
000002d0fMWI0`00000Z0=WIf@<00000;@3IfMT2000002T0fMWI1@0000020=WIf@8000006`3IfMT0
04<0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0Y0=WIf@040000003IfMT0fMWI
000002/0fMWI00@000000=WIf@3IfMT00000:P3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI
00<000000=WIf@3IfMT0603IfMT004@0fMWI00<000000=WIf@3IfMT0:`3IfMT5000002X0fMWI00@0
00000=WIf@3IfMT00000:`3IfMT010000000fMWI0=WIf@00000Z0=WIf@050000003IfMT0fMWI0=WI
f@0000000P3IfMT00`000000fMWI0=WIf@0H0=WIf@00A@3IfMT00`000000fMWI0=WIf@0Z0=WIf@04
0000003IfMT0fMWI000002/0fMWI0`00000]0=WIf@800000:`3IfMT01@000000fMWI0=WIf@3IfMT0
00000080fMWI00<000000=WIf@3IfMT0603IfMT004<0fMWI00@000000=WIf@3IfMT00000;03IfMT0
0`000000fMWI0000000/0=WIf@030000003IfMT0fMWI02/0fMWI00@000000=WIf@3IfMT00000:P3I
fMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT0603IfMT004@0fMWI0P00
000^0=WIf@800000;03IfMT3000002`0fMWI0P00000Z0=WIf@800000103IfMT2000001/0fMWI003o
0=WIfB40fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3I
fMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WIf@3h0=WIf@8000003@3IfMT001H0fMWI00<0
00000=WIf@3IfMT0m`3IfMT010000000fMWI0=WIf@00000<0=WIf@00403IfMT600000>`007l01P00
00080=WIf@030000003IfMT0fMWI00d0fMWI000F0=WIf@030000003IfMT0fMWI00P0fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@D00000303IfMT001H0fMWI00<000000=WI
f@3IfMT0m`3IfMT00`000000fMWI0=WIf@0=0=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0
fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI0P00003o0=WIf@T0fMWI000F
0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WI
f@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@800000o`3IfMT90=WIf@005P3I
fMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT0
01H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0
fMWI000F0=WIf@800000o`3IfMT90=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F
0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WI
f@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@800000o`3IfMT90=WIf@005P3I
fMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT0
00l0fMWI0P0000050=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT000h0fMWI00@000000=WIf@3I
fMT00000103IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000A0=WIf@030000003IfMT0fMWI0080
fMWI0P00003o0=WIf@T0fMWI000?0=WIf@8000001@3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI
000?0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@003`3IfMT3
000000@0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WI
f@P0fMWI000F0=WIf@800000o`3IfMT90=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI
000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT8
0=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@800000o`3IfMT90=WIf@00
5P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203I
fMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WI
f@P0fMWI000F0=WIf@800000o`3IfMT90=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI
000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT8
0=WIf@005P3IfMT200000?l0fMWI2@3IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@00
5P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000>0=WIf@<000001@3IfMT00`000000fMWI0=WI
f@3o0=WIf@P0fMWI000>0=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@3IfMT0o`3I
fMT80=WIf@003P3IfMT010000000fMWI0=WIf@0000040=WIf@800000o`3IfMT90=WIf@003P3IfMT3
000000D0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@003`3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI0?l0fMWI203IfMT000l0fMWI0`0000040=WIf@030000003IfMT0fMWI0?l0
fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT200000?l0fMWI2@3I
fMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WI
f@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0
o`3IfMT80=WIf@005P3IfMT200000?l0fMWI2@3IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT8
0=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0
fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT200000?l0fMWI2@3I
fMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WI
f@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0
o`3IfMT80=WIf@005P3IfMT200000?l0fMWI2@3IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT8
0=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000@0=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@00403IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0?l0fMWI203IfMT00100fMWI00<000000=WIf@3IfMT00`3IfMT200000?l0fMWI2@3I
fMT00140fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000>0=WI
f@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@003P3IfMT40000
00@0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT200000?l0fMWI2@3IfMT001H0fMWI
00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F
0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WI
f@005P3IfMT200000?l0fMWI2@3IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3I
fMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT0
01H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT200000?l0fMWI2@3IfMT001H0fMWI
00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F
0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WI
f@005P3IfMT200000?l0fMWI2@3IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3I
fMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000?0=WIf@8000001@3IfMT00`000000fMWI0=WIf@3o
0=WIf@P0fMWI000>0=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@3IfMT0o`3IfMT8
0=WIf@003P3IfMT010000000fMWI0=WIf@0000040=WIf@800000o`3IfMT90=WIf@003`3IfMT20000
00D0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@003P3IfMT010000000fMWI0=WIf@0000040=WI
f@030000003IfMT0fMWI0?l0fMWI203IfMT000l0fMWI0P0000050=WIf@030000003IfMT0fMWI0?l0
fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT200000?l0fMWI2@3I
fMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WI
f@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0
o`3IfMT80=WIf@005P3IfMT200000?l0fMWI2@3IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT8
0=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0
fMWI203IfMT001H0fMWI0P00003o0=WIf@T0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203I
fMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WI
f@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI0P00003o0=WIf@T0fMWI
000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT8
0=WIf@003P3IfMT3000000D0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@00403IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT000l0fMWI0`0000040=WIf@800000
o`3IfMT90=WIf@003P3IfMT010000000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI0?l0fMWI
203IfMT000h0fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI
000?0=WIf@<00000103IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@030000003IfMT0
fMWI0?l0fMWI203IfMT001H0fMWI0P00003o0=WIf@T0fMWI000F0=WIf@030000003IfMT0fMWI0?l0
fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WI
f@3o0=WIf@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI0P00003o0=WI
f@T0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0
o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@030000003IfMT0
fMWI0?l0fMWI203IfMT001H0fMWI0P00003o0=WIf@T0fMWI000F0=WIf@030000003IfMT0fMWI0?l0
fMWI203IfMT001H0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@005P3IfMT00`000000fMWI0=WI
f@3o0=WIf@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT001H0fMWI0P00003o0=WI
f@T0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT000P0fMWI1@0000020=WIf@800000
1@3IfMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000:0=WIf@050000003IfMT0fMWI0=WIf@000000
0P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT000X0fMWI00D0
00000=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI0080fMWIk0000?lN0=WIf@002P3I
fMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@3o0=WIf@P0fMWI000:0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT000T0fMWI0P0000040=WIf@8000001@3I
fMT00`000000fMWI0=WIf@3o0=WIf@P0fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT0
0?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00280fMWI0P000006
0=WIf@800000203IfMT200000>X0fMWI000S0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@3X0=WIf@00903IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI0P0000040=WIf@030000003IfMT0fMWI0>P0fMWI000S0=WIf@030000
003IfMT0000000@0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@050000003IfMT0fMWI0=WI
f@000000jP3IfMT001H0fMWI2@00O`030=WIf@040000003IfMT0fMWI000000@0fMWI00D000000=WI
f@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0>P0fMWI000Q0=WIf@<0000000<0fMWI0000
000000000`3IfMT00`000000fMWI0=WIf@05000000<0fMWI00<000000=WIf@3IfMT0j03IfMT002X0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0>P0fMWI000Z0=WIf@80
0000203IfMT200000>X0fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WI
fB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WI
fB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI000Z0=WIf@800000203IfMT200000>X0fMWI000Z
0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0j03IfMT00240fMWI0P0000000`3I
fMT00000000000040=WIf@030000003IfMT0fMWI0080fMWI0P0000040=WIf@030000003IfMT0fMWI
0>P0fMWI000F0=WIf@T0003o0`3IfMT00`000000fMWI000000050=WIf@050000003IfMT0fMWI0=WI
f@0000000P3IfMT01@000000fMWI0=WIf@3IfMT000000>X0fMWI000S0=WIf@030000003IfMT0fMWI
00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0>P0fMWI000Q0=WI
f@80000000<0fMWI000000000000103IfMT00`000000fMWI0=WIf@05000000<0fMWI00<000000=WI
f@3IfMT0j03IfMT002X0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI
0>P0fMWI000Z0=WIf@800000203IfMT200000>X0fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o
0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o
0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI0000
\
\>"],
  ImageRangeCache->{{{138, 425}, {395, 181.75}} -> {-2.06252, 0.676418, \
0.00732689, 0.00732689}, {{145, 417.938}, {389.875, 221.188}} -> {-6.79066, \
10.6437, 0.0424163, 0.0411787}, {{158.625, 295.125}, {227.75, 186.813}} -> \
{-19.1203, 0.792574, 0.119891, 0.0615577}, {{160.125, 168.438}, {224.813, \
208.563}} -> {-39.5267, 0.827076, 0.240604, 0.240604}, {{160.125, 168.438}, \
{205.938, 189.688}} -> {-39.5267, -3.71432, 0.240604, 0.240604}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Characteristics of Continous time systems and Discrete event systems. Example \
of Hybrid System.\
\>", "Section"],

Cell["\<\
Continous tyme system
  - can change their variables values infinitely often during a finite time \
period
Discrete event systems
  - they can change the variables only a finite number of times in a time \
step.
  
Hybrid system
  An hybrid system is every computer system that by using sensors to gain \
information on a continous phenomenon,  controls this phenomenon using \
actuators.
  Inside the computer system everything is discrete, it happens only at time \
intervals.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["General Impressions", "Section"],

Cell[TextData[{
  "Course:\n     I liked the course. \nExam: \n     The exam was good but it \
can be improved in the future. \n     Working with modeling tools was a \
pleasure.\n\nRecommandation:\n      In general it took me 10% for modeling \
the systems and 90% of the time trying to figure out how can I plot variables \
in ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "and debugging the Problem 3.\n      Use Dymola directly till you have a \
stable model then move it to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". It is much more easy to simulate and plot values.\n      I encountered \
problems in ploting the Body.body.frame_a.r0[1, 2, 3] in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " but it worked fine in Dymola.\n\nHowever,  the exam comes with a bitter \
taste:\n  - 43 crashes of ModelEditor in less than 6 hours.\n  - 2 computer \
resets (blue screen) \n \n Tools:\n    ",
  StyleBox["Mathematica:",
    FontSlant->"Italic"],
  " \n       - nice environment.\n    MathModelica: \n       - Works fine, \
but sometimes (often) you have to kill everything to make it work as it \
should again.\n       - Sometimes you really don't know what's wrong when \
you're trying to plot something (that works in Dymola) and it doesn't work in \
MathModelica\n       - Error messages are more than vague.\n    ModelEditor: \
\n       - Extremly buggy and instable. If it doesn't crash, it consumes all \
the CPU after some work with it.\n       - The save option doesn't work and \
that is annoying. For people that use Ctrl+S combination to save documents \
before they try something that might\n          crash. The options in the \
MathModelicaPalette are not that useful.\n    Dymola\n        - Is really not \
an intuitive graphical environment. You begin to make a model, you double \
click by mistake on a component, it shows you the component, but when you \
close the\n          component your model is gone. It is somewhere because \
when you close the environment it asks you to save it. But how you make it \
come back from where it went\n          is still a mistery for me. All the \
opened frames should appear in the Window menu but they don't.\n        - The \
reported error messages at the translation/compilation are vague and doesn't \
point you to the problem.\n        - It doesn't crash, but i got internal \
errors. (Problem 3)\n\nProblem 1\n     - \"Use ... and other values\", what \
other values? ",
  ButtonBox["Here",
    ButtonData:>{
      URL[ 
      "http://www.csu.edu.au/ci/vol03/yux_cmx2/node3.html#\
SECTION00020000000000000000"], None},
    ButtonStyle->"Hyperlink"],
  " it explains that for certain values of  R the system exibits chaos.\n\n\
Problem 2\n     - What is the definition of an \"interesting response\"? \n   \
  - It would be prefferable that Spring and IdealGear have the same \
superclass(or interface). Both have flange_a and flange_b, but one is\n       \
extended from Compliant and the other from TwoFlanges. Maybe it could be made \
so that they inherit from the same interface.\n       Or maybe the \
restriction of the \"replaceable\" should be relaxed.\n     \nProblem 3\n     \
This problem is a hack and is buggy. It is a hack because it doesn't \
encourage the object-oriented modelling. It has bugs because 4 ecuations are \
wrong(could be typo error)\n     and 3 ecuations are redundant. \n     The \
wrong ecuations don't even stand the dimensional check: y2' (speed=m/s) = y2' \
(speed=m/s) + constant * y1 (distance=m) (it should be y1' in the end).\n     \
The redundant ecuations (y1'=x1' - y1') causes this error message: \n       \
",
  StyleBox["DAE with 15 unknown scalars and 18 scalar equations.\n       \
Error: Model is singular:\n          The number of non-trivial (scalar) \
equations is 14.\n          The number of (scalar) variables is 11.\n      \
Additional equations: \n          equation\n            0 = der(y1der);\n     \
       which was derived from\n            y1derder = der(y1der);\n           \
 0 = der(y2der);\n           which was derived from\n           y2derder = \
der(y2der);\n           0 = der(y3der);\n          which was derived from\n   \
       y3derder = der(y3der);\n        Translation aborted.\n        \
Translation aborted.\n        Translation started\n      Error: Internal \
error, please report to Dynasim.\n      Occured when sorting parameter \
bindings.\n      Errors or failure to expand vector or matrix expressions.\n  \
    Translation aborted.", "Commentary"],
  "\n      The error message doesn't point you in any good direction. \n    \n\
\n    \n    "
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->Automatic,
WindowSize->{892, 646},
WindowMargins->{{9, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1,
StyleDefinitions -> "MathModelica.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 38, 0, 68, "Title"],
Cell[1768, 54, 87, 2, 35, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[1880, 60, 50, 0, 68, "Section"],
Cell[1933, 62, 122, 2, 46, "Text"],
Cell[2058, 66, 652, 13, 222, "ModelicaInput"],
Cell[2713, 81, 479, 11, 137, "ModelicaInput"],
Cell[3195, 94, 41, 4, 63, "Text"],

Cell[CellGroupData[{
Cell[3261, 102, 71, 1, 35, "Input"],
Cell[3335, 105, 2590, 40, 144, "Output"]
}, Open  ]],
Cell[5940, 148, 1054, 24, 165, "Text"],

Cell[CellGroupData[{
Cell[7019, 176, 401, 8, 55, "Input"],

Cell[CellGroupData[{
Cell[7445, 188, 25306, 942, 194, 11578, 768, "GraphicsData", "PostScript", \
"Graphics"],
Cell[32754, 1132, 33533, 846, 194, 7763, 523, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[66336, 1984, 583, 11, 155, "Input"],

Cell[CellGroupData[{
Cell[66944, 1999, 47818, 1312, 296, 10418, 846, "GraphicsData", "PostScript", \
"Graphics"],
Cell[114765, 3313, 65670, 1577, 373, 11140, 899, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[180496, 4897, 33, 0, 68, "Section"],
Cell[180532, 4899, 139, 3, 29, "Text"],
Cell[180674, 4904, 1316, 29, 494, "ModelicaInput"],
Cell[181993, 4935, 310, 8, 137, "ModelicaInput"],
Cell[182306, 4945, 16, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[182347, 4949, 89, 1, 35, "Input"],
Cell[182439, 4952, 12967, 180, 467, "Output"]
}, Open  ]],
Cell[195421, 5135, 221, 5, 86, "ModelicaInput"],

Cell[CellGroupData[{
Cell[195667, 5144, 90, 1, 35, "Input"],
Cell[195760, 5147, 12968, 180, 467, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[208765, 5332, 464, 7, 95, "Input"],

Cell[CellGroupData[{
Cell[209254, 5343, 47778, 1291, 231, 17125, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[257035, 6636, 40068, 1225, 231, 17691, 944, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[297118, 7864, 130, 3, 49, "Output"]
}, Open  ]],
Cell[297263, 7870, 350, 9, 131, "Text"],
Cell[297616, 7881, 318, 9, 154, "ModelicaInput"],
Cell[297937, 7892, 146, 3, 29, "Text"],
Cell[298086, 7897, 200, 5, 69, "ModelicaInput"],

Cell[CellGroupData[{
Cell[298311, 7906, 87, 1, 35, "Input"],
Cell[298401, 7909, 12965, 180, 467, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[311403, 8094, 659, 11, 135, "Input"],

Cell[CellGroupData[{
Cell[312087, 8109, 47931, 1195, 231, 14639, 779, "GraphicsData", \
"PostScript", "Graphics"],
Cell[360021, 9306, 51425, 1272, 231, 15264, 821, "GraphicsData", \
"PostScript", "Graphics"],
Cell[411449, 10580, 41307, 1147, 231, 15260, 821, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[452783, 11731, 246, 6, 80, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[453066, 11742, 36, 0, 68, "Section"],
Cell[453105, 11744, 1746, 60, 1021, "ModelicaInput"],

Cell[CellGroupData[{
Cell[454876, 11808, 77, 1, 35, "Input"],
Cell[454956, 11811, 1863, 27, 87, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[456856, 11843, 220, 4, 55, "Input"],

Cell[CellGroupData[{
Cell[457101, 11851, 61302, 3002, 231, 44256, 2787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[518406, 14855, 62122, 2524, 231, 34701, 2181, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[580589, 17386, 30, 0, 68, "Section"],
Cell[580622, 17388, 924, 30, 511, "ModelicaInput"],
Cell[581549, 17420, 168, 5, 69, "ModelicaInput"],

Cell[CellGroupData[{
Cell[581742, 17429, 80, 1, 35, "Input"],
Cell[581825, 17432, 2524, 34, 106, "Output"]
}, Open  ]],
Cell[584364, 17469, 50, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[584439, 17476, 88, 1, 35, "Input"],
Cell[584530, 17479, 112, 2, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[584691, 17487, 45, 0, 68, "Section"],
Cell[584739, 17489, 820, 15, 165, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[585596, 17509, 44, 0, 68, "Section"],
Cell[585643, 17511, 260, 15, 256, "ModelicaInput"],
Cell[585906, 17528, 218, 8, 97, "Text"],
Cell[586127, 17538, 102, 4, 69, "ModelicaInput"],

Cell[CellGroupData[{
Cell[586254, 17546, 69, 1, 35, "Input"],
Cell[586326, 17549, 359, 5, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[586722, 17559, 61, 1, 35, "Input"],
Cell[586786, 17562, 38, 1, 40, "Print"]
}, Open  ]],
Cell[586839, 17566, 199, 4, 46, "Text"],
Cell[587041, 17572, 193, 5, 69, "ModelicaInput"],
Cell[587237, 17579, 82, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[587344, 17584, 193, 4, 35, "Input"],
Cell[587540, 17590, 303, 6, 40, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[587892, 17602, 41, 0, 68, "Section"],
Cell[587936, 17604, 1035, 23, 250, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[589008, 17632, 54, 0, 68, "Section"],
Cell[589065, 17634, 20, 0, 29, "Text"],
Cell[589088, 17636, 312, 8, 120, "ModelicaInput"],
Cell[589403, 17646, 116, 7, 120, "ModelicaInput"],
Cell[589522, 17655, 75, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[589622, 17660, 54, 1, 35, "Input"],
Cell[589679, 17663, 37, 1, 40, "Print"]
}, Open  ]],
Cell[589731, 17667, 20, 0, 29, "Text"],
Cell[589754, 17669, 469, 17, 256, "ModelicaInput"],
Cell[590226, 17688, 75, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[590326, 17693, 54, 1, 35, "Input"],
Cell[590383, 17696, 52, 1, 40, "Print"]
}, Open  ]],
Cell[590450, 17700, 265, 6, 63, "Text"],
Cell[590718, 17708, 314, 17, 290, "ModelicaInput"],
Cell[591035, 17727, 67, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[591127, 17732, 86, 1, 35, "Input"],
Cell[591216, 17735, 35200, 1599, 231, 23178, 1446, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[626431, 19337, 268, 6, 63, "Text"],
Cell[626702, 19345, 196, 15, 256, "ModelicaInput"],
Cell[626901, 19362, 67, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[626993, 19367, 86, 1, 35, "Input"],
Cell[627082, 19370, 34920, 1622, 231, 23552, 1477, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[662051, 20998, 124, 3, 68, "Section"],
Cell[662178, 21003, 502, 14, 148, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[662717, 21022, 38, 0, 68, "Section"],
Cell[662758, 21024, 4648, 75, 1228, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

